Class: Late::AdTreeAdSet

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/ad_tree_ad_set.rb

Overview

Ad set (or ad group/line item depending on platform) with rolled-up metrics and child ads

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdTreeAdSet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::AdTreeAdSet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::AdTreeAdSet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'platform_ad_set_id')
    self.platform_ad_set_id = attributes[:'platform_ad_set_id']
  end

  if attributes.key?(:'ad_set_name')
    self.ad_set_name = attributes[:'ad_set_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'ad_count')
    self.ad_count = attributes[:'ad_count']
  end

  if attributes.key?(:'budget')
    self.budget = attributes[:'budget']
  end

  if attributes.key?(:'metrics')
    self.metrics = attributes[:'metrics']
  end

  if attributes.key?(:'ads')
    if (value = attributes[:'ads']).is_a?(Array)
      self.ads = value
    end
  end
end

Instance Attribute Details

#ad_countObject

Returns the value of attribute ad_count.



26
27
28
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 26

def ad_count
  @ad_count
end

#ad_set_nameObject

Returns the value of attribute ad_set_name.



21
22
23
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 21

def ad_set_name
  @ad_set_name
end

#adsObject

Individual ads within this ad set (capped at 100). Returns a subset of Ad fields from the aggregation (core fields like _id, name, platform, status, budget, metrics, creative, goal are included; targeting and schedule may be absent).



33
34
35
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 33

def ads
  @ads
end

#budgetObject

Returns the value of attribute budget.



28
29
30
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 28

def budget
  @budget
end

#metricsObject

Returns the value of attribute metrics.



30
31
32
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 30

def metrics
  @metrics
end

#platform_ad_set_idObject

Returns the value of attribute platform_ad_set_id.



19
20
21
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 19

def platform_ad_set_id
  @platform_ad_set_id
end

#statusObject

Derived from child ad statuses



24
25
26
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 24

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 58

def self.attribute_map
  {
    :'platform_ad_set_id' => :'platformAdSetId',
    :'ad_set_name' => :'adSetName',
    :'status' => :'status',
    :'ad_count' => :'adCount',
    :'budget' => :'budget',
    :'metrics' => :'metrics',
    :'ads' => :'ads'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 202

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 81

def self.openapi_types
  {
    :'platform_ad_set_id' => :'String',
    :'ad_set_name' => :'String',
    :'status' => :'String',
    :'ad_count' => :'Integer',
    :'budget' => :'AdBudget',
    :'metrics' => :'AdMetrics',
    :'ads' => :'Array<Ad>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



175
176
177
178
179
180
181
182
183
184
185
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 175

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      platform_ad_set_id == o.platform_ad_set_id &&
      ad_set_name == o.ad_set_name &&
      status == o.status &&
      ad_count == o.ad_count &&
      budget == o.budget &&
      metrics == o.metrics &&
      ads == o.ads
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


189
190
191
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 189

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



195
196
197
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 195

def hash
  [platform_ad_set_id, ad_set_name, status, ad_count, budget, metrics, ads].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 224

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
# File 'lib/late-sdk/models/ad_tree_ad_set.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["active", "paused", "pending_review", "rejected", "completed", "cancelled", "error"])
  return false unless status_validator.valid?(@status)
  true
end