Class: Late::AnalyticsListResponsePostsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::AnalyticsListResponsePostsInner
- Defined in:
- lib/late-sdk/models/analytics_list_response_posts_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#analytics ⇒ Object
Returns the value of attribute analytics.
-
#content ⇒ Object
Returns the value of attribute content.
-
#is_external ⇒ Object
Returns the value of attribute is_external.
-
#media_items ⇒ Object
Returns the value of attribute media_items.
-
#media_type ⇒ Object
Returns the value of attribute media_type.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
-
#platforms ⇒ Object
Returns the value of attribute platforms.
-
#published_at ⇒ Object
Returns the value of attribute published_at.
-
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
-
#status ⇒ Object
Returns the value of attribute status.
-
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnalyticsListResponsePostsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AnalyticsListResponsePostsInner
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::AnalyticsListResponsePostsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::AnalyticsListResponsePostsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'scheduled_for') self.scheduled_for = attributes[:'scheduled_for'] end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'analytics') self.analytics = attributes[:'analytics'] end if attributes.key?(:'platforms') if (value = attributes[:'platforms']).is_a?(Array) self.platforms = value end end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'platform_post_url') self.platform_post_url = attributes[:'platform_post_url'] end if attributes.key?(:'is_external') self.is_external = attributes[:'is_external'] end if attributes.key?(:'thumbnail_url') self.thumbnail_url = attributes[:'thumbnail_url'] end if attributes.key?(:'media_type') self.media_type = attributes[:'media_type'] end if attributes.key?(:'media_items') if (value = attributes[:'media_items']).is_a?(Array) self.media_items = value end end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 18 def _id @_id end |
#analytics ⇒ Object
Returns the value of attribute analytics.
28 29 30 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 28 def analytics @analytics end |
#content ⇒ Object
Returns the value of attribute content.
20 21 22 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 20 def content @content end |
#is_external ⇒ Object
Returns the value of attribute is_external.
36 37 38 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 36 def is_external @is_external end |
#media_items ⇒ Object
Returns the value of attribute media_items.
42 43 44 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 42 def media_items @media_items end |
#media_type ⇒ Object
Returns the value of attribute media_type.
40 41 42 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 40 def media_type @media_type end |
#platform ⇒ Object
Returns the value of attribute platform.
32 33 34 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 32 def platform @platform end |
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
34 35 36 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 34 def platform_post_url @platform_post_url end |
#platforms ⇒ Object
Returns the value of attribute platforms.
30 31 32 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 30 def platforms @platforms end |
#published_at ⇒ Object
Returns the value of attribute published_at.
24 25 26 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 24 def published_at @published_at end |
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
22 23 24 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 22 def scheduled_for @scheduled_for end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 26 def status @status end |
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
38 39 40 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 38 def thumbnail_url @thumbnail_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 67 def self.attribute_map { :'_id' => :'_id', :'content' => :'content', :'scheduled_for' => :'scheduledFor', :'published_at' => :'publishedAt', :'status' => :'status', :'analytics' => :'analytics', :'platforms' => :'platforms', :'platform' => :'platform', :'platform_post_url' => :'platformPostUrl', :'is_external' => :'isExternal', :'thumbnail_url' => :'thumbnailUrl', :'media_type' => :'mediaType', :'media_items' => :'mediaItems' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 255 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 115 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 96 def self.openapi_types { :'_id' => :'String', :'content' => :'String', :'scheduled_for' => :'Time', :'published_at' => :'Time', :'status' => :'String', :'analytics' => :'PostAnalytics', :'platforms' => :'Array<PlatformAnalytics>', :'platform' => :'String', :'platform_post_url' => :'String', :'is_external' => :'Boolean', :'thumbnail_url' => :'String', :'media_type' => :'String', :'media_items' => :'Array<MediaItem>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 222 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && content == o.content && scheduled_for == o.scheduled_for && published_at == o.published_at && status == o.status && analytics == o.analytics && platforms == o.platforms && platform == o.platform && platform_post_url == o.platform_post_url && is_external == o.is_external && thumbnail_url == o.thumbnail_url && media_type == o.media_type && media_items == o.media_items end |
#eql?(o) ⇒ Boolean
242 243 244 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 242 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
248 249 250 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 248 def hash [_id, content, scheduled_for, published_at, status, analytics, platforms, platform, platform_post_url, is_external, thumbnail_url, media_type, media_items].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 277 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 |
# File 'lib/late-sdk/models/analytics_list_response_posts_inner.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' media_type_validator = EnumAttributeValidator.new('String', ["image", "video", "gif", "document"]) return false unless media_type_validator.valid?(@media_type) true end |