Class: Late::AnalyticsSinglePostResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::AnalyticsSinglePostResponse
- Defined in:
- lib/late-sdk/models/analytics_single_post_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#analytics ⇒ Object
Returns the value of attribute analytics.
-
#content ⇒ Object
Returns the value of attribute content.
-
#is_external ⇒ Object
Returns the value of attribute is_external.
-
#late_post_id ⇒ Object
Original Zernio post ID if scheduled via Zernio.
-
#media_items ⇒ Object
All media items for this post.
-
#media_type ⇒ Object
Returns the value of attribute media_type.
-
#message ⇒ Object
Human-readable status message for pending, partial, or failed states.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_analytics ⇒ Object
Returns the value of attribute platform_analytics.
-
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
-
#post_id ⇒ Object
Returns the value of attribute post_id.
-
#published_at ⇒ Object
Returns the value of attribute published_at.
-
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
-
#status ⇒ Object
Overall post status.
-
#sync_status ⇒ Object
Overall sync state across all platforms.
-
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnalyticsSinglePostResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AnalyticsSinglePostResponse
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 139 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::AnalyticsSinglePostResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::AnalyticsSinglePostResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'post_id') self.post_id = attributes[:'post_id'] end if attributes.key?(:'late_post_id') self.late_post_id = attributes[:'late_post_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'scheduled_for') self.scheduled_for = attributes[:'scheduled_for'] end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] end if attributes.key?(:'analytics') self.analytics = attributes[:'analytics'] end if attributes.key?(:'platform_analytics') if (value = attributes[:'platform_analytics']).is_a?(Array) self.platform_analytics = value end end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'platform_post_url') self.platform_post_url = attributes[:'platform_post_url'] end if attributes.key?(:'is_external') self.is_external = attributes[:'is_external'] end if attributes.key?(:'sync_status') self.sync_status = attributes[:'sync_status'] end if attributes.key?(:'message') self. = attributes[:'message'] end if attributes.key?(:'thumbnail_url') self.thumbnail_url = attributes[:'thumbnail_url'] end if attributes.key?(:'media_type') self.media_type = attributes[:'media_type'] end if attributes.key?(:'media_items') if (value = attributes[:'media_items']).is_a?(Array) self.media_items = value end end end |
Instance Attribute Details
#analytics ⇒ Object
Returns the value of attribute analytics.
32 33 34 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 32 def analytics @analytics end |
#content ⇒ Object
Returns the value of attribute content.
26 27 28 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 26 def content @content end |
#is_external ⇒ Object
Returns the value of attribute is_external.
40 41 42 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 40 def is_external @is_external end |
#late_post_id ⇒ Object
Original Zernio post ID if scheduled via Zernio
21 22 23 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 21 def late_post_id @late_post_id end |
#media_items ⇒ Object
All media items for this post. Carousel posts contain one entry per slide.
53 54 55 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 53 def media_items @media_items end |
#media_type ⇒ Object
Returns the value of attribute media_type.
50 51 52 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 50 def media_type @media_type end |
#message ⇒ Object
Human-readable status message for pending, partial, or failed states
46 47 48 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 46 def @message end |
#platform ⇒ Object
Returns the value of attribute platform.
36 37 38 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 36 def platform @platform end |
#platform_analytics ⇒ Object
Returns the value of attribute platform_analytics.
34 35 36 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 34 def platform_analytics @platform_analytics end |
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
38 39 40 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 38 def platform_post_url @platform_post_url end |
#post_id ⇒ Object
Returns the value of attribute post_id.
18 19 20 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 18 def post_id @post_id end |
#published_at ⇒ Object
Returns the value of attribute published_at.
30 31 32 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 30 def published_at @published_at end |
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
28 29 30 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 28 def scheduled_for @scheduled_for end |
#status ⇒ Object
Overall post status. "partial" when some platforms published and others failed.
24 25 26 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 24 def status @status end |
#sync_status ⇒ Object
Overall sync state across all platforms
43 44 45 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 43 def sync_status @sync_status end |
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
48 49 50 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 48 def thumbnail_url @thumbnail_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
100 101 102 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 100 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
105 106 107 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 105 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 78 def self.attribute_map { :'post_id' => :'postId', :'late_post_id' => :'latePostId', :'status' => :'status', :'content' => :'content', :'scheduled_for' => :'scheduledFor', :'published_at' => :'publishedAt', :'analytics' => :'analytics', :'platform_analytics' => :'platformAnalytics', :'platform' => :'platform', :'platform_post_url' => :'platformPostUrl', :'is_external' => :'isExternal', :'sync_status' => :'syncStatus', :'message' => :'message', :'thumbnail_url' => :'thumbnailUrl', :'media_type' => :'mediaType', :'media_items' => :'mediaItems' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 311 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
132 133 134 135 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 132 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 110 def self.openapi_types { :'post_id' => :'String', :'late_post_id' => :'String', :'status' => :'String', :'content' => :'String', :'scheduled_for' => :'Time', :'published_at' => :'Time', :'analytics' => :'PostAnalytics', :'platform_analytics' => :'Array<PlatformAnalytics>', :'platform' => :'String', :'platform_post_url' => :'String', :'is_external' => :'Boolean', :'sync_status' => :'String', :'message' => :'String', :'thumbnail_url' => :'String', :'media_type' => :'String', :'media_items' => :'Array<AnalyticsSinglePostResponseMediaItemsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 275 def ==(o) return true if self.equal?(o) self.class == o.class && post_id == o.post_id && late_post_id == o.late_post_id && status == o.status && content == o.content && scheduled_for == o.scheduled_for && published_at == o.published_at && analytics == o.analytics && platform_analytics == o.platform_analytics && platform == o.platform && platform_post_url == o.platform_post_url && is_external == o.is_external && sync_status == o.sync_status && == o. && thumbnail_url == o.thumbnail_url && media_type == o.media_type && media_items == o.media_items end |
#eql?(o) ⇒ Boolean
298 299 300 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 298 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 304 def hash [post_id, late_post_id, status, content, scheduled_for, published_at, analytics, platform_analytics, platform, platform_post_url, is_external, sync_status, , thumbnail_url, media_type, media_items].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
224 225 226 227 228 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 224 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
232 233 234 235 236 237 238 239 240 241 |
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 232 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["published", "failed", "partial"]) return false unless status_validator.valid?(@status) sync_status_validator = EnumAttributeValidator.new('String', ["synced", "pending", "partial", "unavailable"]) return false unless sync_status_validator.valid?(@sync_status) media_type_validator = EnumAttributeValidator.new('String', ["image", "video", "carousel", "text"]) return false unless media_type_validator.valid?(@media_type) true end |