Class: Late::BoostPostRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::BoostPostRequest
- Defined in:
- lib/late-sdk/models/boost_post_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Social account ID.
-
#ad_account_id ⇒ Object
Platform ad account ID.
-
#bid_amount ⇒ Object
Max bid cap (Meta only).
-
#budget ⇒ Object
Returns the value of attribute budget.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#goal ⇒ Object
Returns the value of attribute goal.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform_post_id ⇒ Object
Platform post ID (alternative to postId).
-
#post_id ⇒ Object
Zernio post ID (provide this or platformPostId).
-
#schedule ⇒ Object
Returns the value of attribute schedule.
-
#special_ad_categories ⇒ Object
Meta only.
-
#targeting ⇒ Object
Returns the value of attribute targeting.
-
#tracking ⇒ Object
Returns the value of attribute tracking.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BoostPostRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BoostPostRequest
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::BoostPostRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::BoostPostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'post_id') self.post_id = attributes[:'post_id'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] else self.ad_account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'goal') self.goal = attributes[:'goal'] else self.goal = nil end if attributes.key?(:'budget') self.budget = attributes[:'budget'] else self.budget = nil end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.key?(:'targeting') self.targeting = attributes[:'targeting'] end if attributes.key?(:'bid_amount') self.bid_amount = attributes[:'bid_amount'] end if attributes.key?(:'tracking') self.tracking = attributes[:'tracking'] end if attributes.key?(:'special_ad_categories') if (value = attributes[:'special_ad_categories']).is_a?(Array) self.special_ad_categories = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Social account ID
25 26 27 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 25 def account_id @account_id end |
#ad_account_id ⇒ Object
Platform ad account ID
28 29 30 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 28 def ad_account_id @ad_account_id end |
#bid_amount ⇒ Object
Max bid cap (Meta only)
43 44 45 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 43 def bid_amount @bid_amount end |
#budget ⇒ Object
Returns the value of attribute budget.
34 35 36 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 34 def budget @budget end |
#currency ⇒ Object
Returns the value of attribute currency.
36 37 38 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 36 def currency @currency end |
#goal ⇒ Object
Returns the value of attribute goal.
32 33 34 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 32 def goal @goal end |
#name ⇒ Object
Returns the value of attribute name.
30 31 32 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 30 def name @name end |
#platform_post_id ⇒ Object
Platform post ID (alternative to postId)
22 23 24 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 22 def platform_post_id @platform_post_id end |
#post_id ⇒ Object
Zernio post ID (provide this or platformPostId)
19 20 21 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 19 def post_id @post_id end |
#schedule ⇒ Object
Returns the value of attribute schedule.
38 39 40 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 38 def schedule @schedule end |
#special_ad_categories ⇒ Object
Meta only. Required for housing, employment, credit, or political ads.
48 49 50 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 48 def special_ad_categories @special_ad_categories end |
#targeting ⇒ Object
Returns the value of attribute targeting.
40 41 42 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 40 def targeting @targeting end |
#tracking ⇒ Object
Returns the value of attribute tracking.
45 46 47 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 45 def tracking @tracking end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 73 def self.attribute_map { :'post_id' => :'postId', :'platform_post_id' => :'platformPostId', :'account_id' => :'accountId', :'ad_account_id' => :'adAccountId', :'name' => :'name', :'goal' => :'goal', :'budget' => :'budget', :'currency' => :'currency', :'schedule' => :'schedule', :'targeting' => :'targeting', :'bid_amount' => :'bidAmount', :'tracking' => :'tracking', :'special_ad_categories' => :'specialAdCategories' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 343 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 102 def self.openapi_types { :'post_id' => :'String', :'platform_post_id' => :'String', :'account_id' => :'String', :'ad_account_id' => :'String', :'name' => :'String', :'goal' => :'String', :'budget' => :'BoostPostRequestBudget', :'currency' => :'String', :'schedule' => :'BoostPostRequestSchedule', :'targeting' => :'BoostPostRequestTargeting', :'bid_amount' => :'Float', :'tracking' => :'BoostPostRequestTracking', :'special_ad_categories' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && post_id == o.post_id && platform_post_id == o.platform_post_id && account_id == o.account_id && ad_account_id == o.ad_account_id && name == o.name && goal == o.goal && budget == o.budget && currency == o.currency && schedule == o.schedule && targeting == o.targeting && bid_amount == o.bid_amount && tracking == o.tracking && special_ad_categories == o.special_ad_categories end |
#eql?(o) ⇒ Boolean
330 331 332 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 330 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
336 337 338 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 336 def hash [post_id, platform_post_id, account_id, ad_account_id, name, goal, budget, currency, schedule, targeting, bid_amount, tracking, special_ad_categories].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 209 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @ad_account_id.nil? invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @goal.nil? invalid_properties.push('invalid value for "goal", goal cannot be nil.') end if @budget.nil? invalid_properties.push('invalid value for "budget", budget cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
365 366 367 368 369 370 371 372 373 374 375 376 377 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 365 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/late-sdk/models/boost_post_request.rb', line 241 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @ad_account_id.nil? return false if @name.nil? return false if @name.to_s.length > 255 return false if @goal.nil? goal_validator = EnumAttributeValidator.new('String', ["engagement", "traffic", "awareness", "video_views"]) return false unless goal_validator.valid?(@goal) return false if @budget.nil? true end |