Class: Late::ConnectionLog

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/connection_log.rb

Overview

Connection event log showing account connection/disconnection history

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConnectionLog

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/late-sdk/models/connection_log.rb', line 129

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::ConnectionLog` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::ConnectionLog`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'user_id')
    self.user_id = attributes[:'user_id']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'connection_method')
    self.connection_method = attributes[:'connection_method']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'duration_ms')
    self.duration_ms = attributes[:'duration_ms']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



19
20
21
# File 'lib/late-sdk/models/connection_log.rb', line 19

def _id
  @_id
end

#account_idObject

The social account ID (present on successful connections and disconnects)



27
28
29
# File 'lib/late-sdk/models/connection_log.rb', line 27

def 
  @account_id
end

#connection_methodObject

How the connection was initiated



35
36
37
# File 'lib/late-sdk/models/connection_log.rb', line 35

def connection_method
  @connection_method
end

#contextObject

Returns the value of attribute context.



41
42
43
# File 'lib/late-sdk/models/connection_log.rb', line 41

def context
  @context
end

#created_atObject

Returns the value of attribute created_at.



49
50
51
# File 'lib/late-sdk/models/connection_log.rb', line 49

def created_at
  @created_at
end

#duration_msObject

How long the operation took in milliseconds



44
45
46
# File 'lib/late-sdk/models/connection_log.rb', line 44

def duration_ms
  @duration_ms
end

#errorObject

Returns the value of attribute error.



37
38
39
# File 'lib/late-sdk/models/connection_log.rb', line 37

def error
  @error
end

#event_typeObject

Type of connection event: connect_success, connect_failed, disconnect, reconnect_success, reconnect_failed



32
33
34
# File 'lib/late-sdk/models/connection_log.rb', line 32

def event_type
  @event_type
end

#metadataObject

Additional metadata



47
48
49
# File 'lib/late-sdk/models/connection_log.rb', line 47

def 
  @metadata
end

#platformObject

Returns the value of attribute platform.



29
30
31
# File 'lib/late-sdk/models/connection_log.rb', line 29

def platform
  @platform
end

#profile_idObject

Returns the value of attribute profile_id.



24
25
26
# File 'lib/late-sdk/models/connection_log.rb', line 24

def profile_id
  @profile_id
end

#successObject

Returns the value of attribute success.



39
40
41
# File 'lib/late-sdk/models/connection_log.rb', line 39

def success
  @success
end

#user_idObject

User who owns the connection (may be null for early OAuth failures)



22
23
24
# File 'lib/late-sdk/models/connection_log.rb', line 22

def user_id
  @user_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



93
94
95
# File 'lib/late-sdk/models/connection_log.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/late-sdk/models/connection_log.rb', line 98

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/late-sdk/models/connection_log.rb', line 74

def self.attribute_map
  {
    :'_id' => :'_id',
    :'user_id' => :'userId',
    :'profile_id' => :'profileId',
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'event_type' => :'eventType',
    :'connection_method' => :'connectionMethod',
    :'error' => :'error',
    :'success' => :'success',
    :'context' => :'context',
    :'duration_ms' => :'durationMs',
    :'metadata' => :'metadata',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/late-sdk/models/connection_log.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



122
123
124
125
# File 'lib/late-sdk/models/connection_log.rb', line 122

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/late-sdk/models/connection_log.rb', line 103

def self.openapi_types
  {
    :'_id' => :'String',
    :'user_id' => :'String',
    :'profile_id' => :'String',
    :'account_id' => :'String',
    :'platform' => :'String',
    :'event_type' => :'String',
    :'connection_method' => :'String',
    :'error' => :'ConnectionLogError',
    :'success' => :'ConnectionLogSuccess',
    :'context' => :'ConnectionLogContext',
    :'duration_ms' => :'Integer',
    :'metadata' => :'Object',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/late-sdk/models/connection_log.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      user_id == o.user_id &&
      profile_id == o.profile_id &&
       == o. &&
      platform == o.platform &&
      event_type == o.event_type &&
      connection_method == o.connection_method &&
      error == o.error &&
      success == o.success &&
      context == o.context &&
      duration_ms == o.duration_ms &&
       == o. &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/late-sdk/models/connection_log.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/late-sdk/models/connection_log.rb', line 275

def hash
  [_id, user_id, profile_id, , platform, event_type, connection_method, error, success, context, duration_ms, , created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



198
199
200
201
202
# File 'lib/late-sdk/models/connection_log.rb', line 198

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/late-sdk/models/connection_log.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
# File 'lib/late-sdk/models/connection_log.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["tiktok", "instagram", "facebook", "youtube", "linkedin", "twitter", "threads", "pinterest", "reddit", "bluesky", "googlebusiness", "telegram", "snapchat"])
  return false unless platform_validator.valid?(@platform)
  event_type_validator = EnumAttributeValidator.new('String', ["connect_success", "connect_failed", "disconnect", "reconnect_success", "reconnect_failed"])
  return false unless event_type_validator.valid?(@event_type)
  connection_method_validator = EnumAttributeValidator.new('String', ["oauth", "credentials", "invitation"])
  return false unless connection_method_validator.valid?(@connection_method)
  true
end