Class: Late::ConnectionLogContext
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::ConnectionLogContext
- Defined in:
- lib/late-sdk/models/connection_log_context.rb
Overview
Additional context about the connection attempt
Instance Attribute Summary collapse
-
#connect_token ⇒ Object
Returns the value of attribute connect_token.
-
#has_custom_redirect_url ⇒ Object
Returns the value of attribute has_custom_redirect_url.
-
#invitation_token ⇒ Object
Returns the value of attribute invitation_token.
-
#is_byok ⇒ Object
Using bring-your-own-keys.
-
#is_headless_mode ⇒ Object
Returns the value of attribute is_headless_mode.
-
#is_reconnection ⇒ Object
Returns the value of attribute is_reconnection.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectionLogContext
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConnectionLogContext
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::ConnectionLogContext` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::ConnectionLogContext`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_headless_mode') self.is_headless_mode = attributes[:'is_headless_mode'] end if attributes.key?(:'has_custom_redirect_url') self.has_custom_redirect_url = attributes[:'has_custom_redirect_url'] end if attributes.key?(:'is_reconnection') self.is_reconnection = attributes[:'is_reconnection'] end if attributes.key?(:'is_byok') self.is_byok = attributes[:'is_byok'] end if attributes.key?(:'invitation_token') self.invitation_token = attributes[:'invitation_token'] end if attributes.key?(:'connect_token') self.connect_token = attributes[:'connect_token'] end end |
Instance Attribute Details
#connect_token ⇒ Object
Returns the value of attribute connect_token.
30 31 32 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 30 def connect_token @connect_token end |
#has_custom_redirect_url ⇒ Object
Returns the value of attribute has_custom_redirect_url.
21 22 23 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 21 def has_custom_redirect_url @has_custom_redirect_url end |
#invitation_token ⇒ Object
Returns the value of attribute invitation_token.
28 29 30 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 28 def invitation_token @invitation_token end |
#is_byok ⇒ Object
Using bring-your-own-keys
26 27 28 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 26 def is_byok @is_byok end |
#is_headless_mode ⇒ Object
Returns the value of attribute is_headless_mode.
19 20 21 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 19 def is_headless_mode @is_headless_mode end |
#is_reconnection ⇒ Object
Returns the value of attribute is_reconnection.
23 24 25 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 23 def is_reconnection @is_reconnection end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 33 def self.attribute_map { :'is_headless_mode' => :'isHeadlessMode', :'has_custom_redirect_url' => :'hasCustomRedirectUrl', :'is_reconnection' => :'isReconnection', :'is_byok' => :'isBYOK', :'invitation_token' => :'invitationToken', :'connect_token' => :'connectToken' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 55 def self.openapi_types { :'is_headless_mode' => :'Boolean', :'has_custom_redirect_url' => :'Boolean', :'is_reconnection' => :'Boolean', :'is_byok' => :'Boolean', :'invitation_token' => :'String', :'connect_token' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 139 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 130 def ==(o) return true if self.equal?(o) self.class == o.class && is_headless_mode == o.is_headless_mode && has_custom_redirect_url == o.has_custom_redirect_url && is_reconnection == o.is_reconnection && is_byok == o.is_byok && invitation_token == o.invitation_token && connect_token == o.connect_token end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 149 def hash [is_headless_mode, has_custom_redirect_url, is_reconnection, is_byok, invitation_token, connect_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 |
# File 'lib/late-sdk/models/connection_log_context.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |