Class: Late::ConnectionLogSuccess
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::ConnectionLogSuccess
- Defined in:
- lib/late-sdk/models/connection_log_success.rb
Overview
Success details (present on successful events)
Instance Attribute Summary collapse
-
#account_type ⇒ Object
Account type (personal, business, organization).
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#permissions ⇒ Object
OAuth scopes/permissions granted.
-
#profile_picture ⇒ Object
Returns the value of attribute profile_picture.
-
#token_expires_at ⇒ Object
Returns the value of attribute token_expires_at.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectionLogSuccess
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConnectionLogSuccess
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::ConnectionLogSuccess` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::ConnectionLogSuccess`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'profile_picture') self.profile_picture = attributes[:'profile_picture'] end if attributes.key?(:'permissions') if (value = attributes[:'permissions']).is_a?(Array) self. = value end end if attributes.key?(:'token_expires_at') self.token_expires_at = attributes[:'token_expires_at'] end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] end end |
Instance Attribute Details
#account_type ⇒ Object
Account type (personal, business, organization)
31 32 33 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 31 def account_type @account_type end |
#display_name ⇒ Object
Returns the value of attribute display_name.
19 20 21 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 19 def display_name @display_name end |
#permissions ⇒ Object
OAuth scopes/permissions granted
26 27 28 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 26 def @permissions end |
#profile_picture ⇒ Object
Returns the value of attribute profile_picture.
23 24 25 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 23 def profile_picture @profile_picture end |
#token_expires_at ⇒ Object
Returns the value of attribute token_expires_at.
28 29 30 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 28 def token_expires_at @token_expires_at end |
#username ⇒ Object
Returns the value of attribute username.
21 22 23 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 21 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 34 def self.attribute_map { :'display_name' => :'displayName', :'username' => :'username', :'profile_picture' => :'profilePicture', :'permissions' => :'permissions', :'token_expires_at' => :'tokenExpiresAt', :'account_type' => :'accountType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 159 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 56 def self.openapi_types { :'display_name' => :'String', :'username' => :'String', :'profile_picture' => :'String', :'permissions' => :'Array<String>', :'token_expires_at' => :'Time', :'account_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 133 def ==(o) return true if self.equal?(o) self.class == o.class && display_name == o.display_name && username == o.username && profile_picture == o.profile_picture && == o. && token_expires_at == o.token_expires_at && account_type == o.account_type end |
#eql?(o) ⇒ Boolean
146 147 148 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 146 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 152 def hash [display_name, username, profile_picture, , token_expires_at, account_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 |
# File 'lib/late-sdk/models/connection_log_success.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |