Class: Late::CreatePostRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::CreatePostRequest
- Defined in:
- lib/late-sdk/models/create_post_request.rb
Instance Attribute Summary collapse
-
#content ⇒ Object
Post caption/text.
-
#crossposting_enabled ⇒ Object
Returns the value of attribute crossposting_enabled.
-
#hashtags ⇒ Object
Returns the value of attribute hashtags.
-
#is_draft ⇒ Object
Returns the value of attribute is_draft.
-
#media_items ⇒ Object
Returns the value of attribute media_items.
-
#mentions ⇒ Object
Returns the value of attribute mentions.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#platforms ⇒ Object
Returns the value of attribute platforms.
-
#publish_now ⇒ Object
Returns the value of attribute publish_now.
-
#queue_id ⇒ Object
Specific queue ID to use when scheduling via queue.
-
#queued_from_profile ⇒ Object
Profile ID to schedule via queue.
-
#recycling ⇒ Object
Returns the value of attribute recycling.
-
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
-
#tags ⇒ Object
Tags/keywords.
-
#tiktok_settings ⇒ Object
Root-level TikTok settings applied to all TikTok platforms.
-
#timezone ⇒ Object
Returns the value of attribute timezone.
-
#title ⇒ Object
Returns the value of attribute title.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePostRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreatePostRequest
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/late-sdk/models/create_post_request.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::CreatePostRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::CreatePostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'media_items') if (value = attributes[:'media_items']).is_a?(Array) self.media_items = value end end if attributes.key?(:'platforms') if (value = attributes[:'platforms']).is_a?(Array) self.platforms = value end end if attributes.key?(:'scheduled_for') self.scheduled_for = attributes[:'scheduled_for'] end if attributes.key?(:'publish_now') self.publish_now = attributes[:'publish_now'] else self.publish_now = false end if attributes.key?(:'is_draft') self.is_draft = attributes[:'is_draft'] else self.is_draft = false end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] else self.timezone = 'UTC' end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'hashtags') if (value = attributes[:'hashtags']).is_a?(Array) self. = value end end if attributes.key?(:'mentions') if (value = attributes[:'mentions']).is_a?(Array) self.mentions = value end end if attributes.key?(:'crossposting_enabled') self.crossposting_enabled = attributes[:'crossposting_enabled'] else self.crossposting_enabled = true end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'tiktok_settings') self.tiktok_settings = attributes[:'tiktok_settings'] end if attributes.key?(:'recycling') self.recycling = attributes[:'recycling'] end if attributes.key?(:'queued_from_profile') self.queued_from_profile = attributes[:'queued_from_profile'] end if attributes.key?(:'queue_id') self.queue_id = attributes[:'queue_id'] end end |
Instance Attribute Details
#content ⇒ Object
Post caption/text. Optional when media is attached or all platforms have customContent. Required for text-only posts.
21 22 23 |
# File 'lib/late-sdk/models/create_post_request.rb', line 21 def content @content end |
#crossposting_enabled ⇒ Object
Returns the value of attribute crossposting_enabled.
42 43 44 |
# File 'lib/late-sdk/models/create_post_request.rb', line 42 def crossposting_enabled @crossposting_enabled end |
#hashtags ⇒ Object
Returns the value of attribute hashtags.
38 39 40 |
# File 'lib/late-sdk/models/create_post_request.rb', line 38 def @hashtags end |
#is_draft ⇒ Object
Returns the value of attribute is_draft.
31 32 33 |
# File 'lib/late-sdk/models/create_post_request.rb', line 31 def is_draft @is_draft end |
#media_items ⇒ Object
Returns the value of attribute media_items.
23 24 25 |
# File 'lib/late-sdk/models/create_post_request.rb', line 23 def media_items @media_items end |
#mentions ⇒ Object
Returns the value of attribute mentions.
40 41 42 |
# File 'lib/late-sdk/models/create_post_request.rb', line 40 def mentions @mentions end |
#metadata ⇒ Object
Returns the value of attribute metadata.
44 45 46 |
# File 'lib/late-sdk/models/create_post_request.rb', line 44 def @metadata end |
#platforms ⇒ Object
Returns the value of attribute platforms.
25 26 27 |
# File 'lib/late-sdk/models/create_post_request.rb', line 25 def platforms @platforms end |
#publish_now ⇒ Object
Returns the value of attribute publish_now.
29 30 31 |
# File 'lib/late-sdk/models/create_post_request.rb', line 29 def publish_now @publish_now end |
#queue_id ⇒ Object
Specific queue ID to use when scheduling via queue. Only used when queuedFromProfile is also provided. If omitted, uses the profile’s default queue.
55 56 57 |
# File 'lib/late-sdk/models/create_post_request.rb', line 55 def queue_id @queue_id end |
#queued_from_profile ⇒ Object
Profile ID to schedule via queue. When provided without scheduledFor, the post is auto-assigned to the next available slot. Do not call /v1/queue/next-slot and use that time in scheduledFor, as that bypasses queue locking.
52 53 54 |
# File 'lib/late-sdk/models/create_post_request.rb', line 52 def queued_from_profile @queued_from_profile end |
#recycling ⇒ Object
Returns the value of attribute recycling.
49 50 51 |
# File 'lib/late-sdk/models/create_post_request.rb', line 49 def recycling @recycling end |
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
27 28 29 |
# File 'lib/late-sdk/models/create_post_request.rb', line 27 def scheduled_for @scheduled_for end |
#tags ⇒ Object
Tags/keywords. YouTube constraints: each tag max 100 chars, combined max 500 chars, duplicates auto-removed.
36 37 38 |
# File 'lib/late-sdk/models/create_post_request.rb', line 36 def @tags end |
#tiktok_settings ⇒ Object
Root-level TikTok settings applied to all TikTok platforms. Merged into each platform’s platformSpecificData, with platform-specific settings taking precedence.
47 48 49 |
# File 'lib/late-sdk/models/create_post_request.rb', line 47 def tiktok_settings @tiktok_settings end |
#timezone ⇒ Object
Returns the value of attribute timezone.
33 34 35 |
# File 'lib/late-sdk/models/create_post_request.rb', line 33 def timezone @timezone end |
#title ⇒ Object
Returns the value of attribute title.
18 19 20 |
# File 'lib/late-sdk/models/create_post_request.rb', line 18 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/late-sdk/models/create_post_request.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/late-sdk/models/create_post_request.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/late-sdk/models/create_post_request.rb', line 58 def self.attribute_map { :'title' => :'title', :'content' => :'content', :'media_items' => :'mediaItems', :'platforms' => :'platforms', :'scheduled_for' => :'scheduledFor', :'publish_now' => :'publishNow', :'is_draft' => :'isDraft', :'timezone' => :'timezone', :'tags' => :'tags', :'hashtags' => :'hashtags', :'mentions' => :'mentions', :'crossposting_enabled' => :'crosspostingEnabled', :'metadata' => :'metadata', :'tiktok_settings' => :'tiktokSettings', :'recycling' => :'recycling', :'queued_from_profile' => :'queuedFromProfile', :'queue_id' => :'queueId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/late-sdk/models/create_post_request.rb', line 278 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 |
# File 'lib/late-sdk/models/create_post_request.rb', line 114 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/late-sdk/models/create_post_request.rb', line 91 def self.openapi_types { :'title' => :'String', :'content' => :'String', :'media_items' => :'Array<CreatePostRequestMediaItemsInner>', :'platforms' => :'Array<CreatePostRequestPlatformsInner>', :'scheduled_for' => :'Time', :'publish_now' => :'Boolean', :'is_draft' => :'Boolean', :'timezone' => :'String', :'tags' => :'Array<String>', :'hashtags' => :'Array<String>', :'mentions' => :'Array<String>', :'crossposting_enabled' => :'Boolean', :'metadata' => :'Hash<String, Object>', :'tiktok_settings' => :'TikTokPlatformData', :'recycling' => :'RecyclingConfig', :'queued_from_profile' => :'String', :'queue_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/late-sdk/models/create_post_request.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && content == o.content && media_items == o.media_items && platforms == o.platforms && scheduled_for == o.scheduled_for && publish_now == o.publish_now && is_draft == o.is_draft && timezone == o.timezone && == o. && == o. && mentions == o.mentions && crossposting_enabled == o.crossposting_enabled && == o. && tiktok_settings == o.tiktok_settings && recycling == o.recycling && queued_from_profile == o.queued_from_profile && queue_id == o.queue_id end |
#eql?(o) ⇒ Boolean
265 266 267 |
# File 'lib/late-sdk/models/create_post_request.rb', line 265 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
271 272 273 |
# File 'lib/late-sdk/models/create_post_request.rb', line 271 def hash [title, content, media_items, platforms, scheduled_for, publish_now, is_draft, timezone, , , mentions, crossposting_enabled, , tiktok_settings, recycling, queued_from_profile, queue_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
226 227 228 229 230 |
# File 'lib/late-sdk/models/create_post_request.rb', line 226 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/late-sdk/models/create_post_request.rb', line 300 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
234 235 236 237 |
# File 'lib/late-sdk/models/create_post_request.rb', line 234 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |