Class: Late::GMBReviewsApi
- Inherits:
-
Object
- Object
- Late::GMBReviewsApi
- Defined in:
- lib/late-sdk/api/gmb_reviews_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_google_business_reviews(account_id, opts = {}) ⇒ GetGoogleBusinessReviews200Response
Get reviews Returns reviews for a GBP account including ratings, comments, and owner replies.
-
#get_google_business_reviews_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessReviews200Response, Integer, Hash)>
Get reviews Returns reviews for a GBP account including ratings, comments, and owner replies.
-
#initialize(api_client = ApiClient.default) ⇒ GMBReviewsApi
constructor
A new instance of GMBReviewsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ GMBReviewsApi
Returns a new instance of GMBReviewsApi.
19 20 21 |
# File 'lib/late-sdk/api/gmb_reviews_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/late-sdk/api/gmb_reviews_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_google_business_reviews(account_id, opts = {}) ⇒ GetGoogleBusinessReviews200Response
Get reviews Returns reviews for a GBP account including ratings, comments, and owner replies. Use nextPageToken for pagination.
30 31 32 33 |
# File 'lib/late-sdk/api/gmb_reviews_api.rb', line 30 def get_google_business_reviews(account_id, opts = {}) data, _status_code, _headers = get_google_business_reviews_with_http_info(account_id, opts) data end |
#get_google_business_reviews_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessReviews200Response, Integer, Hash)>
Get reviews Returns reviews for a GBP account including ratings, comments, and owner replies. Use nextPageToken for pagination.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/late-sdk/api/gmb_reviews_api.rb', line 43 def get_google_business_reviews_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBReviewsApi.get_google_business_reviews ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBReviewsApi.get_google_business_reviews" end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 50 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling GMBReviewsApi.get_google_business_reviews, must be smaller than or equal to 50.' end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling GMBReviewsApi.get_google_business_reviews, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-reviews'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'pageToken'] = opts[:'page_token'] if !opts[:'page_token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetGoogleBusinessReviews200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBReviewsApi.get_google_business_reviews", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBReviewsApi#get_google_business_reviews\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |