Class: Late::GetWhatsAppContact200ResponseContact

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/late-sdk/models/get_whats_app_contact200_response_contact.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppContact200ResponseContact

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::GetWhatsAppContact200ResponseContact` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::GetWhatsAppContact200ResponseContact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  end

  if attributes.key?(:'wa_id')
    self.wa_id = attributes[:'wa_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'company')
    self.company = attributes[:'company']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'is_opted_in')
    self.is_opted_in = attributes[:'is_opted_in']
  end

  if attributes.key?(:'opt_in_date')
    self.opt_in_date = attributes[:'opt_in_date']
  end

  if attributes.key?(:'opt_out_date')
    self.opt_out_date = attributes[:'opt_out_date']
  end

  if attributes.key?(:'is_blocked')
    self.is_blocked = attributes[:'is_blocked']
  end

  if attributes.key?(:'last_message_sent_at')
    self.last_message_sent_at = attributes[:'last_message_sent_at']
  end

  if attributes.key?(:'last_message_received_at')
    self.last_message_received_at = attributes[:'last_message_received_at']
  end

  if attributes.key?(:'messages_sent_count')
    self.messages_sent_count = attributes[:'messages_sent_count']
  end

  if attributes.key?(:'messages_received_count')
    self.messages_received_count = attributes[:'messages_received_count']
  end

  if attributes.key?(:'custom_fields')
    self.custom_fields = attributes[:'custom_fields']
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#companyObject

Returns the value of attribute company.



28
29
30
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 28

def company
  @company
end

#created_atObject

Returns the value of attribute created_at.



54
55
56
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 54

def created_at
  @created_at
end

#custom_fieldsObject

Returns the value of attribute custom_fields.



50
51
52
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 50

def custom_fields
  @custom_fields
end

#emailObject

Returns the value of attribute email.



26
27
28
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 26

def email
  @email
end

#groupsObject

Returns the value of attribute groups.



32
33
34
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 32

def groups
  @groups
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 18

def id
  @id
end

#is_blockedObject

Returns the value of attribute is_blocked.



40
41
42
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 40

def is_blocked
  @is_blocked
end

#is_opted_inObject

Returns the value of attribute is_opted_in.



34
35
36
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 34

def is_opted_in
  @is_opted_in
end

#last_message_received_atObject

Returns the value of attribute last_message_received_at.



44
45
46
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 44

def last_message_received_at
  @last_message_received_at
end

#last_message_sent_atObject

Returns the value of attribute last_message_sent_at.



42
43
44
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 42

def last_message_sent_at
  @last_message_sent_at
end

#messages_received_countObject

Returns the value of attribute messages_received_count.



48
49
50
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 48

def messages_received_count
  @messages_received_count
end

#messages_sent_countObject

Returns the value of attribute messages_sent_count.



46
47
48
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 46

def messages_sent_count
  @messages_sent_count
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 24

def name
  @name
end

#notesObject

Returns the value of attribute notes.



52
53
54
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 52

def notes
  @notes
end

#opt_in_dateObject

Returns the value of attribute opt_in_date.



36
37
38
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 36

def opt_in_date
  @opt_in_date
end

#opt_out_dateObject

Returns the value of attribute opt_out_date.



38
39
40
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 38

def opt_out_date
  @opt_out_date
end

#phoneObject

Returns the value of attribute phone.



20
21
22
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 20

def phone
  @phone
end

#tagsObject

Returns the value of attribute tags.



30
31
32
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 30

def tags
  @tags
end

#updated_atObject

Returns the value of attribute updated_at.



56
57
58
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 56

def updated_at
  @updated_at
end

#wa_idObject

Returns the value of attribute wa_id.



22
23
24
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 22

def wa_id
  @wa_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 59

def self.attribute_map
  {
    :'id' => :'id',
    :'phone' => :'phone',
    :'wa_id' => :'waId',
    :'name' => :'name',
    :'email' => :'email',
    :'company' => :'company',
    :'tags' => :'tags',
    :'groups' => :'groups',
    :'is_opted_in' => :'isOptedIn',
    :'opt_in_date' => :'optInDate',
    :'opt_out_date' => :'optOutDate',
    :'is_blocked' => :'isBlocked',
    :'last_message_sent_at' => :'lastMessageSentAt',
    :'last_message_received_at' => :'lastMessageReceivedAt',
    :'messages_sent_count' => :'messagesSentCount',
    :'messages_received_count' => :'messagesReceivedCount',
    :'custom_fields' => :'customFields',
    :'notes' => :'notes',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 284

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



121
122
123
124
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 121

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 95

def self.openapi_types
  {
    :'id' => :'String',
    :'phone' => :'String',
    :'wa_id' => :'String',
    :'name' => :'String',
    :'email' => :'String',
    :'company' => :'String',
    :'tags' => :'Array<String>',
    :'groups' => :'Array<String>',
    :'is_opted_in' => :'Boolean',
    :'opt_in_date' => :'Time',
    :'opt_out_date' => :'Time',
    :'is_blocked' => :'Boolean',
    :'last_message_sent_at' => :'Time',
    :'last_message_received_at' => :'Time',
    :'messages_sent_count' => :'Integer',
    :'messages_received_count' => :'Integer',
    :'custom_fields' => :'Object',
    :'notes' => :'String',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      phone == o.phone &&
      wa_id == o.wa_id &&
      name == o.name &&
      email == o.email &&
      company == o.company &&
      tags == o.tags &&
      groups == o.groups &&
      is_opted_in == o.is_opted_in &&
      opt_in_date == o.opt_in_date &&
      opt_out_date == o.opt_out_date &&
      is_blocked == o.is_blocked &&
      last_message_sent_at == o.last_message_sent_at &&
      last_message_received_at == o.last_message_received_at &&
      messages_sent_count == o.messages_sent_count &&
      messages_received_count == o.messages_received_count &&
      custom_fields == o.custom_fields &&
      notes == o.notes &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


271
272
273
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 271

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



277
278
279
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 277

def hash
  [id, phone, wa_id, name, email, company, tags, groups, is_opted_in, opt_in_date, opt_out_date, is_blocked, last_message_sent_at, last_message_received_at, messages_sent_count, messages_received_count, custom_fields, notes, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



229
230
231
232
233
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 229

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



237
238
239
240
# File 'lib/late-sdk/models/get_whats_app_contact200_response_contact.rb', line 237

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end