Class: Late::ImportWhatsAppContactsRequestContactsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::ImportWhatsAppContactsRequestContactsInner
- Defined in:
- lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb
Instance Attribute Summary collapse
-
#company ⇒ Object
Returns the value of attribute company.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#email ⇒ Object
Returns the value of attribute email.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#name ⇒ Object
Contact name.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#phone ⇒ Object
Phone number in E.164 format.
-
#tags ⇒ Object
Returns the value of attribute tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImportWhatsAppContactsRequestContactsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ImportWhatsAppContactsRequestContactsInner
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::ImportWhatsAppContactsRequestContactsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::ImportWhatsAppContactsRequestContactsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone') self.phone = attributes[:'phone'] else self.phone = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'custom_fields') if (value = attributes[:'custom_fields']).is_a?(Hash) self.custom_fields = value end end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end end |
Instance Attribute Details
#company ⇒ Object
Returns the value of attribute company.
26 27 28 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 26 def company @company end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
32 33 34 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 32 def custom_fields @custom_fields end |
#email ⇒ Object
Returns the value of attribute email.
24 25 26 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 24 def email @email end |
#groups ⇒ Object
Returns the value of attribute groups.
30 31 32 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 30 def groups @groups end |
#name ⇒ Object
Contact name
22 23 24 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 22 def name @name end |
#notes ⇒ Object
Returns the value of attribute notes.
34 35 36 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 34 def notes @notes end |
#phone ⇒ Object
Phone number in E.164 format
19 20 21 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 19 def phone @phone end |
#tags ⇒ Object
Returns the value of attribute tags.
28 29 30 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 28 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 37 def self.attribute_map { :'phone' => :'phone', :'name' => :'name', :'email' => :'email', :'company' => :'company', :'tags' => :'tags', :'groups' => :'groups', :'custom_fields' => :'customFields', :'notes' => :'notes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 61 def self.openapi_types { :'phone' => :'String', :'name' => :'String', :'email' => :'String', :'company' => :'String', :'tags' => :'Array<String>', :'groups' => :'Array<String>', :'custom_fields' => :'Hash<String, String>', :'notes' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && phone == o.phone && name == o.name && email == o.email && company == o.company && == o. && groups == o.groups && custom_fields == o.custom_fields && notes == o.notes end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 207 def hash [phone, name, email, company, , groups, custom_fields, notes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @phone.nil? invalid_properties.push('invalid value for "phone", phone cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 |
# File 'lib/late-sdk/models/import_whats_app_contacts_request_contacts_inner.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @phone.nil? return false if @name.nil? true end |