Class: Late::InstagramAccountInsightsResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::InstagramAccountInsightsResponse
- Defined in:
- lib/late-sdk/models/instagram_account_insights_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The Zernio SocialAccount ID.
-
#breakdown ⇒ Object
Breakdown dimension used (only present when breakdown was requested).
-
#data_delay ⇒ Object
Returns the value of attribute data_delay.
-
#date_range ⇒ Object
Returns the value of attribute date_range.
-
#metric_type ⇒ Object
Returns the value of attribute metric_type.
-
#metrics ⇒ Object
Object keyed by metric name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#success ⇒ Object
Returns the value of attribute success.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstagramAccountInsightsResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InstagramAccountInsightsResponse
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::InstagramAccountInsightsResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::InstagramAccountInsightsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'date_range') self.date_range = attributes[:'date_range'] end if attributes.key?(:'metric_type') self.metric_type = attributes[:'metric_type'] end if attributes.key?(:'breakdown') self.breakdown = attributes[:'breakdown'] end if attributes.key?(:'metrics') if (value = attributes[:'metrics']).is_a?(Hash) self.metrics = value end end if attributes.key?(:'data_delay') self.data_delay = attributes[:'data_delay'] end end |
Instance Attribute Details
#account_id ⇒ Object
The Zernio SocialAccount ID
21 22 23 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 21 def account_id @account_id end |
#breakdown ⇒ Object
Breakdown dimension used (only present when breakdown was requested)
30 31 32 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 30 def breakdown @breakdown end |
#data_delay ⇒ Object
Returns the value of attribute data_delay.
35 36 37 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 35 def data_delay @data_delay end |
#date_range ⇒ Object
Returns the value of attribute date_range.
25 26 27 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 25 def date_range @date_range end |
#metric_type ⇒ Object
Returns the value of attribute metric_type.
27 28 29 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 27 def metric_type @metric_type end |
#metrics ⇒ Object
Object keyed by metric name. For time_series: each metric has "total" (number) and "values" (array of value). For total_value: each metric has "total" (number) and optionally "breakdowns" (array of value).
33 34 35 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 33 def metrics @metrics end |
#platform ⇒ Object
Returns the value of attribute platform.
23 24 25 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 23 def platform @platform end |
#success ⇒ Object
Returns the value of attribute success.
18 19 20 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 18 def success @success end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 60 def self.attribute_map { :'success' => :'success', :'account_id' => :'accountId', :'platform' => :'platform', :'date_range' => :'dateRange', :'metric_type' => :'metricType', :'breakdown' => :'breakdown', :'metrics' => :'metrics', :'data_delay' => :'dataDelay' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 84 def self.openapi_types { :'success' => :'Boolean', :'account_id' => :'String', :'platform' => :'String', :'date_range' => :'InstagramAccountInsightsResponseDateRange', :'metric_type' => :'String', :'breakdown' => :'String', :'metrics' => :'Hash<String, InstagramAccountInsightsResponseMetricsValue>', :'data_delay' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && account_id == o.account_id && platform == o.platform && date_range == o.date_range && metric_type == o.metric_type && breakdown == o.breakdown && metrics == o.metrics && data_delay == o.data_delay end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 204 def hash [success, account_id, platform, date_range, metric_type, breakdown, metrics, data_delay].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 |
# File 'lib/late-sdk/models/instagram_account_insights_response.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' metric_type_validator = EnumAttributeValidator.new('String', ["time_series", "total_value"]) return false unless metric_type_validator.valid?(@metric_type) true end |