Class: Late::MediaItem

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/media_item.rb

Overview

Media referenced in posts. URLs must be publicly reachable over HTTPS. Use POST /v1/media/presign for uploads up to 5GB. Late auto-compresses images and videos that exceed platform limits (videos over 200 MB may not be compressed).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MediaItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/late-sdk/models/media_item.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::MediaItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::MediaItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'filename')
    self.filename = attributes[:'filename']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'mime_type')
    self.mime_type = attributes[:'mime_type']
  end

  if attributes.key?(:'thumbnail')
    self.thumbnail = attributes[:'thumbnail']
  end

  if attributes.key?(:'instagram_thumbnail')
    self.instagram_thumbnail = attributes[:'instagram_thumbnail']
  end

  if attributes.key?(:'tiktok_processed')
    self.tiktok_processed = attributes[:'tiktok_processed']
  end
end

Instance Attribute Details

#filenameObject

Returns the value of attribute filename.



26
27
28
# File 'lib/late-sdk/models/media_item.rb', line 26

def filename
  @filename
end

#instagram_thumbnailObject

Optional custom cover image URL for Instagram Reels



38
39
40
# File 'lib/late-sdk/models/media_item.rb', line 38

def instagram_thumbnail
  @instagram_thumbnail
end

#mime_typeObject

Optional MIME type (e.g. image/jpeg, video/mp4)



32
33
34
# File 'lib/late-sdk/models/media_item.rb', line 32

def mime_type
  @mime_type
end

#sizeObject

Optional file size in bytes



29
30
31
# File 'lib/late-sdk/models/media_item.rb', line 29

def size
  @size
end

#thumbnailObject

Optional thumbnail image URL for videos



35
36
37
# File 'lib/late-sdk/models/media_item.rb', line 35

def thumbnail
  @thumbnail
end

#tiktok_processedObject

Internal flag indicating the image was resized for TikTok



41
42
43
# File 'lib/late-sdk/models/media_item.rb', line 41

def tiktok_processed
  @tiktok_processed
end

#titleObject

Optional title for the media item. Used as the document title for LinkedIn PDF/carousel posts. If omitted, falls back to the post title, then the filename.



24
25
26
# File 'lib/late-sdk/models/media_item.rb', line 24

def title
  @title
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/late-sdk/models/media_item.rb', line 19

def type
  @type
end

#urlObject

Returns the value of attribute url.



21
22
23
# File 'lib/late-sdk/models/media_item.rb', line 21

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/late-sdk/models/media_item.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/late-sdk/models/media_item.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/late-sdk/models/media_item.rb', line 66

def self.attribute_map
  {
    :'type' => :'type',
    :'url' => :'url',
    :'title' => :'title',
    :'filename' => :'filename',
    :'size' => :'size',
    :'mime_type' => :'mimeType',
    :'thumbnail' => :'thumbnail',
    :'instagram_thumbnail' => :'instagramThumbnail',
    :'tiktok_processed' => :'tiktokProcessed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/late-sdk/models/media_item.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
# File 'lib/late-sdk/models/media_item.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/late-sdk/models/media_item.rb', line 91

def self.openapi_types
  {
    :'type' => :'String',
    :'url' => :'String',
    :'title' => :'String',
    :'filename' => :'String',
    :'size' => :'Integer',
    :'mime_type' => :'String',
    :'thumbnail' => :'String',
    :'instagram_thumbnail' => :'String',
    :'tiktok_processed' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/late-sdk/models/media_item.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      url == o.url &&
      title == o.title &&
      filename == o.filename &&
      size == o.size &&
      mime_type == o.mime_type &&
      thumbnail == o.thumbnail &&
      instagram_thumbnail == o.instagram_thumbnail &&
      tiktok_processed == o.tiktok_processed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/late-sdk/models/media_item.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/late-sdk/models/media_item.rb', line 215

def hash
  [type, url, title, filename, size, mime_type, thumbnail, instagram_thumbnail, tiktok_processed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
# File 'lib/late-sdk/models/media_item.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/late-sdk/models/media_item.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
# File 'lib/late-sdk/models/media_item.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["image", "video", "gif", "document"])
  return false unless type_validator.valid?(@type)
  true
end