Class: Late::PlatformAnalytics

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/platform_analytics.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PlatformAnalytics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/late-sdk/models/platform_analytics.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::PlatformAnalytics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::PlatformAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'account_username')
    self. = attributes[:'account_username']
  end

  if attributes.key?(:'analytics')
    self.analytics = attributes[:'analytics']
  end

  if attributes.key?(:'sync_status')
    self.sync_status = attributes[:'sync_status']
  end

  if attributes.key?(:'platform_post_url')
    self.platform_post_url = attributes[:'platform_post_url']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



22
23
24
# File 'lib/late-sdk/models/platform_analytics.rb', line 22

def 
  @account_id
end

#account_usernameObject

Returns the value of attribute account_username.



24
25
26
# File 'lib/late-sdk/models/platform_analytics.rb', line 24

def 
  @account_username
end

#analyticsObject

Returns the value of attribute analytics.



26
27
28
# File 'lib/late-sdk/models/platform_analytics.rb', line 26

def analytics
  @analytics
end

#error_messageObject

Error details when status is failed



34
35
36
# File 'lib/late-sdk/models/platform_analytics.rb', line 34

def error_message
  @error_message
end

#platformObject

Returns the value of attribute platform.



18
19
20
# File 'lib/late-sdk/models/platform_analytics.rb', line 18

def platform
  @platform
end

#platform_post_urlObject

Returns the value of attribute platform_post_url.



31
32
33
# File 'lib/late-sdk/models/platform_analytics.rb', line 31

def platform_post_url
  @platform_post_url
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/late-sdk/models/platform_analytics.rb', line 20

def status
  @status
end

#sync_statusObject

Sync state of analytics for this platform



29
30
31
# File 'lib/late-sdk/models/platform_analytics.rb', line 29

def sync_status
  @sync_status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/late-sdk/models/platform_analytics.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/late-sdk/models/platform_analytics.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/late-sdk/models/platform_analytics.rb', line 59

def self.attribute_map
  {
    :'platform' => :'platform',
    :'status' => :'status',
    :'account_id' => :'accountId',
    :'account_username' => :'accountUsername',
    :'analytics' => :'analytics',
    :'sync_status' => :'syncStatus',
    :'platform_post_url' => :'platformPostUrl',
    :'error_message' => :'errorMessage'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/late-sdk/models/platform_analytics.rb', line 220

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/late-sdk/models/platform_analytics.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/late-sdk/models/platform_analytics.rb', line 83

def self.openapi_types
  {
    :'platform' => :'String',
    :'status' => :'String',
    :'account_id' => :'String',
    :'account_username' => :'String',
    :'analytics' => :'PostAnalytics',
    :'sync_status' => :'String',
    :'platform_post_url' => :'String',
    :'error_message' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/late-sdk/models/platform_analytics.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      platform == o.platform &&
      status == o.status &&
       == o. &&
       == o. &&
      analytics == o.analytics &&
      sync_status == o.sync_status &&
      platform_post_url == o.platform_post_url &&
      error_message == o.error_message
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


207
208
209
# File 'lib/late-sdk/models/platform_analytics.rb', line 207

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



213
214
215
# File 'lib/late-sdk/models/platform_analytics.rb', line 213

def hash
  [platform, status, , , analytics, sync_status, platform_post_url, error_message].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
# File 'lib/late-sdk/models/platform_analytics.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/late-sdk/models/platform_analytics.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
167
168
# File 'lib/late-sdk/models/platform_analytics.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["published", "failed"])
  return false unless status_validator.valid?(@status)
  sync_status_validator = EnumAttributeValidator.new('String', ["synced", "pending", "unavailable"])
  return false unless sync_status_validator.valid?(@sync_status)
  true
end