Class: Late::PostAnalytics

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/post_analytics.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostAnalytics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/late-sdk/models/post_analytics.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::PostAnalytics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::PostAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'impressions')
    self.impressions = attributes[:'impressions']
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  end

  if attributes.key?(:'likes')
    self.likes = attributes[:'likes']
  end

  if attributes.key?(:'comments')
    self.comments = attributes[:'comments']
  end

  if attributes.key?(:'shares')
    self.shares = attributes[:'shares']
  end

  if attributes.key?(:'saves')
    self.saves = attributes[:'saves']
  end

  if attributes.key?(:'clicks')
    self.clicks = attributes[:'clicks']
  end

  if attributes.key?(:'views')
    self.views = attributes[:'views']
  end

  if attributes.key?(:'engagement_rate')
    self.engagement_rate = attributes[:'engagement_rate']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end
end

Instance Attribute Details

#clicksObject

Returns the value of attribute clicks.



31
32
33
# File 'lib/late-sdk/models/post_analytics.rb', line 31

def clicks
  @clicks
end

#commentsObject

Returns the value of attribute comments.



24
25
26
# File 'lib/late-sdk/models/post_analytics.rb', line 24

def comments
  @comments
end

#engagement_rateObject

Returns the value of attribute engagement_rate.



35
36
37
# File 'lib/late-sdk/models/post_analytics.rb', line 35

def engagement_rate
  @engagement_rate
end

#impressionsObject

Returns the value of attribute impressions.



18
19
20
# File 'lib/late-sdk/models/post_analytics.rb', line 18

def impressions
  @impressions
end

#last_updatedObject

Returns the value of attribute last_updated.



37
38
39
# File 'lib/late-sdk/models/post_analytics.rb', line 37

def last_updated
  @last_updated
end

#likesObject

Returns the value of attribute likes.



22
23
24
# File 'lib/late-sdk/models/post_analytics.rb', line 22

def likes
  @likes
end

#reachObject

Returns the value of attribute reach.



20
21
22
# File 'lib/late-sdk/models/post_analytics.rb', line 20

def reach
  @reach
end

#savesObject

Number of saves/bookmarks (Instagram, Pinterest)



29
30
31
# File 'lib/late-sdk/models/post_analytics.rb', line 29

def saves
  @saves
end

#sharesObject

Returns the value of attribute shares.



26
27
28
# File 'lib/late-sdk/models/post_analytics.rb', line 26

def shares
  @shares
end

#viewsObject

Returns the value of attribute views.



33
34
35
# File 'lib/late-sdk/models/post_analytics.rb', line 33

def views
  @views
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/late-sdk/models/post_analytics.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/late-sdk/models/post_analytics.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/late-sdk/models/post_analytics.rb', line 40

def self.attribute_map
  {
    :'impressions' => :'impressions',
    :'reach' => :'reach',
    :'likes' => :'likes',
    :'comments' => :'comments',
    :'shares' => :'shares',
    :'saves' => :'saves',
    :'clicks' => :'clicks',
    :'views' => :'views',
    :'engagement_rate' => :'engagementRate',
    :'last_updated' => :'lastUpdated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/late-sdk/models/post_analytics.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/late-sdk/models/post_analytics.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/late-sdk/models/post_analytics.rb', line 66

def self.openapi_types
  {
    :'impressions' => :'Integer',
    :'reach' => :'Integer',
    :'likes' => :'Integer',
    :'comments' => :'Integer',
    :'shares' => :'Integer',
    :'saves' => :'Integer',
    :'clicks' => :'Integer',
    :'views' => :'Integer',
    :'engagement_rate' => :'Float',
    :'last_updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/late-sdk/models/post_analytics.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      impressions == o.impressions &&
      reach == o.reach &&
      likes == o.likes &&
      comments == o.comments &&
      shares == o.shares &&
      saves == o.saves &&
      clicks == o.clicks &&
      views == o.views &&
      engagement_rate == o.engagement_rate &&
      last_updated == o.last_updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/late-sdk/models/post_analytics.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/late-sdk/models/post_analytics.rb', line 184

def hash
  [impressions, reach, likes, comments, shares, saves, clicks, views, engagement_rate, last_updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
# File 'lib/late-sdk/models/post_analytics.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/late-sdk/models/post_analytics.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
# File 'lib/late-sdk/models/post_analytics.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end