Class: Late::PostsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/late-sdk/api/posts_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ PostsApi

Returns a new instance of PostsApi.



19
20
21
# File 'lib/late-sdk/api/posts_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/late-sdk/api/posts_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#bulk_upload_posts(opts = {}) ⇒ BulkUploadPosts200Response

Bulk upload from CSV Create multiple posts by uploading a CSV file. Use dryRun=true to validate without creating posts.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :dry_run (Boolean) — default: default to false
  • :file (File)

Returns:



28
29
30
31
# File 'lib/late-sdk/api/posts_api.rb', line 28

def bulk_upload_posts(opts = {})
  data, _status_code, _headers = bulk_upload_posts_with_http_info(opts)
  data
end

#bulk_upload_posts_with_http_info(opts = {}) ⇒ Array<(BulkUploadPosts200Response, Integer, Hash)>

Bulk upload from CSV Create multiple posts by uploading a CSV file. Use dryRun&#x3D;true to validate without creating posts.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :dry_run (Boolean) — default: default to false
  • :file (File)

Returns:

  • (Array<(BulkUploadPosts200Response, Integer, Hash)>)

    BulkUploadPosts200Response data, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/late-sdk/api/posts_api.rb', line 39

def bulk_upload_posts_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.bulk_upload_posts ...'
  end
  # resource path
  local_var_path = '/v1/posts/bulk-upload'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'dryRun'] = opts[:'dry_run'] if !opts[:'dry_run'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['file'] = opts[:'file'] if !opts[:'file'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BulkUploadPosts200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.bulk_upload_posts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#bulk_upload_posts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_post(create_post_request, opts = {}) ⇒ PostCreateResponse

Create post Create and optionally publish a post. Immediate posts (publishNow: true) include platformPostUrl in the response. Content is optional when media is attached or all platforms have customContent. See each platform’s schema for media constraints.

Parameters:

  • create_post_request (CreatePostRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



95
96
97
98
# File 'lib/late-sdk/api/posts_api.rb', line 95

def create_post(create_post_request, opts = {})
  data, _status_code, _headers = create_post_with_http_info(create_post_request, opts)
  data
end

#create_post_with_http_info(create_post_request, opts = {}) ⇒ Array<(PostCreateResponse, Integer, Hash)>

Create post Create and optionally publish a post. Immediate posts (publishNow: true) include platformPostUrl in the response. Content is optional when media is attached or all platforms have customContent. See each platform&#39;s schema for media constraints.

Parameters:

  • create_post_request (CreatePostRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PostCreateResponse, Integer, Hash)>)

    PostCreateResponse data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/late-sdk/api/posts_api.rb', line 105

def create_post_with_http_info(create_post_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.create_post ...'
  end
  # verify the required parameter 'create_post_request' is set
  if @api_client.config.client_side_validation && create_post_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_post_request' when calling PostsApi.create_post"
  end
  # resource path
  local_var_path = '/v1/posts'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_post_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PostCreateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.create_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#create_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_post(post_id, opts = {}) ⇒ PostDeleteResponse

Delete post Delete a draft or scheduled post from Late. Published posts cannot be deleted; use the Unpublish endpoint instead. Upload quota is automatically refunded.

Parameters:

  • post_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



163
164
165
166
# File 'lib/late-sdk/api/posts_api.rb', line 163

def delete_post(post_id, opts = {})
  data, _status_code, _headers = delete_post_with_http_info(post_id, opts)
  data
end

#delete_post_with_http_info(post_id, opts = {}) ⇒ Array<(PostDeleteResponse, Integer, Hash)>

Delete post Delete a draft or scheduled post from Late. Published posts cannot be deleted; use the Unpublish endpoint instead. Upload quota is automatically refunded.

Parameters:

  • post_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PostDeleteResponse, Integer, Hash)>)

    PostDeleteResponse data, response status code and response headers



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/late-sdk/api/posts_api.rb', line 173

def delete_post_with_http_info(post_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.delete_post ...'
  end
  # verify the required parameter 'post_id' is set
  if @api_client.config.client_side_validation && post_id.nil?
    fail ArgumentError, "Missing the required parameter 'post_id' when calling PostsApi.delete_post"
  end
  # resource path
  local_var_path = '/v1/posts/{postId}'.sub('{' + 'postId' + '}', CGI.escape(post_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PostDeleteResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.delete_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#delete_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_post(post_id, opts = {}) ⇒ PostGetResponse

Get post Fetch a single post by ID. For published posts, this returns platformPostUrl for each platform.

Parameters:

  • post_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



226
227
228
229
# File 'lib/late-sdk/api/posts_api.rb', line 226

def get_post(post_id, opts = {})
  data, _status_code, _headers = get_post_with_http_info(post_id, opts)
  data
end

#get_post_with_http_info(post_id, opts = {}) ⇒ Array<(PostGetResponse, Integer, Hash)>

Get post Fetch a single post by ID. For published posts, this returns platformPostUrl for each platform.

Parameters:

  • post_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PostGetResponse, Integer, Hash)>)

    PostGetResponse data, response status code and response headers



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/late-sdk/api/posts_api.rb', line 236

def get_post_with_http_info(post_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.get_post ...'
  end
  # verify the required parameter 'post_id' is set
  if @api_client.config.client_side_validation && post_id.nil?
    fail ArgumentError, "Missing the required parameter 'post_id' when calling PostsApi.get_post"
  end
  # resource path
  local_var_path = '/v1/posts/{postId}'.sub('{' + 'postId' + '}', CGI.escape(post_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PostGetResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.get_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#get_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_posts(opts = {}) ⇒ PostsListResponse

List posts Returns a paginated list of posts. Published posts include platformPostUrl with the public URL on each platform.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (1-based) (default to 1)

  • :limit (Integer)

    Page size (default to 10)

  • :status (String)
  • :platform (String)
  • :profile_id (String)
  • :created_by (String)
  • :date_from (Date)
  • :date_to (Date)
  • :include_hidden (Boolean) — default: default to false
  • :search (String)

    Search posts by text content.

  • :sort_by (String)

    Sort order for results. (default to ‘scheduled-desc’)

Returns:



299
300
301
302
# File 'lib/late-sdk/api/posts_api.rb', line 299

def list_posts(opts = {})
  data, _status_code, _headers = list_posts_with_http_info(opts)
  data
end

#list_posts_with_http_info(opts = {}) ⇒ Array<(PostsListResponse, Integer, Hash)>

List posts Returns a paginated list of posts. Published posts include platformPostUrl with the public URL on each platform.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page (Integer)

    Page number (1-based) (default to 1)

  • :limit (Integer)

    Page size (default to 10)

  • :status (String)
  • :platform (String)
  • :profile_id (String)
  • :created_by (String)
  • :date_from (Date)
  • :date_to (Date)
  • :include_hidden (Boolean) — default: default to false
  • :search (String)

    Search posts by text content.

  • :sort_by (String)

    Sort order for results. (default to ‘scheduled-desc’)

Returns:

  • (Array<(PostsListResponse, Integer, Hash)>)

    PostsListResponse data, response status code and response headers



319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/late-sdk/api/posts_api.rb', line 319

def list_posts_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.list_posts ...'
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling PostsApi.list_posts, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling PostsApi.list_posts, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling PostsApi.list_posts, must be greater than or equal to 1.'
  end

  allowable_values = ["draft", "scheduled", "published", "failed"]
  if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status'])
    fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}"
  end
  allowable_values = ["scheduled-desc", "scheduled-asc", "created-desc", "created-asc", "status", "platform"]
  if @api_client.config.client_side_validation && opts[:'sort_by'] && !allowable_values.include?(opts[:'sort_by'])
    fail ArgumentError, "invalid value for \"sort_by\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/v1/posts'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil?
  query_params[:'platform'] = opts[:'platform'] if !opts[:'platform'].nil?
  query_params[:'profileId'] = opts[:'profile_id'] if !opts[:'profile_id'].nil?
  query_params[:'createdBy'] = opts[:'created_by'] if !opts[:'created_by'].nil?
  query_params[:'dateFrom'] = opts[:'date_from'] if !opts[:'date_from'].nil?
  query_params[:'dateTo'] = opts[:'date_to'] if !opts[:'date_to'].nil?
  query_params[:'includeHidden'] = opts[:'include_hidden'] if !opts[:'include_hidden'].nil?
  query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil?
  query_params[:'sortBy'] = opts[:'sort_by'] if !opts[:'sort_by'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PostsListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.list_posts",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#list_posts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#retry_post(post_id, opts = {}) ⇒ PostRetryResponse

Retry failed post Immediately retries publishing a failed post. Returns the updated post with its new status.

Parameters:

  • post_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



399
400
401
402
# File 'lib/late-sdk/api/posts_api.rb', line 399

def retry_post(post_id, opts = {})
  data, _status_code, _headers = retry_post_with_http_info(post_id, opts)
  data
end

#retry_post_with_http_info(post_id, opts = {}) ⇒ Array<(PostRetryResponse, Integer, Hash)>

Retry failed post Immediately retries publishing a failed post. Returns the updated post with its new status.

Parameters:

  • post_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PostRetryResponse, Integer, Hash)>)

    PostRetryResponse data, response status code and response headers



409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
# File 'lib/late-sdk/api/posts_api.rb', line 409

def retry_post_with_http_info(post_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.retry_post ...'
  end
  # verify the required parameter 'post_id' is set
  if @api_client.config.client_side_validation && post_id.nil?
    fail ArgumentError, "Missing the required parameter 'post_id' when calling PostsApi.retry_post"
  end
  # resource path
  local_var_path = '/v1/posts/{postId}/retry'.sub('{' + 'postId' + '}', CGI.escape(post_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PostRetryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.retry_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#retry_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#unpublish_post(post_id, unpublish_post_request, opts = {}) ⇒ UnpublishPost200Response

Unpublish post Deletes a published post from the specified platform. The post record in Late is kept but its status is updated to cancelled. Not supported on Instagram, TikTok, or Snapchat. Threaded posts delete all items. YouTube deletion is permanent.

Parameters:

  • post_id (String)
  • unpublish_post_request (UnpublishPostRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



463
464
465
466
# File 'lib/late-sdk/api/posts_api.rb', line 463

def unpublish_post(post_id, unpublish_post_request, opts = {})
  data, _status_code, _headers = unpublish_post_with_http_info(post_id, unpublish_post_request, opts)
  data
end

#unpublish_post_with_http_info(post_id, unpublish_post_request, opts = {}) ⇒ Array<(UnpublishPost200Response, Integer, Hash)>

Unpublish post Deletes a published post from the specified platform. The post record in Late is kept but its status is updated to cancelled. Not supported on Instagram, TikTok, or Snapchat. Threaded posts delete all items. YouTube deletion is permanent.

Parameters:

  • post_id (String)
  • unpublish_post_request (UnpublishPostRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UnpublishPost200Response, Integer, Hash)>)

    UnpublishPost200Response data, response status code and response headers



474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
# File 'lib/late-sdk/api/posts_api.rb', line 474

def unpublish_post_with_http_info(post_id, unpublish_post_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.unpublish_post ...'
  end
  # verify the required parameter 'post_id' is set
  if @api_client.config.client_side_validation && post_id.nil?
    fail ArgumentError, "Missing the required parameter 'post_id' when calling PostsApi.unpublish_post"
  end
  # verify the required parameter 'unpublish_post_request' is set
  if @api_client.config.client_side_validation && unpublish_post_request.nil?
    fail ArgumentError, "Missing the required parameter 'unpublish_post_request' when calling PostsApi.unpublish_post"
  end
  # resource path
  local_var_path = '/v1/posts/{postId}/unpublish'.sub('{' + 'postId' + '}', CGI.escape(post_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(unpublish_post_request)

  # return_type
  return_type = opts[:debug_return_type] || 'UnpublishPost200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.unpublish_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#unpublish_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_post(post_id, update_post_request, opts = {}) ⇒ PostUpdateResponse

Update post Update an existing post. Only draft, scheduled, failed, and partial posts can be edited. Published, publishing, and cancelled posts cannot be modified.

Parameters:

  • post_id (String)
  • update_post_request (UpdatePostRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



537
538
539
540
# File 'lib/late-sdk/api/posts_api.rb', line 537

def update_post(post_id, update_post_request, opts = {})
  data, _status_code, _headers = update_post_with_http_info(post_id, update_post_request, opts)
  data
end

#update_post_with_http_info(post_id, update_post_request, opts = {}) ⇒ Array<(PostUpdateResponse, Integer, Hash)>

Update post Update an existing post. Only draft, scheduled, failed, and partial posts can be edited. Published, publishing, and cancelled posts cannot be modified.

Parameters:

  • post_id (String)
  • update_post_request (UpdatePostRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PostUpdateResponse, Integer, Hash)>)

    PostUpdateResponse data, response status code and response headers



548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/late-sdk/api/posts_api.rb', line 548

def update_post_with_http_info(post_id, update_post_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: PostsApi.update_post ...'
  end
  # verify the required parameter 'post_id' is set
  if @api_client.config.client_side_validation && post_id.nil?
    fail ArgumentError, "Missing the required parameter 'post_id' when calling PostsApi.update_post"
  end
  # verify the required parameter 'update_post_request' is set
  if @api_client.config.client_side_validation && update_post_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_post_request' when calling PostsApi.update_post"
  end
  # resource path
  local_var_path = '/v1/posts/{postId}'.sub('{' + 'postId' + '}', CGI.escape(post_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_post_request)

  # return_type
  return_type = opts[:debug_return_type] || 'PostUpdateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"PostsApi.update_post",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: PostsApi#update_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end