Class: Late::SearchReddit200ResponsePostsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/late-sdk/models/search_reddit200_response_posts_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SearchReddit200ResponsePostsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::SearchReddit200ResponsePostsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::SearchReddit200ResponsePostsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'selftext')
    self.selftext = attributes[:'selftext']
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  end

  if attributes.key?(:'subreddit')
    self.subreddit = attributes[:'subreddit']
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'num_comments')
    self.num_comments = attributes[:'num_comments']
  end

  if attributes.key?(:'created_utc')
    self.created_utc = attributes[:'created_utc']
  end

  if attributes.key?(:'permalink')
    self.permalink = attributes[:'permalink']
  end
end

Instance Attribute Details

#authorObject

Returns the value of attribute author.



24
25
26
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 24

def author
  @author
end

#created_utcObject

Returns the value of attribute created_utc.



32
33
34
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 32

def created_utc
  @created_utc
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 18

def id
  @id
end

#num_commentsObject

Returns the value of attribute num_comments.



30
31
32
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 30

def num_comments
  @num_comments
end

Returns the value of attribute permalink.



34
35
36
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 34

def permalink
  @permalink
end

#scoreObject

Returns the value of attribute score.



28
29
30
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 28

def score
  @score
end

#selftextObject

Returns the value of attribute selftext.



22
23
24
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 22

def selftext
  @selftext
end

#subredditObject

Returns the value of attribute subreddit.



26
27
28
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 26

def subreddit
  @subreddit
end

#titleObject

Returns the value of attribute title.



20
21
22
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 20

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'title' => :'title',
    :'selftext' => :'selftext',
    :'author' => :'author',
    :'subreddit' => :'subreddit',
    :'score' => :'score',
    :'num_comments' => :'num_comments',
    :'created_utc' => :'created_utc',
    :'permalink' => :'permalink'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 62

def self.openapi_types
  {
    :'id' => :'String',
    :'title' => :'String',
    :'selftext' => :'String',
    :'author' => :'String',
    :'subreddit' => :'String',
    :'score' => :'Integer',
    :'num_comments' => :'Integer',
    :'created_utc' => :'Float',
    :'permalink' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      title == o.title &&
      selftext == o.selftext &&
      author == o.author &&
      subreddit == o.subreddit &&
      score == o.score &&
      num_comments == o.num_comments &&
      created_utc == o.created_utc &&
      permalink == o.permalink
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 174

def hash
  [id, title, selftext, author, subreddit, score, num_comments, created_utc, permalink].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
# File 'lib/late-sdk/models/search_reddit200_response_posts_inner.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end