Class: Late::SendWhatsAppBulkRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::SendWhatsAppBulkRequest
- Defined in:
- lib/late-sdk/models/send_whats_app_bulk_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
WhatsApp social account ID.
-
#recipients ⇒ Object
List of recipients (max 100).
-
#template ⇒ Object
Returns the value of attribute template.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendWhatsAppBulkRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendWhatsAppBulkRequest
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::SendWhatsAppBulkRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::SendWhatsAppBulkRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'recipients') if (value = attributes[:'recipients']).is_a?(Array) self.recipients = value end else self.recipients = nil end if attributes.key?(:'template') self.template = attributes[:'template'] else self.template = nil end end |
Instance Attribute Details
#account_id ⇒ Object
WhatsApp social account ID
19 20 21 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 19 def account_id @account_id end |
#recipients ⇒ Object
List of recipients (max 100)
22 23 24 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 22 def recipients @recipients end |
#template ⇒ Object
Returns the value of attribute template.
24 25 26 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 24 def template @template end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 27 def self.attribute_map { :'account_id' => :'accountId', :'recipients' => :'recipients', :'template' => :'template' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 46 def self.openapi_types { :'account_id' => :'String', :'recipients' => :'Array<SendWhatsAppBulkRequestRecipientsInner>', :'template' => :'SendWhatsAppBulkRequestTemplate' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && recipients == o.recipients && template == o.template end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 184 def hash [account_id, recipients, template].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 99 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @recipients.nil? invalid_properties.push('invalid value for "recipients", recipients cannot be nil.') end if @recipients.length > 100 invalid_properties.push('invalid value for "recipients", number of items must be less than or equal to 100.') end if @template.nil? invalid_properties.push('invalid value for "template", template cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 127 128 129 130 |
# File 'lib/late-sdk/models/send_whats_app_bulk_request.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @recipients.nil? return false if @recipients.length > 100 return false if @template.nil? true end |