Class: Late::UpdateGoogleBusinessLocationDetailsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/late-sdk/models/update_google_business_location_details_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateGoogleBusinessLocationDetailsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::UpdateGoogleBusinessLocationDetailsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::UpdateGoogleBusinessLocationDetailsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'update_mask')
    self.update_mask = attributes[:'update_mask']
  else
    self.update_mask = nil
  end

  if attributes.key?(:'regular_hours')
    self.regular_hours = attributes[:'regular_hours']
  end

  if attributes.key?(:'special_hours')
    self.special_hours = attributes[:'special_hours']
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  end

  if attributes.key?(:'website_uri')
    self.website_uri = attributes[:'website_uri']
  end

  if attributes.key?(:'phone_numbers')
    self.phone_numbers = attributes[:'phone_numbers']
  end
end

Instance Attribute Details

#phone_numbersObject

Returns the value of attribute phone_numbers.



29
30
31
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 29

def phone_numbers
  @phone_numbers
end

#profileObject

Returns the value of attribute profile.



25
26
27
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 25

def profile
  @profile
end

#regular_hoursObject

Returns the value of attribute regular_hours.



21
22
23
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 21

def regular_hours
  @regular_hours
end

#special_hoursObject

Returns the value of attribute special_hours.



23
24
25
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 23

def special_hours
  @special_hours
end

#update_maskObject

Required. Comma-separated fields to update (e.g. ‘regularHours’, ‘specialHours’, ‘profile.description’)



19
20
21
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 19

def update_mask
  @update_mask
end

#website_uriObject

Returns the value of attribute website_uri.



27
28
29
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 27

def website_uri
  @website_uri
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 32

def self.attribute_map
  {
    :'update_mask' => :'updateMask',
    :'regular_hours' => :'regularHours',
    :'special_hours' => :'specialHours',
    :'profile' => :'profile',
    :'website_uri' => :'websiteUri',
    :'phone_numbers' => :'phoneNumbers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 172

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 54

def self.openapi_types
  {
    :'update_mask' => :'String',
    :'regular_hours' => :'UpdateGoogleBusinessLocationDetailsRequestRegularHours',
    :'special_hours' => :'GetGoogleBusinessLocationDetails200ResponseSpecialHours',
    :'profile' => :'UpdateGoogleBusinessLocationDetailsRequestProfile',
    :'website_uri' => :'String',
    :'phone_numbers' => :'GetGoogleBusinessLocationDetails200ResponsePhoneNumbers'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
155
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      update_mask == o.update_mask &&
      regular_hours == o.regular_hours &&
      special_hours == o.special_hours &&
      profile == o.profile &&
      website_uri == o.website_uri &&
      phone_numbers == o.phone_numbers
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 159

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



165
166
167
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 165

def hash
  [update_mask, regular_hours, special_hours, profile, website_uri, phone_numbers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @update_mask.nil?
    invalid_properties.push('invalid value for "update_mask", update_mask cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 194

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
132
# File 'lib/late-sdk/models/update_google_business_location_details_request.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @update_mask.nil?
  true
end