Class: Late::UpdatePostMetadataRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::UpdatePostMetadataRequest
- Defined in:
- lib/late-sdk/models/update_post_metadata_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio social account ID (required for direct mode, ignored for post-based mode).
-
#category_id ⇒ Object
YouTube video category ID.
-
#description ⇒ Object
New video description.
-
#platform ⇒ Object
The platform to update metadata on.
-
#privacy_status ⇒ Object
Video privacy setting.
-
#tags ⇒ Object
Array of keyword tags (max 500 characters combined for YouTube).
-
#title ⇒ Object
New video title (max 100 characters for YouTube).
-
#video_id ⇒ Object
YouTube video ID (required for direct mode, ignored for post-based mode).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdatePostMetadataRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdatePostMetadataRequest
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::UpdatePostMetadataRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::UpdatePostMetadataRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'video_id') self.video_id = attributes[:'video_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'category_id') self.category_id = attributes[:'category_id'] end if attributes.key?(:'privacy_status') self.privacy_status = attributes[:'privacy_status'] end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio social account ID (required for direct mode, ignored for post-based mode)
25 26 27 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 25 def account_id @account_id end |
#category_id ⇒ Object
YouTube video category ID
37 38 39 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 37 def category_id @category_id end |
#description ⇒ Object
New video description
31 32 33 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 31 def description @description end |
#platform ⇒ Object
The platform to update metadata on
19 20 21 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 19 def platform @platform end |
#privacy_status ⇒ Object
Video privacy setting
40 41 42 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 40 def privacy_status @privacy_status end |
#tags ⇒ Object
Array of keyword tags (max 500 characters combined for YouTube)
34 35 36 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 34 def @tags end |
#title ⇒ Object
New video title (max 100 characters for YouTube)
28 29 30 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 28 def title @title end |
#video_id ⇒ Object
YouTube video ID (required for direct mode, ignored for post-based mode)
22 23 24 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 22 def video_id @video_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 65 def self.attribute_map { :'platform' => :'platform', :'video_id' => :'videoId', :'account_id' => :'accountId', :'title' => :'title', :'description' => :'description', :'tags' => :'tags', :'category_id' => :'categoryId', :'privacy_status' => :'privacyStatus' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 254 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 89 def self.openapi_types { :'platform' => :'String', :'video_id' => :'String', :'account_id' => :'String', :'title' => :'String', :'description' => :'String', :'tags' => :'Array<String>', :'category_id' => :'String', :'privacy_status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && video_id == o.video_id && account_id == o.account_id && title == o.title && description == o.description && == o. && category_id == o.category_id && privacy_status == o.privacy_status end |
#eql?(o) ⇒ Boolean
241 242 243 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 241 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
247 248 249 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 247 def hash [platform, video_id, account_id, title, description, , category_id, privacy_status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if !@title.nil? && @title.to_s.length > 100 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 100.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/late-sdk/models/update_post_metadata_request.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @platform.nil? platform_validator = EnumAttributeValidator.new('String', ["youtube"]) return false unless platform_validator.valid?(@platform) return false if !@title.nil? && @title.to_s.length > 100 privacy_status_validator = EnumAttributeValidator.new('String', ["public", "private", "unlisted"]) return false unless privacy_status_validator.valid?(@privacy_status) true end |