Class: Late::UpdateWhatsAppContact200ResponseContact
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::UpdateWhatsAppContact200ResponseContact
- Defined in:
- lib/late-sdk/models/update_whats_app_contact200_response_contact.rb
Instance Attribute Summary collapse
-
#company ⇒ Object
Returns the value of attribute company.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#email ⇒ Object
Returns the value of attribute email.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_blocked ⇒ Object
Returns the value of attribute is_blocked.
-
#is_opted_in ⇒ Object
Returns the value of attribute is_opted_in.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWhatsAppContact200ResponseContact
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWhatsAppContact200ResponseContact
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::UpdateWhatsAppContact200ResponseContact` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::UpdateWhatsAppContact200ResponseContact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'is_opted_in') self.is_opted_in = attributes[:'is_opted_in'] end if attributes.key?(:'is_blocked') self.is_blocked = attributes[:'is_blocked'] end if attributes.key?(:'custom_fields') self.custom_fields = attributes[:'custom_fields'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#company ⇒ Object
Returns the value of attribute company.
26 27 28 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 26 def company @company end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
36 37 38 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 36 def custom_fields @custom_fields end |
#email ⇒ Object
Returns the value of attribute email.
24 25 26 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 24 def email @email end |
#groups ⇒ Object
Returns the value of attribute groups.
30 31 32 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 30 def groups @groups end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 18 def id @id end |
#is_blocked ⇒ Object
Returns the value of attribute is_blocked.
34 35 36 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 34 def is_blocked @is_blocked end |
#is_opted_in ⇒ Object
Returns the value of attribute is_opted_in.
32 33 34 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 32 def is_opted_in @is_opted_in end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 22 def name @name end |
#notes ⇒ Object
Returns the value of attribute notes.
38 39 40 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 38 def notes @notes end |
#phone ⇒ Object
Returns the value of attribute phone.
20 21 22 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 20 def phone @phone end |
#tags ⇒ Object
Returns the value of attribute tags.
28 29 30 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 28 def @tags end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
40 41 42 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 40 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 43 def self.attribute_map { :'id' => :'id', :'phone' => :'phone', :'name' => :'name', :'email' => :'email', :'company' => :'company', :'tags' => :'tags', :'groups' => :'groups', :'is_opted_in' => :'isOptedIn', :'is_blocked' => :'isBlocked', :'custom_fields' => :'customFields', :'notes' => :'notes', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 212 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 71 def self.openapi_types { :'id' => :'String', :'phone' => :'String', :'name' => :'String', :'email' => :'String', :'company' => :'String', :'tags' => :'Array<String>', :'groups' => :'Array<String>', :'is_opted_in' => :'Boolean', :'is_blocked' => :'Boolean', :'custom_fields' => :'Object', :'notes' => :'String', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && phone == o.phone && name == o.name && email == o.email && company == o.company && == o. && groups == o.groups && is_opted_in == o.is_opted_in && is_blocked == o.is_blocked && custom_fields == o.custom_fields && notes == o.notes && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
199 200 201 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 199 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
205 206 207 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 205 def hash [id, phone, name, email, company, , groups, is_opted_in, is_blocked, custom_fields, notes, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 234 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 |
# File 'lib/late-sdk/models/update_whats_app_contact200_response_contact.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |