Class: Late::WebhookPayloadMessage

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/webhook_payload_message.rb

Overview

Webhook payload for message received events (DMs from Instagram, Facebook, Telegram, Bluesky, Reddit)

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::WebhookPayloadMessage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::WebhookPayloadMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'conversation')
    self.conversation = attributes[:'conversation']
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



25
26
27
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 25

def 
  @account
end

#conversationObject

Returns the value of attribute conversation.



23
24
25
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 23

def conversation
  @conversation
end

#eventObject

Returns the value of attribute event.



19
20
21
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 19

def event
  @event
end

#messageObject

Returns the value of attribute message.



21
22
23
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 21

def message
  @message
end

#metadataObject

Returns the value of attribute metadata.



27
28
29
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 27

def 
  @metadata
end

#timestampObject

Returns the value of attribute timestamp.



29
30
31
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 29

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 54

def self.attribute_map
  {
    :'event' => :'event',
    :'message' => :'message',
    :'conversation' => :'conversation',
    :'account' => :'account',
    :'metadata' => :'metadata',
    :'timestamp' => :'timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 76

def self.openapi_types
  {
    :'event' => :'String',
    :'message' => :'WebhookPayloadMessageMessage',
    :'conversation' => :'WebhookPayloadMessageConversation',
    :'account' => :'WebhookPayloadMessageAccount',
    :'metadata' => :'WebhookPayloadMessageMetadata',
    :'timestamp' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



163
164
165
166
167
168
169
170
171
172
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      event == o.event &&
      message == o.message &&
      conversation == o.conversation &&
       == o. &&
       == o. &&
      timestamp == o.timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 182

def hash
  [event, message, conversation, , , timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
149
# File 'lib/late-sdk/models/webhook_payload_message.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  event_validator = EnumAttributeValidator.new('String', ["message.received"])
  return false unless event_validator.valid?(@event)
  true
end