Class: Zernio::AccountWithFollowerStatsAllOfAccountStats

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb

Overview

Platform-specific account stats from the latest daily snapshot. Fields vary by platform. Only present if metadata has been captured.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountWithFollowerStatsAllOfAccountStats

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AccountWithFollowerStatsAllOfAccountStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AccountWithFollowerStatsAllOfAccountStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'following_count')
    self.following_count = attributes[:'following_count']
  end

  if attributes.key?(:'media_count')
    self.media_count = attributes[:'media_count']
  end

  if attributes.key?(:'video_count')
    self.video_count = attributes[:'video_count']
  end

  if attributes.key?(:'tweet_count')
    self.tweet_count = attributes[:'tweet_count']
  end

  if attributes.key?(:'posts_count')
    self.posts_count = attributes[:'posts_count']
  end

  if attributes.key?(:'pin_count')
    self.pin_count = attributes[:'pin_count']
  end

  if attributes.key?(:'total_views')
    self.total_views = attributes[:'total_views']
  end

  if attributes.key?(:'likes_count')
    self.likes_count = attributes[:'likes_count']
  end

  if attributes.key?(:'monthly_views')
    self.monthly_views = attributes[:'monthly_views']
  end

  if attributes.key?(:'listed_count')
    self.listed_count = attributes[:'listed_count']
  end

  if attributes.key?(:'board_count')
    self.board_count = attributes[:'board_count']
  end
end

Instance Attribute Details

#board_countObject

Total boards (Pinterest)



50
51
52
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 50

def board_count
  @board_count
end

#following_countObject

Number of accounts being followed



20
21
22
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 20

def following_count
  @following_count
end

#likes_countObject

Total likes received (TikTok)



41
42
43
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 41

def likes_count
  @likes_count
end

#listed_countObject

Lists the user appears on (X/Twitter)



47
48
49
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 47

def listed_count
  @listed_count
end

#media_countObject

Total media posts (Instagram)



23
24
25
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 23

def media_count
  @media_count
end

#monthly_viewsObject

Monthly profile views (Pinterest)



44
45
46
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 44

def monthly_views
  @monthly_views
end

#pin_countObject

Total pins (Pinterest)



35
36
37
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 35

def pin_count
  @pin_count
end

#posts_countObject

Total posts (Bluesky)



32
33
34
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 32

def posts_count
  @posts_count
end

#total_viewsObject

Total channel views (YouTube)



38
39
40
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 38

def total_views
  @total_views
end

#tweet_countObject

Total tweets (X/Twitter)



29
30
31
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 29

def tweet_count
  @tweet_count
end

#video_countObject

Total videos (YouTube, TikTok)



26
27
28
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 26

def video_count
  @video_count
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 53

def self.attribute_map
  {
    :'following_count' => :'followingCount',
    :'media_count' => :'mediaCount',
    :'video_count' => :'videoCount',
    :'tweet_count' => :'tweetCount',
    :'posts_count' => :'postsCount',
    :'pin_count' => :'pinCount',
    :'total_views' => :'totalViews',
    :'likes_count' => :'likesCount',
    :'monthly_views' => :'monthlyViews',
    :'listed_count' => :'listedCount',
    :'board_count' => :'boardCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 80

def self.openapi_types
  {
    :'following_count' => :'Float',
    :'media_count' => :'Float',
    :'video_count' => :'Float',
    :'tweet_count' => :'Float',
    :'posts_count' => :'Float',
    :'pin_count' => :'Float',
    :'total_views' => :'Float',
    :'likes_count' => :'Float',
    :'monthly_views' => :'Float',
    :'listed_count' => :'Float',
    :'board_count' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      following_count == o.following_count &&
      media_count == o.media_count &&
      video_count == o.video_count &&
      tweet_count == o.tweet_count &&
      posts_count == o.posts_count &&
      pin_count == o.pin_count &&
      total_views == o.total_views &&
      likes_count == o.likes_count &&
      monthly_views == o.monthly_views &&
      listed_count == o.listed_count &&
      board_count == o.board_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 204

def hash
  [following_count, media_count, video_count, tweet_count, posts_count, pin_count, total_views, likes_count, monthly_views, listed_count, board_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
# File 'lib/zernio-sdk/models/account_with_follower_stats_all_of_account_stats.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end