Class: Zernio::AdCampaignBudget

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/ad_campaign_budget.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdCampaignBudget

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AdCampaignBudget` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AdCampaignBudget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'amount')
    self.amount = attributes[:'amount']
  else
    self.amount = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'amount_micros')
    self.amount_micros = attributes[:'amount_micros']
  end

  if attributes.key?(:'explicitly_shared')
    self.explicitly_shared = attributes[:'explicitly_shared']
  end

  if attributes.key?(:'resource_name')
    self.resource_name = attributes[:'resource_name']
  end

  if attributes.key?(:'delivery_method')
    self.delivery_method = attributes[:'delivery_method']
  end
end

Instance Attribute Details

#amountObject

Returns the value of attribute amount.



18
19
20
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 18

def amount
  @amount
end

#amount_microsObject

Google only. Exact decimal micros; DAILY uses amount_micros and CUSTOM_PERIOD uses total_amount_micros.



23
24
25
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 23

def amount_micros
  @amount_micros
end

#delivery_methodObject

Google only. campaign_budget.delivery_method, typically STANDARD, or null when unavailable.



32
33
34
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 32

def delivery_method
  @delivery_method
end

#explicitly_sharedObject

Google only. True for a shared budget; null when unavailable. Shared writes require allowSharedBudgetUpdate=true; unknown sharing status cannot be overridden.



26
27
28
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 26

def explicitly_shared
  @explicitly_shared
end

#resource_nameObject

Google only. campaign_budget.resource_name, or null when unavailable.



29
30
31
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 29

def resource_name
  @resource_name
end

#typeObject

Returns the value of attribute type.



20
21
22
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 57

def self.attribute_map
  {
    :'amount' => :'amount',
    :'type' => :'type',
    :'amount_micros' => :'amountMicros',
    :'explicitly_shared' => :'explicitlyShared',
    :'resource_name' => :'resourceName',
    :'delivery_method' => :'deliveryMethod'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 247

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



100
101
102
103
104
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 100

def self.openapi_all_of
  [
  :'AdBudget'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 91

def self.openapi_nullable
  Set.new([
    :'explicitly_shared',
    :'resource_name',
    :'delivery_method'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 79

def self.openapi_types
  {
    :'amount' => :'Float',
    :'type' => :'String',
    :'amount_micros' => :'String',
    :'explicitly_shared' => :'Boolean',
    :'resource_name' => :'String',
    :'delivery_method' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      amount == o.amount &&
      type == o.type &&
      amount_micros == o.amount_micros &&
      explicitly_shared == o.explicitly_shared &&
      resource_name == o.resource_name &&
      delivery_method == o.delivery_method
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 240

def hash
  [amount, type, amount_micros, explicitly_shared, resource_name, delivery_method].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @amount.nil?
    invalid_properties.push('invalid value for "amount", amount cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@amount_micros.nil? && @amount_micros !~ pattern
    invalid_properties.push("invalid value for \"amount_micros\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 269

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
# File 'lib/zernio-sdk/models/ad_campaign_budget.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @amount.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["daily", "lifetime"])
  return false unless type_validator.valid?(@type)
  return false if !@amount_micros.nil? && @amount_micros !~ Regexp.new(/^\d+$/)
  true
end