Class: Zernio::AdNegativeKeywordList

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/ad_negative_keyword_list.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdNegativeKeywordList

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AdNegativeKeywordList` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AdNegativeKeywordList`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'resource_name')
    self.resource_name = attributes[:'resource_name']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'member_count')
    self.member_count = attributes[:'member_count']
  end

  if attributes.key?(:'reference_count')
    self.reference_count = attributes[:'reference_count']
  end
end

Instance Attribute Details

#idObject

Google shared set id.



19
20
21
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 19

def id
  @id
end

#member_countObject

Number of keywords in the list.



28
29
30
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 28

def member_count
  @member_count
end

#nameObject

List name.



25
26
27
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 25

def name
  @name
end

#reference_countObject

Number of resources referencing the list.



31
32
33
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 31

def reference_count
  @reference_count
end

#resource_nameObject

Google shared set resource name.



22
23
24
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 22

def resource_name
  @resource_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 34

def self.attribute_map
  {
    :'id' => :'id',
    :'resource_name' => :'resourceName',
    :'name' => :'name',
    :'member_count' => :'memberCount',
    :'reference_count' => :'referenceCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 171

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 55

def self.openapi_types
  {
    :'id' => :'String',
    :'resource_name' => :'String',
    :'name' => :'String',
    :'member_count' => :'Integer',
    :'reference_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      resource_name == o.resource_name &&
      name == o.name &&
      member_count == o.member_count &&
      reference_count == o.reference_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


158
159
160
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 158

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



164
165
166
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 164

def hash
  [id, resource_name, name, member_count, reference_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



110
111
112
113
114
115
116
117
118
119
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 110

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@id.nil? && @id !~ pattern
    invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 193

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
# File 'lib/zernio-sdk/models/ad_negative_keyword_list.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/)
  true
end