Class: Zernio::AdNegativeKeywordListKeyword
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AdNegativeKeywordListKeyword
- Defined in:
- lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#criterion_id ⇒ Object
Google shared criterion id.
-
#match_type ⇒ Object
Returns the value of attribute match_type.
-
#text ⇒ Object
Keyword text.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdNegativeKeywordListKeyword
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdNegativeKeywordListKeyword
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AdNegativeKeywordListKeyword` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AdNegativeKeywordListKeyword`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'criterion_id') self.criterion_id = attributes[:'criterion_id'] end if attributes.key?(:'text') self.text = attributes[:'text'] end if attributes.key?(:'match_type') self.match_type = attributes[:'match_type'] end end |
Instance Attribute Details
#criterion_id ⇒ Object
Google shared criterion id.
19 20 21 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 19 def criterion_id @criterion_id end |
#match_type ⇒ Object
Returns the value of attribute match_type.
24 25 26 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 24 def match_type @match_type end |
#text ⇒ Object
Keyword text.
22 23 24 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 22 def text @text end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 49 def self.attribute_map { :'criterion_id' => :'criterionId', :'text' => :'text', :'match_type' => :'matchType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 68 def self.openapi_types { :'criterion_id' => :'String', :'text' => :'String', :'match_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && criterion_id == o.criterion_id && text == o.text && match_type == o.match_type end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 177 def hash [criterion_id, text, match_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@criterion_id.nil? && @criterion_id !~ pattern invalid_properties.push("invalid value for \"criterion_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 130 131 132 |
# File 'lib/zernio-sdk/models/ad_negative_keyword_list_keyword.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@criterion_id.nil? && @criterion_id !~ Regexp.new(/^\d+$/) match_type_validator = EnumAttributeValidator.new('String', ["broad", "phrase", "exact"]) return false unless match_type_validator.valid?(@match_type) true end |