Class: Zernio::AddBroadcastRecipientsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AddBroadcastRecipientsRequest
- Defined in:
- lib/zernio-sdk/models/add_broadcast_recipients_request.rb
Instance Attribute Summary collapse
-
#contact_ids ⇒ Object
Specific contact IDs to add.
-
#phones ⇒ Object
Raw phone numbers (auto-creates contacts).
-
#use_segment ⇒ Object
Auto-populate from broadcast segment filters.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddBroadcastRecipientsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AddBroadcastRecipientsRequest
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AddBroadcastRecipientsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AddBroadcastRecipientsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'contact_ids') if (value = attributes[:'contact_ids']).is_a?(Array) self.contact_ids = value end end if attributes.key?(:'phones') if (value = attributes[:'phones']).is_a?(Array) self.phones = value end end if attributes.key?(:'use_segment') self.use_segment = attributes[:'use_segment'] end end |
Instance Attribute Details
#contact_ids ⇒ Object
Specific contact IDs to add
19 20 21 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 19 def contact_ids @contact_ids end |
#phones ⇒ Object
Raw phone numbers (auto-creates contacts). Useful for WhatsApp/Telegram manual entry
22 23 24 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 22 def phones @phones end |
#use_segment ⇒ Object
Auto-populate from broadcast segment filters
25 26 27 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 25 def use_segment @use_segment end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 28 def self.attribute_map { :'contact_ids' => :'contactIds', :'phones' => :'phones', :'use_segment' => :'useSegment' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 153 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 47 def self.openapi_types { :'contact_ids' => :'Array<String>', :'phones' => :'Array<String>', :'use_segment' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 130 def ==(o) return true if self.equal?(o) self.class == o.class && contact_ids == o.contact_ids && phones == o.phones && use_segment == o.use_segment end |
#eql?(o) ⇒ Boolean
140 141 142 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 140 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 146 def hash [contact_ids, phones, use_segment].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 101 102 103 104 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@phones.nil? && @phones.length > 20000 invalid_properties.push('invalid value for "phones", number of items must be less than or equal to 20000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
108 109 110 111 112 |
# File 'lib/zernio-sdk/models/add_broadcast_recipients_request.rb', line 108 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@phones.nil? && @phones.length > 20000 true end |