Class: Zernio::AddConversionAssociations200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AddConversionAssociations200Response
- Defined in:
- lib/zernio-sdk/models/add_conversion_associations200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#failed ⇒ Object
Returns the value of attribute failed.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#succeeded ⇒ Object
Numeric campaign IDs that were successfully associated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AddConversionAssociations200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AddConversionAssociations200Response
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AddConversionAssociations200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AddConversionAssociations200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'succeeded') if (value = attributes[:'succeeded']).is_a?(Array) self.succeeded = value end end if attributes.key?(:'failed') if (value = attributes[:'failed']).is_a?(Array) self.failed = value end end end |
Instance Attribute Details
#failed ⇒ Object
Returns the value of attribute failed.
23 24 25 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 23 def failed @failed end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 18 def platform @platform end |
#succeeded ⇒ Object
Numeric campaign IDs that were successfully associated.
21 22 23 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 21 def succeeded @succeeded end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 54 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 48 def self.attribute_map { :'platform' => :'platform', :'succeeded' => :'succeeded', :'failed' => :'failed' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 166 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 67 def self.openapi_types { :'platform' => :'String', :'succeeded' => :'Array<String>', :'failed' => :'Array<AddConversionAssociations200ResponseFailedInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
143 144 145 146 147 148 149 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 143 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && succeeded == o.succeeded && failed == o.failed end |
#eql?(o) ⇒ Boolean
153 154 155 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 153 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 159 def hash [platform, succeeded, failed].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 129 |
# File 'lib/zernio-sdk/models/add_conversion_associations200_response.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["linkedinads"]) return false unless platform_validator.valid?(@platform) true end |