Class: Zernio::AdjustConversionsRequestAdjustmentsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdjustConversionsRequestAdjustmentsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AdjustConversionsRequestAdjustmentsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AdjustConversionsRequestAdjustmentsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'adjustment_type')
    self.adjustment_type = attributes[:'adjustment_type']
  else
    self.adjustment_type = nil
  end

  if attributes.key?(:'adjustment_time')
    self.adjustment_time = attributes[:'adjustment_time']
  else
    self.adjustment_time = nil
  end

  if attributes.key?(:'order_id')
    self.order_id = attributes[:'order_id']
  end

  if attributes.key?(:'gclid')
    self.gclid = attributes[:'gclid']
  end

  if attributes.key?(:'conversion_time')
    self.conversion_time = attributes[:'conversion_time']
  end

  if attributes.key?(:'restatement_value')
    self.restatement_value = attributes[:'restatement_value']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'user_agent')
    self.user_agent = attributes[:'user_agent']
  end
end

Instance Attribute Details

#adjustment_timeObject

When the adjustment occurred, unix seconds.



21
22
23
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 21

def adjustment_time
  @adjustment_time
end

#adjustment_typeObject

Returns the value of attribute adjustment_type.



18
19
20
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 18

def adjustment_type
  @adjustment_type
end

#conversion_timeObject

The original conversion's time, unix seconds. Required when identifying by gclid.



30
31
32
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 30

def conversion_time
  @conversion_time
end

#currencyObject

RESTATEMENT only — ISO 4217 currency for restatementValue.



36
37
38
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 36

def currency
  @currency
end

#gclidObject

Alternative key — the original click ID. Pair with conversionTime. Not valid for ENHANCEMENT.



27
28
29
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 27

def gclid
  @gclid
end

#order_idObject

Transaction ID of the original conversion (the eventId you sent). Recommended; required for ENHANCEMENT.



24
25
26
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 24

def order_id
  @order_id
end

#restatement_valueObject

RESTATEMENT only — the corrected TOTAL conversion value.



33
34
35
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 33

def restatement_value
  @restatement_value
end

#userObject

Returns the value of attribute user.



38
39
40
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 38

def user
  @user
end

#user_agentObject

ENHANCEMENT only — the original conversion's user agent (improves match quality).



41
42
43
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 41

def user_agent
  @user_agent
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 66

def self.attribute_map
  {
    :'adjustment_type' => :'adjustmentType',
    :'adjustment_time' => :'adjustmentTime',
    :'order_id' => :'orderId',
    :'gclid' => :'gclid',
    :'conversion_time' => :'conversionTime',
    :'restatement_value' => :'restatementValue',
    :'currency' => :'currency',
    :'user' => :'user',
    :'user_agent' => :'userAgent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 246

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 91

def self.openapi_types
  {
    :'adjustment_type' => :'String',
    :'adjustment_time' => :'Float',
    :'order_id' => :'String',
    :'gclid' => :'String',
    :'conversion_time' => :'Float',
    :'restatement_value' => :'Float',
    :'currency' => :'String',
    :'user' => :'AdjustConversionsRequestAdjustmentsInnerUser',
    :'user_agent' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      adjustment_type == o.adjustment_type &&
      adjustment_time == o.adjustment_time &&
      order_id == o.order_id &&
      gclid == o.gclid &&
      conversion_time == o.conversion_time &&
      restatement_value == o.restatement_value &&
      currency == o.currency &&
      user == o.user &&
      user_agent == o.user_agent
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 233

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



239
240
241
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 239

def hash
  [adjustment_type, adjustment_time, order_id, gclid, conversion_time, restatement_value, currency, user, user_agent].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @adjustment_type.nil?
    invalid_properties.push('invalid value for "adjustment_type", adjustment_type cannot be nil.')
  end

  if @adjustment_time.nil?
    invalid_properties.push('invalid value for "adjustment_time", adjustment_time cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/adjust_conversions_request_adjustments_inner.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @adjustment_type.nil?
  adjustment_type_validator = EnumAttributeValidator.new('String', ["RETRACTION", "RESTATEMENT", "ENHANCEMENT"])
  return false unless adjustment_type_validator.valid?(@adjustment_type)
  return false if @adjustment_time.nil?
  true
end