Class: Zernio::AnalyticsDeltaEntryMetrics

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/analytics_delta_entry_metrics.rb

Overview

Metrics a platform does not report are 0, not absent.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AnalyticsDeltaEntryMetrics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AnalyticsDeltaEntryMetrics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AnalyticsDeltaEntryMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'impressions')
    self.impressions = attributes[:'impressions']
  else
    self.impressions = nil
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  else
    self.reach = nil
  end

  if attributes.key?(:'likes')
    self.likes = attributes[:'likes']
  else
    self.likes = nil
  end

  if attributes.key?(:'comments')
    self.comments = attributes[:'comments']
  else
    self.comments = nil
  end

  if attributes.key?(:'shares')
    self.shares = attributes[:'shares']
  else
    self.shares = nil
  end

  if attributes.key?(:'saves')
    self.saves = attributes[:'saves']
  else
    self.saves = nil
  end

  if attributes.key?(:'sends')
    self.sends = attributes[:'sends']
  else
    self.sends = nil
  end

  if attributes.key?(:'clicks')
    self.clicks = attributes[:'clicks']
  else
    self.clicks = nil
  end

  if attributes.key?(:'views')
    self.views = attributes[:'views']
  else
    self.views = nil
  end

  if attributes.key?(:'follows')
    self.follows = attributes[:'follows']
  else
    self.follows = nil
  end

  if attributes.key?(:'ig_reels_avg_watch_time')
    self.ig_reels_avg_watch_time = attributes[:'ig_reels_avg_watch_time']
  else
    self.ig_reels_avg_watch_time = nil
  end

  if attributes.key?(:'ig_reels_video_view_total_time')
    self.ig_reels_video_view_total_time = attributes[:'ig_reels_video_view_total_time']
  else
    self.ig_reels_video_view_total_time = nil
  end

  if attributes.key?(:'reposts')
    self.reposts = attributes[:'reposts']
  else
    self.reposts = nil
  end

  if attributes.key?(:'reels_skip_rate')
    self.reels_skip_rate = attributes[:'reels_skip_rate']
  else
    self.reels_skip_rate = nil
  end

  if attributes.key?(:'completion_rate')
    self.completion_rate = attributes[:'completion_rate']
  else
    self.completion_rate = nil
  end

  if attributes.key?(:'profile_views')
    self.profile_views = attributes[:'profile_views']
  else
    self.profile_views = nil
  end

  if attributes.key?(:'website_clicks')
    self.website_clicks = attributes[:'website_clicks']
  else
    self.website_clicks = nil
  end

  if attributes.key?(:'impression_sources')
    if (value = attributes[:'impression_sources']).is_a?(Hash)
      self.impression_sources = value
    end
  else
    self.impression_sources = nil
  end

  if attributes.key?(:'audience_types')
    if (value = attributes[:'audience_types']).is_a?(Hash)
      self.audience_types = value
    end
  else
    self.audience_types = nil
  end
end

Instance Attribute Details

#audience_typesObject

TikTok business lane: follower / nonFollower and newViewer / returnViewer shares, fractions 0 to 1. Empty object elsewhere.



64
65
66
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 64

def audience_types
  @audience_types
end

#clicksObject

Returns the value of attribute clicks.



33
34
35
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 33

def clicks
  @clicks
end

#commentsObject

Returns the value of attribute comments.



25
26
27
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 25

def comments
  @comments
end

#completion_rateObject

TikTok business lane: share of viewers who watched to the end, 0 to 1



52
53
54
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 52

def completion_rate
  @completion_rate
end

#followsObject

Follows attributed to this post (Instagram)



38
39
40
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 38

def follows
  @follows
end

#ig_reels_avg_watch_timeObject

Instagram Reels average watch time, in milliseconds



41
42
43
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 41

def ig_reels_avg_watch_time
  @ig_reels_avg_watch_time
end

#ig_reels_video_view_total_timeObject

Instagram Reels total watch time, in milliseconds



44
45
46
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 44

def ig_reels_video_view_total_time
  @ig_reels_video_view_total_time
end

#impression_sourcesObject

TikTok business lane: share of views by surface (forYou, follow, search, personalProfile, sound, directMessage, other), fractions 0 to 1. Empty object elsewhere.



61
62
63
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 61

def impression_sources
  @impression_sources
end

#impressionsObject

Returns the value of attribute impressions.



19
20
21
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 19

def impressions
  @impressions
end

#likesObject

Returns the value of attribute likes.



23
24
25
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 23

def likes
  @likes
end

#profile_viewsObject

TikTok business lane: profile views attributed to the post



55
56
57
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 55

def profile_views
  @profile_views
end

#reachObject

Returns the value of attribute reach.



21
22
23
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 21

def reach
  @reach
end

#reels_skip_rateObject

Instagram Reels skip rate, 0 to 1



49
50
51
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 49

def reels_skip_rate
  @reels_skip_rate
end

#repostsObject

Returns the value of attribute reposts.



46
47
48
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 46

def reposts
  @reposts
end

#savesObject

Returns the value of attribute saves.



29
30
31
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 29

def saves
  @saves
end

#sendsObject

Returns the value of attribute sends.



31
32
33
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 31

def sends
  @sends
end

#sharesObject

Returns the value of attribute shares.



27
28
29
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 27

def shares
  @shares
end

#viewsObject

Returns the value of attribute views.



35
36
37
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 35

def views
  @views
end

#website_clicksObject

TikTok business lane: website-link clicks attributed to the post (also inside clicks)



58
59
60
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 58

def website_clicks
  @website_clicks
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 67

def self.attribute_map
  {
    :'impressions' => :'impressions',
    :'reach' => :'reach',
    :'likes' => :'likes',
    :'comments' => :'comments',
    :'shares' => :'shares',
    :'saves' => :'saves',
    :'sends' => :'sends',
    :'clicks' => :'clicks',
    :'views' => :'views',
    :'follows' => :'follows',
    :'ig_reels_avg_watch_time' => :'igReelsAvgWatchTime',
    :'ig_reels_video_view_total_time' => :'igReelsVideoViewTotalTime',
    :'reposts' => :'reposts',
    :'reels_skip_rate' => :'reelsSkipRate',
    :'completion_rate' => :'completionRate',
    :'profile_views' => :'profileViews',
    :'website_clicks' => :'websiteClicks',
    :'impression_sources' => :'impressionSources',
    :'audience_types' => :'audienceTypes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 608

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 102

def self.openapi_types
  {
    :'impressions' => :'Integer',
    :'reach' => :'Integer',
    :'likes' => :'Integer',
    :'comments' => :'Integer',
    :'shares' => :'Integer',
    :'saves' => :'Integer',
    :'sends' => :'Integer',
    :'clicks' => :'Integer',
    :'views' => :'Integer',
    :'follows' => :'Integer',
    :'ig_reels_avg_watch_time' => :'Integer',
    :'ig_reels_video_view_total_time' => :'Integer',
    :'reposts' => :'Integer',
    :'reels_skip_rate' => :'Float',
    :'completion_rate' => :'Float',
    :'profile_views' => :'Integer',
    :'website_clicks' => :'Integer',
    :'impression_sources' => :'Hash<String, Float>',
    :'audience_types' => :'Hash<String, Float>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 569

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      impressions == o.impressions &&
      reach == o.reach &&
      likes == o.likes &&
      comments == o.comments &&
      shares == o.shares &&
      saves == o.saves &&
      sends == o.sends &&
      clicks == o.clicks &&
      views == o.views &&
      follows == o.follows &&
      ig_reels_avg_watch_time == o.ig_reels_avg_watch_time &&
      ig_reels_video_view_total_time == o.ig_reels_video_view_total_time &&
      reposts == o.reposts &&
      reels_skip_rate == o.reels_skip_rate &&
      completion_rate == o.completion_rate &&
      profile_views == o.profile_views &&
      website_clicks == o.website_clicks &&
      impression_sources == o.impression_sources &&
      audience_types == o.audience_types
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


595
596
597
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 595

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



601
602
603
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 601

def hash
  [impressions, reach, likes, comments, shares, saves, sends, clicks, views, follows, ig_reels_avg_watch_time, ig_reels_video_view_total_time, reposts, reels_skip_rate, completion_rate, profile_views, website_clicks, impression_sources, audience_types].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 269

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @impressions.nil?
    invalid_properties.push('invalid value for "impressions", impressions cannot be nil.')
  end

  if @reach.nil?
    invalid_properties.push('invalid value for "reach", reach cannot be nil.')
  end

  if @likes.nil?
    invalid_properties.push('invalid value for "likes", likes cannot be nil.')
  end

  if @comments.nil?
    invalid_properties.push('invalid value for "comments", comments cannot be nil.')
  end

  if @shares.nil?
    invalid_properties.push('invalid value for "shares", shares cannot be nil.')
  end

  if @saves.nil?
    invalid_properties.push('invalid value for "saves", saves cannot be nil.')
  end

  if @sends.nil?
    invalid_properties.push('invalid value for "sends", sends cannot be nil.')
  end

  if @clicks.nil?
    invalid_properties.push('invalid value for "clicks", clicks cannot be nil.')
  end

  if @views.nil?
    invalid_properties.push('invalid value for "views", views cannot be nil.')
  end

  if @follows.nil?
    invalid_properties.push('invalid value for "follows", follows cannot be nil.')
  end

  if @ig_reels_avg_watch_time.nil?
    invalid_properties.push('invalid value for "ig_reels_avg_watch_time", ig_reels_avg_watch_time cannot be nil.')
  end

  if @ig_reels_video_view_total_time.nil?
    invalid_properties.push('invalid value for "ig_reels_video_view_total_time", ig_reels_video_view_total_time cannot be nil.')
  end

  if @reposts.nil?
    invalid_properties.push('invalid value for "reposts", reposts cannot be nil.')
  end

  if @reels_skip_rate.nil?
    invalid_properties.push('invalid value for "reels_skip_rate", reels_skip_rate cannot be nil.')
  end

  if @completion_rate.nil?
    invalid_properties.push('invalid value for "completion_rate", completion_rate cannot be nil.')
  end

  if @profile_views.nil?
    invalid_properties.push('invalid value for "profile_views", profile_views cannot be nil.')
  end

  if @website_clicks.nil?
    invalid_properties.push('invalid value for "website_clicks", website_clicks cannot be nil.')
  end

  if @impression_sources.nil?
    invalid_properties.push('invalid value for "impression_sources", impression_sources cannot be nil.')
  end

  if @audience_types.nil?
    invalid_properties.push('invalid value for "audience_types", audience_types cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



630
631
632
633
634
635
636
637
638
639
640
641
642
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 630

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/zernio-sdk/models/analytics_delta_entry_metrics.rb', line 353

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @impressions.nil?
  return false if @reach.nil?
  return false if @likes.nil?
  return false if @comments.nil?
  return false if @shares.nil?
  return false if @saves.nil?
  return false if @sends.nil?
  return false if @clicks.nil?
  return false if @views.nil?
  return false if @follows.nil?
  return false if @ig_reels_avg_watch_time.nil?
  return false if @ig_reels_video_view_total_time.nil?
  return false if @reposts.nil?
  return false if @reels_skip_rate.nil?
  return false if @completion_rate.nil?
  return false if @profile_views.nil?
  return false if @website_clicks.nil?
  return false if @impression_sources.nil?
  return false if @audience_types.nil?
  true
end