Class: Zernio::AnalyticsSinglePostResponse

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/analytics_single_post_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AnalyticsSinglePostResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 166

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AnalyticsSinglePostResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AnalyticsSinglePostResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'post_id')
    self.post_id = attributes[:'post_id']
  end

  if attributes.key?(:'late_post_id')
    self.late_post_id = attributes[:'late_post_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'scheduled_for')
    self.scheduled_for = attributes[:'scheduled_for']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'analytics')
    self.analytics = attributes[:'analytics']
  end

  if attributes.key?(:'platform_analytics')
    if (value = attributes[:'platform_analytics']).is_a?(Array)
      self.platform_analytics = value
    end
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_post_url')
    self.platform_post_url = attributes[:'platform_post_url']
  end

  if attributes.key?(:'is_external')
    self.is_external = attributes[:'is_external']
  end

  if attributes.key?(:'sync_status')
    self.sync_status = attributes[:'sync_status']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  end

  if attributes.key?(:'media_items')
    if (value = attributes[:'media_items']).is_a?(Array)
      self.media_items = value
    end
  end

  if attributes.key?(:'media_product_type')
    self.media_product_type = attributes[:'media_product_type']
  end

  if attributes.key?(:'is_ai_generated')
    self.is_ai_generated = attributes[:'is_ai_generated']
  end

  if attributes.key?(:'is_shared_to_feed')
    self.is_shared_to_feed = attributes[:'is_shared_to_feed']
  end

  if attributes.key?(:'media_audio_type')
    self.media_audio_type = attributes[:'media_audio_type']
  end
end

Instance Attribute Details

#analytics ⇒ Object

Returns the value of attribute analytics.



32
33
34
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 32

def analytics
  @analytics
end

#content ⇒ Object

Returns the value of attribute content.



26
27
28
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 26

def content
  @content
end

#is_ai_generated ⇒ Object

Instagram only: whether Instagram labeled the media as AI-generated. Absent when the platform did not report it.



60
61
62
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 60

def is_ai_generated
  @is_ai_generated
end

#is_external ⇒ Object

Returns the value of attribute is_external.



40
41
42
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 40

def is_external
  @is_external
end

#is_shared_to_feed ⇒ Object

Instagram reels only: whether the reel is also shared to the main feed. Absent when the platform did not report it.



63
64
65
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 63

def is_shared_to_feed
  @is_shared_to_feed
end

#late_post_id ⇒ Object

Original Zernio post ID if scheduled via Zernio



21
22
23
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 21

def late_post_id
  @late_post_id
end

#media_audio_type ⇒ Object

Instagram only: audio type of the media (MUSIC or ORIGINAL_SOUND). Absent when the platform did not report it.



66
67
68
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 66

def media_audio_type
  @media_audio_type
end

#media_items ⇒ Object

All media items for this post. Carousel posts contain one entry per slide. Facebook and Instagram images and video covers whose Meta CDN links expired are re-read and served from Zernio storage (non-expiring). Facebook and Instagram video file URLs, and LinkedIn media URLs, stay the platform's signed links and are refreshed on read once they lapse.



54
55
56
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 54

def media_items
  @media_items
end

#media_product_type ⇒ Object

Instagram only: the platform media product type (e.g. FEED, REELS, STORY, AD). Absent when the platform did not report it.



57
58
59
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 57

def media_product_type
  @media_product_type
end

#media_type ⇒ Object

Returns the value of attribute media_type.



51
52
53
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 51

def media_type
  @media_type
end

#message ⇒ Object

Human-readable status message for pending, partial, or failed states



46
47
48
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 46

def message
  @message
end

#platform ⇒ Object

Returns the value of attribute platform.



36
37
38
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 36

def platform
  @platform
end

#platform_analytics ⇒ Object

Returns the value of attribute platform_analytics.



34
35
36
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 34

def platform_analytics
  @platform_analytics
end

#platform_post_url ⇒ Object

Returns the value of attribute platform_post_url.



38
39
40
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 38

def platform_post_url
  @platform_post_url
end

#post_id ⇒ Object

Returns the value of attribute post_id.



18
19
20
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 18

def post_id
  @post_id
end

#published_at ⇒ Object

Returns the value of attribute published_at.



30
31
32
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 30

def published_at
  @published_at
end

#scheduled_for ⇒ Object

Returns the value of attribute scheduled_for.



28
29
30
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 28

def scheduled_for
  @scheduled_for
end

#status ⇒ Object

Overall post status. "partial" when some platforms published and others failed. While any platform is still pending or processing, the post's own status is returned instead (usually scheduled or publishing), even if another platform already published.



24
25
26
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 24

def status
  @status
end

#sync_status ⇒ Object

Overall sync state across all platforms



43
44
45
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 43

def sync_status
  @sync_status
end

#thumbnail_url ⇒ Object

Cover image URL. Facebook and Instagram covers whose Meta CDN link expired are re-read from Meta and served from Zernio storage, so that URL does not expire and can be cached.



49
50
51
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 49

def thumbnail_url
  @thumbnail_url
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



117
118
119
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 117

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



122
123
124
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 122

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 91

def self.attribute_map
  {
    :'post_id' => :'postId',
    :'late_post_id' => :'latePostId',
    :'status' => :'status',
    :'content' => :'content',
    :'scheduled_for' => :'scheduledFor',
    :'published_at' => :'publishedAt',
    :'analytics' => :'analytics',
    :'platform_analytics' => :'platformAnalytics',
    :'platform' => :'platform',
    :'platform_post_url' => :'platformPostUrl',
    :'is_external' => :'isExternal',
    :'sync_status' => :'syncStatus',
    :'message' => :'message',
    :'thumbnail_url' => :'thumbnailUrl',
    :'media_type' => :'mediaType',
    :'media_items' => :'mediaItems',
    :'media_product_type' => :'mediaProductType',
    :'is_ai_generated' => :'isAiGenerated',
    :'is_shared_to_feed' => :'isSharedToFeed',
    :'media_audio_type' => :'mediaAudioType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 358

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



153
154
155
156
157
158
159
160
161
162
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 153

def self.openapi_nullable
  Set.new([
    :'late_post_id',
    :'published_at',
    :'platform_post_url',
    :'message',
    :'thumbnail_url',
    :'media_type',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 127

def self.openapi_types
  {
    :'post_id' => :'String',
    :'late_post_id' => :'String',
    :'status' => :'String',
    :'content' => :'String',
    :'scheduled_for' => :'Time',
    :'published_at' => :'Time',
    :'analytics' => :'PostAnalytics',
    :'platform_analytics' => :'Array<PlatformAnalytics>',
    :'platform' => :'String',
    :'platform_post_url' => :'String',
    :'is_external' => :'Boolean',
    :'sync_status' => :'String',
    :'message' => :'String',
    :'thumbnail_url' => :'String',
    :'media_type' => :'String',
    :'media_items' => :'Array<AnalyticsSinglePostResponseMediaItemsInner>',
    :'media_product_type' => :'String',
    :'is_ai_generated' => :'Boolean',
    :'is_shared_to_feed' => :'Boolean',
    :'media_audio_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 318

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      post_id == o.post_id &&
      late_post_id == o.late_post_id &&
      status == o.status &&
      content == o.content &&
      scheduled_for == o.scheduled_for &&
      published_at == o.published_at &&
      analytics == o.analytics &&
      platform_analytics == o.platform_analytics &&
      platform == o.platform &&
      platform_post_url == o.platform_post_url &&
      is_external == o.is_external &&
      sync_status == o.sync_status &&
      message == o.message &&
      thumbnail_url == o.thumbnail_url &&
      media_type == o.media_type &&
      media_items == o.media_items &&
      media_product_type == o.media_product_type &&
      is_ai_generated == o.is_ai_generated &&
      is_shared_to_feed == o.is_shared_to_feed &&
      media_audio_type == o.media_audio_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


345
346
347
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 345

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



351
352
353
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 351

def hash
  [post_id, late_post_id, status, content, scheduled_for, published_at, analytics, platform_analytics, platform, platform_post_url, is_external, sync_status, message, thumbnail_url, media_type, media_items, media_product_type, is_ai_generated, is_shared_to_feed, media_audio_type].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



267
268
269
270
271
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 267

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 380

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



275
276
277
278
279
280
281
282
283
284
# File 'lib/zernio-sdk/models/analytics_single_post_response.rb', line 275

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["published", "failed", "partial", "scheduled", "publishing", "draft", "cancelled"])
  return false unless status_validator.valid?(@status)
  sync_status_validator = EnumAttributeValidator.new('String', ["synced", "pending", "partial", "unavailable"])
  return false unless sync_status_validator.valid?(@sync_status)
  media_type_validator = EnumAttributeValidator.new('String', ["image", "video", "carousel", "text"])
  return false unless media_type_validator.valid?(@media_type)
  true
end