Class: Zernio::AppealSmsRegistrationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/appeal_sms_registration_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AppealSmsRegistrationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AppealSmsRegistrationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AppealSmsRegistrationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'appeal_reason')
    self.appeal_reason = attributes[:'appeal_reason']
  else
    self.appeal_reason = nil
  end

  if attributes.key?(:'message_flow')
    self.message_flow = attributes[:'message_flow']
  end

  if attributes.key?(:'sample1')
    self.sample1 = attributes[:'sample1']
  end

  if attributes.key?(:'sample2')
    self.sample2 = attributes[:'sample2']
  end
end

Instance Attribute Details

#appeal_reasonObject

Goes verbatim to the carrier reviewer — address the decline reason directly.



19
20
21
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 19

def appeal_reason
  @appeal_reason
end

#message_flowObject

Corrected opt-in flow; include a link to the opt-in page/form.



22
23
24
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 22

def message_flow
  @message_flow
end

#sample1Object

Returns the value of attribute sample1.



24
25
26
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 24

def sample1
  @sample1
end

#sample2Object

Returns the value of attribute sample2.



26
27
28
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 26

def sample2
  @sample2
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



39
40
41
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 29

def self.attribute_map
  {
    :'appeal_reason' => :'appealReason',
    :'message_flow' => :'messageFlow',
    :'sample1' => :'sample1',
    :'sample2' => :'sample2'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 49

def self.openapi_types
  {
    :'appeal_reason' => :'String',
    :'message_flow' => :'String',
    :'sample1' => :'String',
    :'sample2' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      appeal_reason == o.appeal_reason &&
      message_flow == o.message_flow &&
      sample1 == o.sample1 &&
      sample2 == o.sample2
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 232

def hash
  [appeal_reason, message_flow, sample1, sample2].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 101

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @appeal_reason.nil?
    invalid_properties.push('invalid value for "appeal_reason", appeal_reason cannot be nil.')
  end

  if @appeal_reason.to_s.length > 2000
    invalid_properties.push('invalid value for "appeal_reason", the character length must be smaller than or equal to 2000.')
  end

  if @appeal_reason.to_s.length < 10
    invalid_properties.push('invalid value for "appeal_reason", the character length must be greater than or equal to 10.')
  end

  if !@message_flow.nil? && @message_flow.to_s.length > 2048
    invalid_properties.push('invalid value for "message_flow", the character length must be smaller than or equal to 2048.')
  end

  if !@message_flow.nil? && @message_flow.to_s.length < 40
    invalid_properties.push('invalid value for "message_flow", the character length must be greater than or equal to 40.')
  end

  if !@sample1.nil? && @sample1.to_s.length < 20
    invalid_properties.push('invalid value for "sample1", the character length must be greater than or equal to 20.')
  end

  if !@sample2.nil? && @sample2.to_s.length < 20
    invalid_properties.push('invalid value for "sample2", the character length must be greater than or equal to 20.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/appeal_sms_registration_request.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @appeal_reason.nil?
  return false if @appeal_reason.to_s.length > 2000
  return false if @appeal_reason.to_s.length < 10
  return false if !@message_flow.nil? && @message_flow.to_s.length > 2048
  return false if !@message_flow.nil? && @message_flow.to_s.length < 40
  return false if !@sample1.nil? && @sample1.to_s.length < 20
  return false if !@sample2.nil? && @sample2.to_s.length < 20
  true
end