Class: Zernio::AssignGoogleBusinessLocation200ResponseAccount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AssignGoogleBusinessLocation200ResponseAccount
- Defined in:
- lib/zernio-sdk/models/assign_google_business_location200_response_account.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#selected_location_id ⇒ Object
Bare GBP location id (digits only).
-
#selected_location_name ⇒ Object
Human-readable location display name (e.g. "Snap Fitness Dianella"), NOT a resource name.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AssignGoogleBusinessLocation200ResponseAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AssignGoogleBusinessLocation200ResponseAccount
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AssignGoogleBusinessLocation200ResponseAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AssignGoogleBusinessLocation200ResponseAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'selected_location_name') self.selected_location_name = attributes[:'selected_location_name'] end if attributes.key?(:'selected_location_id') self.selected_location_id = attributes[:'selected_location_id'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 18 def account_id @account_id end |
#display_name ⇒ Object
Returns the value of attribute display_name.
24 25 26 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 24 def display_name @display_name end |
#is_active ⇒ Object
Returns the value of attribute is_active.
26 27 28 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 26 def is_active @is_active end |
#platform ⇒ Object
Returns the value of attribute platform.
20 21 22 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 20 def platform @platform end |
#selected_location_id ⇒ Object
Bare GBP location id (digits only). Combine with the GBP account id as accounts/gbpAccountId/locations/selectedLocationId to form the location resource names that gmb-reviews/batch expects in locationNames.
32 33 34 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 32 def selected_location_id @selected_location_id end |
#selected_location_name ⇒ Object
Human-readable location display name (e.g. "Snap Fitness Dianella"), NOT a resource name. Do not use it to build API paths.
29 30 31 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 29 def selected_location_name @selected_location_name end |
#username ⇒ Object
Returns the value of attribute username.
22 23 24 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 22 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 35 def self.attribute_map { :'account_id' => :'accountId', :'platform' => :'platform', :'username' => :'username', :'display_name' => :'displayName', :'is_active' => :'isActive', :'selected_location_name' => :'selectedLocationName', :'selected_location_id' => :'selectedLocationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 165 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 58 def self.openapi_types { :'account_id' => :'String', :'platform' => :'String', :'username' => :'String', :'display_name' => :'String', :'is_active' => :'Boolean', :'selected_location_name' => :'String', :'selected_location_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && platform == o.platform && username == o.username && display_name == o.display_name && is_active == o.is_active && selected_location_name == o.selected_location_name && selected_location_id == o.selected_location_id end |
#eql?(o) ⇒ Boolean
152 153 154 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 152 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
158 159 160 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 158 def hash [account_id, platform, username, display_name, is_active, selected_location_name, selected_location_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 187 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 |
# File 'lib/zernio-sdk/models/assign_google_business_location200_response_account.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |