Class: Zernio::AttachBrandedCallingNumbersRequestSignature
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AttachBrandedCallingNumbersRequestSignature
- Defined in:
- lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb
Instance Attribute Summary collapse
-
#image_base64 ⇒ Object
The signer's drawn signature as a PNG, base64 (a data:image/png;base64 prefix is accepted).
-
#signer_name ⇒ Object
Printed under the signature.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachBrandedCallingNumbersRequestSignature
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AttachBrandedCallingNumbersRequestSignature
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AttachBrandedCallingNumbersRequestSignature` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AttachBrandedCallingNumbersRequestSignature`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'image_base64') self.image_base64 = attributes[:'image_base64'] else self.image_base64 = nil end if attributes.key?(:'signer_name') self.signer_name = attributes[:'signer_name'] end end |
Instance Attribute Details
#image_base64 ⇒ Object
The signer's drawn signature as a PNG, base64 (a data:image/png;base64 prefix is accepted).
19 20 21 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 19 def image_base64 @image_base64 end |
#signer_name ⇒ Object
Printed under the signature. Defaults to the business contact's name.
22 23 24 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 22 def signer_name @signer_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 25 def self.attribute_map { :'image_base64' => :'imageBase64', :'signer_name' => :'signerName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 43 def self.openapi_types { :'image_base64' => :'String', :'signer_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && image_base64 == o.image_base64 && signer_name == o.signer_name end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 149 def hash [image_base64, signer_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @image_base64.nil? invalid_properties.push('invalid value for "image_base64", image_base64 cannot be nil.') end if !@signer_name.nil? && @signer_name.to_s.length > 255 invalid_properties.push('invalid value for "signer_name", the character length must be smaller than or equal to 255.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
101 102 103 104 105 106 |
# File 'lib/zernio-sdk/models/attach_branded_calling_numbers_request_signature.rb', line 101 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @image_base64.nil? return false if !@signer_name.nil? && @signer_name.to_s.length > 255 true end |