Class: Zernio::BillingSnapshotStatus

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/billing_snapshot_status.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BillingSnapshotStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BillingSnapshotStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BillingSnapshotStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'has_access')
    self.has_access = attributes[:'has_access']
  end

  if attributes.key?(:'suspended')
    self.suspended = attributes[:'suspended']
  end

  if attributes.key?(:'suspended_at')
    self.suspended_at = attributes[:'suspended_at']
  end

  if attributes.key?(:'suspension_reason')
    self.suspension_reason = attributes[:'suspension_reason']
  end

  if attributes.key?(:'open_invoice_url')
    self.open_invoice_url = attributes[:'open_invoice_url']
  end

  if attributes.key?(:'decline_reason')
    self.decline_reason = attributes[:'decline_reason']
  end

  if attributes.key?(:'auto_upgrade_enabled')
    self.auto_upgrade_enabled = attributes[:'auto_upgrade_enabled']
  end
end

Instance Attribute Details

#auto_upgrade_enabledObject

Returns the value of attribute auto_upgrade_enabled.



31
32
33
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 31

def auto_upgrade_enabled
  @auto_upgrade_enabled
end

#decline_reasonObject

Returns the value of attribute decline_reason.



29
30
31
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 29

def decline_reason
  @decline_reason
end

#has_accessObject

Returns the value of attribute has_access.



18
19
20
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 18

def has_access
  @has_access
end

#open_invoice_urlObject

Hosted invoice URL for dunning (Stripe).



27
28
29
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 27

def open_invoice_url
  @open_invoice_url
end

#suspendedObject

Returns the value of attribute suspended.



20
21
22
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 20

def suspended
  @suspended
end

#suspended_atObject

Returns the value of attribute suspended_at.



22
23
24
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 22

def suspended_at
  @suspended_at
end

#suspension_reasonObject

Returns the value of attribute suspension_reason.



24
25
26
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 24

def suspension_reason
  @suspension_reason
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 34

def self.attribute_map
  {
    :'has_access' => :'hasAccess',
    :'suspended' => :'suspended',
    :'suspended_at' => :'suspendedAt',
    :'suspension_reason' => :'suspensionReason',
    :'open_invoice_url' => :'openInvoiceUrl',
    :'decline_reason' => :'declineReason',
    :'auto_upgrade_enabled' => :'autoUpgradeEnabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
74
75
76
77
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 70

def self.openapi_nullable
  Set.new([
    :'suspended_at',
    :'suspension_reason',
    :'open_invoice_url',
    :'decline_reason',
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 57

def self.openapi_types
  {
    :'has_access' => :'Boolean',
    :'suspended' => :'Boolean',
    :'suspended_at' => :'Time',
    :'suspension_reason' => :'String',
    :'open_invoice_url' => :'String',
    :'decline_reason' => :'String',
    :'auto_upgrade_enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      has_access == o.has_access &&
      suspended == o.suspended &&
      suspended_at == o.suspended_at &&
      suspension_reason == o.suspension_reason &&
      open_invoice_url == o.open_invoice_url &&
      decline_reason == o.decline_reason &&
      auto_upgrade_enabled == o.auto_upgrade_enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 161

def hash
  [has_access, suspended, suspended_at, suspension_reason, open_invoice_url, decline_reason, auto_upgrade_enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
# File 'lib/zernio-sdk/models/billing_snapshot_status.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end