Class: Zernio::BlogArticle
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::BlogArticle
- Defined in:
- lib/zernio-sdk/models/blog_article.rb
Overview
An article inside a blog on the connected platform.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#author ⇒ Object
Display name of the article author.
-
#blog_id ⇒ Object
Platform-native id of the blog the article belongs to.
-
#body_html ⇒ Object
Article body as HTML.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#excerpt ⇒ Object
Short summary shown in blog listings.
-
#handle ⇒ Object
URL slug of the article.
-
#id ⇒ Object
Platform-native article id (numeric string for Shopify).
-
#image ⇒ Object
Returns the value of attribute image.
-
#is_published ⇒ Object
False while the article is a draft or its publish date is still in the future.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#published_at ⇒ Object
When the article was (or is scheduled to be) published; null for drafts.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#title ⇒ Object
Returns the value of attribute title.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BlogArticle
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BlogArticle
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BlogArticle` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BlogArticle`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'blog_id') self.blog_id = attributes[:'blog_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'body_html') self.body_html = attributes[:'body_html'] end if attributes.key?(:'handle') self.handle = attributes[:'handle'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'author') self. = attributes[:'author'] end if attributes.key?(:'excerpt') self.excerpt = attributes[:'excerpt'] end if attributes.key?(:'image') self.image = attributes[:'image'] end if attributes.key?(:'is_published') self.is_published = attributes[:'is_published'] end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#author ⇒ Object
Display name of the article author.
38 39 40 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 38 def @author end |
#blog_id ⇒ Object
Platform-native id of the blog the article belongs to.
23 24 25 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 23 def blog_id @blog_id end |
#body_html ⇒ Object
Article body as HTML.
30 31 32 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 30 def body_html @body_html end |
#created_at ⇒ Object
Returns the value of attribute created_at.
51 52 53 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 51 def created_at @created_at end |
#excerpt ⇒ Object
Short summary shown in blog listings.
41 42 43 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 41 def excerpt @excerpt end |
#handle ⇒ Object
URL slug of the article.
33 34 35 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 33 def handle @handle end |
#id ⇒ Object
Platform-native article id (numeric string for Shopify).
20 21 22 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 20 def id @id end |
#image ⇒ Object
Returns the value of attribute image.
43 44 45 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 43 def image @image end |
#is_published ⇒ Object
False while the article is a draft or its publish date is still in the future.
46 47 48 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 46 def is_published @is_published end |
#platform ⇒ Object
Returns the value of attribute platform.
25 26 27 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 25 def platform @platform end |
#published_at ⇒ Object
When the article was (or is scheduled to be) published; null for drafts.
49 50 51 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 49 def published_at @published_at end |
#tags ⇒ Object
Returns the value of attribute tags.
35 36 37 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 35 def @tags end |
#title ⇒ Object
Returns the value of attribute title.
27 28 29 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 27 def title @title end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
53 54 55 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 53 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
98 99 100 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 98 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
103 104 105 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 103 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 78 def self.attribute_map { :'id' => :'id', :'blog_id' => :'blogId', :'platform' => :'platform', :'title' => :'title', :'body_html' => :'bodyHtml', :'handle' => :'handle', :'tags' => :'tags', :'author' => :'author', :'excerpt' => :'excerpt', :'image' => :'image', :'is_published' => :'isPublished', :'published_at' => :'publishedAt', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 132 133 134 135 136 137 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 128 def self.openapi_nullable Set.new([ :'body_html', :'author', :'excerpt', :'published_at', :'created_at', :'updated_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 108 def self.openapi_types { :'id' => :'String', :'blog_id' => :'String', :'platform' => :'String', :'title' => :'String', :'body_html' => :'String', :'handle' => :'String', :'tags' => :'Array<String>', :'author' => :'String', :'excerpt' => :'String', :'image' => :'BlogArticleImage', :'is_published' => :'Boolean', :'published_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 243 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && blog_id == o.blog_id && platform == o.platform && title == o.title && body_html == o.body_html && handle == o.handle && == o. && == o. && excerpt == o.excerpt && image == o.image && is_published == o.is_published && published_at == o.published_at && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 270 def hash [id, blog_id, platform, title, body_html, handle, , , excerpt, image, is_published, published_at, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
216 217 218 219 220 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 216 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
224 225 226 227 228 229 |
# File 'lib/zernio-sdk/models/blog_article.rb', line 224 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["shopify"]) return false unless platform_validator.valid?(@platform) true end |