Class: Zernio::BoostPostRequestTargetingCustomLocationsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BoostPostRequestTargetingCustomLocationsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BoostPostRequestTargetingCustomLocationsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BoostPostRequestTargetingCustomLocationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'latitude')
    self.latitude = attributes[:'latitude']
  else
    self.latitude = nil
  end

  if attributes.key?(:'longitude')
    self.longitude = attributes[:'longitude']
  else
    self.longitude = nil
  end

  if attributes.key?(:'radius')
    self.radius = attributes[:'radius']
  else
    self.radius = nil
  end

  if attributes.key?(:'distance_unit')
    self.distance_unit = attributes[:'distance_unit']
  else
    self.distance_unit = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end
end

Instance Attribute Details

#addressObject

Optional label, sent to Meta as address_string.



29
30
31
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 29

def address
  @address
end

#distance_unitObject

Returns the value of attribute distance_unit.



24
25
26
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 24

def distance_unit
  @distance_unit
end

#latitudeObject

Returns the value of attribute latitude.



18
19
20
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 18

def latitude
  @latitude
end

#longitudeObject

Returns the value of attribute longitude.



20
21
22
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 20

def longitude
  @longitude
end

#nameObject

Returns the value of attribute name.



26
27
28
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 26

def name
  @name
end

#radiusObject

Returns the value of attribute radius.



22
23
24
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 22

def radius
  @radius
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 54

def self.attribute_map
  {
    :'latitude' => :'latitude',
    :'longitude' => :'longitude',
    :'radius' => :'radius',
    :'distance_unit' => :'distanceUnit',
    :'name' => :'name',
    :'address' => :'address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 283

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 76

def self.openapi_types
  {
    :'latitude' => :'Float',
    :'longitude' => :'Float',
    :'radius' => :'Float',
    :'distance_unit' => :'String',
    :'name' => :'String',
    :'address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      latitude == o.latitude &&
      longitude == o.longitude &&
      radius == o.radius &&
      distance_unit == o.distance_unit &&
      name == o.name &&
      address == o.address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 276

def hash
  [latitude, longitude, radius, distance_unit, name, address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @latitude.nil?
    invalid_properties.push('invalid value for "latitude", latitude cannot be nil.')
  end

  if @latitude > 90
    invalid_properties.push('invalid value for "latitude", must be smaller than or equal to 90.')
  end

  if @latitude < -90
    invalid_properties.push('invalid value for "latitude", must be greater than or equal to -90.')
  end

  if @longitude.nil?
    invalid_properties.push('invalid value for "longitude", longitude cannot be nil.')
  end

  if @longitude > 180
    invalid_properties.push('invalid value for "longitude", must be smaller than or equal to 180.')
  end

  if @longitude < -180
    invalid_properties.push('invalid value for "longitude", must be greater than or equal to -180.')
  end

  if @radius.nil?
    invalid_properties.push('invalid value for "radius", radius cannot be nil.')
  end

  if @distance_unit.nil?
    invalid_properties.push('invalid value for "distance_unit", distance_unit cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 305

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/zernio-sdk/models/boost_post_request_targeting_custom_locations_inner.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @latitude.nil?
  return false if @latitude > 90
  return false if @latitude < -90
  return false if @longitude.nil?
  return false if @longitude > 180
  return false if @longitude < -180
  return false if @radius.nil?
  return false if @distance_unit.nil?
  distance_unit_validator = EnumAttributeValidator.new('String', ["mile", "kilometer"])
  return false unless distance_unit_validator.valid?(@distance_unit)
  true
end