Class: Zernio::BusinessAgentConnector

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/business_agent_connector.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BusinessAgentConnector

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 128

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentConnector` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentConnector`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'base_url')
    self.base_url = attributes[:'base_url']
  else
    self.base_url = nil
  end

  if attributes.key?(:'connector_protocol')
    self.connector_protocol = attributes[:'connector_protocol']
  end

  if attributes.key?(:'auth_type')
    self.auth_type = attributes[:'auth_type']
  else
    self.auth_type = nil
  end

  if attributes.key?(:'auth_config')
    self.auth_config = attributes[:'auth_config']
  end

  if attributes.key?(:'user_auth_injection_config')
    self.user_auth_injection_config = attributes[:'user_auth_injection_config']
  end

  if attributes.key?(:'requires_certificate')
    self.requires_certificate = attributes[:'requires_certificate']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'mcp_tool_sync')
    if (value = attributes[:'mcp_tool_sync']).is_a?(Hash)
      self.mcp_tool_sync = value
    end
  end

  if attributes.key?(:'mtls_config')
    if (value = attributes[:'mtls_config']).is_a?(Hash)
      self.mtls_config = value
    end
  end

  if attributes.key?(:'connection_status')
    self.connection_status = attributes[:'connection_status']
  end
end

Instance Attribute Details

#auth_configObject

Returns the value of attribute auth_config.



31
32
33
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 31

def auth_config
  @auth_config
end

#auth_typeObject

Returns the value of attribute auth_type.



29
30
31
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 29

def auth_type
  @auth_type
end

#base_urlObject

Public HTTPS URL reachable from Meta.



25
26
27
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 25

def base_url
  @base_url
end

#connection_statusObject

Returns the value of attribute connection_status.



43
44
45
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 43

def connection_status
  @connection_status
end

#connector_protocolObject

Returns the value of attribute connector_protocol.



27
28
29
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 27

def connector_protocol
  @connector_protocol
end

#descriptionObject

Tell the agent what the service provides.



22
23
24
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 22

def description
  @description
end

#idObject

Returns the value of attribute id.



37
38
39
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 37

def id
  @id
end

#mcp_tool_syncObject

Returns the value of attribute mcp_tool_sync.



39
40
41
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 39

def mcp_tool_sync
  @mcp_tool_sync
end

#mtls_configObject

Returns the value of attribute mtls_config.



41
42
43
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 41

def mtls_config
  @mtls_config
end

#nameObject

Unique per number.



19
20
21
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 19

def name
  @name
end

#requires_certificateObject

Returns the value of attribute requires_certificate.



35
36
37
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 35

def requires_certificate
  @requires_certificate
end

#user_auth_injection_configObject

Returns the value of attribute user_auth_injection_config.



33
34
35
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 33

def user_auth_injection_config
  @user_auth_injection_config
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 68

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'base_url' => :'base_url',
    :'connector_protocol' => :'connector_protocol',
    :'auth_type' => :'auth_type',
    :'auth_config' => :'auth_config',
    :'user_auth_injection_config' => :'user_auth_injection_config',
    :'requires_certificate' => :'requires_certificate',
    :'id' => :'id',
    :'mcp_tool_sync' => :'mcp_tool_sync',
    :'mtls_config' => :'mtls_config',
    :'connection_status' => :'connection_status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 314

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



120
121
122
123
124
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 120

def self.openapi_all_of
  [
  :'BusinessAgentConnectorInput'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 96

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'base_url' => :'String',
    :'connector_protocol' => :'String',
    :'auth_type' => :'String',
    :'auth_config' => :'BusinessAgentConnectorInputAuthConfig',
    :'user_auth_injection_config' => :'BusinessAgentConnectorInputUserAuthInjectionConfig',
    :'requires_certificate' => :'Boolean',
    :'id' => :'String',
    :'mcp_tool_sync' => :'Hash<String, Object>',
    :'mtls_config' => :'Hash<String, Object>',
    :'connection_status' => :'BusinessAgentConnectorAllOfConnectionStatus'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      base_url == o.base_url &&
      connector_protocol == o.connector_protocol &&
      auth_type == o.auth_type &&
      auth_config == o.auth_config &&
      user_auth_injection_config == o.user_auth_injection_config &&
      requires_certificate == o.requires_certificate &&
      id == o.id &&
      mcp_tool_sync == o.mcp_tool_sync &&
      mtls_config == o.mtls_config &&
      connection_status == o.connection_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


301
302
303
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 301

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



307
308
309
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 307

def hash
  [name, description, base_url, connector_protocol, auth_type, auth_config, user_auth_injection_config, requires_certificate, id, mcp_tool_sync, mtls_config, connection_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 205

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @base_url.nil?
    invalid_properties.push('invalid value for "base_url", base_url cannot be nil.')
  end

  if @auth_type.nil?
    invalid_properties.push('invalid value for "auth_type", auth_type cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



229
230
231
232
233
234
235
236
237
238
# File 'lib/zernio-sdk/models/business_agent_connector.rb', line 229

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @base_url.nil?
  return false if @auth_type.nil?
  auth_type_validator = EnumAttributeValidator.new('String', ["OAUTH2_CLIENT_CREDENTIALS", "API_KEY", "NONE"])
  return false unless auth_type_validator.valid?(@auth_type)
  return false if @id.nil?
  true
end