Class: Zernio::BusinessAgentConnectorToolInput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/business_agent_connector_tool_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BusinessAgentConnectorToolInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentConnectorToolInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentConnectorToolInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'request_definition')
    if (value = attributes[:'request_definition']).is_a?(Hash)
      self.request_definition = value
    end
  else
    self.request_definition = nil
  end

  if attributes.key?(:'user_auth_required')
    self.user_auth_required = attributes[:'user_auth_required']
  end

  if attributes.key?(:'user_auth_action_config')
    if (value = attributes[:'user_auth_action_config']).is_a?(Hash)
      self.user_auth_action_config = value
    end
  end

  if attributes.key?(:'transformation_spec')
    if (value = attributes[:'transformation_spec']).is_a?(Hash)
      self.transformation_spec = value
    end
  end
end

Instance Attribute Details

#descriptionObject

When and how the agent should use the operation.



21
22
23
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 21

def description
  @description
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 18

def name
  @name
end

#request_definitionObject

Meta request definition: method, path, path_parameters, query_parameters, headers and a typed body schema (content_type, params, required).



24
25
26
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 24

def request_definition
  @request_definition
end

#transformation_specObject

Returns the value of attribute transformation_spec.



30
31
32
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 30

def transformation_spec
  @transformation_spec
end

#user_auth_action_configObject

Returns the value of attribute user_auth_action_config.



28
29
30
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 28

def user_auth_action_config
  @user_auth_action_config
end

#user_auth_requiredObject

Returns the value of attribute user_auth_required.



26
27
28
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 26

def user_auth_required
  @user_auth_required
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 33

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'request_definition' => :'request_definition',
    :'user_auth_required' => :'user_auth_required',
    :'user_auth_action_config' => :'user_auth_action_config',
    :'transformation_spec' => :'transformation_spec'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'request_definition' => :'Hash<String, Object>',
    :'user_auth_required' => :'Boolean',
    :'user_auth_action_config' => :'Hash<String, Object>',
    :'transformation_spec' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      request_definition == o.request_definition &&
      user_auth_required == o.user_auth_required &&
      user_auth_action_config == o.user_auth_action_config &&
      transformation_spec == o.transformation_spec
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 206

def hash
  [name, description, request_definition, user_auth_required, user_auth_action_config, transformation_spec].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @request_definition.nil?
    invalid_properties.push('invalid value for "request_definition", request_definition cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
# File 'lib/zernio-sdk/models/business_agent_connector_tool_input.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @description.nil?
  return false if @request_definition.nil?
  true
end