Class: Zernio::BusinessAgentSkillInput

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/business_agent_skill_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BusinessAgentSkillInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentSkillInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentSkillInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'skill')
    self.skill = attributes[:'skill']
  else
    self.skill = nil
  end
end

Instance Attribute Details

#descriptionObject

When the agent should apply the skill.



22
23
24
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 22

def description
  @description
end

#skillObject

The instructions themselves. Avoid two skills that both claim priority for the same situation.



25
26
27
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 25

def skill
  @skill
end

#titleObject

Lowercase letters, digits and hyphens, e.g. greeting-skill.



19
20
21
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 28

def self.attribute_map
  {
    :'title' => :'title',
    :'description' => :'description',
    :'skill' => :'skill'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 205

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 47

def self.openapi_types
  {
    :'title' => :'String',
    :'description' => :'String',
    :'skill' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      description == o.description &&
      skill == o.skill
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


192
193
194
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 192

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



198
199
200
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 198

def hash
  [title, description, skill].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 94

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@title.nil? && @title.to_s.length > 64
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 64.')
  end

  pattern = Regexp.new(/^[a-z0-9]+(?:-[a-z0-9]+)*$/)
  if !@title.nil? && @title !~ pattern
    invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 1024
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1024.')
  end

  if @skill.nil?
    invalid_properties.push('invalid value for "skill", skill cannot be nil.')
  end

  if @skill.to_s.length > 20000
    invalid_properties.push('invalid value for "skill", the character length must be smaller than or equal to 20000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 227

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



123
124
125
126
127
128
129
130
131
# File 'lib/zernio-sdk/models/business_agent_skill_input.rb', line 123

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@title.nil? && @title.to_s.length > 64
  return false if !@title.nil? && @title !~ Regexp.new(/^[a-z0-9]+(?:-[a-z0-9]+)*$/)
  return false if !@description.nil? && @description.to_s.length > 1024
  return false if @skill.nil?
  return false if @skill.to_s.length > 20000
  true
end