Class: Zernio::BusinessAgentUiSkill

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/business_agent_ui_skill.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BusinessAgentUiSkill

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentUiSkill` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentUiSkill`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'component_type')
    self.component_type = attributes[:'component_type']
  else
    self.component_type = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'instruction')
    self.instruction = attributes[:'instruction']
  else
    self.instruction = nil
  end

  if attributes.key?(:'flow_id')
    self.flow_id = attributes[:'flow_id']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#component_typeObject

Returns the value of attribute component_type.



20
21
22
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 20

def component_type
  @component_type
end

#created_atObject

Unix seconds.



33
34
35
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 33

def created_at
  @created_at
end

#flow_idObject

Required for component_type flow, rejected otherwise.



28
29
30
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 28

def flow_id
  @flow_id
end

#idObject

Returns the value of attribute id.



30
31
32
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 30

def id
  @id
end

#instructionObject

When to send the component and everything needed to fill its fields.



25
26
27
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 25

def instruction
  @instruction
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 22

def status
  @status
end

#titleObject

Returns the value of attribute title.



18
19
20
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 18

def title
  @title
end

#updated_atObject

Unix seconds.



36
37
38
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 36

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 61

def self.attribute_map
  {
    :'title' => :'title',
    :'component_type' => :'component_type',
    :'status' => :'status',
    :'instruction' => :'instruction',
    :'flow_id' => :'flow_id',
    :'id' => :'id',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 277

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



105
106
107
108
109
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 105

def self.openapi_all_of
  [
  :'BusinessAgentUiSkillInput'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 85

def self.openapi_types
  {
    :'title' => :'String',
    :'component_type' => :'String',
    :'status' => :'String',
    :'instruction' => :'String',
    :'flow_id' => :'Integer',
    :'id' => :'String',
    :'created_at' => :'Integer',
    :'updated_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 249

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      component_type == o.component_type &&
      status == o.status &&
      instruction == o.instruction &&
      flow_id == o.flow_id &&
      id == o.id &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


264
265
266
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



270
271
272
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 270

def hash
  [title, component_type, status, instruction, flow_id, id, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 170

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @component_type.nil?
    invalid_properties.push('invalid value for "component_type", component_type cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @instruction.nil?
    invalid_properties.push('invalid value for "instruction", instruction cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 299

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/zernio-sdk/models/business_agent_ui_skill.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @component_type.nil?
  component_type_validator = EnumAttributeValidator.new('String', ["carousel_quick_reply", "carousel_url", "cta_url", "flow", "image", "interactive_list", "interactive_reply_buttons", "location", "location_request"])
  return false unless component_type_validator.valid?(@component_type)
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["enabled", "disabled"])
  return false unless status_validator.valid?(@status)
  return false if @instruction.nil?
  return false if @id.nil?
  true
end