Class: Zernio::BusinessAgentWebsite

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/business_agent_website.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BusinessAgentWebsite

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentWebsite` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentWebsite`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'included_sub_domains')
    if (value = attributes[:'included_sub_domains']).is_a?(Array)
      self.included_sub_domains = value
    end
  end

  if attributes.key?(:'included_url_patterns')
    if (value = attributes[:'included_url_patterns']).is_a?(Array)
      self.included_url_patterns = value
    end
  end

  if attributes.key?(:'excluded_sub_domains')
    if (value = attributes[:'excluded_sub_domains']).is_a?(Array)
      self.excluded_sub_domains = value
    end
  end

  if attributes.key?(:'excluded_url_patterns')
    if (value = attributes[:'excluded_url_patterns']).is_a?(Array)
      self.excluded_url_patterns = value
    end
  end

  if attributes.key?(:'single_urls')
    if (value = attributes[:'single_urls']).is_a?(Array)
      self.single_urls = value
    end
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'crawl_status')
    self.crawl_status = attributes[:'crawl_status']
  end

  if attributes.key?(:'crawl_error')
    self.crawl_error = attributes[:'crawl_error']
  end

  if attributes.key?(:'pages_crawled')
    self.pages_crawled = attributes[:'pages_crawled']
  end

  if attributes.key?(:'last_crawled_at')
    self.last_crawled_at = attributes[:'last_crawled_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#crawl_errorObject

Returns the value of attribute crawl_error.



37
38
39
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 37

def crawl_error
  @crawl_error
end

#crawl_statusObject

not_started, pending, in_progress, completed, completed_no_data or failed (see crawl_error).



35
36
37
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 35

def crawl_status
  @crawl_status
end

#created_atObject

Unix seconds.



45
46
47
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 45

def created_at
  @created_at
end

#excluded_sub_domainsObject

Returns the value of attribute excluded_sub_domains.



25
26
27
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 25

def excluded_sub_domains
  @excluded_sub_domains
end

#excluded_url_patternsObject

Returns the value of attribute excluded_url_patterns.



27
28
29
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 27

def excluded_url_patterns
  @excluded_url_patterns
end

#idObject

Returns the value of attribute id.



32
33
34
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 32

def id
  @id
end

#included_sub_domainsObject

Returns the value of attribute included_sub_domains.



20
21
22
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 20

def included_sub_domains
  @included_sub_domains
end

#included_url_patternsObject

Only URLs containing one of these substrings are ingested.



23
24
25
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 23

def included_url_patterns
  @included_url_patterns
end

#last_crawled_atObject

Unix seconds.



42
43
44
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 42

def last_crawled_at
  @last_crawled_at
end

#pages_crawledObject

Returns the value of attribute pages_crawled.



39
40
41
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 39

def pages_crawled
  @pages_crawled
end

#single_urlsObject

Crawl only these exact pages instead of the whole site.



30
31
32
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 30

def single_urls
  @single_urls
end

#urlObject

Returns the value of attribute url.



18
19
20
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 18

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 48

def self.attribute_map
  {
    :'url' => :'url',
    :'included_sub_domains' => :'included_sub_domains',
    :'included_url_patterns' => :'included_url_patterns',
    :'excluded_sub_domains' => :'excluded_sub_domains',
    :'excluded_url_patterns' => :'excluded_url_patterns',
    :'single_urls' => :'single_urls',
    :'id' => :'id',
    :'crawl_status' => :'crawl_status',
    :'crawl_error' => :'crawl_error',
    :'pages_crawled' => :'pages_crawled',
    :'last_crawled_at' => :'last_crawled_at',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 264

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



100
101
102
103
104
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 100

def self.openapi_all_of
  [
  :'BusinessAgentWebsiteInput'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 76

def self.openapi_types
  {
    :'url' => :'String',
    :'included_sub_domains' => :'Array<String>',
    :'included_url_patterns' => :'Array<String>',
    :'excluded_sub_domains' => :'Array<String>',
    :'excluded_url_patterns' => :'Array<String>',
    :'single_urls' => :'Array<String>',
    :'id' => :'String',
    :'crawl_status' => :'String',
    :'crawl_error' => :'String',
    :'pages_crawled' => :'Integer',
    :'last_crawled_at' => :'Integer',
    :'created_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 232

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      included_sub_domains == o.included_sub_domains &&
      included_url_patterns == o.included_url_patterns &&
      excluded_sub_domains == o.excluded_sub_domains &&
      excluded_url_patterns == o.excluded_url_patterns &&
      single_urls == o.single_urls &&
      id == o.id &&
      crawl_status == o.crawl_status &&
      crawl_error == o.crawl_error &&
      pages_crawled == o.pages_crawled &&
      last_crawled_at == o.last_crawled_at &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 251

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



257
258
259
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 257

def hash
  [url, included_sub_domains, included_url_patterns, excluded_sub_domains, excluded_url_patterns, single_urls, id, crawl_status, crawl_error, pages_crawled, last_crawled_at, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
# File 'lib/zernio-sdk/models/business_agent_website.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @url.nil?
  return false if @id.nil?
  true
end