Class: Zernio::CallRecordBilling

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/call_record_billing.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CallRecordBilling

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CallRecordBilling` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CallRecordBilling`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'meta_minutes')
    self.meta_minutes = attributes[:'meta_minutes']
  end

  if attributes.key?(:'telnyx_seconds')
    self.telnyx_seconds = attributes[:'telnyx_seconds']
  end

  if attributes.key?(:'transcription_seconds')
    self.transcription_seconds = attributes[:'transcription_seconds']
  end

  if attributes.key?(:'transcription_cost_usd')
    self.transcription_cost_usd = attributes[:'transcription_cost_usd']
  end

  if attributes.key?(:'meta_cost_usd')
    self.meta_cost_usd = attributes[:'meta_cost_usd']
  end

  if attributes.key?(:'telnyx_cost_usd')
    self.telnyx_cost_usd = attributes[:'telnyx_cost_usd']
  end

  if attributes.key?(:'recording_cost_usd')
    self.recording_cost_usd = attributes[:'recording_cost_usd']
  end

  if attributes.key?(:'billable_cost_usd')
    self.billable_cost_usd = attributes[:'billable_cost_usd']
  end

  if attributes.key?(:'total_cost_usd')
    self.total_cost_usd = attributes[:'total_cost_usd']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end
end

Instance Attribute Details

#billable_cost_usd ⇒ Object

Amount Zernio bills you = telephony leg + recording + transcription (excludes any Meta portion).



34
35
36
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 34

def billable_cost_usd
  @billable_cost_usd
end

#currency ⇒ Object

Returns the value of attribute currency.



39
40
41
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 39

def currency
  @currency
end

#meta_cost_usd ⇒ Object

WhatsApp channel only. Meta per-minute charge, billed by Meta directly to your WABA. Display only; not billed by Zernio.



27
28
29
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 27

def meta_cost_usd
  @meta_cost_usd
end

#meta_minutes ⇒ Object

Returns the value of attribute meta_minutes.



18
19
20
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 18

def meta_minutes
  @meta_minutes
end

#recording_cost_usd ⇒ Object

Returns the value of attribute recording_cost_usd.



31
32
33
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 31

def recording_cost_usd
  @recording_cost_usd
end

#telnyx_cost_usd ⇒ Object

Returns the value of attribute telnyx_cost_usd.



29
30
31
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 29

def telnyx_cost_usd
  @telnyx_cost_usd
end

#telnyx_seconds ⇒ Object

Returns the value of attribute telnyx_seconds.



20
21
22
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 20

def telnyx_seconds
  @telnyx_seconds
end

#total_cost_usd ⇒ Object

Full cost incl. any Meta portion you pay directly. Display only.



37
38
39
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 37

def total_cost_usd
  @total_cost_usd
end

#transcription_cost_usd ⇒ Object

Returns the value of attribute transcription_cost_usd.



24
25
26
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 24

def transcription_cost_usd
  @transcription_cost_usd
end

#transcription_seconds ⇒ Object

Returns the value of attribute transcription_seconds.



22
23
24
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 22

def transcription_seconds
  @transcription_seconds
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



58
59
60
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 42

def self.attribute_map
  {
    :'meta_minutes' => :'metaMinutes',
    :'telnyx_seconds' => :'telnyxSeconds',
    :'transcription_seconds' => :'transcriptionSeconds',
    :'transcription_cost_usd' => :'transcriptionCostUSD',
    :'meta_cost_usd' => :'metaCostUSD',
    :'telnyx_cost_usd' => :'telnyxCostUSD',
    :'recording_cost_usd' => :'recordingCostUSD',
    :'billable_cost_usd' => :'billableCostUSD',
    :'total_cost_usd' => :'totalCostUSD',
    :'currency' => :'currency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



84
85
86
87
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 68

def self.openapi_types
  {
    :'meta_minutes' => :'Float',
    :'telnyx_seconds' => :'Float',
    :'transcription_seconds' => :'Float',
    :'transcription_cost_usd' => :'Float',
    :'meta_cost_usd' => :'Float',
    :'telnyx_cost_usd' => :'Float',
    :'recording_cost_usd' => :'Float',
    :'billable_cost_usd' => :'Float',
    :'total_cost_usd' => :'Float',
    :'currency' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 163

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      meta_minutes == o.meta_minutes &&
      telnyx_seconds == o.telnyx_seconds &&
      transcription_seconds == o.transcription_seconds &&
      transcription_cost_usd == o.transcription_cost_usd &&
      meta_cost_usd == o.meta_cost_usd &&
      telnyx_cost_usd == o.telnyx_cost_usd &&
      recording_cost_usd == o.recording_cost_usd &&
      billable_cost_usd == o.billable_cost_usd &&
      total_cost_usd == o.total_cost_usd &&
      currency == o.currency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 180

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



186
187
188
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 186

def hash
  [meta_minutes, telnyx_seconds, transcription_seconds, transcription_cost_usd, meta_cost_usd, telnyx_cost_usd, recording_cost_usd, billable_cost_usd, total_cost_usd, currency].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



156
157
158
159
# File 'lib/zernio-sdk/models/call_record_billing.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end