Class: Zernio::CheckVerification200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/check_verification200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CheckVerification200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CheckVerification200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CheckVerification200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'attempts')
    self.attempts = attributes[:'attempts']
  end

  if attributes.key?(:'max_attempts')
    self.max_attempts = attributes[:'max_attempts']
  end

  if attributes.key?(:'send_count')
    self.send_count = attributes[:'send_count']
  end

  if attributes.key?(:'last_sent_at')
    self.last_sent_at = attributes[:'last_sent_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'resend')
    self.resend = attributes[:'resend']
  end

  if attributes.key?(:'valid')
    self.valid = attributes[:'valid']
  end
end

Instance Attribute Details

#attemptsObject

Returns the value of attribute attempts.



28
29
30
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 28

def attempts
  @attempts
end

#channelObject

Returns the value of attribute channel.



22
23
24
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 22

def channel
  @channel
end

#created_atObject

Returns the value of attribute created_at.



37
38
39
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 37

def created_at
  @created_at
end

#expires_atObject

Returns the value of attribute expires_at.



26
27
28
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 26

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 18

def id
  @id
end

#last_sent_atObject

Returns the value of attribute last_sent_at.



35
36
37
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 35

def last_sent_at
  @last_sent_at
end

#max_attemptsObject

Returns the value of attribute max_attempts.



30
31
32
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 30

def max_attempts
  @max_attempts
end

#resendObject

Present on create responses: true when an active verification was resent instead of created.



40
41
42
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 40

def resend
  @resend
end

#send_countObject

Accepted deliveries (initial send + resends); each bills one verification fee.



33
34
35
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 33

def send_count
  @send_count
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 20

def status
  @status
end

#toObject

Returns the value of attribute to.



24
25
26
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 24

def to
  @to
end

#validObject

Returns the value of attribute valid.



42
43
44
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 42

def valid
  @valid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 67

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'channel' => :'channel',
    :'to' => :'to',
    :'expires_at' => :'expiresAt',
    :'attempts' => :'attempts',
    :'max_attempts' => :'maxAttempts',
    :'send_count' => :'sendCount',
    :'last_sent_at' => :'lastSentAt',
    :'created_at' => :'createdAt',
    :'resend' => :'resend',
    :'valid' => :'valid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 263

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



119
120
121
122
123
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 119

def self.openapi_all_of
  [
  :'Verification'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 95

def self.openapi_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'channel' => :'String',
    :'to' => :'String',
    :'expires_at' => :'Time',
    :'attempts' => :'Integer',
    :'max_attempts' => :'Integer',
    :'send_count' => :'Integer',
    :'last_sent_at' => :'Time',
    :'created_at' => :'Time',
    :'resend' => :'Boolean',
    :'valid' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 231

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      channel == o.channel &&
      to == o.to &&
      expires_at == o.expires_at &&
      attempts == o.attempts &&
      max_attempts == o.max_attempts &&
      send_count == o.send_count &&
      last_sent_at == o.last_sent_at &&
      created_at == o.created_at &&
      resend == o.resend &&
      valid == o.valid
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


250
251
252
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 250

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



256
257
258
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 256

def hash
  [id, status, channel, to, expires_at, attempts, max_attempts, send_count, last_sent_at, created_at, resend, valid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 285

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
206
207
# File 'lib/zernio-sdk/models/check_verification200_response.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending", "approved", "expired", "max_attempts_reached", "canceled", "delivery_failed"])
  return false unless status_validator.valid?(@status)
  channel_validator = EnumAttributeValidator.new('String', ["sms"])
  return false unless channel_validator.valid?(@channel)
  true
end