Class: Zernio::CompleteWhatsAppPhoneSelection200ResponseAccount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CompleteWhatsAppPhoneSelection200ResponseAccount
- Defined in:
- lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#display_name ⇒ Object
Meta-verified business name.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#selected_phone_number ⇒ Object
Returns the value of attribute selected_phone_number.
-
#username ⇒ Object
Display phone number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompleteWhatsAppPhoneSelection200ResponseAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CompleteWhatsAppPhoneSelection200ResponseAccount
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CompleteWhatsAppPhoneSelection200ResponseAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CompleteWhatsAppPhoneSelection200ResponseAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'selected_phone_number') self.selected_phone_number = attributes[:'selected_phone_number'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 18 def account_id @account_id end |
#display_name ⇒ Object
Meta-verified business name
26 27 28 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 26 def display_name @display_name end |
#is_active ⇒ Object
Returns the value of attribute is_active.
28 29 30 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 28 def is_active @is_active end |
#platform ⇒ Object
Returns the value of attribute platform.
20 21 22 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 20 def platform @platform end |
#selected_phone_number ⇒ Object
Returns the value of attribute selected_phone_number.
30 31 32 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 30 def selected_phone_number @selected_phone_number end |
#username ⇒ Object
Display phone number
23 24 25 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 23 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 55 def self.attribute_map { :'account_id' => :'accountId', :'platform' => :'platform', :'username' => :'username', :'display_name' => :'displayName', :'is_active' => :'isActive', :'selected_phone_number' => :'selectedPhoneNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 77 def self.openapi_types { :'account_id' => :'String', :'platform' => :'String', :'username' => :'String', :'display_name' => :'String', :'is_active' => :'Boolean', :'selected_phone_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
164 165 166 167 168 169 170 171 172 173 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 164 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && platform == o.platform && username == o.username && display_name == o.display_name && is_active == o.is_active && selected_phone_number == o.selected_phone_number end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 183 def hash [account_id, platform, username, display_name, is_active, selected_phone_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection200_response_account.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["whatsapp"]) return false unless platform_validator.valid?(@platform) true end |