Class: Zernio::CompleteWhatsAppPhoneSelectionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CompleteWhatsAppPhoneSelectionRequest
- Defined in:
- lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb
Instance Attribute Summary collapse
-
#phone_number_id ⇒ Object
The selected phone number ID (from listWhatsAppPhoneNumbers).
-
#profile_id ⇒ Object
The Zernio profile ID.
-
#redirect_url ⇒ Object
Optional URL to receive the post-connection redirect target.
-
#temp_token ⇒ Object
The temporary access token from the headless redirect.
-
#user_profile ⇒ Object
Optional user profile data (passthrough).
-
#waba_id ⇒ Object
The WABA ID containing the selected phone.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompleteWhatsAppPhoneSelectionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CompleteWhatsAppPhoneSelectionRequest
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CompleteWhatsAppPhoneSelectionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CompleteWhatsAppPhoneSelectionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] else self.profile_id = nil end if attributes.key?(:'phone_number_id') self.phone_number_id = attributes[:'phone_number_id'] else self.phone_number_id = nil end if attributes.key?(:'waba_id') self.waba_id = attributes[:'waba_id'] else self.waba_id = nil end if attributes.key?(:'temp_token') self.temp_token = attributes[:'temp_token'] else self.temp_token = nil end if attributes.key?(:'user_profile') self.user_profile = attributes[:'user_profile'] end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end end |
Instance Attribute Details
#phone_number_id ⇒ Object
The selected phone number ID (from listWhatsAppPhoneNumbers)
22 23 24 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 22 def phone_number_id @phone_number_id end |
#profile_id ⇒ Object
The Zernio profile ID
19 20 21 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 19 def profile_id @profile_id end |
#redirect_url ⇒ Object
Optional URL to receive the post-connection redirect target
34 35 36 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 34 def redirect_url @redirect_url end |
#temp_token ⇒ Object
The temporary access token from the headless redirect
28 29 30 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 28 def temp_token @temp_token end |
#user_profile ⇒ Object
Optional user profile data (passthrough)
31 32 33 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 31 def user_profile @user_profile end |
#waba_id ⇒ Object
The WABA ID containing the selected phone
25 26 27 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 25 def waba_id @waba_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 37 def self.attribute_map { :'profile_id' => :'profileId', :'phone_number_id' => :'phoneNumberId', :'waba_id' => :'wabaId', :'temp_token' => :'tempToken', :'user_profile' => :'userProfile', :'redirect_url' => :'redirect_url' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 59 def self.openapi_types { :'profile_id' => :'String', :'phone_number_id' => :'String', :'waba_id' => :'String', :'temp_token' => :'String', :'user_profile' => :'Object', :'redirect_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && profile_id == o.profile_id && phone_number_id == o.phone_number_id && waba_id == o.waba_id && temp_token == o.temp_token && user_profile == o.user_profile && redirect_url == o.redirect_url end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 221 def hash [profile_id, phone_number_id, waba_id, temp_token, user_profile, redirect_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @profile_id.nil? invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.') end if @phone_number_id.nil? invalid_properties.push('invalid value for "phone_number_id", phone_number_id cannot be nil.') end if @waba_id.nil? invalid_properties.push('invalid value for "waba_id", waba_id cannot be nil.') end if @temp_token.nil? invalid_properties.push('invalid value for "temp_token", temp_token cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 157 158 |
# File 'lib/zernio-sdk/models/complete_whats_app_phone_selection_request.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @profile_id.nil? return false if @phone_number_id.nil? return false if @waba_id.nil? return false if @temp_token.nil? true end |