Class: Zernio::ConnectWhatsAppCredentialsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/connect_whats_app_credentials_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConnectWhatsAppCredentialsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ConnectWhatsAppCredentialsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ConnectWhatsAppCredentialsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'access_token')
    self.access_token = attributes[:'access_token']
  else
    self.access_token = nil
  end

  if attributes.key?(:'waba_id')
    self.waba_id = attributes[:'waba_id']
  else
    self.waba_id = nil
  end

  if attributes.key?(:'phone_number_id')
    self.phone_number_id = attributes[:'phone_number_id']
  else
    self.phone_number_id = nil
  end

  if attributes.key?(:'pin')
    self.pin = attributes[:'pin']
  end
end

Instance Attribute Details

#access_tokenObject

Permanent System User access token from Meta Business Suite



22
23
24
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 22

def access_token
  @access_token
end

#phone_number_idObject

Phone Number ID from Meta WhatsApp Manager



28
29
30
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 28

def phone_number_id
  @phone_number_id
end

#pinObject

The 6-digit two-step verification PIN set on the number. Required if you enabled two-step verification for it, otherwise Meta rejects the Cloud API registration with error 133005 and the number cannot send messages.



31
32
33
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 31

def pin
  @pin
end

#profile_idObject

Your Zernio profile ID



19
20
21
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 19

def profile_id
  @profile_id
end

#waba_idObject

WhatsApp Business Account ID from Meta



25
26
27
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 25

def waba_id
  @waba_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 34

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'access_token' => :'accessToken',
    :'waba_id' => :'wabaId',
    :'phone_number_id' => :'phoneNumberId',
    :'pin' => :'pin'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 239

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 55

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'access_token' => :'String',
    :'waba_id' => :'String',
    :'phone_number_id' => :'String',
    :'pin' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



214
215
216
217
218
219
220
221
222
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 214

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      access_token == o.access_token &&
      waba_id == o.waba_id &&
      phone_number_id == o.phone_number_id &&
      pin == o.pin
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


226
227
228
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 226

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



232
233
234
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 232

def hash
  [profile_id, access_token, waba_id, phone_number_id, pin].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @access_token.nil?
    invalid_properties.push('invalid value for "access_token", access_token cannot be nil.')
  end

  if @waba_id.nil?
    invalid_properties.push('invalid value for "waba_id", waba_id cannot be nil.')
  end

  if @phone_number_id.nil?
    invalid_properties.push('invalid value for "phone_number_id", phone_number_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d{6}$/)
  if !@pin.nil? && @pin !~ pattern
    invalid_properties.push("invalid value for \"pin\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 261

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
# File 'lib/zernio-sdk/models/connect_whats_app_credentials_request.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @access_token.nil?
  return false if @waba_id.nil?
  return false if @phone_number_id.nil?
  return false if !@pin.nil? && @pin !~ Regexp.new(/^\d{6}$/)
  true
end