Class: Zernio::ConnectedApp
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ConnectedApp
- Defined in:
- lib/zernio-sdk/models/connected_app.rb
Overview
An OAuth client (AI assistant / MCP connector) authorized by the user and still holding at least one live token.
Instance Attribute Summary collapse
-
#authorized_at ⇒ Object
Returns the value of attribute authorized_at.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#client_name ⇒ Object
Name the client declared at registration.
-
#last_used_at ⇒ Object
Last time any of the client's live tokens authenticated a request.
-
#redirect_host ⇒ Object
Host of the client's registered redirect URI (non-http schemes are shown as scheme//host).
-
#scopes ⇒ Object
Scopes granted on the most recent token.
-
#token_count ⇒ Object
Live tokens held by the client (an active session is typically one access plus one refresh token).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConnectedApp
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConnectedApp
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ConnectedApp` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ConnectedApp`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'client_name') self.client_name = attributes[:'client_name'] end if attributes.key?(:'redirect_host') self.redirect_host = attributes[:'redirect_host'] end if attributes.key?(:'scopes') if (value = attributes[:'scopes']).is_a?(Array) self.scopes = value end end if attributes.key?(:'authorized_at') self. = attributes[:'authorized_at'] end if attributes.key?(:'last_used_at') self.last_used_at = attributes[:'last_used_at'] end if attributes.key?(:'token_count') self.token_count = attributes[:'token_count'] end end |
Instance Attribute Details
#authorized_at ⇒ Object
Returns the value of attribute authorized_at.
30 31 32 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 30 def @authorized_at end |
#client_id ⇒ Object
Returns the value of attribute client_id.
19 20 21 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 19 def client_id @client_id end |
#client_name ⇒ Object
Name the client declared at registration. Registration is open, so this is self-declared and not verified.
22 23 24 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 22 def client_name @client_name end |
#last_used_at ⇒ Object
Last time any of the client's live tokens authenticated a request.
33 34 35 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 33 def last_used_at @last_used_at end |
#redirect_host ⇒ Object
Host of the client's registered redirect URI (non-http schemes are shown as scheme//host). The destination an impostor cannot fake.
25 26 27 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 25 def redirect_host @redirect_host end |
#scopes ⇒ Object
Scopes granted on the most recent token.
28 29 30 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 28 def scopes @scopes end |
#token_count ⇒ Object
Live tokens held by the client (an active session is typically one access plus one refresh token).
36 37 38 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 36 def token_count @token_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 39 def self.attribute_map { :'client_id' => :'clientId', :'client_name' => :'clientName', :'redirect_host' => :'redirectHost', :'scopes' => :'scopes', :'authorized_at' => :'authorizedAt', :'last_used_at' => :'lastUsedAt', :'token_count' => :'tokenCount' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 79 80 81 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 75 def self.openapi_nullable Set.new([ :'redirect_host', :'authorized_at', :'last_used_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 62 def self.openapi_types { :'client_id' => :'String', :'client_name' => :'String', :'redirect_host' => :'String', :'scopes' => :'Array<String>', :'authorized_at' => :'Time', :'last_used_at' => :'Time', :'token_count' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 147 def ==(o) return true if self.equal?(o) self.class == o.class && client_id == o.client_id && client_name == o.client_name && redirect_host == o.redirect_host && scopes == o.scopes && == o. && last_used_at == o.last_used_at && token_count == o.token_count end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 167 def hash [client_id, client_name, redirect_host, scopes, , last_used_at, token_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
140 141 142 143 |
# File 'lib/zernio-sdk/models/connected_app.rb', line 140 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |