Class: Zernio::ConversionAction

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/conversion_action.rb

Overview

A Google Ads conversion action, e.g. a WEBPAGE conversion created via createConversionAction. Returned by listConversionActions and createConversionAction.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConversionAction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/zernio-sdk/models/conversion_action.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ConversionAction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ConversionAction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'tag_snippets')
    if (value = attributes[:'tag_snippets']).is_a?(Array)
      self.tag_snippets = value
    end
  else
    self.tag_snippets = nil
  end
end

Instance Attribute Details

#categoryObject

Google's ConversionActionCategory, e.g. DEFAULT, PURCHASE, LEAD.



31
32
33
# File 'lib/zernio-sdk/models/conversion_action.rb', line 31

def category
  @category
end

#idObject

Google Ads conversion action id.



20
21
22
# File 'lib/zernio-sdk/models/conversion_action.rb', line 20

def id
  @id
end

#nameObject

Returns the value of attribute name.



22
23
24
# File 'lib/zernio-sdk/models/conversion_action.rb', line 22

def name
  @name
end

#statusObject

Google's ConversionActionStatus, e.g. ENABLED, REMOVED, HIDDEN.



28
29
30
# File 'lib/zernio-sdk/models/conversion_action.rb', line 28

def status
  @status
end

#tag_snippetsObject

The code a customer pastes onto their site. Present for types Google generates a snippet for (e.g. WEBPAGE); empty otherwise.



34
35
36
# File 'lib/zernio-sdk/models/conversion_action.rb', line 34

def tag_snippets
  @tag_snippets
end

#typeObject

Google's ConversionActionType, e.g. WEBPAGE, UPLOAD_CLICKS.



25
26
27
# File 'lib/zernio-sdk/models/conversion_action.rb', line 25

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/zernio-sdk/models/conversion_action.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/zernio-sdk/models/conversion_action.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/zernio-sdk/models/conversion_action.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'type' => :'type',
    :'status' => :'status',
    :'category' => :'category',
    :'tag_snippets' => :'tagSnippets'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/models/conversion_action.rb', line 264

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/zernio-sdk/models/conversion_action.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/conversion_action.rb', line 59

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'status' => :'String',
    :'category' => :'String',
    :'tag_snippets' => :'Array<ConversionActionTagSnippetsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/conversion_action.rb', line 238

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      type == o.type &&
      status == o.status &&
      category == o.category &&
      tag_snippets == o.tag_snippets
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/zernio-sdk/models/conversion_action.rb', line 251

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



257
258
259
# File 'lib/zernio-sdk/models/conversion_action.rb', line 257

def hash
  [id, name, type, status, category, tag_snippets].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zernio-sdk/models/conversion_action.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  if @tag_snippets.nil?
    invalid_properties.push('invalid value for "tag_snippets", tag_snippets cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/zernio-sdk/models/conversion_action.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
172
173
174
# File 'lib/zernio-sdk/models/conversion_action.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @type.nil?
  return false if @status.nil?
  return false if @category.nil?
  return false if @tag_snippets.nil?
  true
end