Class: Zernio::ConversionEventUserClickIds
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ConversionEventUserClickIds
- Defined in:
- lib/zernio-sdk/models/conversion_event_user_click_ids.rb
Overview
Platform click identifiers captured from the originating ad click.
Instance Attribute Summary collapse
-
#fbc ⇒ Object
Meta click ID (from fbclid URL param).
-
#fbp ⇒ Object
Meta browser ID (_fbp cookie).
-
#gbraid ⇒ Object
Google iOS 14.5+ app attribution ID.
-
#gclid ⇒ Object
Google click ID (from gclid URL param).
-
#li_fat_id ⇒ Object
LinkedIn first-party ad tracking click ID.
-
#wbraid ⇒ Object
Google iOS 14.5+ web-to-app attribution ID.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ConversionEventUserClickIds
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ConversionEventUserClickIds
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ConversionEventUserClickIds` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ConversionEventUserClickIds`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'fbc') self.fbc = attributes[:'fbc'] end if attributes.key?(:'fbp') self.fbp = attributes[:'fbp'] end if attributes.key?(:'gclid') self.gclid = attributes[:'gclid'] end if attributes.key?(:'gbraid') self.gbraid = attributes[:'gbraid'] end if attributes.key?(:'wbraid') self.wbraid = attributes[:'wbraid'] end if attributes.key?(:'li_fat_id') self.li_fat_id = attributes[:'li_fat_id'] end end |
Instance Attribute Details
#fbc ⇒ Object
Meta click ID (from fbclid URL param).
20 21 22 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 20 def fbc @fbc end |
#fbp ⇒ Object
Meta browser ID (_fbp cookie).
23 24 25 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 23 def fbp @fbp end |
#gbraid ⇒ Object
Google iOS 14.5+ app attribution ID.
29 30 31 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 29 def gbraid @gbraid end |
#gclid ⇒ Object
Google click ID (from gclid URL param).
26 27 28 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 26 def gclid @gclid end |
#li_fat_id ⇒ Object
LinkedIn first-party ad tracking click ID. Captured by parsing li_fat_id from landing-page URLs after the advertiser enables enhanced conversion tracking on the LinkedIn Insight Tag. Sent to LinkedIn as the LINKEDIN_FIRST_PARTY_ADS_TRACKING_UUID userId. Opaque token, not hashed.
35 36 37 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 35 def li_fat_id @li_fat_id end |
#wbraid ⇒ Object
Google iOS 14.5+ web-to-app attribution ID.
32 33 34 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 32 def wbraid @wbraid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 38 def self.attribute_map { :'fbc' => :'fbc', :'fbp' => :'fbp', :'gclid' => :'gclid', :'gbraid' => :'gbraid', :'wbraid' => :'wbraid', :'li_fat_id' => :'li_fat_id' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 161 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 60 def self.openapi_types { :'fbc' => :'String', :'fbp' => :'String', :'gclid' => :'String', :'gbraid' => :'String', :'wbraid' => :'String', :'li_fat_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && fbc == o.fbc && fbp == o.fbp && gclid == o.gclid && gbraid == o.gbraid && wbraid == o.wbraid && li_fat_id == o.li_fat_id end |
#eql?(o) ⇒ Boolean
148 149 150 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 148 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 154 def hash [fbc, fbp, gclid, gbraid, wbraid, li_fat_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 |
# File 'lib/zernio-sdk/models/conversion_event_user_click_ids.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |