Class: Zernio::CreateAdAccount201Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateAdAccount201Response
- Defined in:
- lib/zernio-sdk/models/create_ad_account201_response.rb
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
New Meta ad account ID for subsequent ads calls.
-
#ads_manager_url ⇒ Object
Open the created account in Ads Manager.
-
#business_id ⇒ Object
Owning business portfolio ID.
-
#connection_updated ⇒ Object
Whether the connection scope and discovery schedule were updated.
-
#next_steps ⇒ Object
Payment setup instructions for the user.
-
#payment_method_required ⇒ Object
Always true as a delivery prerequisite.
-
#warnings ⇒ Object
Recovery instructions if the account could not be attached to the connection.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAdAccount201Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateAdAccount201Response
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdAccount201Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdAccount201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] else self.ad_account_id = nil end if attributes.key?(:'business_id') self.business_id = attributes[:'business_id'] else self.business_id = nil end if attributes.key?(:'connection_updated') self.connection_updated = attributes[:'connection_updated'] else self.connection_updated = nil end if attributes.key?(:'payment_method_required') self.payment_method_required = attributes[:'payment_method_required'] else self.payment_method_required = nil end if attributes.key?(:'ads_manager_url') self.ads_manager_url = attributes[:'ads_manager_url'] else self.ads_manager_url = nil end if attributes.key?(:'next_steps') self.next_steps = attributes[:'next_steps'] else self.next_steps = nil end if attributes.key?(:'warnings') if (value = attributes[:'warnings']).is_a?(Array) self.warnings = value end else self.warnings = nil end end |
Instance Attribute Details
#ad_account_id ⇒ Object
New Meta ad account ID for subsequent ads calls.
19 20 21 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 19 def ad_account_id @ad_account_id end |
#ads_manager_url ⇒ Object
Open the created account in Ads Manager.
31 32 33 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 31 def ads_manager_url @ads_manager_url end |
#business_id ⇒ Object
Owning business portfolio ID.
22 23 24 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 22 def business_id @business_id end |
#connection_updated ⇒ Object
Whether the connection scope and discovery schedule were updated.
25 26 27 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 25 def connection_updated @connection_updated end |
#next_steps ⇒ Object
Payment setup instructions for the user.
34 35 36 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 34 def next_steps @next_steps end |
#payment_method_required ⇒ Object
Always true as a delivery prerequisite. This is not a live funding-source check. Confirm payment or invoicing in Ads Manager.
28 29 30 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 28 def payment_method_required @payment_method_required end |
#warnings ⇒ Object
Recovery instructions if the account could not be attached to the connection.
37 38 39 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 37 def warnings @warnings end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 40 def self.attribute_map { :'ad_account_id' => :'adAccountId', :'business_id' => :'businessId', :'connection_updated' => :'connectionUpdated', :'payment_method_required' => :'paymentMethodRequired', :'ads_manager_url' => :'adsManagerUrl', :'next_steps' => :'nextSteps', :'warnings' => :'warnings' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 302 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 63 def self.openapi_types { :'ad_account_id' => :'String', :'business_id' => :'String', :'connection_updated' => :'Boolean', :'payment_method_required' => :'Boolean', :'ads_manager_url' => :'String', :'next_steps' => :'String', :'warnings' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 275 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && business_id == o.business_id && connection_updated == o.connection_updated && payment_method_required == o.payment_method_required && ads_manager_url == o.ads_manager_url && next_steps == o.next_steps && warnings == o.warnings end |
#eql?(o) ⇒ Boolean
289 290 291 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 289 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 295 def hash [ad_account_id, business_id, connection_updated, payment_method_required, ads_manager_url, next_steps, warnings].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 144 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @ad_account_id.nil? invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.') end pattern = Regexp.new(/^act_[0-9]+$/) if @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end if @business_id.nil? invalid_properties.push('invalid value for "business_id", business_id cannot be nil.') end if @connection_updated.nil? invalid_properties.push('invalid value for "connection_updated", connection_updated cannot be nil.') end if @payment_method_required.nil? invalid_properties.push('invalid value for "payment_method_required", payment_method_required cannot be nil.') end if @ads_manager_url.nil? invalid_properties.push('invalid value for "ads_manager_url", ads_manager_url cannot be nil.') end if @next_steps.nil? invalid_properties.push('invalid value for "next_steps", next_steps cannot be nil.') end if @warnings.nil? invalid_properties.push('invalid value for "warnings", warnings cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 324 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/zernio-sdk/models/create_ad_account201_response.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @ad_account_id.nil? return false if @ad_account_id !~ Regexp.new(/^act_[0-9]+$/) return false if @business_id.nil? return false if @connection_updated.nil? return false if @payment_method_required.nil? return false if @ads_manager_url.nil? return false if @next_steps.nil? return false if @warnings.nil? true end |