Class: Zernio::CreateAdCatalogRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_ad_catalog_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateAdCatalogRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdCatalogRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdCatalogRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'catalog_account_id')
    self. = attributes[:'catalog_account_id']
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'business_id')
    self.business_id = attributes[:'business_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'vertical')
    self.vertical = attributes[:'vertical']
  else
    self.vertical = 'commerce'
  end
end

Instance Attribute Details

#account_idObject

A facebook, instagram, metaads or whatsapp account ID



19
20
21
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 19

def 
  @account_id
end

#ad_account_idObject

Ad account whose owner business creates the catalog



25
26
27
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 25

def 
  @ad_account_id
end

#business_idObject

Business portfolio that owns the catalog



28
29
30
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 28

def business_id
  @business_id
end

#catalog_account_idObject

Account whose Meta login token performs the call (see GET)



22
23
24
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 22

def 
  @catalog_account_id
end

#nameObject

Returns the value of attribute name.



30
31
32
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 30

def name
  @name
end

#verticalObject

Returns the value of attribute vertical.



32
33
34
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 32

def vertical
  @vertical
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 57

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'catalog_account_id' => :'catalogAccountId',
    :'ad_account_id' => :'adAccountId',
    :'business_id' => :'businessId',
    :'name' => :'name',
    :'vertical' => :'vertical'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 79

def self.openapi_types
  {
    :'account_id' => :'String',
    :'catalog_account_id' => :'String',
    :'ad_account_id' => :'String',
    :'business_id' => :'String',
    :'name' => :'String',
    :'vertical' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
       == o. &&
      business_id == o.business_id &&
      name == o.name &&
      vertical == o.vertical
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 230

def hash
  [, , , business_id, name, vertical].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 145

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
172
173
# File 'lib/zernio-sdk/models/create_ad_catalog_request.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  vertical_validator = EnumAttributeValidator.new('String', ["commerce", "vehicles", "hotels", "flights", "destinations", "home_listings", "local_service_business", "offline_commerce", "ticketed_experiences", "transactable_items"])
  return false unless vertical_validator.valid?(@vertical)
  true
end