Class: Zernio::CreateAdLabelRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_ad_label_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateAdLabelRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdLabelRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdLabelRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'background_color')
    self.background_color = attributes[:'background_color']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end
end

Instance Attribute Details

#account_id ⇒ Object

Zernio SocialAccount id (Google Ads)



19
20
21
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 19

def 
  @account_id
end

#ad_account_id ⇒ Object

Google customer id. Required when the connection has multiple customers.



22
23
24
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 22

def 
  @ad_account_id
end

#background_color ⇒ Object

#RRGGBB. Google picks a color when omitted.



31
32
33
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 31

def background_color
  @background_color
end

#customer_id ⇒ Object

Alias of adAccountId



25
26
27
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 25

def customer_id
  @customer_id
end

#description ⇒ Object

Returns the value of attribute description.



33
34
35
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 33

def description
  @description
end

#name ⇒ Object

Trimmed before sending.



28
29
30
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 28

def name
  @name
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



48
49
50
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 36

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'ad_account_id' => :'adAccountId',
    :'customer_id' => :'customerId',
    :'name' => :'name',
    :'background_color' => :'backgroundColor',
    :'description' => :'description'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 293

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



70
71
72
73
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 58

def self.openapi_types
  {
    :'account_id' => :'String',
    :'ad_account_id' => :'String',
    :'customer_id' => :'String',
    :'name' => :'String',
    :'background_color' => :'String',
    :'description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



267
268
269
270
271
272
273
274
275
276
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 267

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      customer_id == o.customer_id &&
      name == o.name &&
      background_color == o.background_color &&
      description == o.description
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


280
281
282
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 280

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



286
287
288
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 286

def hash
  [, , customer_id, name, background_color, description].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  pattern = Regexp.new(/^\d+$/)
  if !@ad_account_id.nil? && @ad_account_id !~ pattern
    invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@customer_id.nil? && @customer_id !~ pattern
    invalid_properties.push("invalid value for \"customer_id\", must conform to the pattern #{pattern}.")
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 80
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^#[0-9a-fA-F]{6}$/)
  if !@background_color.nil? && @background_color !~ pattern
    invalid_properties.push("invalid value for \"background_color\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 200
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 200.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 315

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/create_ad_label_request.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/)
  return false if !@customer_id.nil? && @customer_id !~ Regexp.new(/^\d+$/)
  return false if @name.nil?
  return false if @name.to_s.length > 80
  return false if @name.to_s.length < 1
  return false if !@background_color.nil? && @background_color !~ Regexp.new(/^#[0-9a-fA-F]{6}$/)
  return false if !@description.nil? && @description.to_s.length > 200
  true
end