Class: Zernio::CreateAdNegativeKeywordList201Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateAdNegativeKeywordList201Response
- Defined in:
- lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb
Instance Attribute Summary collapse
-
#created ⇒ Object
Number of initial keyword criteria created.
-
#customer_id ⇒ Object
Resolved Google Ads customer id.
-
#id ⇒ Object
New shared set id.
-
#resource_name ⇒ Object
New shared set resource name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAdNegativeKeywordList201Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateAdNegativeKeywordList201Response
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateAdNegativeKeywordList201Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateAdNegativeKeywordList201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'resource_name') self.resource_name = attributes[:'resource_name'] end if attributes.key?(:'created') self.created = attributes[:'created'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end end |
Instance Attribute Details
#created ⇒ Object
Number of initial keyword criteria created.
25 26 27 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 25 def created @created end |
#customer_id ⇒ Object
Resolved Google Ads customer id.
28 29 30 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 28 def customer_id @customer_id end |
#id ⇒ Object
New shared set id.
19 20 21 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 19 def id @id end |
#resource_name ⇒ Object
New shared set resource name.
22 23 24 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 22 def resource_name @resource_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 31 def self.attribute_map { :'id' => :'id', :'resource_name' => :'resourceName', :'created' => :'created', :'customer_id' => :'customerId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 182 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 51 def self.openapi_types { :'id' => :'String', :'resource_name' => :'String', :'created' => :'Integer', :'customer_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 158 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && resource_name == o.resource_name && created == o.created && customer_id == o.customer_id end |
#eql?(o) ⇒ Boolean
169 170 171 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 169 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
175 176 177 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 175 def hash [id, resource_name, created, customer_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 101 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d+$/) if !@id.nil? && @id !~ pattern invalid_properties.push("invalid value for \"id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@customer_id.nil? && @customer_id !~ pattern invalid_properties.push("invalid value for \"customer_id\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 204 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 123 124 |
# File 'lib/zernio-sdk/models/create_ad_negative_keyword_list201_response.rb', line 119 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@id.nil? && @id !~ Regexp.new(/^\d+$/) return false if !@customer_id.nil? && @customer_id !~ Regexp.new(/^\d+$/) true end |