Class: Zernio::CreateContactRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_contact_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateContactRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateContactRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateContactRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'company')
    self.company = attributes[:'company']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'is_subscribed')
    self.is_subscribed = attributes[:'is_subscribed']
  else
    self.is_subscribed = true
  end

  if attributes.key?(:'notes')
    self.notes = attributes[:'notes']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_identifier')
    self.platform_identifier = attributes[:'platform_identifier']
  end

  if attributes.key?(:'display_identifier')
    self.display_identifier = attributes[:'display_identifier']
  end
end

Instance Attribute Details

#account_idObject

Optional. Creates a channel if provided with platform + platformIdentifier



33
34
35
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 33

def 
  @account_id
end

#companyObject

Returns the value of attribute company.



24
25
26
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 24

def company
  @company
end

#display_identifierObject

Returns the value of attribute display_identifier.



40
41
42
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 40

def display_identifier
  @display_identifier
end

#emailObject

Returns the value of attribute email.



22
23
24
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 22

def email
  @email
end

#is_subscribedObject

Returns the value of attribute is_subscribed.



28
29
30
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 28

def is_subscribed
  @is_subscribed
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 20

def name
  @name
end

#notesObject

Returns the value of attribute notes.



30
31
32
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 30

def notes
  @notes
end

#platformObject

Channel platform. Only the enum values support contact channels; any other platform is rejected with code platform_not_supported.



36
37
38
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 36

def platform
  @platform
end

#platform_identifierObject

Returns the value of attribute platform_identifier.



38
39
40
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 38

def platform_identifier
  @platform_identifier
end

#profile_idObject

Returns the value of attribute profile_id.



18
19
20
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 18

def profile_id
  @profile_id
end

#tagsObject

Returns the value of attribute tags.



26
27
28
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 26

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 65

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'name' => :'name',
    :'email' => :'email',
    :'company' => :'company',
    :'tags' => :'tags',
    :'is_subscribed' => :'isSubscribed',
    :'notes' => :'notes',
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'platform_identifier' => :'platformIdentifier',
    :'display_identifier' => :'displayIdentifier'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 273

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 109

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 92

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'name' => :'String',
    :'email' => :'String',
    :'company' => :'String',
    :'tags' => :'Array<String>',
    :'is_subscribed' => :'Boolean',
    :'notes' => :'String',
    :'account_id' => :'String',
    :'platform' => :'String',
    :'platform_identifier' => :'String',
    :'display_identifier' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      name == o.name &&
      email == o.email &&
      company == o.company &&
      tags == o.tags &&
      is_subscribed == o.is_subscribed &&
      notes == o.notes &&
       == o. &&
      platform == o.platform &&
      platform_identifier == o.platform_identifier &&
      display_identifier == o.display_identifier
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 266

def hash
  [profile_id, name, email, company, tags, is_subscribed, notes, , platform, platform_identifier, display_identifier].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 185

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
# File 'lib/zernio-sdk/models/create_contact_request.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @name.nil?
  platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook", "telegram", "twitter", "bluesky", "reddit", "whatsapp", "slack", "sms"])
  return false unless platform_validator.valid?(@platform)
  true
end