Class: Zernio::CreateConversionActionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateConversionActionRequest
- Defined in:
- lib/zernio-sdk/models/create_conversion_action_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
SocialAccount ID.
-
#always_use_default_value ⇒ Object
When true, always use defaultValue and ignore any value sent with the event.
-
#customer_id ⇒ Object
Google Ads customer id (digits only).
-
#default_value ⇒ Object
Default conversion value used when an event doesn't carry its own value.
-
#name ⇒ Object
Returns the value of attribute name.
-
#type ⇒ Object
Only WEBPAGE is supported for creation today.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateConversionActionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateConversionActionRequest
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateConversionActionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateConversionActionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'default_value') self.default_value = attributes[:'default_value'] end if attributes.key?(:'always_use_default_value') self.always_use_default_value = attributes[:'always_use_default_value'] end end |
Instance Attribute Details
#account_id ⇒ Object
SocialAccount ID. Must be a googleads account.
19 20 21 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 19 def account_id @account_id end |
#always_use_default_value ⇒ Object
When true, always use defaultValue and ignore any value sent with the event. Defaults to true when defaultValue is set.
33 34 35 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 33 def always_use_default_value @always_use_default_value end |
#customer_id ⇒ Object
Google Ads customer id (digits only). Resolved automatically when the connection has exactly one accessible customer.
22 23 24 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 22 def customer_id @customer_id end |
#default_value ⇒ Object
Default conversion value used when an event doesn't carry its own value.
30 31 32 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 30 def default_value @default_value end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 24 def name @name end |
#type ⇒ Object
Only WEBPAGE is supported for creation today.
27 28 29 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 27 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 58 def self.attribute_map { :'account_id' => :'accountId', :'customer_id' => :'customerId', :'name' => :'name', :'type' => :'type', :'default_value' => :'defaultValue', :'always_use_default_value' => :'alwaysUseDefaultValue' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 80 def self.openapi_types { :'account_id' => :'String', :'customer_id' => :'String', :'name' => :'String', :'type' => :'String', :'default_value' => :'Float', :'always_use_default_value' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
245 246 247 248 249 250 251 252 253 254 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 245 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && customer_id == o.customer_id && name == o.name && type == o.type && default_value == o.default_value && always_use_default_value == o.always_use_default_value end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 264 def hash [account_id, customer_id, name, type, default_value, always_use_default_value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if !@default_value.nil? && @default_value < 0 invalid_properties.push('invalid value for "default_value", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/create_conversion_action_request.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 1 return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["WEBPAGE"]) return false unless type_validator.valid?(@type) return false if !@default_value.nil? && @default_value < 0 true end |