Class: Zernio::CreateCustomConversionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateCustomConversionRequest
- Defined in:
- lib/zernio-sdk/models/create_custom_conversion_request.rb
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
Meta ad account id (act_
). -
#custom_event_type ⇒ Object
Meta custom_event_type, e.g.
-
#name ⇒ Object
Also the reuse key, together with pixelId.
-
#pixel_id ⇒ Object
Meta pixel id (event_source_id).
-
#rule ⇒ Object
Meta conversion rule, forwarded verbatim.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCustomConversionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCustomConversionRequest
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateCustomConversionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateCustomConversionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] else self.ad_account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'pixel_id') self.pixel_id = attributes[:'pixel_id'] else self.pixel_id = nil end if attributes.key?(:'custom_event_type') self.custom_event_type = attributes[:'custom_event_type'] else self.custom_event_type = nil end if attributes.key?(:'rule') self.rule = attributes[:'rule'] else self.rule = nil end end |
Instance Attribute Details
#ad_account_id ⇒ Object
Meta ad account id (act_
19 20 21 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 19 def ad_account_id @ad_account_id end |
#custom_event_type ⇒ Object
Meta custom_event_type, e.g. LEAD, PURCHASE, OTHER.
28 29 30 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 28 def custom_event_type @custom_event_type end |
#name ⇒ Object
Also the reuse key, together with pixelId.
22 23 24 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 22 def name @name end |
#pixel_id ⇒ Object
Meta pixel id (event_source_id). From GET /v1/accounts/accountId/tracking-tags.
25 26 27 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 25 def pixel_id @pixel_id end |
#rule ⇒ Object
Meta conversion rule, forwarded verbatim.
31 32 33 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 31 def rule @rule end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 34 def self.attribute_map { :'ad_account_id' => :'adAccountId', :'name' => :'name', :'pixel_id' => :'pixelId', :'custom_event_type' => :'customEventType', :'rule' => :'rule' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 244 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 55 def self.openapi_types { :'ad_account_id' => :'String', :'name' => :'String', :'pixel_id' => :'String', :'custom_event_type' => :'String', :'rule' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && name == o.name && pixel_id == o.pixel_id && custom_event_type == o.custom_event_type && rule == o.rule end |
#eql?(o) ⇒ Boolean
231 232 233 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 231 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
237 238 239 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 237 def hash [ad_account_id, name, pixel_id, custom_event_type, rule].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @ad_account_id.nil? invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if @pixel_id.nil? invalid_properties.push('invalid value for "pixel_id", pixel_id cannot be nil.') end if @custom_event_type.nil? invalid_properties.push('invalid value for "custom_event_type", custom_event_type cannot be nil.') end if @rule.nil? invalid_properties.push('invalid value for "rule", rule cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 266 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 160 161 |
# File 'lib/zernio-sdk/models/create_custom_conversion_request.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @ad_account_id.nil? return false if @name.nil? return false if @name.to_s.length > 255 return false if @pixel_id.nil? return false if @custom_event_type.nil? return false if @rule.nil? true end |