Class: Zernio::CreateDiscordGuildRoleRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_discord_guild_role_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateDiscordGuildRoleRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateDiscordGuildRoleRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateDiscordGuildRoleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'hoist')
    self.hoist = attributes[:'hoist']
  end

  if attributes.key?(:'mentionable')
    self.mentionable = attributes[:'mentionable']
  end

  if attributes.key?(:'permissions')
    self.permissions = attributes[:'permissions']
  end
end

Instance Attribute Details

#colorObject

Decimal color (0 = no color). 0xFF0000 red is 16711680.



21
22
23
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 21

def color
  @color
end

#hoistObject

Display members with this role separately in the member list



24
25
26
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 24

def hoist
  @hoist
end

#mentionableObject

Allow anyone to @mention this role



27
28
29
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 27

def mentionable
  @mentionable
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 18

def name
  @name
end

#permissionsObject

Permissions bitfield as a stringified integer



30
31
32
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 30

def permissions
  @permissions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 33

def self.attribute_map
  {
    :'name' => :'name',
    :'color' => :'color',
    :'hoist' => :'hoist',
    :'mentionable' => :'mentionable',
    :'permissions' => :'permissions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 54

def self.openapi_types
  {
    :'name' => :'String',
    :'color' => :'Integer',
    :'hoist' => :'Boolean',
    :'mentionable' => :'Boolean',
    :'permissions' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      color == o.color &&
      hoist == o.hoist &&
      mentionable == o.mentionable &&
      permissions == o.permissions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 205

def hash
  [name, color, hoist, mentionable, permissions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@color.nil? && @color > 16777215
    invalid_properties.push('invalid value for "color", must be smaller than or equal to 16777215.')
  end

  if !@color.nil? && @color < 0
    invalid_properties.push('invalid value for "color", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/create_discord_guild_role_request.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @name.to_s.length < 1
  return false if !@color.nil? && @color > 16777215
  return false if !@color.nil? && @color < 0
  true
end