Class: Zernio::CreateDiscordScheduledEventRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateDiscordScheduledEventRequest
- Defined in:
- lib/zernio-sdk/models/create_discord_scheduled_event_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#description ⇒ Object
Returns the value of attribute description.
-
#entity ⇒ Object
Returns the value of attribute entity.
-
#image_data_uri ⇒ Object
Optional cover image as a base64 data URI.
-
#name ⇒ Object
Returns the value of attribute name.
-
#starts_at ⇒ Object
ISO 8601 start time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDiscordScheduledEventRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateDiscordScheduledEventRequest
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateDiscordScheduledEventRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateDiscordScheduledEventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'starts_at') self.starts_at = attributes[:'starts_at'] else self.starts_at = nil end if attributes.key?(:'entity') self.entity = attributes[:'entity'] else self.entity = nil end if attributes.key?(:'image_data_uri') self.image_data_uri = attributes[:'image_data_uri'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 18 def account_id @account_id end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 22 def description @description end |
#entity ⇒ Object
Returns the value of attribute entity.
27 28 29 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 27 def entity @entity end |
#image_data_uri ⇒ Object
Optional cover image as a base64 data URI.
30 31 32 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 30 def image_data_uri @image_data_uri end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 20 def name @name end |
#starts_at ⇒ Object
ISO 8601 start time. Must be in the future.
25 26 27 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 25 def starts_at @starts_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 33 def self.attribute_map { :'account_id' => :'accountId', :'name' => :'name', :'description' => :'description', :'starts_at' => :'startsAt', :'entity' => :'entity', :'image_data_uri' => :'imageDataUri' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 282 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 55 def self.openapi_types { :'account_id' => :'String', :'name' => :'String', :'description' => :'String', :'starts_at' => :'Time', :'entity' => :'CreateDiscordScheduledEventRequestEntity', :'image_data_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && name == o.name && description == o.description && starts_at == o.starts_at && entity == o.entity && image_data_uri == o.image_data_uri end |
#eql?(o) ⇒ Boolean
269 270 271 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 269 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
275 276 277 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 275 def hash [account_id, name, description, starts_at, entity, image_data_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@description.nil? && @description.to_s.length > 1000 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.') end if @starts_at.nil? invalid_properties.push('invalid value for "starts_at", starts_at cannot be nil.') end if @entity.nil? invalid_properties.push('invalid value for "entity", entity cannot be nil.') end pattern = Regexp.new(/^data:image\/(png|jpeg|gif);base64,/) if !@image_data_uri.nil? && @image_data_uri !~ pattern invalid_properties.push("invalid value for \"image_data_uri\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zernio-sdk/models/create_discord_scheduled_event_request.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @name.nil? return false if @name.to_s.length > 100 return false if @name.to_s.length < 1 return false if !@description.nil? && @description.to_s.length > 1000 return false if @starts_at.nil? return false if @entity.nil? return false if !@image_data_uri.nil? && @image_data_uri !~ Regexp.new(/^data:image\/(png|jpeg|gif);base64,/) true end |