Class: Zernio::CreateImessageGroupRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateImessageGroupRequest
- Defined in:
- lib/zernio-sdk/models/create_imessage_group_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The iMessage account (sender) that opens the group.
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#contacts ⇒ Object
Participant handles (E.164 phones or iMessage emails).
-
#name ⇒ Object
Group name (required for WhatsApp groups).
-
#text ⇒ Object
The first message.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateImessageGroupRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateImessageGroupRequest
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateImessageGroupRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateImessageGroupRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'contacts') if (value = attributes[:'contacts']).is_a?(Array) self.contacts = value end else self.contacts = nil end if attributes.key?(:'text') self.text = attributes[:'text'] else self.text = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'channel') self.channel = attributes[:'channel'] else self.channel = 'imessage' end end |
Instance Attribute Details
#account_id ⇒ Object
The iMessage account (sender) that opens the group
19 20 21 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 19 def account_id @account_id end |
#channel ⇒ Object
Returns the value of attribute channel.
30 31 32 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 30 def channel @channel end |
#contacts ⇒ Object
Participant handles (E.164 phones or iMessage emails)
22 23 24 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 22 def contacts @contacts end |
#name ⇒ Object
Group name (required for WhatsApp groups)
28 29 30 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 28 def name @name end |
#text ⇒ Object
The first message
25 26 27 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 25 def text @text end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 55 def self.attribute_map { :'account_id' => :'accountId', :'contacts' => :'contacts', :'text' => :'text', :'name' => :'name', :'channel' => :'channel' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 284 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 76 def self.openapi_types { :'account_id' => :'String', :'contacts' => :'Array<String>', :'text' => :'String', :'name' => :'String', :'channel' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && contacts == o.contacts && text == o.text && name == o.name && channel == o.channel end |
#eql?(o) ⇒ Boolean
271 272 273 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 271 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
277 278 279 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 277 def hash [account_id, contacts, text, name, channel].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @contacts.nil? invalid_properties.push('invalid value for "contacts", contacts cannot be nil.') end if @contacts.length > 32 invalid_properties.push('invalid value for "contacts", number of items must be less than or equal to 32.') end if @contacts.length < 2 invalid_properties.push('invalid value for "contacts", number of items must be greater than or equal to 2.') end if @text.nil? invalid_properties.push('invalid value for "text", text cannot be nil.') end if @text.to_s.length > 10000 invalid_properties.push('invalid value for "text", the character length must be smaller than or equal to 10000.') end if !@name.nil? && @name.to_s.length > 32 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 32.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/create_imessage_group_request.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @contacts.nil? return false if @contacts.length > 32 return false if @contacts.length < 2 return false if @text.nil? return false if @text.to_s.length > 10000 return false if !@name.nil? && @name.to_s.length > 32 channel_validator = EnumAttributeValidator.new('String', ["imessage", "sms", "rcs", "whatsapp"]) return false unless channel_validator.valid?(@channel) true end |