Class: Zernio::CreateInviteTokenRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_invite_token_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateInviteTokenRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateInviteTokenRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateInviteTokenRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  else
    self.scope = nil
  end

  if attributes.key?(:'profile_ids')
    if (value = attributes[:'profile_ids']).is_a?(Array)
      self.profile_ids = value
    end
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = 'member'
  end

  if attributes.key?(:'read_only')
    self.read_only = attributes[:'read_only']
  end
end

Instance Attribute Details

#profile_idsObject

Required if scope is 'profiles'. Array of profile IDs to grant access to.



22
23
24
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 22

def profile_ids
  @profile_ids
end

#read_onlyObject

Deprecated. Use role 'viewer' instead. When true, the invite is created with role 'viewer'. Cannot be combined with role 'billing_admin' or 'admin'.



28
29
30
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 28

def read_only
  @read_only
end

#roleObject

Org role granted to the invitee. Defaults to 'member'. 'admin' can manage the team (invite/remove members, change roles and access) and billing, but not ownership transfer or account deletion. 'billing_admin' (displayed as Billing Manager) manages billing only. 'viewer' creates a read-only member who can view everything in their profile scope but cannot perform any content mutation (publish, edit, delete, connect accounts).



25
26
27
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 25

def role
  @role
end

#scopeObject

'all' grants access to all profiles, 'profiles' restricts to specific profiles



19
20
21
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 19

def scope
  @scope
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 53

def self.attribute_map
  {
    :'scope' => :'scope',
    :'profile_ids' => :'profileIds',
    :'role' => :'role',
    :'read_only' => :'readOnly'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 73

def self.openapi_types
  {
    :'scope' => :'String',
    :'profile_ids' => :'Array<String>',
    :'role' => :'String',
    :'read_only' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scope == o.scope &&
      profile_ids == o.profile_ids &&
      role == o.role &&
      read_only == o.read_only
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 190

def hash
  [scope, profile_ids, role, read_only].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @scope.nil?
    invalid_properties.push('invalid value for "scope", scope cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
149
# File 'lib/zernio-sdk/models/create_invite_token_request.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @scope.nil?
  scope_validator = EnumAttributeValidator.new('String', ["all", "profiles"])
  return false unless scope_validator.valid?(@scope)
  role_validator = EnumAttributeValidator.new('String', ["admin", "member", "billing_admin", "viewer"])
  return false unless role_validator.valid?(@role)
  true
end