Class: Zernio::CreateLeadFormRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_lead_form_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateLeadFormRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateLeadFormRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateLeadFormRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'questions')
    if (value = attributes[:'questions']).is_a?(Array)
      self.questions = value
    end
  end

  if attributes.key?(:'privacy_policy_url')
    self.privacy_policy_url = attributes[:'privacy_policy_url']
  else
    self.privacy_policy_url = nil
  end

  if attributes.key?(:'privacy_policy_link_text')
    self.privacy_policy_link_text = attributes[:'privacy_policy_link_text']
  end

  if attributes.key?(:'follow_up_action_url')
    self.follow_up_action_url = attributes[:'follow_up_action_url']
  end

  if attributes.key?(:'locale')
    self.locale = attributes[:'locale']
  end

  if attributes.key?(:'thank_you_title')
    self.thank_you_title = attributes[:'thank_you_title']
  end

  if attributes.key?(:'thank_you_body')
    self.thank_you_body = attributes[:'thank_you_body']
  end

  if attributes.key?(:'thank_you_button_text')
    self.thank_you_button_text = attributes[:'thank_you_button_text']
  end

  if attributes.key?(:'thank_you_button_type')
    self.thank_you_button_type = attributes[:'thank_you_button_type']
  end

  if attributes.key?(:'thank_you_website_url')
    self.thank_you_website_url = attributes[:'thank_you_website_url']
  end

  if attributes.key?(:'is_optimized_for_quality')
    self.is_optimized_for_quality = attributes[:'is_optimized_for_quality']
  end

  if attributes.key?(:'platform_specific_data')
    self.platform_specific_data = attributes[:'platform_specific_data']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 18

def 
  @account_id
end

#follow_up_action_urlObject

Deprecated: use platformSpecificData.followUpActionUrl.



31
32
33
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 31

def follow_up_action_url
  @follow_up_action_url
end

#is_optimized_for_qualityObject

Deprecated: use platformSpecificData.isOptimizedForQuality.



52
53
54
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 52

def is_optimized_for_quality
  @is_optimized_for_quality
end

#localeObject

Deprecated: use platformSpecificData.locale.



34
35
36
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 34

def locale
  @locale
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 20

def name
  @name
end

#platform_specific_dataObject

Returns the value of attribute platform_specific_data.



54
55
56
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 54

def platform_specific_data
  @platform_specific_data
end

Deprecated: use platformSpecificData.privacyPolicyLinkText.



28
29
30
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 28

def privacy_policy_link_text
  @privacy_policy_link_text
end

#privacy_policy_urlObject

Returns the value of attribute privacy_policy_url.



25
26
27
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 25

def privacy_policy_url
  @privacy_policy_url
end

#questionsObject

Deprecated (Meta legacy shape): use platformSpecificData.questions.



23
24
25
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 23

def questions
  @questions
end

#thank_you_bodyObject

Deprecated: use platformSpecificData.thankYouBody.



40
41
42
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 40

def thank_you_body
  @thank_you_body
end

#thank_you_button_textObject

Deprecated: use platformSpecificData.thankYouButtonText.



43
44
45
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 43

def thank_you_button_text
  @thank_you_button_text
end

#thank_you_button_typeObject

Deprecated: use platformSpecificData.thankYouButtonType.



46
47
48
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 46

def thank_you_button_type
  @thank_you_button_type
end

#thank_you_titleObject

Deprecated: use platformSpecificData.thankYouTitle.



37
38
39
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 37

def thank_you_title
  @thank_you_title
end

#thank_you_website_urlObject

Deprecated: use platformSpecificData.thankYouWebsiteUrl.



49
50
51
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 49

def thank_you_website_url
  @thank_you_website_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 57

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'questions' => :'questions',
    :'privacy_policy_url' => :'privacyPolicyUrl',
    :'privacy_policy_link_text' => :'privacyPolicyLinkText',
    :'follow_up_action_url' => :'followUpActionUrl',
    :'locale' => :'locale',
    :'thank_you_title' => :'thankYouTitle',
    :'thank_you_body' => :'thankYouBody',
    :'thank_you_button_text' => :'thankYouButtonText',
    :'thank_you_button_type' => :'thankYouButtonType',
    :'thank_you_website_url' => :'thankYouWebsiteUrl',
    :'is_optimized_for_quality' => :'isOptimizedForQuality',
    :'platform_specific_data' => :'platformSpecificData'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 336

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 87

def self.openapi_types
  {
    :'account_id' => :'String',
    :'name' => :'String',
    :'questions' => :'Array<CreateLeadFormRequestQuestionsInner>',
    :'privacy_policy_url' => :'String',
    :'privacy_policy_link_text' => :'String',
    :'follow_up_action_url' => :'String',
    :'locale' => :'String',
    :'thank_you_title' => :'String',
    :'thank_you_body' => :'String',
    :'thank_you_button_text' => :'String',
    :'thank_you_button_type' => :'String',
    :'thank_you_website_url' => :'String',
    :'is_optimized_for_quality' => :'Boolean',
    :'platform_specific_data' => :'CreateLeadFormRequestPlatformSpecificData'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      questions == o.questions &&
      privacy_policy_url == o.privacy_policy_url &&
      privacy_policy_link_text == o.privacy_policy_link_text &&
      follow_up_action_url == o.follow_up_action_url &&
      locale == o.locale &&
      thank_you_title == o.thank_you_title &&
      thank_you_body == o.thank_you_body &&
      thank_you_button_text == o.thank_you_button_text &&
      thank_you_button_type == o.thank_you_button_type &&
      thank_you_website_url == o.thank_you_website_url &&
      is_optimized_for_quality == o.is_optimized_for_quality &&
      platform_specific_data == o.platform_specific_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


323
324
325
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



329
330
331
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 329

def hash
  [, name, questions, privacy_policy_url, privacy_policy_link_text, follow_up_action_url, locale, thank_you_title, thank_you_body, thank_you_button_text, thank_you_button_type, thank_you_website_url, is_optimized_for_quality, platform_specific_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 200
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 200.')
  end

  if !@questions.nil? && @questions.length < 1
    invalid_properties.push('invalid value for "questions", number of items must be greater than or equal to 1.')
  end

  if @privacy_policy_url.nil?
    invalid_properties.push('invalid value for "privacy_policy_url", privacy_policy_url cannot be nil.')
  end

  if !@privacy_policy_link_text.nil? && @privacy_policy_link_text.to_s.length > 70
    invalid_properties.push('invalid value for "privacy_policy_link_text", the character length must be smaller than or equal to 70.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 358

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



227
228
229
230
231
232
233
234
235
236
# File 'lib/zernio-sdk/models/create_lead_form_request.rb', line 227

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 200
  return false if !@questions.nil? && @questions.length < 1
  return false if @privacy_policy_url.nil?
  return false if !@privacy_policy_link_text.nil? && @privacy_policy_link_text.to_s.length > 70
  true
end