Class: Zernio::CreatePhoneNumberKycLinkRequestBranding
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreatePhoneNumberKycLinkRequestBranding
- Defined in:
- lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb
Overview
Optional white-label of the hosted page the end customer sees.
Instance Attribute Summary collapse
-
#brand_color ⇒ Object
Hex color (e.g. #1a73e8) used as a brand accent on the page.
-
#company_name ⇒ Object
Your company name, shown on the hosted page.
-
#logo_url ⇒ Object
Logo shown above the form.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePhoneNumberKycLinkRequestBranding
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreatePhoneNumberKycLinkRequestBranding
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreatePhoneNumberKycLinkRequestBranding` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreatePhoneNumberKycLinkRequestBranding`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] end if attributes.key?(:'logo_url') self.logo_url = attributes[:'logo_url'] end if attributes.key?(:'brand_color') self.brand_color = attributes[:'brand_color'] end end |
Instance Attribute Details
#brand_color ⇒ Object
Hex color (e.g. #1a73e8) used as a brand accent on the page.
26 27 28 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 26 def brand_color @brand_color end |
#company_name ⇒ Object
Your company name, shown on the hosted page.
20 21 22 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 20 def company_name @company_name end |
#logo_url ⇒ Object
Logo shown above the form.
23 24 25 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 23 def logo_url @logo_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 29 def self.attribute_map { :'company_name' => :'companyName', :'logo_url' => :'logoUrl', :'brand_color' => :'brandColor' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 171 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 48 def self.openapi_types { :'company_name' => :'String', :'logo_url' => :'String', :'brand_color' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
148 149 150 151 152 153 154 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 148 def ==(o) return true if self.equal?(o) self.class == o.class && company_name == o.company_name && logo_url == o.logo_url && brand_color == o.brand_color end |
#eql?(o) ⇒ Boolean
158 159 160 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 158 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 164 def hash [company_name, logo_url, brand_color].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@company_name.nil? && @company_name.to_s.length > 60 invalid_properties.push('invalid value for "company_name", the character length must be smaller than or equal to 60.') end pattern = Regexp.new(/^#[0-9a-fA-F]{6}$/) if !@brand_color.nil? && @brand_color !~ pattern invalid_properties.push("invalid value for \"brand_color\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
110 111 112 113 114 115 |
# File 'lib/zernio-sdk/models/create_phone_number_kyc_link_request_branding.rb', line 110 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@company_name.nil? && @company_name.to_s.length > 60 return false if !@brand_color.nil? && @brand_color !~ Regexp.new(/^#[0-9a-fA-F]{6}$/) true end |