Class: Zernio::CreatePinterestBoardRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreatePinterestBoardRequest
- Defined in:
- lib/zernio-sdk/models/create_pinterest_board_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
Board description.
-
#name ⇒ Object
Name of the board.
-
#privacy ⇒ Object
Board privacy setting.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePinterestBoardRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreatePinterestBoardRequest
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreatePinterestBoardRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreatePinterestBoardRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'privacy') self.privacy = attributes[:'privacy'] else self.privacy = 'PUBLIC' end end |
Instance Attribute Details
#description ⇒ Object
Board description
22 23 24 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 22 def description @description end |
#name ⇒ Object
Name of the board
19 20 21 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 19 def name @name end |
#privacy ⇒ Object
Board privacy setting
25 26 27 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 25 def privacy @privacy end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 50 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'privacy' => :'privacy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 183 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 69 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'privacy' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && privacy == o.privacy end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 176 def hash [name, description, privacy].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 134 135 136 |
# File 'lib/zernio-sdk/models/create_pinterest_board_request.rb', line 130 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? privacy_validator = EnumAttributeValidator.new('String', ["PUBLIC", "PROTECTED", "SECRET"]) return false unless privacy_validator.valid?(@privacy) true end |