Class: Zernio::CreateRcsAgentRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_rcs_agent_request.rb

Overview

Send exactly one of brandId or brand.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateRcsAgentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateRcsAgentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateRcsAgentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'brand_id')
    self.brand_id = attributes[:'brand_id']
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  else
    self.display_name = nil
  end

  if attributes.key?(:'use_case')
    self.use_case = attributes[:'use_case']
  else
    self.use_case = nil
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  else
    self.profile = nil
  end

  if attributes.key?(:'sms_fallback_from')
    self.sms_fallback_from = attributes[:'sms_fallback_from']
  end
end

Instance Attribute Details

#brand ⇒ Object

Returns the value of attribute brand.



23
24
25
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 23

def brand
  @brand
end

#brand_id ⇒ Object

Returns the value of attribute brand_id.



21
22
23
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 21

def brand_id
  @brand_id
end

#display_name ⇒ Object

Shown as the sender name.



26
27
28
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 26

def display_name
  @display_name
end

#profile ⇒ Object

Returns the value of attribute profile.



30
31
32
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 30

def profile
  @profile
end

#profile_id ⇒ Object

Returns the value of attribute profile_id.



19
20
21
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 19

def profile_id
  @profile_id
end

#sms_fallback_from ⇒ Object

One of your SMS-enabled numbers. Phones without RCS get the message as SMS from it.



33
34
35
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 33

def sms_fallback_from
  @sms_fallback_from
end

#use_case ⇒ Object

Returns the value of attribute use_case.



28
29
30
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 28

def use_case
  @use_case
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 58

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'brand_id' => :'brandId',
    :'brand' => :'brand',
    :'display_name' => :'displayName',
    :'use_case' => :'useCase',
    :'profile' => :'profile',
    :'sms_fallback_from' => :'smsFallbackFrom'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 267

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



94
95
96
97
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 81

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'brand_id' => :'String',
    :'brand' => :'RcsBrandInput',
    :'display_name' => :'String',
    :'use_case' => :'String',
    :'profile' => :'RcsAgentProfile',
    :'sms_fallback_from' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



240
241
242
243
244
245
246
247
248
249
250
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      brand_id == o.brand_id &&
      brand == o.brand &&
      display_name == o.display_name &&
      use_case == o.use_case &&
      profile == o.profile &&
      sms_fallback_from == o.sms_fallback_from
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 254

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



260
261
262
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 260

def hash
  [profile_id, brand_id, brand, display_name, use_case, profile, sms_fallback_from].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @display_name.nil?
    invalid_properties.push('invalid value for "display_name", display_name cannot be nil.')
  end

  if @display_name.to_s.length > 40
    invalid_properties.push('invalid value for "display_name", the character length must be smaller than or equal to 40.')
  end

  if @use_case.nil?
    invalid_properties.push('invalid value for "use_case", use_case cannot be nil.')
  end

  if @profile.nil?
    invalid_properties.push('invalid value for "profile", profile cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
192
# File 'lib/zernio-sdk/models/create_rcs_agent_request.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @display_name.nil?
  return false if @display_name.to_s.length > 40
  return false if @use_case.nil?
  use_case_validator = EnumAttributeValidator.new('String', ["MULTI_USE", "PROMOTIONAL", "TRANSACTIONAL", "OTP"])
  return false unless use_case_validator.valid?(@use_case)
  return false if @profile.nil?
  true
end