Class: Zernio::CreateSipTrunk201Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_sip_trunk201_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateSipTrunk201Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateSipTrunk201Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateSipTrunk201Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'sip_host')
    self.sip_host = attributes[:'sip_host']
  end

  if attributes.key?(:'sip_port')
    self.sip_port = attributes[:'sip_port']
  end

  if attributes.key?(:'transport')
    self.transport = attributes[:'transport']
  end

  if attributes.key?(:'termination')
    self.termination = attributes[:'termination']
  end

  if attributes.key?(:'numbers_attached')
    self.numbers_attached = attributes[:'numbers_attached']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'digest_password')
    self.digest_password = attributes[:'digest_password']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



32
33
34
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 32

def created_at
  @created_at
end

#digest_passwordObject

SIP digest password, shown only in this response.



35
36
37
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 35

def digest_password
  @digest_password
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 18

def id
  @id
end

#labelObject

Returns the value of attribute label.



20
21
22
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 20

def label
  @label
end

#numbers_attachedObject

Returns the value of attribute numbers_attached.



30
31
32
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 30

def numbers_attached
  @numbers_attached
end

#sip_hostObject

Returns the value of attribute sip_host.



22
23
24
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 22

def sip_host
  @sip_host
end

#sip_portObject

Returns the value of attribute sip_port.



24
25
26
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 24

def sip_port
  @sip_port
end

#terminationObject

Returns the value of attribute termination.



28
29
30
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 28

def termination
  @termination
end

#transportObject

Returns the value of attribute transport.



26
27
28
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 26

def transport
  @transport
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 60

def self.attribute_map
  {
    :'id' => :'id',
    :'label' => :'label',
    :'sip_host' => :'sipHost',
    :'sip_port' => :'sipPort',
    :'transport' => :'transport',
    :'termination' => :'termination',
    :'numbers_attached' => :'numbersAttached',
    :'created_at' => :'createdAt',
    :'digest_password' => :'digestPassword'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 100

def self.openapi_nullable
  Set.new([
    :'created_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 85

def self.openapi_types
  {
    :'id' => :'String',
    :'label' => :'String',
    :'sip_host' => :'String',
    :'sip_port' => :'Integer',
    :'transport' => :'String',
    :'termination' => :'CreateSipTrunk201ResponseTermination',
    :'numbers_attached' => :'Integer',
    :'created_at' => :'Time',
    :'digest_password' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      label == o.label &&
      sip_host == o.sip_host &&
      sip_port == o.sip_port &&
      transport == o.transport &&
      termination == o.termination &&
      numbers_attached == o.numbers_attached &&
      created_at == o.created_at &&
      digest_password == o.digest_password
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 210

def hash
  [id, label, sip_host, sip_port, transport, termination, numbers_attached, created_at, digest_password].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
# File 'lib/zernio-sdk/models/create_sip_trunk201_response.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  transport_validator = EnumAttributeValidator.new('String', ["tls", "tcp", "udp"])
  return false unless transport_validator.valid?(@transport)
  true
end