Class: Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInner
- Defined in:
- lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb
Instance Attribute Summary collapse
-
#body ⇒ Object
One primary text pinned to this rule.
-
#description ⇒ Object
One link description pinned to this rule.
-
#headline ⇒ Object
One headline pinned to this rule.
-
#image_url ⇒ Object
Image mode.
-
#placements ⇒ Object
Returns the value of attribute placements.
-
#thumbnail_url ⇒ Object
Video mode (optional).
-
#video_url ⇒ Object
Video mode.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestPlacementAssetsRulesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestPlacementAssetsRulesInner
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'video_url') self.video_url = attributes[:'video_url'] end if attributes.key?(:'thumbnail_url') self.thumbnail_url = attributes[:'thumbnail_url'] end if attributes.key?(:'headline') self.headline = attributes[:'headline'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'placements') self.placements = attributes[:'placements'] else self.placements = nil end end |
Instance Attribute Details
#body ⇒ Object
One primary text pinned to this rule. Omit to inherit the top-level body.
31 32 33 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 31 def body @body end |
#description ⇒ Object
One link description pinned to this rule. Omit to inherit the top-level description.
34 35 36 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 34 def description @description end |
#headline ⇒ Object
One headline pinned to this rule. Omit to inherit the top-level headline.
28 29 30 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 28 def headline @headline end |
#image_url ⇒ Object
Image mode. The image to deliver for this rule's placements.
19 20 21 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 19 def image_url @image_url end |
#placements ⇒ Object
Returns the value of attribute placements.
36 37 38 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 36 def placements @placements end |
#thumbnail_url ⇒ Object
Video mode (optional). Poster image for this rule's video; auto-generated when omitted.
25 26 27 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 25 def thumbnail_url @thumbnail_url end |
#video_url ⇒ Object
Video mode. The video to deliver for this rule's placements.
22 23 24 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 22 def video_url @video_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 39 def self.attribute_map { :'image_url' => :'imageUrl', :'video_url' => :'videoUrl', :'thumbnail_url' => :'thumbnailUrl', :'headline' => :'headline', :'body' => :'body', :'description' => :'description', :'placements' => :'placements' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 62 def self.openapi_types { :'image_url' => :'String', :'video_url' => :'String', :'thumbnail_url' => :'String', :'headline' => :'String', :'body' => :'String', :'description' => :'String', :'placements' => :'CreateStandaloneAdRequestPlacementAssetsRulesInnerPlacements' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && image_url == o.image_url && video_url == o.video_url && thumbnail_url == o.thumbnail_url && headline == o.headline && body == o.body && description == o.description && placements == o.placements end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 254 def hash [image_url, video_url, thumbnail_url, headline, body, description, placements].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@headline.nil? && @headline.to_s.length > 255 invalid_properties.push('invalid value for "headline", the character length must be smaller than or equal to 255.') end if !@headline.nil? && @headline.to_s.length < 1 invalid_properties.push('invalid value for "headline", the character length must be greater than or equal to 1.') end if !@body.nil? && @body.to_s.length < 1 invalid_properties.push('invalid value for "body", the character length must be greater than or equal to 1.') end if !@description.nil? && @description.to_s.length > 255 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.') end if !@description.nil? && @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be greater than or equal to 1.') end if @placements.nil? invalid_properties.push('invalid value for "placements", placements cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 168 169 170 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner.rb', line 161 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@headline.nil? && @headline.to_s.length > 255 return false if !@headline.nil? && @headline.to_s.length < 1 return false if !@body.nil? && @body.to_s.length < 1 return false if !@description.nil? && @description.to_s.length > 255 return false if !@description.nil? && @description.to_s.length < 1 return false if @placements.nil? true end |