Class: Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInnerPlacements
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInnerPlacements
- Defined in:
- lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb
Overview
Placements this asset is pinned to. At least one field must be set (an empty rule is invalid — that role is served by the default asset). Same enums as the top-level placements object.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#audience_network_positions ⇒ Object
Returns the value of attribute audience_network_positions.
-
#device_platforms ⇒ Object
Returns the value of attribute device_platforms.
-
#facebook_positions ⇒ Object
Returns the value of attribute facebook_positions.
-
#instagram_positions ⇒ Object
Returns the value of attribute instagram_positions.
-
#messenger_positions ⇒ Object
Returns the value of attribute messenger_positions.
-
#publisher_platforms ⇒ Object
Returns the value of attribute publisher_platforms.
-
#threads_positions ⇒ Object
Returns the value of attribute threads_positions.
-
#whatsapp_positions ⇒ Object
Returns the value of attribute whatsapp_positions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestPlacementAssetsRulesInnerPlacements
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestPlacementAssetsRulesInnerPlacements
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInnerPlacements` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateStandaloneAdRequestPlacementAssetsRulesInnerPlacements`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'publisher_platforms') if (value = attributes[:'publisher_platforms']).is_a?(Array) self.publisher_platforms = value end end if attributes.key?(:'facebook_positions') if (value = attributes[:'facebook_positions']).is_a?(Array) self.facebook_positions = value end end if attributes.key?(:'instagram_positions') if (value = attributes[:'instagram_positions']).is_a?(Array) self.instagram_positions = value end end if attributes.key?(:'messenger_positions') if (value = attributes[:'messenger_positions']).is_a?(Array) self.messenger_positions = value end end if attributes.key?(:'audience_network_positions') if (value = attributes[:'audience_network_positions']).is_a?(Array) self.audience_network_positions = value end end if attributes.key?(:'threads_positions') if (value = attributes[:'threads_positions']).is_a?(Array) self.threads_positions = value end end if attributes.key?(:'whatsapp_positions') if (value = attributes[:'whatsapp_positions']).is_a?(Array) self.whatsapp_positions = value end end if attributes.key?(:'device_platforms') if (value = attributes[:'device_platforms']).is_a?(Array) self.device_platforms = value end end end |
Instance Attribute Details
#audience_network_positions ⇒ Object
Returns the value of attribute audience_network_positions.
27 28 29 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 27 def audience_network_positions @audience_network_positions end |
#device_platforms ⇒ Object
Returns the value of attribute device_platforms.
33 34 35 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 33 def device_platforms @device_platforms end |
#facebook_positions ⇒ Object
Returns the value of attribute facebook_positions.
21 22 23 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 21 def facebook_positions @facebook_positions end |
#instagram_positions ⇒ Object
Returns the value of attribute instagram_positions.
23 24 25 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 23 def instagram_positions @instagram_positions end |
#messenger_positions ⇒ Object
Returns the value of attribute messenger_positions.
25 26 27 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 25 def messenger_positions @messenger_positions end |
#publisher_platforms ⇒ Object
Returns the value of attribute publisher_platforms.
19 20 21 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 19 def publisher_platforms @publisher_platforms end |
#threads_positions ⇒ Object
Returns the value of attribute threads_positions.
29 30 31 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 29 def threads_positions @threads_positions end |
#whatsapp_positions ⇒ Object
Returns the value of attribute whatsapp_positions.
31 32 33 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 31 def whatsapp_positions @whatsapp_positions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 58 def self.attribute_map { :'publisher_platforms' => :'publisherPlatforms', :'facebook_positions' => :'facebookPositions', :'instagram_positions' => :'instagramPositions', :'messenger_positions' => :'messengerPositions', :'audience_network_positions' => :'audienceNetworkPositions', :'threads_positions' => :'threadsPositions', :'whatsapp_positions' => :'whatsappPositions', :'device_platforms' => :'devicePlatforms' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 82 def self.openapi_types { :'publisher_platforms' => :'Array<String>', :'facebook_positions' => :'Array<String>', :'instagram_positions' => :'Array<String>', :'messenger_positions' => :'Array<String>', :'audience_network_positions' => :'Array<String>', :'threads_positions' => :'Array<String>', :'whatsapp_positions' => :'Array<String>', :'device_platforms' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && publisher_platforms == o.publisher_platforms && facebook_positions == o.facebook_positions && instagram_positions == o.instagram_positions && messenger_positions == o.messenger_positions && audience_network_positions == o.audience_network_positions && threads_positions == o.threads_positions && whatsapp_positions == o.whatsapp_positions && device_platforms == o.device_platforms end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 204 def hash [publisher_platforms, facebook_positions, instagram_positions, messenger_positions, audience_network_positions, threads_positions, whatsapp_positions, device_platforms].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
168 169 170 171 172 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 168 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_placement_assets_rules_inner_placements.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |