Class: Zernio::CreateStandaloneAdRequestSitelinksInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestSitelinksInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateStandaloneAdRequestSitelinksInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateStandaloneAdRequestSitelinksInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'link_url')
    self.link_url = attributes[:'link_url']
  else
    self.link_url = nil
  end

  if attributes.key?(:'description1')
    self.description1 = attributes[:'description1']
  end

  if attributes.key?(:'description2')
    self.description2 = attributes[:'description2']
  end
end

Instance Attribute Details

#description1Object

First description line under the link text (optional). 35-char cap.



25
26
27
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 25

def description1
  @description1
end

#description2Object

Second description line (optional; usually paired with description1).



28
29
30
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 28

def description2
  @description2
end

Final URL the sitelink navigates to.



22
23
24
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 22

def link_url
  @link_url
end

#textObject

The clickable link text shown under the ad. 25-char cap comes from Google.



19
20
21
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 19

def text
  @text
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 31

def self.attribute_map
  {
    :'text' => :'text',
    :'link_url' => :'linkUrl',
    :'description1' => :'description1',
    :'description2' => :'description2'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 248

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 51

def self.openapi_types
  {
    :'text' => :'String',
    :'link_url' => :'String',
    :'description1' => :'String',
    :'description2' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      text == o.text &&
      link_url == o.link_url &&
      description1 == o.description1 &&
      description2 == o.description2
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


235
236
237
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 235

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



241
242
243
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 241

def hash
  [text, link_url, description1, description2].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @text.nil?
    invalid_properties.push('invalid value for "text", text cannot be nil.')
  end

  if @text.to_s.length > 25
    invalid_properties.push('invalid value for "text", the character length must be smaller than or equal to 25.')
  end

  if @text.to_s.length < 1
    invalid_properties.push('invalid value for "text", the character length must be greater than or equal to 1.')
  end

  if @link_url.nil?
    invalid_properties.push('invalid value for "link_url", link_url cannot be nil.')
  end

  if !@description1.nil? && @description1.to_s.length > 35
    invalid_properties.push('invalid value for "description1", the character length must be smaller than or equal to 35.')
  end

  if !@description1.nil? && @description1.to_s.length < 1
    invalid_properties.push('invalid value for "description1", the character length must be greater than or equal to 1.')
  end

  if !@description2.nil? && @description2.to_s.length > 35
    invalid_properties.push('invalid value for "description2", the character length must be smaller than or equal to 35.')
  end

  if !@description2.nil? && @description2.to_s.length < 1
    invalid_properties.push('invalid value for "description2", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 270

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/zernio-sdk/models/create_standalone_ad_request_sitelinks_inner.rb', line 145

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @text.nil?
  return false if @text.to_s.length > 25
  return false if @text.to_s.length < 1
  return false if @link_url.nil?
  return false if !@description1.nil? && @description1.to_s.length > 35
  return false if !@description1.nil? && @description1.to_s.length < 1
  return false if !@description2.nil? && @description2.to_s.length > 35
  return false if !@description2.nil? && @description2.to_s.length < 1
  true
end