Class: Zernio::CreateStandaloneAdRequestTranslationsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateStandaloneAdRequestTranslationsInner
- Defined in:
- lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb
Instance Attribute Summary collapse
-
#body ⇒ Object
Primary text for this language.
-
#description ⇒ Object
Link description for this language.
-
#headline ⇒ Object
Headline for this language.
-
#image_url ⇒ Object
Image for this language.
-
#locale ⇒ Object
Language code, resolved to Meta's numeric locale id.
-
#thumbnail_url ⇒ Object
Poster frame for this language's video.
-
#video_url ⇒ Object
Video for this language.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestTranslationsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestTranslationsInner
Initializes the object
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 83 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateStandaloneAdRequestTranslationsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateStandaloneAdRequestTranslationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'locale') self.locale = attributes[:'locale'] else self.locale = nil end if attributes.key?(:'headline') self.headline = attributes[:'headline'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] end if attributes.key?(:'video_url') self.video_url = attributes[:'video_url'] end if attributes.key?(:'thumbnail_url') self.thumbnail_url = attributes[:'thumbnail_url'] end end |
Instance Attribute Details
#body ⇒ Object
Primary text for this language. Inherits the top-level body when omitted.
25 26 27 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 25 def body @body end |
#description ⇒ Object
Link description for this language. Inherits the top-level description when omitted.
28 29 30 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 28 def description @description end |
#headline ⇒ Object
Headline for this language. Inherits the top-level headline when omitted.
22 23 24 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 22 def headline @headline end |
#image_url ⇒ Object
Image for this language. Inherits the ad's imageUrl when omitted. The feed is all-image OR all-video.
31 32 33 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 31 def image_url @image_url end |
#locale ⇒ Object
Language code, resolved to Meta's numeric locale id. Bare codes target the '(All)' umbrella (es = every Spanish variant); region-qualified codes target the variant (pt_BR, en_GB).
19 20 21 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 19 def locale @locale end |
#thumbnail_url ⇒ Object
Poster frame for this language's video.
37 38 39 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 37 def thumbnail_url @thumbnail_url end |
#video_url ⇒ Object
Video for this language. Inherits the ad's video.url when omitted. The feed is all-image OR all-video.
34 35 36 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 34 def video_url @video_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 40 def self.attribute_map { :'locale' => :'locale', :'headline' => :'headline', :'body' => :'body', :'description' => :'description', :'image_url' => :'imageUrl', :'video_url' => :'videoUrl', :'thumbnail_url' => :'thumbnailUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 225 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 76 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 63 def self.openapi_types { :'locale' => :'String', :'headline' => :'String', :'body' => :'String', :'description' => :'String', :'image_url' => :'String', :'video_url' => :'String', :'thumbnail_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && locale == o.locale && headline == o.headline && body == o.body && description == o.description && image_url == o.image_url && video_url == o.video_url && thumbnail_url == o.thumbnail_url end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 218 def hash [locale, headline, body, description, image_url, video_url, thumbnail_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 130 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @locale.nil? invalid_properties.push('invalid value for "locale", locale cannot be nil.') end if !@headline.nil? && @headline.to_s.length > 255 invalid_properties.push('invalid value for "headline", the character length must be smaller than or equal to 255.') end if !@description.nil? && @description.to_s.length > 255 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 255.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_translations_inner.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @locale.nil? return false if !@headline.nil? && @headline.to_s.length > 255 return false if !@description.nil? && @description.to_s.length > 255 true end |