Class: Zernio::CreateVerificationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_verification_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateVerificationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateVerificationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateVerificationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  else
    self.channel = nil
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  else
    self.to = nil
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  end

  if attributes.key?(:'brand_name')
    self.brand_name = attributes[:'brand_name']
  end

  if attributes.key?(:'code_length')
    self.code_length = attributes[:'code_length']
  else
    self.code_length = 6
  end

  if attributes.key?(:'ttl_minutes')
    self.ttl_minutes = attributes[:'ttl_minutes']
  else
    self.ttl_minutes = 10
  end
end

Instance Attribute Details

#brand_nameObject

Your app or business name, rendered in the message. Defaults to your account name. Letters, numbers, and basic punctuation only.



28
29
30
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 28

def brand_name
  @brand_name
end

#channelObject

SMS-only for now.



19
20
21
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 19

def channel
  @channel
end

#code_lengthObject

Returns the value of attribute code_length.



30
31
32
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 30

def code_length
  @code_length
end

#fromObject

The SMS-enabled number on your account to send from. Defaults to your only SMS number.



25
26
27
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 25

def from
  @from
end

#toObject

E.164 phone number.



22
23
24
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 22

def to
  @to
end

#ttl_minutesObject

Returns the value of attribute ttl_minutes.



32
33
34
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 32

def ttl_minutes
  @ttl_minutes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 57

def self.attribute_map
  {
    :'channel' => :'channel',
    :'to' => :'to',
    :'from' => :'from',
    :'brand_name' => :'brandName',
    :'code_length' => :'codeLength',
    :'ttl_minutes' => :'ttlMinutes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 295

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 79

def self.openapi_types
  {
    :'channel' => :'String',
    :'to' => :'String',
    :'from' => :'String',
    :'brand_name' => :'String',
    :'code_length' => :'Integer',
    :'ttl_minutes' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



269
270
271
272
273
274
275
276
277
278
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 269

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      channel == o.channel &&
      to == o.to &&
      from == o.from &&
      brand_name == o.brand_name &&
      code_length == o.code_length &&
      ttl_minutes == o.ttl_minutes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



288
289
290
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 288

def hash
  [channel, to, from, brand_name, code_length, ttl_minutes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @channel.nil?
    invalid_properties.push('invalid value for "channel", channel cannot be nil.')
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if !@brand_name.nil? && @brand_name.to_s.length > 30
    invalid_properties.push('invalid value for "brand_name", the character length must be smaller than or equal to 30.')
  end

  if !@code_length.nil? && @code_length > 8
    invalid_properties.push('invalid value for "code_length", must be smaller than or equal to 8.')
  end

  if !@code_length.nil? && @code_length < 4
    invalid_properties.push('invalid value for "code_length", must be greater than or equal to 4.')
  end

  if !@ttl_minutes.nil? && @ttl_minutes > 15
    invalid_properties.push('invalid value for "ttl_minutes", must be smaller than or equal to 15.')
  end

  if !@ttl_minutes.nil? && @ttl_minutes < 1
    invalid_properties.push('invalid value for "ttl_minutes", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 317

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/zernio-sdk/models/create_verification_request.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @channel.nil?
  channel_validator = EnumAttributeValidator.new('String', ["sms"])
  return false unless channel_validator.valid?(@channel)
  return false if @to.nil?
  return false if !@brand_name.nil? && @brand_name.to_s.length > 30
  return false if !@code_length.nil? && @code_length > 8
  return false if !@code_length.nil? && @code_length < 4
  return false if !@ttl_minutes.nil? && @ttl_minutes > 15
  return false if !@ttl_minutes.nil? && @ttl_minutes < 1
  true
end