Class: Zernio::CreateVoiceCall200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateVoiceCall200Response
- Defined in:
- lib/zernio-sdk/models/create_voice_call200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#call_id ⇒ Object
Internal Call doc ID.
-
#direction ⇒ Object
Returns the value of attribute direction.
-
#forward_to ⇒ Object
Returns the value of attribute forward_to.
-
#from ⇒ Object
Returns the value of attribute from.
-
#greeting ⇒ Object
Returns the value of attribute greeting.
-
#recording_enabled ⇒ Object
Returns the value of attribute recording_enabled.
-
#status ⇒ Object
Returns the value of attribute status.
-
#success ⇒ Object
Returns the value of attribute success.
-
#telnyx_call_control_id ⇒ Object
Returns the value of attribute telnyx_call_control_id.
-
#to ⇒ Object
Returns the value of attribute to.
-
#transcription_enabled ⇒ Object
Returns the value of attribute transcription_enabled.
-
#transcription_language ⇒ Object
Returns the value of attribute transcription_language.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateVoiceCall200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateVoiceCall200Response
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateVoiceCall200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateVoiceCall200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'call_id') self.call_id = attributes[:'call_id'] end if attributes.key?(:'telnyx_call_control_id') self.telnyx_call_control_id = attributes[:'telnyx_call_control_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'direction') self.direction = attributes[:'direction'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'to') self.to = attributes[:'to'] end if attributes.key?(:'forward_to') self.forward_to = attributes[:'forward_to'] end if attributes.key?(:'greeting') self.greeting = attributes[:'greeting'] end if attributes.key?(:'recording_enabled') self.recording_enabled = attributes[:'recording_enabled'] end if attributes.key?(:'transcription_enabled') self.transcription_enabled = attributes[:'transcription_enabled'] end if attributes.key?(:'transcription_language') self.transcription_language = attributes[:'transcription_language'] end end |
Instance Attribute Details
#call_id ⇒ Object
Internal Call doc ID
21 22 23 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 21 def call_id @call_id end |
#direction ⇒ Object
Returns the value of attribute direction.
27 28 29 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 27 def direction @direction end |
#forward_to ⇒ Object
Returns the value of attribute forward_to.
33 34 35 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 33 def forward_to @forward_to end |
#from ⇒ Object
Returns the value of attribute from.
29 30 31 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 29 def from @from end |
#greeting ⇒ Object
Returns the value of attribute greeting.
35 36 37 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 35 def greeting @greeting end |
#recording_enabled ⇒ Object
Returns the value of attribute recording_enabled.
37 38 39 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 37 def recording_enabled @recording_enabled end |
#status ⇒ Object
Returns the value of attribute status.
25 26 27 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 25 def status @status end |
#success ⇒ Object
Returns the value of attribute success.
18 19 20 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 18 def success @success end |
#telnyx_call_control_id ⇒ Object
Returns the value of attribute telnyx_call_control_id.
23 24 25 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 23 def telnyx_call_control_id @telnyx_call_control_id end |
#to ⇒ Object
Returns the value of attribute to.
31 32 33 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 31 def to @to end |
#transcription_enabled ⇒ Object
Returns the value of attribute transcription_enabled.
39 40 41 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 39 def transcription_enabled @transcription_enabled end |
#transcription_language ⇒ Object
Returns the value of attribute transcription_language.
41 42 43 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 41 def transcription_language @transcription_language end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
84 85 86 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 84 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 89 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 66 def self.attribute_map { :'success' => :'success', :'call_id' => :'callId', :'telnyx_call_control_id' => :'telnyxCallControlId', :'status' => :'status', :'direction' => :'direction', :'from' => :'from', :'to' => :'to', :'forward_to' => :'forwardTo', :'greeting' => :'greeting', :'recording_enabled' => :'recordingEnabled', :'transcription_enabled' => :'transcriptionEnabled', :'transcription_language' => :'transcriptionLanguage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 268 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 116 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 112 def self.openapi_nullable Set.new([ :'greeting', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 94 def self.openapi_types { :'success' => :'Boolean', :'call_id' => :'String', :'telnyx_call_control_id' => :'String', :'status' => :'String', :'direction' => :'String', :'from' => :'String', :'to' => :'String', :'forward_to' => :'String', :'greeting' => :'String', :'recording_enabled' => :'Boolean', :'transcription_enabled' => :'Boolean', :'transcription_language' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && call_id == o.call_id && telnyx_call_control_id == o.telnyx_call_control_id && status == o.status && direction == o.direction && from == o.from && to == o.to && forward_to == o.forward_to && greeting == o.greeting && recording_enabled == o.recording_enabled && transcription_enabled == o.transcription_enabled && transcription_language == o.transcription_language end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 261 def hash [success, call_id, telnyx_call_control_id, status, direction, from, to, forward_to, greeting, recording_enabled, transcription_enabled, transcription_language].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 |
# File 'lib/zernio-sdk/models/create_voice_call200_response.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["dialing"]) return false unless status_validator.valid?(@status) direction_validator = EnumAttributeValidator.new('String', ["outbound"]) return false unless direction_validator.valid?(@direction) transcription_language_validator = EnumAttributeValidator.new('String', ["auto", "en", "es"]) return false unless transcription_language_validator.valid?(@transcription_language) true end |