Class: Zernio::CreateWhatsAppGroupChatRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateWhatsAppGroupChatRequest
- Defined in:
- lib/zernio-sdk/models/create_whats_app_group_chat_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
WhatsApp social account ID.
-
#description ⇒ Object
Group description (max 2048 characters).
-
#join_approval_mode ⇒ Object
Whether users need approval to join via invite link.
-
#subject ⇒ Object
Group name (max 128 characters).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateWhatsAppGroupChatRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateWhatsAppGroupChatRequest
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateWhatsAppGroupChatRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateWhatsAppGroupChatRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'subject') self.subject = attributes[:'subject'] else self.subject = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'join_approval_mode') self.join_approval_mode = attributes[:'join_approval_mode'] end end |
Instance Attribute Details
#account_id ⇒ Object
WhatsApp social account ID
19 20 21 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 19 def account_id @account_id end |
#description ⇒ Object
Group description (max 2048 characters)
25 26 27 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 25 def description @description end |
#join_approval_mode ⇒ Object
Whether users need approval to join via invite link
28 29 30 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 28 def join_approval_mode @join_approval_mode end |
#subject ⇒ Object
Group name (max 128 characters)
22 23 24 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 22 def subject @subject end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 53 def self.attribute_map { :'account_id' => :'accountId', :'subject' => :'subject', :'description' => :'description', :'join_approval_mode' => :'joinApprovalMode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 73 def self.openapi_types { :'account_id' => :'String', :'subject' => :'String', :'description' => :'String', :'join_approval_mode' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && subject == o.subject && description == o.description && join_approval_mode == o.join_approval_mode end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 229 def hash [account_id, subject, description, join_approval_mode].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @subject.nil? invalid_properties.push('invalid value for "subject", subject cannot be nil.') end if @subject.to_s.length > 128 invalid_properties.push('invalid value for "subject", the character length must be smaller than or equal to 128.') end if !@description.nil? && @description.to_s.length > 2048 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 2048.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 157 158 159 160 |
# File 'lib/zernio-sdk/models/create_whats_app_group_chat_request.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @subject.nil? return false if @subject.to_s.length > 128 return false if !@description.nil? && @description.to_s.length > 2048 join_approval_mode_validator = EnumAttributeValidator.new('String', ["approval_required", "auto_approve"]) return false unless join_approval_mode_validator.valid?(@join_approval_mode) true end |