Class: Zernio::CustomConversion
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CustomConversion
- Defined in:
- lib/zernio-sdk/models/custom_conversion.rb
Instance Attribute Summary collapse
-
#custom_event_type ⇒ Object
Returns the value of attribute custom_event_type.
-
#default_conversion_value ⇒ Object
Value Meta assigns a conversion that carries none, in the ad account's currency.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_archived ⇒ Object
Returns the value of attribute is_archived.
-
#name ⇒ Object
Returns the value of attribute name.
-
#pixel_id ⇒ Object
Meta's event_source_id, the pixel the rule reads from.
-
#rule ⇒ Object
Meta's rule, parsed back from the string Meta stores.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomConversion
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomConversion
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CustomConversion` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CustomConversion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'rule') self.rule = attributes[:'rule'] end if attributes.key?(:'custom_event_type') self.custom_event_type = attributes[:'custom_event_type'] end if attributes.key?(:'pixel_id') self.pixel_id = attributes[:'pixel_id'] end if attributes.key?(:'is_archived') self.is_archived = attributes[:'is_archived'] end if attributes.key?(:'default_conversion_value') self.default_conversion_value = attributes[:'default_conversion_value'] end end |
Instance Attribute Details
#custom_event_type ⇒ Object
Returns the value of attribute custom_event_type.
25 26 27 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 25 def custom_event_type @custom_event_type end |
#default_conversion_value ⇒ Object
Value Meta assigns a conversion that carries none, in the ad account's currency.
33 34 35 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 33 def default_conversion_value @default_conversion_value end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 18 def id @id end |
#is_archived ⇒ Object
Returns the value of attribute is_archived.
30 31 32 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 30 def is_archived @is_archived end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 20 def name @name end |
#pixel_id ⇒ Object
Meta's event_source_id, the pixel the rule reads from.
28 29 30 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 28 def pixel_id @pixel_id end |
#rule ⇒ Object
Meta's rule, parsed back from the string Meta stores.
23 24 25 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 23 def rule @rule end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 36 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'rule' => :'rule', :'custom_event_type' => :'customEventType', :'pixel_id' => :'pixelId', :'is_archived' => :'isArchived', :'default_conversion_value' => :'defaultConversionValue' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 171 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 76 77 78 79 80 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 72 def self.openapi_nullable Set.new([ :'name', :'rule', :'custom_event_type', :'pixel_id', :'default_conversion_value' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 59 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'rule' => :'Object', :'custom_event_type' => :'String', :'pixel_id' => :'String', :'is_archived' => :'Boolean', :'default_conversion_value' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && rule == o.rule && custom_event_type == o.custom_event_type && pixel_id == o.pixel_id && is_archived == o.is_archived && default_conversion_value == o.default_conversion_value end |
#eql?(o) ⇒ Boolean
158 159 160 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 158 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 164 def hash [id, name, rule, custom_event_type, pixel_id, is_archived, default_conversion_value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |