Class: Zernio::DuplicateAdCampaign200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DuplicateAdCampaign200Response

Initializes the object



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DuplicateAdCampaign200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DuplicateAdCampaign200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'copied_campaign_id')
    self.copied_campaign_id = attributes[:'copied_campaign_id']
  end

  if attributes.key?(:'discovery')
    self.discovery = attributes[:'discovery']
  end

  if attributes.key?(:'raw')
    self.raw = attributes[:'raw']
  end
end

Instance Attribute Details

#copied_campaign_idObject

Platform ID of the new campaign



19
20
21
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 19

def copied_campaign_id
  @copied_campaign_id
end

#discoveryObject

Returns the value of attribute discovery.



21
22
23
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 21

def discovery
  @discovery
end

#rawObject

Platform-native response from the copy endpoint (Meta includes ad_object_ids for child copies)



24
25
26
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 24

def raw
  @raw
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 49

def self.attribute_map
  {
    :'copied_campaign_id' => :'copiedCampaignId',
    :'discovery' => :'discovery',
    :'raw' => :'raw'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 163

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 68

def self.openapi_types
  {
    :'copied_campaign_id' => :'String',
    :'discovery' => :'String',
    :'raw' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



140
141
142
143
144
145
146
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      copied_campaign_id == o.copied_campaign_id &&
      discovery == o.discovery &&
      raw == o.raw
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


150
151
152
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 150

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



156
157
158
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 156

def hash
  [copied_campaign_id, discovery, raw].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



113
114
115
116
117
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



121
122
123
124
125
126
# File 'lib/zernio-sdk/models/duplicate_ad_campaign200_response.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  discovery_validator = EnumAttributeValidator.new('String', ["triggered", "skipped", "failed"])
  return false unless discovery_validator.valid?(@discovery)
  true
end