Class: Zernio::ErrorResponseDetailsCreatedObjectsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/error_response_details_created_objects_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ErrorResponseDetailsCreatedObjectsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ErrorResponseDetailsCreatedObjectsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ErrorResponseDetailsCreatedObjectsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'cleanup')
    self.cleanup = attributes[:'cleanup']
  end
end

Instance Attribute Details

#cleanup ⇒ Object

deleted: Zernio deleted it. left_behind: Meta refused the delete, so it still exists. kept: deliberately not deleted (image hashes are shared by every upload of the same file).



24
25
26
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 24

def cleanup
  @cleanup
end

#id ⇒ Object

Meta object id; for image the image hash.



21
22
23
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 21

def id
  @id
end

#type ⇒ Object

Returns the value of attribute type.



18
19
20
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



58
59
60
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 49

def self.attribute_map
  {
    :'type' => :'type',
    :'id' => :'id',
    :'cleanup' => :'cleanup'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



77
78
79
80
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 68

def self.openapi_types
  {
    :'type' => :'String',
    :'id' => :'String',
    :'cleanup' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



152
153
154
155
156
157
158
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 152

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      id == o.id &&
      cleanup == o.cleanup
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 162

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



168
169
170
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 168

def hash
  [type, id, cleanup].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/error_response_details_created_objects_inner.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["campaign", "adset", "creative", "ad", "video", "image"])
  return false unless type_validator.valid?(@type)
  cleanup_validator = EnumAttributeValidator.new('String', ["deleted", "left_behind", "kept"])
  return false unless cleanup_validator.valid?(@cleanup)
  true
end