Class: Zernio::ExternalPostSummary

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/external_post_summary.rb

Overview

A post synced from a platform (published directly on the platform, not through Zernio). Returned by GET /v1/posts?source=external and POST /v1/posts/sync-external. Analytics are exposed separately via GET /v1/analytics?source=external.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExternalPostSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ExternalPostSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ExternalPostSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_post_id')
    self.platform_post_id = attributes[:'platform_post_id']
  end

  if attributes.key?(:'platform_post_url')
    self.platform_post_url = attributes[:'platform_post_url']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'media_items')
    if (value = attributes[:'media_items']).is_a?(Array)
      self.media_items = value
    end
  end

  if attributes.key?(:'media_product_type')
    self.media_product_type = attributes[:'media_product_type']
  end

  if attributes.key?(:'is_ai_generated')
    self.is_ai_generated = attributes[:'is_ai_generated']
  end

  if attributes.key?(:'is_shared_to_feed')
    self.is_shared_to_feed = attributes[:'is_shared_to_feed']
  end

  if attributes.key?(:'media_audio_type')
    self.media_audio_type = attributes[:'media_audio_type']
  end

  if attributes.key?(:'analytics')
    self.analytics = attributes[:'analytics']
  end
end

Instance Attribute Details

#analytics ⇒ Object

Returns the value of attribute analytics.



55
56
57
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 55

def analytics
  @analytics
end

#content ⇒ Object

Post caption / text



29
30
31
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 29

def content
  @content
end

#is_ai_generated ⇒ Object

Instagram only: whether Instagram labeled the media as AI-generated. Absent when the platform did not report it.



47
48
49
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 47

def is_ai_generated
  @is_ai_generated
end

#is_shared_to_feed ⇒ Object

Instagram reels only: whether the reel is also shared to the main feed. Absent when the platform did not report it.



50
51
52
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 50

def is_shared_to_feed
  @is_shared_to_feed
end

#media_audio_type ⇒ Object

Instagram only: audio type of the media (MUSIC or ORIGINAL_SOUND). Absent when the platform did not report it.



53
54
55
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 53

def media_audio_type
  @media_audio_type
end

#media_items ⇒ Object

Per-item media (for carousels / multi-media posts)



41
42
43
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 41

def media_items
  @media_items
end

#media_product_type ⇒ Object

Instagram only: the platform media product type (e.g. FEED, REELS, STORY, AD). Absent when the platform did not report it.



44
45
46
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 44

def media_product_type
  @media_product_type
end

#media_type ⇒ Object

Media type (e.g. image, video, carousel)



35
36
37
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 35

def media_type
  @media_type
end

#platform ⇒ Object

Platform the post belongs to (e.g. instagram, youtube, tiktok)



20
21
22
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 20

def platform
  @platform
end

#platform_post_id ⇒ Object

The platform's own post/media/video id



23
24
25
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 23

def platform_post_id
  @platform_post_id
end

#platform_post_url ⇒ Object

Canonical URL (permalink) of the post on the platform



26
27
28
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 26

def platform_post_url
  @platform_post_url
end

#published_at ⇒ Object

When the post was published on the platform



32
33
34
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 32

def published_at
  @published_at
end

#thumbnail_url ⇒ Object

Thumbnail URL



38
39
40
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 38

def thumbnail_url
  @thumbnail_url
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



77
78
79
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 58

def self.attribute_map
  {
    :'platform' => :'platform',
    :'platform_post_id' => :'platformPostId',
    :'platform_post_url' => :'platformPostUrl',
    :'content' => :'content',
    :'published_at' => :'publishedAt',
    :'media_type' => :'mediaType',
    :'thumbnail_url' => :'thumbnailUrl',
    :'media_items' => :'mediaItems',
    :'media_product_type' => :'mediaProductType',
    :'is_ai_generated' => :'isAiGenerated',
    :'is_shared_to_feed' => :'isSharedToFeed',
    :'media_audio_type' => :'mediaAudioType',
    :'analytics' => :'analytics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 232

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



106
107
108
109
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 87

def self.openapi_types
  {
    :'platform' => :'String',
    :'platform_post_id' => :'String',
    :'platform_post_url' => :'String',
    :'content' => :'String',
    :'published_at' => :'Time',
    :'media_type' => :'String',
    :'thumbnail_url' => :'String',
    :'media_items' => :'Array<Object>',
    :'media_product_type' => :'String',
    :'is_ai_generated' => :'Boolean',
    :'is_shared_to_feed' => :'Boolean',
    :'media_audio_type' => :'String',
    :'analytics' => :'ExternalPostSummaryAnalytics'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 199

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      platform == o.platform &&
      platform_post_id == o.platform_post_id &&
      platform_post_url == o.platform_post_url &&
      content == o.content &&
      published_at == o.published_at &&
      media_type == o.media_type &&
      thumbnail_url == o.thumbnail_url &&
      media_items == o.media_items &&
      media_product_type == o.media_product_type &&
      is_ai_generated == o.is_ai_generated &&
      is_shared_to_feed == o.is_shared_to_feed &&
      media_audio_type == o.media_audio_type &&
      analytics == o.analytics
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 219

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



225
226
227
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 225

def hash
  [platform, platform_post_id, platform_post_url, content, published_at, media_type, thumbnail_url, media_items, media_product_type, is_ai_generated, is_shared_to_feed, media_audio_type, analytics].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



192
193
194
195
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end