Class: Zernio::ExternalPostSummaryAnalytics

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/external_post_summary_analytics.rb

Overview

Engagement + insights for the post. likes and comments are available immediately after an on-demand sync (they come from the platform listing). reach, impressions, views depend on the platform's insights, which carry their own delay (e.g. ~24h on Instagram) and read 0 until the platform makes them available.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExternalPostSummaryAnalytics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ExternalPostSummaryAnalytics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ExternalPostSummaryAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'likes')
    self.likes = attributes[:'likes']
  end

  if attributes.key?(:'comments')
    self.comments = attributes[:'comments']
  end

  if attributes.key?(:'shares')
    self.shares = attributes[:'shares']
  end

  if attributes.key?(:'saves')
    self.saves = attributes[:'saves']
  end

  if attributes.key?(:'sends')
    self.sends = attributes[:'sends']
  end

  if attributes.key?(:'clicks')
    self.clicks = attributes[:'clicks']
  end

  if attributes.key?(:'views')
    self.views = attributes[:'views']
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  end

  if attributes.key?(:'impressions')
    self.impressions = attributes[:'impressions']
  end

  if attributes.key?(:'engagement_rate')
    self.engagement_rate = attributes[:'engagement_rate']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end
end

Instance Attribute Details

#clicksObject

Returns the value of attribute clicks.



29
30
31
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 29

def clicks
  @clicks
end

#commentsObject

Returns the value of attribute comments.



21
22
23
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 21

def comments
  @comments
end

#engagement_rateObject

Returns the value of attribute engagement_rate.



37
38
39
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 37

def engagement_rate
  @engagement_rate
end

#impressionsObject

Returns the value of attribute impressions.



35
36
37
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 35

def impressions
  @impressions
end

#last_updatedObject

When these metrics were last refreshed



40
41
42
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 40

def last_updated
  @last_updated
end

#likesObject

Returns the value of attribute likes.



19
20
21
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 19

def likes
  @likes
end

#reachObject

Returns the value of attribute reach.



33
34
35
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 33

def reach
  @reach
end

#savesObject

Returns the value of attribute saves.



25
26
27
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 25

def saves
  @saves
end

#sendsObject

Returns the value of attribute sends.



27
28
29
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 27

def sends
  @sends
end

#sharesObject

Returns the value of attribute shares.



23
24
25
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 23

def shares
  @shares
end

#viewsObject

Returns the value of attribute views.



31
32
33
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 31

def views
  @views
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 43

def self.attribute_map
  {
    :'likes' => :'likes',
    :'comments' => :'comments',
    :'shares' => :'shares',
    :'saves' => :'saves',
    :'sends' => :'sends',
    :'clicks' => :'clicks',
    :'views' => :'views',
    :'reach' => :'reach',
    :'impressions' => :'impressions',
    :'engagement_rate' => :'engagementRate',
    :'last_updated' => :'lastUpdated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 70

def self.openapi_types
  {
    :'likes' => :'Integer',
    :'comments' => :'Integer',
    :'shares' => :'Integer',
    :'saves' => :'Integer',
    :'sends' => :'Integer',
    :'clicks' => :'Integer',
    :'views' => :'Integer',
    :'reach' => :'Integer',
    :'impressions' => :'Integer',
    :'engagement_rate' => :'Float',
    :'last_updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      likes == o.likes &&
      comments == o.comments &&
      shares == o.shares &&
      saves == o.saves &&
      sends == o.sends &&
      clicks == o.clicks &&
      views == o.views &&
      reach == o.reach &&
      impressions == o.impressions &&
      engagement_rate == o.engagement_rate &&
      last_updated == o.last_updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 194

def hash
  [likes, comments, shares, saves, sends, clicks, views, reach, impressions, engagement_rate, last_updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
# File 'lib/zernio-sdk/models/external_post_summary_analytics.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end