Class: Zernio::GMBMediaApi
- Inherits:
-
Object
- Object
- Zernio::GMBMediaApi
- Defined in:
- lib/zernio-sdk/api/gmb_media_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_google_business_media(account_id, create_google_business_media_request, opts = {}) ⇒ CreateGoogleBusinessMedia200Response
Upload photo Creates a media item (photo) for a location from a publicly accessible URL.
-
#create_google_business_media_with_http_info(account_id, create_google_business_media_request, opts = {}) ⇒ Array<(CreateGoogleBusinessMedia200Response, Integer, Hash)>
Upload photo Creates a media item (photo) for a location from a publicly accessible URL.
-
#delete_google_business_media(account_id, media_id, opts = {}) ⇒ DeleteGoogleBusinessMedia200Response
Delete photo Deletes a photo or media item from a GBP location.
-
#delete_google_business_media_with_http_info(account_id, media_id, opts = {}) ⇒ Array<(DeleteGoogleBusinessMedia200Response, Integer, Hash)>
Delete photo Deletes a photo or media item from a GBP location.
-
#initialize(api_client = ApiClient.default) ⇒ GMBMediaApi
constructor
A new instance of GMBMediaApi.
-
#list_google_business_media(account_id, opts = {}) ⇒ ListGoogleBusinessMedia200Response
List media Lists media items (photos) for a Google Business Profile location.
-
#list_google_business_media_with_http_info(account_id, opts = {}) ⇒ Array<(ListGoogleBusinessMedia200Response, Integer, Hash)>
List media Lists media items (photos) for a Google Business Profile location.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ GMBMediaApi
Returns a new instance of GMBMediaApi.
19 20 21 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_google_business_media(account_id, create_google_business_media_request, opts = {}) ⇒ CreateGoogleBusinessMedia200Response
Upload photo Creates a media item (photo) for a location from a publicly accessible URL. Categories determine where the photo appears: COVER, PROFILE, LOGO, EXTERIOR, INTERIOR, FOOD_AND_DRINK, MENU, PRODUCT, TEAMS, ADDITIONAL.
29 30 31 32 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 29 def create_google_business_media(account_id, create_google_business_media_request, opts = {}) data, _status_code, _headers = create_google_business_media_with_http_info(account_id, create_google_business_media_request, opts) data end |
#create_google_business_media_with_http_info(account_id, create_google_business_media_request, opts = {}) ⇒ Array<(CreateGoogleBusinessMedia200Response, Integer, Hash)>
Upload photo Creates a media item (photo) for a location from a publicly accessible URL. Categories determine where the photo appears: COVER, PROFILE, LOGO, EXTERIOR, INTERIOR, FOOD_AND_DRINK, MENU, PRODUCT, TEAMS, ADDITIONAL.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 41 def create_google_business_media_with_http_info(account_id, create_google_business_media_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBMediaApi.create_google_business_media ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBMediaApi.create_google_business_media" end # verify the required parameter 'create_google_business_media_request' is set if @api_client.config.client_side_validation && create_google_business_media_request.nil? fail ArgumentError, "Missing the required parameter 'create_google_business_media_request' when calling GMBMediaApi.create_google_business_media" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-media'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_google_business_media_request) # return_type return_type = opts[:debug_return_type] || 'CreateGoogleBusinessMedia200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBMediaApi.create_google_business_media", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBMediaApi#create_google_business_media\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_google_business_media(account_id, media_id, opts = {}) ⇒ DeleteGoogleBusinessMedia200Response
Delete photo Deletes a photo or media item from a GBP location.
106 107 108 109 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 106 def delete_google_business_media(account_id, media_id, opts = {}) data, _status_code, _headers = delete_google_business_media_with_http_info(account_id, media_id, opts) data end |
#delete_google_business_media_with_http_info(account_id, media_id, opts = {}) ⇒ Array<(DeleteGoogleBusinessMedia200Response, Integer, Hash)>
Delete photo Deletes a photo or media item from a GBP location.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 118 def delete_google_business_media_with_http_info(account_id, media_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBMediaApi.delete_google_business_media ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBMediaApi.delete_google_business_media" end # verify the required parameter 'media_id' is set if @api_client.config.client_side_validation && media_id.nil? fail ArgumentError, "Missing the required parameter 'media_id' when calling GMBMediaApi.delete_google_business_media" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-media'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'mediaId'] = media_id query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DeleteGoogleBusinessMedia200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBMediaApi.delete_google_business_media", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBMediaApi#delete_google_business_media\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_google_business_media(account_id, opts = {}) ⇒ ListGoogleBusinessMedia200Response
List media Lists media items (photos) for a Google Business Profile location. Returns photo URLs, descriptions, categories, and metadata.
180 181 182 183 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 180 def list_google_business_media(account_id, opts = {}) data, _status_code, _headers = list_google_business_media_with_http_info(account_id, opts) data end |
#list_google_business_media_with_http_info(account_id, opts = {}) ⇒ Array<(ListGoogleBusinessMedia200Response, Integer, Hash)>
List media Lists media items (photos) for a Google Business Profile location. Returns photo URLs, descriptions, categories, and metadata.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/zernio-sdk/api/gmb_media_api.rb', line 193 def list_google_business_media_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBMediaApi.list_google_business_media ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBMediaApi.list_google_business_media" end if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 100 fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling GMBMediaApi.list_google_business_media, must be smaller than or equal to 100.' end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-media'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'pageToken'] = opts[:'page_token'] if !opts[:'page_token'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListGoogleBusinessMedia200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBMediaApi.list_google_business_media", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBMediaApi#list_google_business_media\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |