Class: Zernio::GMBPlaceActionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zernio-sdk/api/gmb_place_actions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ GMBPlaceActionsApi

Returns a new instance of GMBPlaceActionsApi.



19
20
21
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_google_business_place_action(account_id, create_google_business_place_action_request, opts = {}) ⇒ CreateGoogleBusinessPlaceAction200Response

Create action link Creates a place action link for a location. Available action types: APPOINTMENT, ONLINE_APPOINTMENT, DINING_RESERVATION, FOOD_ORDERING, FOOD_DELIVERY, FOOD_TAKEOUT, SHOP_ONLINE.

Parameters:

Options Hash (opts):

  • :location_id (String)

    Override which location to target. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

Returns:



29
30
31
32
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 29

def create_google_business_place_action(, create_google_business_place_action_request, opts = {})
  data, _status_code, _headers = create_google_business_place_action_with_http_info(, create_google_business_place_action_request, opts)
  data
end

#create_google_business_place_action_with_http_info(account_id, create_google_business_place_action_request, opts = {}) ⇒ Array<(CreateGoogleBusinessPlaceAction200Response, Integer, Hash)>

Create action link Creates a place action link for a location. Available action types: APPOINTMENT, ONLINE_APPOINTMENT, DINING_RESERVATION, FOOD_ORDERING, FOOD_DELIVERY, FOOD_TAKEOUT, SHOP_ONLINE.

Parameters:

Options Hash (opts):

  • :location_id (String)

    Override which location to target. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 41

def create_google_business_place_action_with_http_info(, create_google_business_place_action_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBPlaceActionsApi.create_google_business_place_action ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBPlaceActionsApi.create_google_business_place_action"
  end
  # verify the required parameter 'create_google_business_place_action_request' is set
  if @api_client.config.client_side_validation && create_google_business_place_action_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_google_business_place_action_request' when calling GMBPlaceActionsApi.create_google_business_place_action"
  end
  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-place-actions'.sub('{' + 'accountId' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_google_business_place_action_request)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateGoogleBusinessPlaceAction200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBPlaceActionsApi.create_google_business_place_action",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBPlaceActionsApi#create_google_business_place_action\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_google_business_place_action(account_id, name, opts = {}) ⇒ DeleteGoogleBusinessPlaceAction200Response

Delete action link Deletes a place action link (e.g. booking or ordering URL) from a GBP location.

Parameters:

  • account_id (String)
  • name (String)

    The resource name of the place action link (e.g. locations/123/placeActionLinks/456)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location_id (String)

    Override which location to target. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

Returns:



106
107
108
109
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 106

def delete_google_business_place_action(, name, opts = {})
  data, _status_code, _headers = delete_google_business_place_action_with_http_info(, name, opts)
  data
end

#delete_google_business_place_action_with_http_info(account_id, name, opts = {}) ⇒ Array<(DeleteGoogleBusinessPlaceAction200Response, Integer, Hash)>

Delete action link Deletes a place action link (e.g. booking or ordering URL) from a GBP location.

Parameters:

  • account_id (String)
  • name (String)

    The resource name of the place action link (e.g. locations/123/placeActionLinks/456)

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location_id (String)

    Override which location to target. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

Returns:



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 118

def delete_google_business_place_action_with_http_info(, name, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBPlaceActionsApi.delete_google_business_place_action ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBPlaceActionsApi.delete_google_business_place_action"
  end
  # verify the required parameter 'name' is set
  if @api_client.config.client_side_validation && name.nil?
    fail ArgumentError, "Missing the required parameter 'name' when calling GMBPlaceActionsApi.delete_google_business_place_action"
  end
  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-place-actions'.sub('{' + 'accountId' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'name'] = name
  query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteGoogleBusinessPlaceAction200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBPlaceActionsApi.delete_google_business_place_action",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBPlaceActionsApi#delete_google_business_place_action\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_google_business_place_actions(account_id, opts = {}) ⇒ ListGoogleBusinessPlaceActions200Response

List action links Lists place action links for a Google Business Profile location. Place actions are the booking, ordering, and reservation buttons that appear on your listing.

Parameters:

  • account_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location_id (String)

    Override which location to query. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

  • :page_size (Integer) — default: default to 100
  • :page_token (String)

Returns:



180
181
182
183
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 180

def list_google_business_place_actions(, opts = {})
  data, _status_code, _headers = list_google_business_place_actions_with_http_info(, opts)
  data
end

#list_google_business_place_actions_with_http_info(account_id, opts = {}) ⇒ Array<(ListGoogleBusinessPlaceActions200Response, Integer, Hash)>

List action links Lists place action links for a Google Business Profile location. Place actions are the booking, ordering, and reservation buttons that appear on your listing.

Parameters:

  • account_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :location_id (String)

    Override which location to query. If omitted, uses the account's selected location. Use GET /gmb-locations to list valid IDs.

  • :page_size (Integer) — default: default to 100
  • :page_token (String)

Returns:



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 193

def list_google_business_place_actions_with_http_info(, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBPlaceActionsApi.list_google_business_place_actions ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBPlaceActionsApi.list_google_business_place_actions"
  end
  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 100
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling GMBPlaceActionsApi.list_google_business_place_actions, must be smaller than or equal to 100.'
  end

  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-place-actions'.sub('{' + 'accountId' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'pageToken'] = opts[:'page_token'] if !opts[:'page_token'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListGoogleBusinessPlaceActions200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBPlaceActionsApi.list_google_business_place_actions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBPlaceActionsApi#list_google_business_place_actions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_google_business_place_action(account_id, update_google_business_place_action_request, opts = {}) ⇒ UpdateGoogleBusinessPlaceAction200Response

Update action link Updates a place action link (change URL or action type). Only the fields included in the request body will be updated.

Parameters:

Options Hash (opts):

  • :location_id (String)

    Override which location to target. If omitted, uses the account's selected location.

Returns:



255
256
257
258
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 255

def update_google_business_place_action(, update_google_business_place_action_request, opts = {})
  data, _status_code, _headers = update_google_business_place_action_with_http_info(, update_google_business_place_action_request, opts)
  data
end

#update_google_business_place_action_with_http_info(account_id, update_google_business_place_action_request, opts = {}) ⇒ Array<(UpdateGoogleBusinessPlaceAction200Response, Integer, Hash)>

Update action link Updates a place action link (change URL or action type). Only the fields included in the request body will be updated.

Parameters:

Options Hash (opts):

  • :location_id (String)

    Override which location to target. If omitted, uses the account's selected location.

Returns:



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/zernio-sdk/api/gmb_place_actions_api.rb', line 267

def update_google_business_place_action_with_http_info(, update_google_business_place_action_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GMBPlaceActionsApi.update_google_business_place_action ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBPlaceActionsApi.update_google_business_place_action"
  end
  # verify the required parameter 'update_google_business_place_action_request' is set
  if @api_client.config.client_side_validation && update_google_business_place_action_request.nil?
    fail ArgumentError, "Missing the required parameter 'update_google_business_place_action_request' when calling GMBPlaceActionsApi.update_google_business_place_action"
  end
  # resource path
  local_var_path = '/v1/accounts/{accountId}/gmb-place-actions'.sub('{' + 'accountId' + '}', CGI.escape(.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(update_google_business_place_action_request)

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateGoogleBusinessPlaceAction200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"GMBPlaceActionsApi.update_google_business_place_action",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GMBPlaceActionsApi#update_google_business_place_action\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end