Class: Zernio::GbpSpecialHourPeriod

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/gbp_special_hour_period.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GbpSpecialHourPeriod

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GbpSpecialHourPeriod` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GbpSpecialHourPeriod`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'open_time')
    self.open_time = attributes[:'open_time']
  end

  if attributes.key?(:'close_time')
    self.close_time = attributes[:'close_time']
  end

  if attributes.key?(:'closed')
    self.closed = attributes[:'closed']
  end
end

Instance Attribute Details

#close_timeObject

Returns the value of attribute close_time.



24
25
26
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 24

def close_time
  @close_time
end

#closedObject

Returns the value of attribute closed.



26
27
28
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 26

def closed
  @closed
end

#end_dateObject

Returns the value of attribute end_date.



20
21
22
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 20

def end_date
  @end_date
end

#open_timeObject

Returns the value of attribute open_time.



22
23
24
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 22

def open_time
  @open_time
end

#start_dateObject

Returns the value of attribute start_date.



18
19
20
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 18

def start_date
  @start_date
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 29

def self.attribute_map
  {
    :'start_date' => :'startDate',
    :'end_date' => :'endDate',
    :'open_time' => :'openTime',
    :'close_time' => :'closeTime',
    :'closed' => :'closed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 145

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 50

def self.openapi_types
  {
    :'start_date' => :'GbpSpecialHourPeriodStartDate',
    :'end_date' => :'GbpSpecialHourPeriodStartDate',
    :'open_time' => :'String',
    :'close_time' => :'String',
    :'closed' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



120
121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 120

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      open_time == o.open_time &&
      close_time == o.close_time &&
      closed == o.closed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


132
133
134
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 132

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



138
139
140
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 138

def hash
  [start_date, end_date, open_time, close_time, closed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 167

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
# File 'lib/zernio-sdk/models/gbp_special_hour_period.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end