Class: Zernio::GenerateKeywordHistoricalMetricsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GenerateKeywordHistoricalMetricsRequest
- Defined in:
- lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio googleads SocialAccount id.
-
#ad_account_id ⇒ Object
Platform ad account ID (Google customer ID, digits only).
-
#countries ⇒ Object
ISO 3166-1 alpha-2 country codes.
-
#customer_id ⇒ Object
Alias of adAccountId, kept for existing callers.
-
#include_adult_keywords ⇒ Object
Returns the value of attribute include_adult_keywords.
-
#include_average_cpc ⇒ Object
Adds averageCpcMicros to each row's keywordMetrics.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#language_constant_id ⇒ Object
Google languageConstant id (1000 = English).
-
#network ⇒ Object
Returns the value of attribute network.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenerateKeywordHistoricalMetricsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GenerateKeywordHistoricalMetricsRequest
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GenerateKeywordHistoricalMetricsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GenerateKeywordHistoricalMetricsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end else self.keywords = nil end if attributes.key?(:'countries') if (value = attributes[:'countries']).is_a?(Array) self.countries = value end end if attributes.key?(:'language_constant_id') self.language_constant_id = attributes[:'language_constant_id'] else self.language_constant_id = '1000' end if attributes.key?(:'network') self.network = attributes[:'network'] else self.network = 'GOOGLE_SEARCH' end if attributes.key?(:'include_adult_keywords') self.include_adult_keywords = attributes[:'include_adult_keywords'] end if attributes.key?(:'include_average_cpc') self.include_average_cpc = attributes[:'include_average_cpc'] end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio googleads SocialAccount id.
19 20 21 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 19 def account_id @account_id end |
#ad_account_id ⇒ Object
Platform ad account ID (Google customer ID, digits only).
22 23 24 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 22 def ad_account_id @ad_account_id end |
#countries ⇒ Object
ISO 3166-1 alpha-2 country codes. Omitted = worldwide.
30 31 32 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 30 def countries @countries end |
#customer_id ⇒ Object
Alias of adAccountId, kept for existing callers
25 26 27 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 25 def customer_id @customer_id end |
#include_adult_keywords ⇒ Object
Returns the value of attribute include_adult_keywords.
37 38 39 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 37 def include_adult_keywords @include_adult_keywords end |
#include_average_cpc ⇒ Object
Adds averageCpcMicros to each row's keywordMetrics.
40 41 42 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 40 def include_average_cpc @include_average_cpc end |
#keywords ⇒ Object
Returns the value of attribute keywords.
27 28 29 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 27 def keywords @keywords end |
#language_constant_id ⇒ Object
Google languageConstant id (1000 = English).
33 34 35 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 33 def language_constant_id @language_constant_id end |
#network ⇒ Object
Returns the value of attribute network.
35 36 37 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 35 def network @network end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
80 81 82 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 80 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
85 86 87 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 85 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 65 def self.attribute_map { :'account_id' => :'accountId', :'ad_account_id' => :'adAccountId', :'customer_id' => :'customerId', :'keywords' => :'keywords', :'countries' => :'countries', :'language_constant_id' => :'languageConstantId', :'network' => :'network', :'include_adult_keywords' => :'includeAdultKeywords', :'include_average_cpc' => :'includeAverageCpc' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 309 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 90 def self.openapi_types { :'account_id' => :'String', :'ad_account_id' => :'String', :'customer_id' => :'String', :'keywords' => :'Array<String>', :'countries' => :'Array<String>', :'language_constant_id' => :'String', :'network' => :'String', :'include_adult_keywords' => :'Boolean', :'include_average_cpc' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 280 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && ad_account_id == o.ad_account_id && customer_id == o.customer_id && keywords == o.keywords && countries == o.countries && language_constant_id == o.language_constant_id && network == o.network && include_adult_keywords == o.include_adult_keywords && include_average_cpc == o.include_average_cpc end |
#eql?(o) ⇒ Boolean
296 297 298 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 296 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
302 303 304 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 302 def hash [account_id, ad_account_id, customer_id, keywords, countries, language_constant_id, network, include_adult_keywords, include_average_cpc].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @keywords.nil? invalid_properties.push('invalid value for "keywords", keywords cannot be nil.') end if @keywords.length > 1000 invalid_properties.push('invalid value for "keywords", number of items must be less than or equal to 1000.') end if @keywords.length < 1 invalid_properties.push('invalid value for "keywords", number of items must be greater than or equal to 1.') end if !@countries.nil? && @countries.length > 10 invalid_properties.push('invalid value for "countries", number of items must be less than or equal to 10.') end if !@countries.nil? && @countries.length < 1 invalid_properties.push('invalid value for "countries", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 331 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 209 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @keywords.nil? return false if @keywords.length > 1000 return false if @keywords.length < 1 return false if !@countries.nil? && @countries.length > 10 return false if !@countries.nil? && @countries.length < 1 network_validator = EnumAttributeValidator.new('String', ["GOOGLE_SEARCH", "GOOGLE_SEARCH_AND_PARTNERS"]) return false unless network_validator.valid?(@network) true end |