Class: Zernio::GetAccountHealth200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/get_account_health200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAccountHealth200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAccountHealth200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAccountHealth200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'integration_lane')
    self.integration_lane = attributes[:'integration_lane']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'token_status')
    self.token_status = attributes[:'token_status']
  end

  if attributes.key?(:'permissions')
    self.permissions = attributes[:'permissions']
  end

  if attributes.key?(:'issues')
    if (value = attributes[:'issues']).is_a?(Array)
      self.issues = value
    end
  end

  if attributes.key?(:'recommendations')
    if (value = attributes[:'recommendations']).is_a?(Array)
      self.recommendations = value
    end
  end

  if attributes.key?(:'messaging_restriction')
    self.messaging_restriction = attributes[:'messaging_restriction']
  end

  if attributes.key?(:'platform_connection')
    self.platform_connection = attributes[:'platform_connection']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 18

def 
  @account_id
end

#display_nameObject

Returns the value of attribute display_name.



27
28
29
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 27

def display_name
  @display_name
end

#integration_laneObject

TikTok only. The TikTok integration the account is connected through: business (TikTok for Business, Accounts API) or developer (the original integration). Absent on other platforms.



23
24
25
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 23

def integration_lane
  @integration_lane
end

#issuesObject

List of issues found



37
38
39
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 37

def issues
  @issues
end

#messaging_restrictionObject

Returns the value of attribute messaging_restriction.



42
43
44
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 42

def messaging_restriction
  @messaging_restriction
end

#permissionsObject

Returns the value of attribute permissions.



34
35
36
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 34

def permissions
  @permissions
end

#platformObject

Returns the value of attribute platform.



20
21
22
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 20

def platform
  @platform
end

#platform_connectionObject

Returns the value of attribute platform_connection.



44
45
46
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 44

def platform_connection
  @platform_connection
end

#recommendationsObject

Actionable recommendations to fix issues



40
41
42
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 40

def recommendations
  @recommendations
end

#statusObject

Overall health status



30
31
32
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 30

def status
  @status
end

#token_statusObject

Returns the value of attribute token_status.



32
33
34
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 32

def token_status
  @token_status
end

#usernameObject

Returns the value of attribute username.



25
26
27
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 25

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 69

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'integration_lane' => :'integrationLane',
    :'username' => :'username',
    :'display_name' => :'displayName',
    :'status' => :'status',
    :'token_status' => :'tokenStatus',
    :'permissions' => :'permissions',
    :'issues' => :'issues',
    :'recommendations' => :'recommendations',
    :'messaging_restriction' => :'messagingRestriction',
    :'platform_connection' => :'platformConnection'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 262

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 97

def self.openapi_types
  {
    :'account_id' => :'String',
    :'platform' => :'String',
    :'integration_lane' => :'String',
    :'username' => :'String',
    :'display_name' => :'String',
    :'status' => :'String',
    :'token_status' => :'GetAccountHealth200ResponseTokenStatus',
    :'permissions' => :'GetAccountHealth200ResponsePermissions',
    :'issues' => :'Array<String>',
    :'recommendations' => :'Array<String>',
    :'messaging_restriction' => :'GetAllAccountsHealth200ResponseAccountsInnerMessagingRestriction',
    :'platform_connection' => :'GetAccountHealth200ResponsePlatformConnection'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 230

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      platform == o.platform &&
      integration_lane == o.integration_lane &&
      username == o.username &&
      display_name == o.display_name &&
      status == o.status &&
      token_status == o.token_status &&
      permissions == o.permissions &&
      issues == o.issues &&
      recommendations == o.recommendations &&
      messaging_restriction == o.messaging_restriction &&
      platform_connection == o.platform_connection
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 255

def hash
  [, platform, integration_lane, username, display_name, status, token_status, permissions, issues, recommendations, messaging_restriction, platform_connection].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



191
192
193
194
195
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 191

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 284

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



199
200
201
202
203
204
205
206
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 199

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  integration_lane_validator = EnumAttributeValidator.new('String', ["business", "developer"])
  return false unless integration_lane_validator.valid?(@integration_lane)
  status_validator = EnumAttributeValidator.new('String', ["healthy", "warning", "error"])
  return false unless status_validator.valid?(@status)
  true
end