Class: Zernio::GetAccountHealth200ResponsePermissions

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_account_health200_response_permissions.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAccountHealth200ResponsePermissions

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAccountHealth200ResponsePermissions` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAccountHealth200ResponsePermissions`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'posting')
    if (value = attributes[:'posting']).is_a?(Array)
      self.posting = value
    end
  end

  if attributes.key?(:'analytics')
    if (value = attributes[:'analytics']).is_a?(Array)
      self.analytics = value
    end
  end

  if attributes.key?(:'optional')
    if (value = attributes[:'optional']).is_a?(Array)
      self.optional = value
    end
  end

  if attributes.key?(:'can_post')
    self.can_post = attributes[:'can_post']
  end

  if attributes.key?(:'can_fetch_analytics')
    self.can_fetch_analytics = attributes[:'can_fetch_analytics']
  end

  if attributes.key?(:'missing_required')
    if (value = attributes[:'missing_required']).is_a?(Array)
      self.missing_required = value
    end
  end
end

Instance Attribute Details

#analyticsObject

Returns the value of attribute analytics.



20
21
22
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 20

def analytics
  @analytics
end

#can_fetch_analyticsObject

Returns the value of attribute can_fetch_analytics.



26
27
28
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 26

def can_fetch_analytics
  @can_fetch_analytics
end

#can_postObject

Returns the value of attribute can_post.



24
25
26
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 24

def can_post
  @can_post
end

#missing_requiredObject

Returns the value of attribute missing_required.



28
29
30
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 28

def missing_required
  @missing_required
end

#optionalObject

Returns the value of attribute optional.



22
23
24
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 22

def optional
  @optional
end

#postingObject

Returns the value of attribute posting.



18
19
20
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 18

def posting
  @posting
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 31

def self.attribute_map
  {
    :'posting' => :'posting',
    :'analytics' => :'analytics',
    :'optional' => :'optional',
    :'can_post' => :'canPost',
    :'can_fetch_analytics' => :'canFetchAnalytics',
    :'missing_required' => :'missingRequired'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 162

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 53

def self.openapi_types
  {
    :'posting' => :'Array<GetAccountHealth200ResponsePermissionsPostingInner>',
    :'analytics' => :'Array<GetAccountHealth200ResponsePermissionsPostingInner>',
    :'optional' => :'Array<GetAccountHealth200ResponsePermissionsPostingInner>',
    :'can_post' => :'Boolean',
    :'can_fetch_analytics' => :'Boolean',
    :'missing_required' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



136
137
138
139
140
141
142
143
144
145
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 136

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      posting == o.posting &&
      analytics == o.analytics &&
      optional == o.optional &&
      can_post == o.can_post &&
      can_fetch_analytics == o.can_fetch_analytics &&
      missing_required == o.missing_required
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


149
150
151
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 149

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



155
156
157
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 155

def hash
  [posting, analytics, optional, can_post, can_fetch_analytics, missing_required].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 184

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
# File 'lib/zernio-sdk/models/get_account_health200_response_permissions.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end