Class: Zernio::GetAd200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetAd200Response
- Defined in:
- lib/zernio-sdk/models/get_ad200_response.rb
Instance Attribute Summary collapse
-
#ad ⇒ Object
Returns the value of attribute ad.
-
#cached_at ⇒ Object
Google RSA details cache timestamp.
-
#stale ⇒ Object
Whether Google RSA details use the last successful cached response.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetAd200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetAd200Response
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAd200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAd200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad') self.ad = attributes[:'ad'] end if attributes.key?(:'cached_at') self.cached_at = attributes[:'cached_at'] end if attributes.key?(:'stale') self.stale = attributes[:'stale'] end end |
Instance Attribute Details
#ad ⇒ Object
Returns the value of attribute ad.
18 19 20 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 18 def ad @ad end |
#cached_at ⇒ Object
Google RSA details cache timestamp.
21 22 23 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 21 def cached_at @cached_at end |
#stale ⇒ Object
Whether Google RSA details use the last successful cached response.
24 25 26 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 24 def stale @stale end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 27 def self.attribute_map { :'ad' => :'ad', :'cached_at' => :'cachedAt', :'stale' => :'stale' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 130 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 59 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 55 def self.openapi_nullable Set.new([ :'cached_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 46 def self.openapi_types { :'ad' => :'Ad', :'cached_at' => :'Time', :'stale' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 107 def ==(o) return true if self.equal?(o) self.class == o.class && ad == o.ad && cached_at == o.cached_at && stale == o.stale end |
#eql?(o) ⇒ Boolean
117 118 119 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 117 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 123 def hash [ad, cached_at, stale].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
92 93 94 95 96 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 92 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 152 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
100 101 102 103 |
# File 'lib/zernio-sdk/models/get_ad200_response.rb', line 100 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |