Class: Zernio::GetAdComments200ResponseMeta

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/get_ad_comments200_response_meta.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAdComments200ResponseMeta

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAdComments200ResponseMeta` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAdComments200ResponseMeta`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  else
    self.platform = nil
  end

  if attributes.key?(:'placement')
    self.placement = attributes[:'placement']
  end

  if attributes.key?(:'ad_id')
    self.ad_id = attributes[:'ad_id']
  else
    self.ad_id = nil
  end

  if attributes.key?(:'platform_ad_id')
    self.platform_ad_id = attributes[:'platform_ad_id']
  end

  if attributes.key?(:'effective_story_id')
    self.effective_story_id = attributes[:'effective_story_id']
  end

  if attributes.key?(:'tiktok_item_id')
    self.tiktok_item_id = attributes[:'tiktok_item_id']
  end

  if attributes.key?(:'since')
    self.since = attributes[:'since']
  end

  if attributes.key?(:'_until')
    self._until = attributes[:'_until']
  end

  if attributes.key?(:'facebook_account_id')
    self. = attributes[:'facebook_account_id']
  end

  if attributes.key?(:'instagram_user_id')
    self.instagram_user_id = attributes[:'instagram_user_id']
  end

  if attributes.key?(:'instagram_permalink')
    self.instagram_permalink = attributes[:'instagram_permalink']
  end

  if attributes.key?(:'instagram_account_id')
    self. = attributes[:'instagram_account_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  else
    self.last_updated = nil
  end
end

Instance Attribute Details

#_untilObject

TikTok-only resolved end date.



40
41
42
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 40

def _until
  @_until
end

#account_idObject

Account ID (ads SocialAccount).



55
56
57
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 55

def 
  @account_id
end

#ad_idObject

Internal Zernio ad ID.



25
26
27
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 25

def ad_id
  @ad_id
end

#effective_story_idObject

Underlying post ID the comments belong to. effective_object_story_id for the Facebook side, effective_instagram_media_id for the Instagram side.



31
32
33
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 31

def effective_story_id
  @effective_story_id
end

#facebook_account_idObject

Facebook-only. The connected Facebook Page SocialAccount these comments were read through. Pass it as accountId (with effectiveStoryId as the postId) to /v1/inbox/comments to reply/hide/delete. Null when no connected Page was used (then moderation isn't possible).



43
44
45
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 43

def 
  @facebook_account_id
end

#instagram_account_idObject

Instagram-only. The connected Instagram SocialAccount these comments were read through. Pass it as accountId (with effectiveStoryId as the postId) to /v1/inbox/comments to reply/hide/delete.



52
53
54
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 52

def 
  @instagram_account_id
end

Instagram-only. Public permalink of the boosted IG post (creative.instagram_permalink_url).



49
50
51
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 49

def instagram_permalink
  @instagram_permalink
end

#instagram_user_idObject

Instagram-only. The Instagram-scoped business ID that owns the boosted media (creative.instagram_user_id).



46
47
48
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 46

def instagram_user_id
  @instagram_user_id
end

#last_updatedObject

Returns the value of attribute last_updated.



57
58
59
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 57

def last_updated
  @last_updated
end

#placementObject

The placement these comments are for, useful when you didn't pass ?placement= and want to know which one you got.



22
23
24
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 22

def placement
  @placement
end

#platformObject

Platform of the comments.



19
20
21
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 19

def platform
  @platform
end

#platform_ad_idObject

Platform ad ID.



28
29
30
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 28

def platform_ad_id
  @platform_ad_id
end

#sinceObject

TikTok-only resolved start date.



37
38
39
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 37

def since
  @since
end

#tiktok_item_idObject

TikTok-only video item ID from stored ad fields or returned comments. Null does not prevent listing; ad details are not fetched to populate it.



34
35
36
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 34

def tiktok_item_id
  @tiktok_item_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



102
103
104
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 102

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 107

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 82

def self.attribute_map
  {
    :'platform' => :'platform',
    :'placement' => :'placement',
    :'ad_id' => :'adId',
    :'platform_ad_id' => :'platformAdId',
    :'effective_story_id' => :'effectiveStoryId',
    :'tiktok_item_id' => :'tiktokItemId',
    :'since' => :'since',
    :'_until' => :'until',
    :'facebook_account_id' => :'facebookAccountId',
    :'instagram_user_id' => :'instagramUserId',
    :'instagram_permalink' => :'instagramPermalink',
    :'instagram_account_id' => :'instagramAccountId',
    :'account_id' => :'accountId',
    :'last_updated' => :'lastUpdated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 345

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
136
137
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 132

def self.openapi_nullable
  Set.new([
    :'tiktok_item_id',
    :'facebook_account_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 112

def self.openapi_types
  {
    :'platform' => :'String',
    :'placement' => :'String',
    :'ad_id' => :'String',
    :'platform_ad_id' => :'String',
    :'effective_story_id' => :'String',
    :'tiktok_item_id' => :'String',
    :'since' => :'Date',
    :'_until' => :'Date',
    :'facebook_account_id' => :'String',
    :'instagram_user_id' => :'String',
    :'instagram_permalink' => :'String',
    :'instagram_account_id' => :'String',
    :'account_id' => :'String',
    :'last_updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 311

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      platform == o.platform &&
      placement == o.placement &&
      ad_id == o.ad_id &&
      platform_ad_id == o.platform_ad_id &&
      effective_story_id == o.effective_story_id &&
      tiktok_item_id == o.tiktok_item_id &&
      since == o.since &&
      _until == o._until &&
       == o. &&
      instagram_user_id == o.instagram_user_id &&
      instagram_permalink == o.instagram_permalink &&
       == o. &&
       == o. &&
      last_updated == o.last_updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


332
333
334
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 332

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



338
339
340
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 338

def hash
  [platform, placement, ad_id, platform_ad_id, effective_story_id, tiktok_item_id, since, _until, , instagram_user_id, instagram_permalink, , , last_updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 222

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if @ad_id.nil?
    invalid_properties.push('invalid value for "ad_id", ad_id cannot be nil.')
  end

  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @last_updated.nil?
    invalid_properties.push('invalid value for "last_updated", last_updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 367

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zernio-sdk/models/get_ad_comments200_response_meta.rb', line 246

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @platform.nil?
  platform_validator = EnumAttributeValidator.new('String', ["facebook", "instagram", "tiktok"])
  return false unless platform_validator.valid?(@platform)
  placement_validator = EnumAttributeValidator.new('String', ["facebook", "instagram"])
  return false unless placement_validator.valid?(@placement)
  return false if @ad_id.nil?
  return false if @account_id.nil?
  return false if @last_updated.nil?
  true
end