Class: Zernio::GetAdMedia200ResponseMediaInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAdMedia200ResponseMediaInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAdMedia200ResponseMediaInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAdMedia200ResponseMediaInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'video_id')
    self.video_id = attributes[:'video_id']
  end

  if attributes.key?(:'length')
    self.length = attributes[:'length']
  end

  if attributes.key?(:'index')
    self.index = attributes[:'index']
  end
end

Instance Attribute Details

#indexObject

0-based position for carousel children or asset_feed_spec entries.



33
34
35
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 33

def index
  @index
end

#lengthObject

Video length in seconds (videos only).



30
31
32
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 30

def length
  @length
end

#thumbnail_urlObject

Video poster URL (videos only).



24
25
26
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 24

def thumbnail_url
  @thumbnail_url
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 18

def type
  @type
end

#urlObject

Direct file URL (signed; short-lived — see description).



21
22
23
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 21

def url
  @url
end

#video_idObject

Meta video id (videos only), reusable as video.id on the create endpoints.



27
28
29
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 27

def video_id
  @video_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 58

def self.attribute_map
  {
    :'type' => :'type',
    :'url' => :'url',
    :'thumbnail_url' => :'thumbnailUrl',
    :'video_id' => :'videoId',
    :'length' => :'length',
    :'index' => :'index'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 80

def self.openapi_types
  {
    :'type' => :'String',
    :'url' => :'String',
    :'thumbnail_url' => :'String',
    :'video_id' => :'String',
    :'length' => :'Float',
    :'index' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 167

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      url == o.url &&
      thumbnail_url == o.thumbnail_url &&
      video_id == o.video_id &&
      length == o.length &&
      index == o.index
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 186

def hash
  [type, url, thumbnail_url, video_id, length, index].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
# File 'lib/zernio-sdk/models/get_ad_media200_response_media_inner.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["image", "video"])
  return false unless type_validator.valid?(@type)
  true
end