Class: Zernio::GetAdsTimeline202Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/get_ads_timeline202_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAdsTimeline202Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAdsTimeline202Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAdsTimeline202Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'backfill_pending')
    self.backfill_pending = attributes[:'backfill_pending']
  else
    self.backfill_pending = nil
  end

  if attributes.key?(:'rows')
    if (value = attributes[:'rows']).is_a?(Array)
      self.rows = value
    end
  end
end

Instance Attribute Details

#backfill_pendingObject

Returns the value of attribute backfill_pending.



18
19
20
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 18

def backfill_pending
  @backfill_pending
end

#rowsObject

Returns the value of attribute rows.



20
21
22
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 20

def rows
  @rows
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 45

def self.attribute_map
  {
    :'backfill_pending' => :'backfillPending',
    :'rows' => :'rows'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



77
78
79
80
81
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 77

def self.openapi_all_of
  [
  :'AdsTimelineResponse'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 63

def self.openapi_types
  {
    :'backfill_pending' => :'Boolean',
    :'rows' => :'Array<AdsTimelineResponseRowsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      backfill_pending == o.backfill_pending &&
      rows == o.rows
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 161

def hash
  [backfill_pending, rows].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



114
115
116
117
118
119
120
121
122
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 114

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @backfill_pending.nil?
    invalid_properties.push('invalid value for "backfill_pending", backfill_pending cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



126
127
128
129
130
131
132
# File 'lib/zernio-sdk/models/get_ads_timeline202_response.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @backfill_pending.nil?
  backfill_pending_validator = EnumAttributeValidator.new('Boolean', ["true"])
  return false unless backfill_pending_validator.valid?(@backfill_pending)
  true
end