Class: Zernio::GetCampaignConversionGoals200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetCampaignConversionGoals200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetCampaignConversionGoals200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetCampaignConversionGoals200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'goal_config_level')
    self.goal_config_level = attributes[:'goal_config_level']
  end

  if attributes.key?(:'custom_conversion_goal_id')
    self.custom_conversion_goal_id = attributes[:'custom_conversion_goal_id']
  end

  if attributes.key?(:'goals')
    if (value = attributes[:'goals']).is_a?(Array)
      self.goals = value
    end
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'cached_at')
    self.cached_at = attributes[:'cached_at']
  end

  if attributes.key?(:'stale')
    self.stale = attributes[:'stale']
  end
end

Instance Attribute Details

#cached_at ⇒ Object

Returns the value of attribute cached_at.



28
29
30
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 28

def cached_at
  @cached_at
end

#campaign_id ⇒ Object

Returns the value of attribute campaign_id.



18
19
20
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 18

def campaign_id
  @campaign_id
end

#custom_conversion_goal_id ⇒ Object

Returns the value of attribute custom_conversion_goal_id.



22
23
24
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 22

def custom_conversion_goal_id
  @custom_conversion_goal_id
end

#customer_id ⇒ Object

Returns the value of attribute customer_id.



26
27
28
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 26

def customer_id
  @customer_id
end

#goal_config_level ⇒ Object

Returns the value of attribute goal_config_level.



20
21
22
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 20

def goal_config_level
  @goal_config_level
end

#goals ⇒ Object

Returns the value of attribute goals.



24
25
26
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 24

def goals
  @goals
end

#stale ⇒ Object

Returns the value of attribute stale.



30
31
32
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 30

def stale
  @stale
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



68
69
70
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 55

def self.attribute_map
  {
    :'campaign_id' => :'campaignId',
    :'goal_config_level' => :'goalConfigLevel',
    :'custom_conversion_goal_id' => :'customConversionGoalId',
    :'goals' => :'goals',
    :'customer_id' => :'customerId',
    :'cached_at' => :'cachedAt',
    :'stale' => :'stale'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 207

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_of ⇒ Object

List of class defined in allOf (OpenAPI v3)



98
99
100
101
102
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 98

def self.openapi_all_of
  [
  :'GoogleCampaignConversionGoals'
  ]
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



91
92
93
94
95
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 91

def self.openapi_nullable
  Set.new([
    :'cached_at',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 78

def self.openapi_types
  {
    :'campaign_id' => :'String',
    :'goal_config_level' => :'String',
    :'custom_conversion_goal_id' => :'String',
    :'goals' => :'Array<GoogleCampaignConversionGoalsGoalsInner>',
    :'customer_id' => :'String',
    :'cached_at' => :'Time',
    :'stale' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



180
181
182
183
184
185
186
187
188
189
190
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      campaign_id == o.campaign_id &&
      goal_config_level == o.goal_config_level &&
      custom_conversion_goal_id == o.custom_conversion_goal_id &&
      goals == o.goals &&
      customer_id == o.customer_id &&
      cached_at == o.cached_at &&
      stale == o.stale
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 194

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



200
201
202
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 200

def hash
  [campaign_id, goal_config_level, custom_conversion_goal_id, goals, customer_id, cached_at, stale].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



161
162
163
164
165
166
# File 'lib/zernio-sdk/models/get_campaign_conversion_goals200_response.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  goal_config_level_validator = EnumAttributeValidator.new('String', ["CUSTOMER", "CAMPAIGN", "UNSPECIFIED", "UNKNOWN"])
  return false unless goal_config_level_validator.valid?(@goal_config_level)
  true
end