Class: Zernio::GetDailyMetrics200ResponsePlatformBreakdownInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetDailyMetrics200ResponsePlatformBreakdownInner
- Defined in:
- lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb
Instance Attribute Summary collapse
-
#clicks ⇒ Object
Returns the value of attribute clicks.
-
#comments ⇒ Object
Returns the value of attribute comments.
-
#impressions ⇒ Object
Returns the value of attribute impressions.
-
#likes ⇒ Object
Returns the value of attribute likes.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#post_count ⇒ Object
Returns the value of attribute post_count.
-
#reach ⇒ Object
Returns the value of attribute reach.
-
#saves ⇒ Object
Returns the value of attribute saves.
-
#shares ⇒ Object
Returns the value of attribute shares.
-
#views ⇒ Object
Returns the value of attribute views.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetDailyMetrics200ResponsePlatformBreakdownInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetDailyMetrics200ResponsePlatformBreakdownInner
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetDailyMetrics200ResponsePlatformBreakdownInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetDailyMetrics200ResponsePlatformBreakdownInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'post_count') self.post_count = attributes[:'post_count'] end if attributes.key?(:'impressions') self.impressions = attributes[:'impressions'] end if attributes.key?(:'reach') self.reach = attributes[:'reach'] end if attributes.key?(:'likes') self.likes = attributes[:'likes'] end if attributes.key?(:'comments') self.comments = attributes[:'comments'] end if attributes.key?(:'shares') self.shares = attributes[:'shares'] end if attributes.key?(:'saves') self.saves = attributes[:'saves'] end if attributes.key?(:'clicks') self.clicks = attributes[:'clicks'] end if attributes.key?(:'views') self.views = attributes[:'views'] end end |
Instance Attribute Details
#clicks ⇒ Object
Returns the value of attribute clicks.
34 35 36 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 34 def clicks @clicks end |
#comments ⇒ Object
Returns the value of attribute comments.
28 29 30 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 28 def comments @comments end |
#impressions ⇒ Object
Returns the value of attribute impressions.
22 23 24 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 22 def impressions @impressions end |
#likes ⇒ Object
Returns the value of attribute likes.
26 27 28 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 26 def likes @likes end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 18 def platform @platform end |
#post_count ⇒ Object
Returns the value of attribute post_count.
20 21 22 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 20 def post_count @post_count end |
#reach ⇒ Object
Returns the value of attribute reach.
24 25 26 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 24 def reach @reach end |
#saves ⇒ Object
Returns the value of attribute saves.
32 33 34 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 32 def saves @saves end |
#shares ⇒ Object
Returns the value of attribute shares.
30 31 32 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 30 def shares @shares end |
#views ⇒ Object
Returns the value of attribute views.
36 37 38 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 36 def views @views end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 39 def self.attribute_map { :'platform' => :'platform', :'post_count' => :'postCount', :'impressions' => :'impressions', :'reach' => :'reach', :'likes' => :'likes', :'comments' => :'comments', :'shares' => :'shares', :'saves' => :'saves', :'clicks' => :'clicks', :'views' => :'views' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 65 def self.openapi_types { :'platform' => :'String', :'post_count' => :'Integer', :'impressions' => :'Integer', :'reach' => :'Integer', :'likes' => :'Integer', :'comments' => :'Integer', :'shares' => :'Integer', :'saves' => :'Integer', :'clicks' => :'Integer', :'views' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && post_count == o.post_count && impressions == o.impressions && reach == o.reach && likes == o.likes && comments == o.comments && shares == o.shares && saves == o.saves && clicks == o.clicks && views == o.views end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 183 def hash [platform, post_count, impressions, reach, likes, comments, shares, saves, clicks, views].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 |
# File 'lib/zernio-sdk/models/get_daily_metrics200_response_platform_breakdown_inner.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |