Class: Zernio::GetDiscordSettings200ResponseAccount

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_discord_settings200_response_account.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetDiscordSettings200ResponseAccount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetDiscordSettings200ResponseAccount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetDiscordSettings200ResponseAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'profile_picture')
    self.profile_picture = attributes[:'profile_picture']
  end

  if attributes.key?(:'channel_id')
    self.channel_id = attributes[:'channel_id']
  end

  if attributes.key?(:'channel_name')
    self.channel_name = attributes[:'channel_name']
  end

  if attributes.key?(:'channel_type')
    self.channel_type = attributes[:'channel_type']
  end

  if attributes.key?(:'guild_id')
    self.guild_id = attributes[:'guild_id']
  end

  if attributes.key?(:'webhook_username')
    self.webhook_username = attributes[:'webhook_username']
  end

  if attributes.key?(:'webhook_avatar_url')
    self.webhook_avatar_url = attributes[:'webhook_avatar_url']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 18

def _id
  @_id
end

#channel_idObject

Connected channel snowflake ID



32
33
34
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 32

def channel_id
  @channel_id
end

#channel_nameObject

Channel name



35
36
37
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 35

def channel_name
  @channel_name
end

#channel_typeObject

Channel type (0 = text, 5 = announcement, 15 = forum)



38
39
40
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 38

def channel_type
  @channel_type
end

#display_nameObject

Guild - #channel display name



26
27
28
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 26

def display_name
  @display_name
end

#guild_idObject

Guild (server) snowflake ID



41
42
43
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 41

def guild_id
  @guild_id
end

#platformObject

Returns the value of attribute platform.



20
21
22
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 20

def platform
  @platform
end

#profile_pictureObject

Guild icon URL



29
30
31
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 29

def profile_picture
  @profile_picture
end

#usernameObject

Channel name



23
24
25
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 23

def username
  @username
end

#webhook_avatar_urlObject

Custom webhook avatar URL (null = default bot avatar)



47
48
49
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 47

def webhook_avatar_url
  @webhook_avatar_url
end

#webhook_usernameObject

Custom webhook display name (null = default "Zernio")



44
45
46
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 44

def webhook_username
  @webhook_username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 50

def self.attribute_map
  {
    :'_id' => :'_id',
    :'platform' => :'platform',
    :'username' => :'username',
    :'display_name' => :'displayName',
    :'profile_picture' => :'profilePicture',
    :'channel_id' => :'channelId',
    :'channel_name' => :'channelName',
    :'channel_type' => :'channelType',
    :'guild_id' => :'guildId',
    :'webhook_username' => :'webhookUsername',
    :'webhook_avatar_url' => :'webhookAvatarUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 94

def self.openapi_nullable
  Set.new([
    :'webhook_username',
    :'webhook_avatar_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 77

def self.openapi_types
  {
    :'_id' => :'String',
    :'platform' => :'String',
    :'username' => :'String',
    :'display_name' => :'String',
    :'profile_picture' => :'String',
    :'channel_id' => :'String',
    :'channel_name' => :'String',
    :'channel_type' => :'String',
    :'guild_id' => :'String',
    :'webhook_username' => :'String',
    :'webhook_avatar_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      platform == o.platform &&
      username == o.username &&
      display_name == o.display_name &&
      profile_picture == o.profile_picture &&
      channel_id == o.channel_id &&
      channel_name == o.channel_name &&
      channel_type == o.channel_type &&
      guild_id == o.guild_id &&
      webhook_username == o.webhook_username &&
      webhook_avatar_url == o.webhook_avatar_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 203

def hash
  [_id, platform, username, display_name, profile_picture, channel_id, channel_name, channel_type, guild_id, webhook_username, webhook_avatar_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
175
# File 'lib/zernio-sdk/models/get_discord_settings200_response_account.rb', line 172

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end