Class: Zernio::GetFacebookPostReactions200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetFacebookPostReactions200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetFacebookPostReactions200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetFacebookPostReactions200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'post_id')
    self.post_id = attributes[:'post_id']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'breakdown')
    self.breakdown = attributes[:'breakdown']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 18

def 
  @account_id
end

#breakdownObject

Returns the value of attribute breakdown.



29
30
31
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 29

def breakdown
  @breakdown
end

#last_updatedObject

Returns the value of attribute last_updated.



31
32
33
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 31

def last_updated
  @last_updated
end

#platformObject

Returns the value of attribute platform.



20
21
22
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 20

def platform
  @platform
end

#post_idObject

Returns the value of attribute post_id.



24
25
26
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 24

def post_id
  @post_id
end

#totalObject

Total reactions across all types



27
28
29
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 27

def total
  @total
end

#usernameObject

Returns the value of attribute username.



22
23
24
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 22

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 34

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'username' => :'username',
    :'post_id' => :'postId',
    :'total' => :'total',
    :'breakdown' => :'breakdown',
    :'last_updated' => :'lastUpdated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 164

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 57

def self.openapi_types
  {
    :'account_id' => :'String',
    :'platform' => :'String',
    :'username' => :'String',
    :'post_id' => :'String',
    :'total' => :'Integer',
    :'breakdown' => :'GetFacebookPostReactions200ResponseBreakdown',
    :'last_updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      platform == o.platform &&
      username == o.username &&
      post_id == o.post_id &&
      total == o.total &&
      breakdown == o.breakdown &&
      last_updated == o.last_updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


151
152
153
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 151

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



157
158
159
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 157

def hash
  [, platform, username, post_id, total, breakdown, last_updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 186

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
# File 'lib/zernio-sdk/models/get_facebook_post_reactions200_response.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end