Class: Zernio::GetGoogleBusinessReviews200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_google_business_reviews200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetGoogleBusinessReviews200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetGoogleBusinessReviews200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetGoogleBusinessReviews200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'location_id')
    self.location_id = attributes[:'location_id']
  end

  if attributes.key?(:'reviews')
    if (value = attributes[:'reviews']).is_a?(Array)
      self.reviews = value
    end
  end

  if attributes.key?(:'average_rating')
    self.average_rating = attributes[:'average_rating']
  end

  if attributes.key?(:'total_review_count')
    self.total_review_count = attributes[:'total_review_count']
  end

  if attributes.key?(:'next_page_token')
    self.next_page_token = attributes[:'next_page_token']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



20
21
22
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 20

def 
  @account_id
end

#average_ratingObject

Overall average rating



27
28
29
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 27

def average_rating
  @average_rating
end

#location_idObject

Returns the value of attribute location_id.



22
23
24
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 22

def location_id
  @location_id
end

#next_page_tokenObject

Token for next page



33
34
35
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 33

def next_page_token
  @next_page_token
end

#reviewsObject

Returns the value of attribute reviews.



24
25
26
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 24

def reviews
  @reviews
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 18

def success
  @success
end

#total_review_countObject

Total number of reviews



30
31
32
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 30

def total_review_count
  @total_review_count
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 36

def self.attribute_map
  {
    :'success' => :'success',
    :'account_id' => :'accountId',
    :'location_id' => :'locationId',
    :'reviews' => :'reviews',
    :'average_rating' => :'averageRating',
    :'total_review_count' => :'totalReviewCount',
    :'next_page_token' => :'nextPageToken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 72

def self.openapi_nullable
  Set.new([
    :'next_page_token'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 59

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'account_id' => :'String',
    :'location_id' => :'String',
    :'reviews' => :'Array<GetGoogleBusinessReviews200ResponseReviewsInner>',
    :'average_rating' => :'Float',
    :'total_review_count' => :'Integer',
    :'next_page_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
       == o. &&
      location_id == o.location_id &&
      reviews == o.reviews &&
      average_rating == o.average_rating &&
      total_review_count == o.total_review_count &&
      next_page_token == o.next_page_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 162

def hash
  [success, , location_id, reviews, average_rating, total_review_count, next_page_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end