Class: Zernio::GetGoogleBusinessReviews200ResponseReviewsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetGoogleBusinessReviews200ResponseReviewsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetGoogleBusinessReviews200ResponseReviewsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetGoogleBusinessReviews200ResponseReviewsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'reviewer')
    self.reviewer = attributes[:'reviewer']
  end

  if attributes.key?(:'rating')
    self.rating = attributes[:'rating']
  end

  if attributes.key?(:'star_rating')
    self.star_rating = attributes[:'star_rating']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'create_time')
    self.create_time = attributes[:'create_time']
  end

  if attributes.key?(:'update_time')
    self.update_time = attributes[:'update_time']
  end

  if attributes.key?(:'review_reply')
    self.review_reply = attributes[:'review_reply']
  end

  if attributes.key?(:'photo_count')
    self.photo_count = attributes[:'photo_count']
  end

  if attributes.key?(:'photos')
    if (value = attributes[:'photos']).is_a?(Array)
      self.photos = value
    end
  end
end

Instance Attribute Details

#commentObject

Review text



33
34
35
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 33

def comment
  @comment
end

#create_timeObject

Returns the value of attribute create_time.



35
36
37
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 35

def create_time
  @create_time
end

#idObject

Review ID



19
20
21
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 19

def id
  @id
end

#nameObject

Full resource name



22
23
24
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 22

def name
  @name
end

#photo_countObject

Number of photos attached to the review (photos only, videos are not counted)



42
43
44
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 42

def photo_count
  @photo_count
end

#photosObject

Photos attached to the review by the reviewer



45
46
47
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 45

def photos
  @photos
end

#ratingObject

Numeric star rating



27
28
29
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 27

def rating
  @rating
end

#review_replyObject

Returns the value of attribute review_reply.



39
40
41
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 39

def review_reply
  @review_reply
end

#reviewerObject

Returns the value of attribute reviewer.



24
25
26
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 24

def reviewer
  @reviewer
end

#star_ratingObject

Google's string rating



30
31
32
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 30

def star_rating
  @star_rating
end

#update_timeObject

Returns the value of attribute update_time.



37
38
39
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 37

def update_time
  @update_time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 70

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'reviewer' => :'reviewer',
    :'rating' => :'rating',
    :'star_rating' => :'starRating',
    :'comment' => :'comment',
    :'create_time' => :'createTime',
    :'update_time' => :'updateTime',
    :'review_reply' => :'reviewReply',
    :'photo_count' => :'photoCount',
    :'photos' => :'photos'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 270

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 97

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'reviewer' => :'GetGoogleBusinessReviews200ResponseReviewsInnerReviewer',
    :'rating' => :'Integer',
    :'star_rating' => :'String',
    :'comment' => :'String',
    :'create_time' => :'Time',
    :'update_time' => :'Time',
    :'review_reply' => :'GetGoogleBusinessReviews200ResponseReviewsInnerReviewReply',
    :'photo_count' => :'Integer',
    :'photos' => :'Array<GetGoogleBusinessReviews200ResponseReviewsInnerPhotosInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      reviewer == o.reviewer &&
      rating == o.rating &&
      star_rating == o.star_rating &&
      comment == o.comment &&
      create_time == o.create_time &&
      update_time == o.update_time &&
      review_reply == o.review_reply &&
      photo_count == o.photo_count &&
      photos == o.photos
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


257
258
259
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 257

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



263
264
265
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 263

def hash
  [id, name, reviewer, rating, star_rating, comment, create_time, update_time, review_reply, photo_count, photos].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@rating.nil? && @rating > 5
    invalid_properties.push('invalid value for "rating", must be smaller than or equal to 5.')
  end

  if !@rating.nil? && @rating < 1
    invalid_properties.push('invalid value for "rating", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 292

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
206
207
# File 'lib/zernio-sdk/models/get_google_business_reviews200_response_reviews_inner.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@rating.nil? && @rating > 5
  return false if !@rating.nil? && @rating < 1
  star_rating_validator = EnumAttributeValidator.new('String', ["ONE", "TWO", "THREE", "FOUR", "FIVE"])
  return false unless star_rating_validator.valid?(@star_rating)
  true
end