Class: Zernio::GetGoogleBusinessVerifications200ResponseVoiceOfMerchantState
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetGoogleBusinessVerifications200ResponseVoiceOfMerchantState
- Defined in:
- lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb
Overview
Raw Voice of Merchant state from Google.
Instance Attribute Summary collapse
-
#has_business_authority ⇒ Object
True when the authenticated user has owner/manager authority over the listing.
-
#has_voice_of_merchant ⇒ Object
True when the listing is verified and published (eligible to surface reviews, edits, etc.).
-
#verify ⇒ Object
Returns the value of attribute verify.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetGoogleBusinessVerifications200ResponseVoiceOfMerchantState
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetGoogleBusinessVerifications200ResponseVoiceOfMerchantState
Initializes the object
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 63 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetGoogleBusinessVerifications200ResponseVoiceOfMerchantState` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetGoogleBusinessVerifications200ResponseVoiceOfMerchantState`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'has_voice_of_merchant') self.has_voice_of_merchant = attributes[:'has_voice_of_merchant'] end if attributes.key?(:'has_business_authority') self. = attributes[:'has_business_authority'] end if attributes.key?(:'verify') self.verify = attributes[:'verify'] end end |
Instance Attribute Details
#has_business_authority ⇒ Object
True when the authenticated user has owner/manager authority over the listing.
23 24 25 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 23 def @has_business_authority end |
#has_voice_of_merchant ⇒ Object
True when the listing is verified and published (eligible to surface reviews, edits, etc.).
20 21 22 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 20 def has_voice_of_merchant @has_voice_of_merchant end |
#verify ⇒ Object
Returns the value of attribute verify.
25 26 27 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 25 def verify @verify end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 28 def self.attribute_map { :'has_voice_of_merchant' => :'hasVoiceOfMerchant', :'has_business_authority' => :'hasBusinessAuthority', :'verify' => :'verify' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 130 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 56 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 47 def self.openapi_types { :'has_voice_of_merchant' => :'Boolean', :'has_business_authority' => :'Boolean', :'verify' => :'GetGoogleBusinessVerifications200ResponseVoiceOfMerchantStateVerify' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
107 108 109 110 111 112 113 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 107 def ==(o) return true if self.equal?(o) self.class == o.class && has_voice_of_merchant == o.has_voice_of_merchant && == o. && verify == o.verify end |
#eql?(o) ⇒ Boolean
117 118 119 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 117 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
123 124 125 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 123 def hash [has_voice_of_merchant, , verify].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
92 93 94 95 96 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 92 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 152 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
100 101 102 103 |
# File 'lib/zernio-sdk/models/get_google_business_verifications200_response_voice_of_merchant_state.rb', line 100 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |