Class: Zernio::GetInstagramFollowStatus200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetInstagramFollowStatus200Response
- Defined in:
- lib/zernio-sdk/models/get_instagram_follow_status200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#follower_count ⇒ Object
Returns the value of attribute follower_count.
-
#is_followed_by_account ⇒ Object
This account follows the user.
-
#is_follower ⇒ Object
The user follows this account.
-
#is_verified ⇒ Object
Returns the value of attribute is_verified.
-
#name ⇒ Object
Returns the value of attribute name.
-
#unavailable_reason ⇒ Object
Why the follow relationship could not be resolved.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetInstagramFollowStatus200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetInstagramFollowStatus200Response
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInstagramFollowStatus200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInstagramFollowStatus200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] else self.user_id = nil end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'is_follower') self.is_follower = attributes[:'is_follower'] else self.is_follower = nil end if attributes.key?(:'is_followed_by_account') self.is_followed_by_account = attributes[:'is_followed_by_account'] end if attributes.key?(:'follower_count') self.follower_count = attributes[:'follower_count'] end if attributes.key?(:'is_verified') self.is_verified = attributes[:'is_verified'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'unavailable_reason') self.unavailable_reason = attributes[:'unavailable_reason'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
20 21 22 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 20 def account_id @account_id end |
#follower_count ⇒ Object
Returns the value of attribute follower_count.
28 29 30 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 28 def follower_count @follower_count end |
#is_followed_by_account ⇒ Object
This account follows the user.
26 27 28 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 26 def is_followed_by_account @is_followed_by_account end |
#is_follower ⇒ Object
The user follows this account. Null = unknown, never "no".
23 24 25 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 23 def is_follower @is_follower end |
#is_verified ⇒ Object
Returns the value of attribute is_verified.
30 31 32 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 30 def is_verified @is_verified end |
#name ⇒ Object
Returns the value of attribute name.
34 35 36 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 34 def name @name end |
#unavailable_reason ⇒ Object
Why the follow relationship could not be resolved. Null when it was.
37 38 39 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 37 def unavailable_reason @unavailable_reason end |
#user_id ⇒ Object
Returns the value of attribute user_id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 18 def user_id @user_id end |
#username ⇒ Object
Returns the value of attribute username.
32 33 34 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 32 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 62 def self.attribute_map { :'user_id' => :'userId', :'account_id' => :'accountId', :'is_follower' => :'isFollower', :'is_followed_by_account' => :'isFollowedByAccount', :'follower_count' => :'followerCount', :'is_verified' => :'isVerified', :'username' => :'username', :'name' => :'name', :'unavailable_reason' => :'unavailableReason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 261 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 102 def self.openapi_nullable Set.new([ :'is_follower', :'is_followed_by_account', :'follower_count', :'is_verified', :'username', :'name', :'unavailable_reason' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 87 def self.openapi_types { :'user_id' => :'String', :'account_id' => :'String', :'is_follower' => :'Boolean', :'is_followed_by_account' => :'Boolean', :'follower_count' => :'Integer', :'is_verified' => :'Boolean', :'username' => :'String', :'name' => :'String', :'unavailable_reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && user_id == o.user_id && account_id == o.account_id && is_follower == o.is_follower && is_followed_by_account == o.is_followed_by_account && follower_count == o.follower_count && is_verified == o.is_verified && username == o.username && name == o.name && unavailable_reason == o.unavailable_reason end |
#eql?(o) ⇒ Boolean
248 249 250 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 248 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
254 255 256 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 254 def hash [user_id, account_id, is_follower, is_followed_by_account, follower_count, is_verified, username, name, unavailable_reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @user_id.nil? invalid_properties.push('invalid value for "user_id", user_id cannot be nil.') end if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 283 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 197 198 |
# File 'lib/zernio-sdk/models/get_instagram_follow_status200_response.rb', line 191 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @user_id.nil? return false if @account_id.nil? unavailable_reason_validator = EnumAttributeValidator.new('String', ["consent_required", "dm_access_disabled", "not_messageable", "error"]) return false unless unavailable_reason_validator.valid?(@unavailable_reason) true end |