Class: Zernio::GetLinkedInPostReactions200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetLinkedInPostReactions200Response
- Defined in:
- lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_type ⇒ Object
Returns the value of attribute account_type.
-
#last_updated ⇒ Object
Returns the value of attribute last_updated.
-
#pagination ⇒ Object
Returns the value of attribute pagination.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#post_urn ⇒ Object
Returns the value of attribute post_urn.
-
#reactions ⇒ Object
Returns the value of attribute reactions.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetLinkedInPostReactions200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetLinkedInPostReactions200Response
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetLinkedInPostReactions200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetLinkedInPostReactions200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'account_type') self.account_type = attributes[:'account_type'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'post_urn') self.post_urn = attributes[:'post_urn'] end if attributes.key?(:'reactions') if (value = attributes[:'reactions']).is_a?(Array) self.reactions = value end end if attributes.key?(:'pagination') self.pagination = attributes[:'pagination'] end if attributes.key?(:'last_updated') self.last_updated = attributes[:'last_updated'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 18 def account_id @account_id end |
#account_type ⇒ Object
Returns the value of attribute account_type.
22 23 24 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 22 def account_type @account_type end |
#last_updated ⇒ Object
Returns the value of attribute last_updated.
32 33 34 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 32 def last_updated @last_updated end |
#pagination ⇒ Object
Returns the value of attribute pagination.
30 31 32 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 30 def pagination @pagination end |
#platform ⇒ Object
Returns the value of attribute platform.
20 21 22 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 20 def platform @platform end |
#post_urn ⇒ Object
Returns the value of attribute post_urn.
26 27 28 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 26 def post_urn @post_urn end |
#reactions ⇒ Object
Returns the value of attribute reactions.
28 29 30 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 28 def reactions @reactions end |
#username ⇒ Object
Returns the value of attribute username.
24 25 26 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 24 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 35 def self.attribute_map { :'account_id' => :'accountId', :'platform' => :'platform', :'account_type' => :'accountType', :'username' => :'username', :'post_urn' => :'postUrn', :'reactions' => :'reactions', :'pagination' => :'pagination', :'last_updated' => :'lastUpdated' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 174 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 59 def self.openapi_types { :'account_id' => :'String', :'platform' => :'String', :'account_type' => :'String', :'username' => :'String', :'post_urn' => :'String', :'reactions' => :'Array<GetLinkedInPostReactions200ResponseReactionsInner>', :'pagination' => :'GetLinkedInPostReactions200ResponsePagination', :'last_updated' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 146 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && platform == o.platform && account_type == o.account_type && username == o.username && post_urn == o.post_urn && reactions == o.reactions && pagination == o.pagination && last_updated == o.last_updated end |
#eql?(o) ⇒ Boolean
161 162 163 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 161 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
167 168 169 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 167 def hash [account_id, platform, account_type, username, post_urn, reactions, pagination, last_updated].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 196 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 |
# File 'lib/zernio-sdk/models/get_linked_in_post_reactions200_response.rb', line 139 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |