Class: Zernio::GetPendingOAuthData200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetPendingOAuthData200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPendingOAuthData200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPendingOAuthData200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'temp_token')
    self.temp_token = attributes[:'temp_token']
  end

  if attributes.key?(:'refresh_token')
    self.refresh_token = attributes[:'refresh_token']
  end

  if attributes.key?(:'expires_in')
    self.expires_in = attributes[:'expires_in']
  end

  if attributes.key?(:'user_profile')
    self. = attributes[:'user_profile']
  end

  if attributes.key?(:'selection_type')
    self.selection_type = attributes[:'selection_type']
  end

  if attributes.key?(:'organizations')
    if (value = attributes[:'organizations']).is_a?(Array)
      self.organizations = value
    end
  end
end

Instance Attribute Details

#expires_inObject

Token expiry in seconds



31
32
33
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 31

def expires_in
  @expires_in
end

#organizationsObject

LinkedIn organizations (when selectionType is "organizations")



40
41
42
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 40

def organizations
  @organizations
end

#platformObject

The platform (e.g., "linkedin")



19
20
21
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 19

def platform
  @platform
end

#profile_idObject

The Zernio profile ID



22
23
24
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 22

def profile_id
  @profile_id
end

#refresh_tokenObject

Refresh token (if available)



28
29
30
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 28

def refresh_token
  @refresh_token
end

#selection_typeObject

Type of selection data



37
38
39
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 37

def selection_type
  @selection_type
end

#temp_tokenObject

Temporary access token for the platform



25
26
27
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 25

def temp_token
  @temp_token
end

#user_profileObject

User profile data (id, username, displayName, profilePicture)



34
35
36
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 34

def 
  @user_profile
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 65

def self.attribute_map
  {
    :'platform' => :'platform',
    :'profile_id' => :'profileId',
    :'temp_token' => :'tempToken',
    :'refresh_token' => :'refreshToken',
    :'expires_in' => :'expiresIn',
    :'user_profile' => :'userProfile',
    :'selection_type' => :'selectionType',
    :'organizations' => :'organizations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 216

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 89

def self.openapi_types
  {
    :'platform' => :'String',
    :'profile_id' => :'String',
    :'temp_token' => :'String',
    :'refresh_token' => :'String',
    :'expires_in' => :'Float',
    :'user_profile' => :'Object',
    :'selection_type' => :'String',
    :'organizations' => :'Array<GetPendingOAuthData200ResponseOrganizationsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      platform == o.platform &&
      profile_id == o.profile_id &&
      temp_token == o.temp_token &&
      refresh_token == o.refresh_token &&
      expires_in == o.expires_in &&
       == o. &&
      selection_type == o.selection_type &&
      organizations == o.organizations
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 209

def hash
  [platform, profile_id, temp_token, refresh_token, expires_in, , selection_type, organizations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 238

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
174
# File 'lib/zernio-sdk/models/get_pending_o_auth_data200_response.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  selection_type_validator = EnumAttributeValidator.new('String', ["organizations", "pages", "boards", "locations", "profiles"])
  return false unless selection_type_validator.valid?(@selection_type)
  true
end