Class: Zernio::GetPhoneNumberPortInOrderRequirements200ResponseRequirementsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetPhoneNumberPortInOrderRequirements200ResponseRequirementsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPhoneNumberPortInOrderRequirements200ResponseRequirementsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPhoneNumberPortInOrderRequirements200ResponseRequirementsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'requirement_id')
    self.requirement_id = attributes[:'requirement_id']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'example')
    self.example = attributes[:'example']
  end

  if attributes.key?(:'acceptable_values')
    if (value = attributes[:'acceptable_values']).is_a?(Array)
      self.acceptable_values = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'filled')
    self.filled = attributes[:'filled']
  end
end

Instance Attribute Details

#acceptable_valuesObject

Returns the value of attribute acceptable_values.



28
29
30
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 28

def acceptable_values
  @acceptable_values
end

#descriptionObject

Returns the value of attribute description.



24
25
26
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 24

def description
  @description
end

#exampleObject

Returns the value of attribute example.



26
27
28
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 26

def example
  @example
end

#filledObject

Returns the value of attribute filled.



33
34
35
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 33

def filled
  @filled
end

#kindObject

Returns the value of attribute kind.



22
23
24
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 22

def kind
  @kind
end

#labelObject

Returns the value of attribute label.



20
21
22
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 20

def label
  @label
end

#requirement_idObject

Returns the value of attribute requirement_id.



18
19
20
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 18

def requirement_id
  @requirement_id
end

#statusObject

requirement-info-pending | requirement-info-under-review | requirement-info-exception | approved



31
32
33
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 31

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 58

def self.attribute_map
  {
    :'requirement_id' => :'requirementId',
    :'label' => :'label',
    :'kind' => :'kind',
    :'description' => :'description',
    :'example' => :'example',
    :'acceptable_values' => :'acceptableValues',
    :'status' => :'status',
    :'filled' => :'filled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 209

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



96
97
98
99
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 96

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 82

def self.openapi_types
  {
    :'requirement_id' => :'String',
    :'label' => :'String',
    :'kind' => :'String',
    :'description' => :'String',
    :'example' => :'String',
    :'acceptable_values' => :'Array<String>',
    :'status' => :'String',
    :'filled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      requirement_id == o.requirement_id &&
      label == o.label &&
      kind == o.kind &&
      description == o.description &&
      example == o.example &&
      acceptable_values == o.acceptable_values &&
      status == o.status &&
      filled == o.filled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


196
197
198
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 196

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



202
203
204
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 202

def hash
  [requirement_id, label, kind, description, example, acceptable_values, status, filled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 231

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
# File 'lib/zernio-sdk/models/get_phone_number_port_in_order_requirements200_response_requirements_inner.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  kind_validator = EnumAttributeValidator.new('String', ["text", "date", "address", "file", "action"])
  return false unless kind_validator.valid?(@kind)
  true
end