Class: Zernio::GetPhoneNumberPortInRequirements200ResponseFieldsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetPhoneNumberPortInRequirements200ResponseFieldsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPhoneNumberPortInRequirements200ResponseFieldsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPhoneNumberPortInRequirements200ResponseFieldsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'requirement_id')
    self.requirement_id = attributes[:'requirement_id']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'example')
    self.example = attributes[:'example']
  end

  if attributes.key?(:'acceptable_values')
    if (value = attributes[:'acceptable_values']).is_a?(Array)
      self.acceptable_values = value
    end
  end
end

Instance Attribute Details

#acceptable_valuesObject

When present, the value must be one of these.



31
32
33
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 31

def acceptable_values
  @acceptable_values
end

#descriptionObject

Returns the value of attribute description.



26
27
28
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 26

def description
  @description
end

#exampleObject

Returns the value of attribute example.



28
29
30
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 28

def example
  @example
end

#kindObject

text/date take a string value; file takes a documentId from the documents endpoint; address is satisfied automatically from the end-user service address.



24
25
26
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 24

def kind
  @kind
end

#labelObject

Returns the value of attribute label.



21
22
23
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 21

def label
  @label
end

#requirement_idObject

Pass back as requirements.requirementTypeId.



19
20
21
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 19

def requirement_id
  @requirement_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 56

def self.attribute_map
  {
    :'requirement_id' => :'requirementId',
    :'label' => :'label',
    :'kind' => :'kind',
    :'description' => :'description',
    :'example' => :'example',
    :'acceptable_values' => :'acceptableValues'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 78

def self.openapi_types
  {
    :'requirement_id' => :'String',
    :'label' => :'String',
    :'kind' => :'String',
    :'description' => :'String',
    :'example' => :'String',
    :'acceptable_values' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 167

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      requirement_id == o.requirement_id &&
      label == o.label &&
      kind == o.kind &&
      description == o.description &&
      example == o.example &&
      acceptable_values == o.acceptable_values
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 186

def hash
  [requirement_id, label, kind, description, example, acceptable_values].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
# File 'lib/zernio-sdk/models/get_phone_number_port_in_requirements200_response_fields_inner.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  kind_validator = EnumAttributeValidator.new('String', ["text", "date", "address", "file", "action"])
  return false unless kind_validator.valid?(@kind)
  true
end