Class: Zernio::GetSequence200ResponseSequence

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_sequence200_response_sequence.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetSequence200ResponseSequence

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetSequence200ResponseSequence` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetSequence200ResponseSequence`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'steps')
    if (value = attributes[:'steps']).is_a?(Array)
      self.steps = value
    end
  end

  if attributes.key?(:'exit_on_reply')
    self.exit_on_reply = attributes[:'exit_on_reply']
  end

  if attributes.key?(:'exit_on_unsubscribe')
    self.exit_on_unsubscribe = attributes[:'exit_on_unsubscribe']
  end

  if attributes.key?(:'total_enrolled')
    self.total_enrolled = attributes[:'total_enrolled']
  end

  if attributes.key?(:'total_completed')
    self.total_completed = attributes[:'total_completed']
  end

  if attributes.key?(:'total_exited')
    self.total_exited = attributes[:'total_exited']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



26
27
28
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 26

def 
  @account_id
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 42

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 22

def description
  @description
end

#exit_on_replyObject

Returns the value of attribute exit_on_reply.



32
33
34
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 32

def exit_on_reply
  @exit_on_reply
end

#exit_on_unsubscribeObject

Returns the value of attribute exit_on_unsubscribe.



34
35
36
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 34

def exit_on_unsubscribe
  @exit_on_unsubscribe
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 20

def name
  @name
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 24

def platform
  @platform
end

#statusObject

Returns the value of attribute status.



28
29
30
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 28

def status
  @status
end

#stepsObject

Returns the value of attribute steps.



30
31
32
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 30

def steps
  @steps
end

#total_completedObject

Returns the value of attribute total_completed.



38
39
40
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 38

def total_completed
  @total_completed
end

#total_enrolledObject

Returns the value of attribute total_enrolled.



36
37
38
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 36

def total_enrolled
  @total_enrolled
end

#total_exitedObject

Returns the value of attribute total_exited.



40
41
42
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 40

def total_exited
  @total_exited
end

#updated_atObject

Returns the value of attribute updated_at.



44
45
46
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 44

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 69

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'platform' => :'platform',
    :'account_id' => :'accountId',
    :'status' => :'status',
    :'steps' => :'steps',
    :'exit_on_reply' => :'exitOnReply',
    :'exit_on_unsubscribe' => :'exitOnUnsubscribe',
    :'total_enrolled' => :'totalEnrolled',
    :'total_completed' => :'totalCompleted',
    :'total_exited' => :'totalExited',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 262

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



119
120
121
122
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 119

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 99

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'platform' => :'String',
    :'account_id' => :'String',
    :'status' => :'String',
    :'steps' => :'Array<GetSequence200ResponseSequenceStepsInner>',
    :'exit_on_reply' => :'Boolean',
    :'exit_on_unsubscribe' => :'Boolean',
    :'total_enrolled' => :'Integer',
    :'total_completed' => :'Integer',
    :'total_exited' => :'Integer',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      platform == o.platform &&
       == o. &&
      status == o.status &&
      steps == o.steps &&
      exit_on_reply == o.exit_on_reply &&
      exit_on_unsubscribe == o.exit_on_unsubscribe &&
      total_enrolled == o.total_enrolled &&
      total_completed == o.total_completed &&
      total_exited == o.total_exited &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 249

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



255
256
257
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 255

def hash
  [id, name, description, platform, , status, steps, exit_on_reply, exit_on_unsubscribe, total_enrolled, total_completed, total_exited, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



201
202
203
204
205
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 201

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 284

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
# File 'lib/zernio-sdk/models/get_sequence200_response_sequence.rb', line 209

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["draft", "active", "paused"])
  return false unless status_validator.valid?(@status)
  true
end