Class: Zernio::GetTelegramCommands200ResponseDataInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetTelegramCommands200ResponseDataInner
- Defined in:
- lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb
Instance Attribute Summary collapse
-
#command ⇒ Object
Returns the value of attribute command.
-
#description ⇒ Object
Returns the value of attribute description.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetTelegramCommands200ResponseDataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetTelegramCommands200ResponseDataInner
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 56 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetTelegramCommands200ResponseDataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetTelegramCommands200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'command') self.command = attributes[:'command'] end if attributes.key?(:'description') self.description = attributes[:'description'] end end |
Instance Attribute Details
#command ⇒ Object
Returns the value of attribute command.
18 19 20 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 18 def command @command end |
#description ⇒ Object
Returns the value of attribute description.
20 21 22 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 20 def description @description end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
31 32 33 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 31 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
36 37 38 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 36 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 23 def self.attribute_map { :'command' => :'command', :'description' => :'description' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 185 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
49 50 51 52 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 49 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 41 def self.openapi_types { :'command' => :'String', :'description' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
163 164 165 166 167 168 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 163 def ==(o) return true if self.equal?(o) self.class == o.class && command == o.command && description == o.description end |
#eql?(o) ⇒ Boolean
172 173 174 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 172 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 178 def hash [command, description].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 81 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@command.nil? && @command.to_s.length > 32 invalid_properties.push('invalid value for "command", the character length must be smaller than or equal to 32.') end if !@command.nil? && @command.to_s.length < 1 invalid_properties.push('invalid value for "command", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^[a-z0-9_]+$/) if !@command.nil? && @command !~ pattern invalid_properties.push("invalid value for \"command\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 256 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 256.') end if !@description.nil? && @description.to_s.length < 1 invalid_properties.push('invalid value for "description", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 207 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
110 111 112 113 114 115 116 117 118 |
# File 'lib/zernio-sdk/models/get_telegram_commands200_response_data_inner.rb', line 110 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@command.nil? && @command.to_s.length > 32 return false if !@command.nil? && @command.to_s.length < 1 return false if !@command.nil? && @command !~ Regexp.new(/^[a-z0-9_]+$/) return false if !@description.nil? && @description.to_s.length > 256 return false if !@description.nil? && @description.to_s.length < 1 true end |