Class: Zernio::GetTikTokCreatorInfo200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetTikTokCreatorInfo200Response
- Defined in:
- lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb
Instance Attribute Summary collapse
-
#commercial_content_types ⇒ Object
Available commercial content disclosure options.
-
#creator ⇒ Object
Returns the value of attribute creator.
-
#posting_limits ⇒ Object
Returns the value of attribute posting_limits.
-
#privacy_levels ⇒ Object
Available privacy level options for this creator.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetTikTokCreatorInfo200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetTikTokCreatorInfo200Response
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetTikTokCreatorInfo200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetTikTokCreatorInfo200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'creator') self.creator = attributes[:'creator'] end if attributes.key?(:'privacy_levels') if (value = attributes[:'privacy_levels']).is_a?(Array) self.privacy_levels = value end end if attributes.key?(:'posting_limits') self.posting_limits = attributes[:'posting_limits'] end if attributes.key?(:'commercial_content_types') if (value = attributes[:'commercial_content_types']).is_a?(Array) self.commercial_content_types = value end end end |
Instance Attribute Details
#commercial_content_types ⇒ Object
Available commercial content disclosure options
26 27 28 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 26 def commercial_content_types @commercial_content_types end |
#creator ⇒ Object
Returns the value of attribute creator.
18 19 20 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 18 def creator @creator end |
#posting_limits ⇒ Object
Returns the value of attribute posting_limits.
23 24 25 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 23 def posting_limits @posting_limits end |
#privacy_levels ⇒ Object
Available privacy level options for this creator
21 22 23 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 21 def privacy_levels @privacy_levels end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 29 def self.attribute_map { :'creator' => :'creator', :'privacy_levels' => :'privacyLevels', :'posting_limits' => :'postingLimits', :'commercial_content_types' => :'commercialContentTypes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 142 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 59 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 49 def self.openapi_types { :'creator' => :'GetTikTokCreatorInfo200ResponseCreator', :'privacy_levels' => :'Array<GetTikTokCreatorInfo200ResponsePrivacyLevelsInner>', :'posting_limits' => :'GetTikTokCreatorInfo200ResponsePostingLimits', :'commercial_content_types' => :'Array<GetTikTokCreatorInfo200ResponseCommercialContentTypesInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 118 def ==(o) return true if self.equal?(o) self.class == o.class && creator == o.creator && privacy_levels == o.privacy_levels && posting_limits == o.posting_limits && commercial_content_types == o.commercial_content_types end |
#eql?(o) ⇒ Boolean
129 130 131 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 129 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 135 def hash [creator, privacy_levels, posting_limits, commercial_content_types].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
111 112 113 114 |
# File 'lib/zernio-sdk/models/get_tik_tok_creator_info200_response.rb', line 111 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |