Class: Zernio::GetTikTokSmartPlusMaterialReport200ResponseRowsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetTikTokSmartPlusMaterialReport200ResponseRowsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetTikTokSmartPlusMaterialReport200ResponseRowsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetTikTokSmartPlusMaterialReport200ResponseRowsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'material_id')
    self.material_id = attributes[:'material_id']
  end

  if attributes.key?(:'material_type')
    self.material_type = attributes[:'material_type']
  end

  if attributes.key?(:'tiktok_item_id')
    self.tiktok_item_id = attributes[:'tiktok_item_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'smart_plus_ad_id')
    self.smart_plus_ad_id = attributes[:'smart_plus_ad_id']
  end

  if attributes.key?(:'ad_group_id')
    self.ad_group_id = attributes[:'ad_group_id']
  end

  if attributes.key?(:'metrics')
    self.metrics = attributes[:'metrics']
  end
end

Instance Attribute Details

#ad_group_id ⇒ Object

Set when level=adGroup



34
35
36
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 34

def ad_group_id
  @ad_group_id
end

#material_id ⇒ Object

TikTok main material id



19
20
21
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 19

def material_id
  @material_id
end

#material_type ⇒ Object

e.g. VIDEO_SPARK_ADS, VIDEO, IMAGE



22
23
24
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 22

def material_type
  @material_type
end

#metrics ⇒ Object

Returns the value of attribute metrics.



36
37
38
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 36

def metrics
  @metrics
end

#name ⇒ Object

Material name or post caption



28
29
30
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 28

def name
  @name
end

#smart_plus_ad_id ⇒ Object

Set when level=ad



31
32
33
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 31

def smart_plus_ad_id
  @smart_plus_ad_id
end

#tiktok_item_id ⇒ Object

The TikTok post id when the material is a Spark post



25
26
27
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 25

def tiktok_item_id
  @tiktok_item_id
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



52
53
54
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 39

def self.attribute_map
  {
    :'material_id' => :'materialId',
    :'material_type' => :'materialType',
    :'tiktok_item_id' => :'tiktokItemId',
    :'name' => :'name',
    :'smart_plus_ad_id' => :'smartPlusAdId',
    :'ad_group_id' => :'adGroupId',
    :'metrics' => :'metrics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 174

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



75
76
77
78
79
80
81
82
83
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 75

def self.openapi_nullable
  Set.new([
    :'material_type',
    :'tiktok_item_id',
    :'name',
    :'smart_plus_ad_id',
    :'ad_group_id',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 62

def self.openapi_types
  {
    :'material_id' => :'String',
    :'material_type' => :'String',
    :'tiktok_item_id' => :'String',
    :'name' => :'String',
    :'smart_plus_ad_id' => :'String',
    :'ad_group_id' => :'String',
    :'metrics' => :'GetTikTokSmartPlusMaterialReport200ResponseRowsInnerMetrics'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



147
148
149
150
151
152
153
154
155
156
157
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      material_id == o.material_id &&
      material_type == o.material_type &&
      tiktok_item_id == o.tiktok_item_id &&
      name == o.name &&
      smart_plus_ad_id == o.smart_plus_ad_id &&
      ad_group_id == o.ad_group_id &&
      metrics == o.metrics
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 161

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



167
168
169
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 167

def hash
  [material_id, material_type, tiktok_item_id, name, smart_plus_ad_id, ad_group_id, metrics].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



140
141
142
143
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end