Class: Zernio::GetTikTokSmartPlusMaterialReport200ResponseRowsInnerMetrics
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetTikTokSmartPlusMaterialReport200ResponseRowsInnerMetrics
- Defined in:
- lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb
Instance Attribute Summary collapse
-
#add_payment_info ⇒ Object
Returns the value of attribute add_payment_info.
-
#add_to_cart ⇒ Object
Returns the value of attribute add_to_cart.
-
#clicks ⇒ Object
Returns the value of attribute clicks.
-
#cpc ⇒ Object
Returns the value of attribute cpc.
-
#impressions ⇒ Object
Returns the value of attribute impressions.
-
#initiate_checkout ⇒ Object
Returns the value of attribute initiate_checkout.
-
#purchase_value ⇒ Object
Returns the value of attribute purchase_value.
-
#purchases ⇒ Object
Returns the value of attribute purchases.
-
#roas ⇒ Object
Returns the value of attribute roas.
-
#spend ⇒ Object
Returns the value of attribute spend.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetTikTokSmartPlusMaterialReport200ResponseRowsInnerMetrics
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetTikTokSmartPlusMaterialReport200ResponseRowsInnerMetrics
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetTikTokSmartPlusMaterialReport200ResponseRowsInnerMetrics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetTikTokSmartPlusMaterialReport200ResponseRowsInnerMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'spend') self.spend = attributes[:'spend'] end if attributes.key?(:'impressions') self.impressions = attributes[:'impressions'] end if attributes.key?(:'clicks') self.clicks = attributes[:'clicks'] end if attributes.key?(:'cpc') self.cpc = attributes[:'cpc'] end if attributes.key?(:'add_to_cart') self.add_to_cart = attributes[:'add_to_cart'] end if attributes.key?(:'initiate_checkout') self.initiate_checkout = attributes[:'initiate_checkout'] end if attributes.key?(:'add_payment_info') self.add_payment_info = attributes[:'add_payment_info'] end if attributes.key?(:'purchases') self.purchases = attributes[:'purchases'] end if attributes.key?(:'purchase_value') self.purchase_value = attributes[:'purchase_value'] end if attributes.key?(:'roas') self.roas = attributes[:'roas'] end end |
Instance Attribute Details
#add_payment_info ⇒ Object
Returns the value of attribute add_payment_info.
30 31 32 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 30 def add_payment_info @add_payment_info end |
#add_to_cart ⇒ Object
Returns the value of attribute add_to_cart.
26 27 28 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 26 def add_to_cart @add_to_cart end |
#clicks ⇒ Object
Returns the value of attribute clicks.
22 23 24 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 22 def clicks @clicks end |
#cpc ⇒ Object
Returns the value of attribute cpc.
24 25 26 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 24 def cpc @cpc end |
#impressions ⇒ Object
Returns the value of attribute impressions.
20 21 22 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 20 def impressions @impressions end |
#initiate_checkout ⇒ Object
Returns the value of attribute initiate_checkout.
28 29 30 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 28 def initiate_checkout @initiate_checkout end |
#purchase_value ⇒ Object
Returns the value of attribute purchase_value.
34 35 36 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 34 def purchase_value @purchase_value end |
#purchases ⇒ Object
Returns the value of attribute purchases.
32 33 34 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 32 def purchases @purchases end |
#roas ⇒ Object
Returns the value of attribute roas.
36 37 38 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 36 def roas @roas end |
#spend ⇒ Object
Returns the value of attribute spend.
18 19 20 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 18 def spend @spend end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 39 def self.attribute_map { :'spend' => :'spend', :'impressions' => :'impressions', :'clicks' => :'clicks', :'cpc' => :'cpc', :'add_to_cart' => :'addToCart', :'initiate_checkout' => :'initiateCheckout', :'add_payment_info' => :'addPaymentInfo', :'purchases' => :'purchases', :'purchase_value' => :'purchaseValue', :'roas' => :'roas' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 200 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 81 def self.openapi_nullable Set.new([ :'spend', :'impressions', :'clicks', :'cpc', :'add_to_cart', :'initiate_checkout', :'add_payment_info', :'purchases', :'purchase_value', :'roas' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 65 def self.openapi_types { :'spend' => :'Float', :'impressions' => :'Float', :'clicks' => :'Float', :'cpc' => :'Float', :'add_to_cart' => :'Float', :'initiate_checkout' => :'Float', :'add_payment_info' => :'Float', :'purchases' => :'Float', :'purchase_value' => :'Float', :'roas' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && spend == o.spend && impressions == o.impressions && clicks == o.clicks && cpc == o.cpc && add_to_cart == o.add_to_cart && initiate_checkout == o.initiate_checkout && add_payment_info == o.add_payment_info && purchases == o.purchases && purchase_value == o.purchase_value && roas == o.roas end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 193 def hash [spend, impressions, clicks, cpc, add_to_cart, initiate_checkout, add_payment_info, purchases, purchase_value, roas].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response_rows_inner_metrics.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |