Class: Zernio::GetWhatsAppBusinessProfile200ResponseBusinessProfile
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetWhatsAppBusinessProfile200ResponseBusinessProfile
- Defined in:
- lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb
Instance Attribute Summary collapse
-
#about ⇒ Object
Short description (max 139 chars).
-
#address ⇒ Object
Returns the value of attribute address.
-
#description ⇒ Object
Full description (max 512 chars).
-
#email ⇒ Object
Returns the value of attribute email.
-
#profile_picture_url ⇒ Object
Returns the value of attribute profile_picture_url.
-
#vertical ⇒ Object
Business category.
-
#websites ⇒ Object
Returns the value of attribute websites.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetWhatsAppBusinessProfile200ResponseBusinessProfile
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetWhatsAppBusinessProfile200ResponseBusinessProfile
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppBusinessProfile200ResponseBusinessProfile` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppBusinessProfile200ResponseBusinessProfile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'about') self.about = attributes[:'about'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'profile_picture_url') self.profile_picture_url = attributes[:'profile_picture_url'] end if attributes.key?(:'websites') if (value = attributes[:'websites']).is_a?(Array) self.websites = value end end if attributes.key?(:'vertical') self.vertical = attributes[:'vertical'] end end |
Instance Attribute Details
#about ⇒ Object
Short description (max 139 chars)
19 20 21 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 19 def about @about end |
#address ⇒ Object
Returns the value of attribute address.
21 22 23 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 21 def address @address end |
#description ⇒ Object
Full description (max 512 chars)
24 25 26 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 24 def description @description end |
#email ⇒ Object
Returns the value of attribute email.
26 27 28 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 26 def email @email end |
#profile_picture_url ⇒ Object
Returns the value of attribute profile_picture_url.
28 29 30 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 28 def profile_picture_url @profile_picture_url end |
#vertical ⇒ Object
Business category
33 34 35 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 33 def vertical @vertical end |
#websites ⇒ Object
Returns the value of attribute websites.
30 31 32 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 30 def websites @websites end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 36 def self.attribute_map { :'about' => :'about', :'address' => :'address', :'description' => :'description', :'email' => :'email', :'profile_picture_url' => :'profilePictureUrl', :'websites' => :'websites', :'vertical' => :'vertical' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 187 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 59 def self.openapi_types { :'about' => :'String', :'address' => :'String', :'description' => :'String', :'email' => :'String', :'profile_picture_url' => :'String', :'websites' => :'Array<String>', :'vertical' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && about == o.about && address == o.address && description == o.description && email == o.email && profile_picture_url == o.profile_picture_url && websites == o.websites && vertical == o.vertical end |
#eql?(o) ⇒ Boolean
174 175 176 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 174 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 180 def hash [about, address, description, email, profile_picture_url, websites, vertical].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@websites.nil? && @websites.length > 2 invalid_properties.push('invalid value for "websites", number of items must be less than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
138 139 140 141 142 |
# File 'lib/zernio-sdk/models/get_whats_app_business_profile200_response_business_profile.rb', line 138 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@websites.nil? && @websites.length > 2 true end |