Class: Zernio::GetWhatsAppCallEstimate200ResponseBreakdown

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppCallEstimate200ResponseBreakdown

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppCallEstimate200ResponseBreakdown` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppCallEstimate200ResponseBreakdown`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'meta_minutes')
    self.meta_minutes = attributes[:'meta_minutes']
  end

  if attributes.key?(:'meta_cost_usd')
    self.meta_cost_usd = attributes[:'meta_cost_usd']
  end

  if attributes.key?(:'telnyx_cost_usd')
    self.telnyx_cost_usd = attributes[:'telnyx_cost_usd']
  end

  if attributes.key?(:'recording_cost_usd')
    self.recording_cost_usd = attributes[:'recording_cost_usd']
  end

  if attributes.key?(:'billable_cost_usd')
    self.billable_cost_usd = attributes[:'billable_cost_usd']
  end

  if attributes.key?(:'total_cost_usd')
    self.total_cost_usd = attributes[:'total_cost_usd']
  end
end

Instance Attribute Details

#billable_cost_usdObject

Estimated amount Zernio bills you = Telnyx leg + recording (excludes Meta).



28
29
30
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 28

def billable_cost_usd
  @billable_cost_usd
end

#meta_cost_usdObject

Estimated Meta per-minute charge, billed by Meta directly to your WABA. Display only; not billed by Zernio.



21
22
23
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 21

def meta_cost_usd
  @meta_cost_usd
end

#meta_minutesObject

Returns the value of attribute meta_minutes.



18
19
20
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 18

def meta_minutes
  @meta_minutes
end

#recording_cost_usdObject

Returns the value of attribute recording_cost_usd.



25
26
27
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 25

def recording_cost_usd
  @recording_cost_usd
end

#telnyx_cost_usdObject

Returns the value of attribute telnyx_cost_usd.



23
24
25
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 23

def telnyx_cost_usd
  @telnyx_cost_usd
end

#total_cost_usdObject

Estimated full cost incl. the Meta portion you pay directly. Display only.



31
32
33
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 31

def total_cost_usd
  @total_cost_usd
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 34

def self.attribute_map
  {
    :'meta_minutes' => :'metaMinutes',
    :'meta_cost_usd' => :'metaCostUSD',
    :'telnyx_cost_usd' => :'telnyxCostUSD',
    :'recording_cost_usd' => :'recordingCostUSD',
    :'billable_cost_usd' => :'billableCostUSD',
    :'total_cost_usd' => :'totalCostUSD'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 157

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 68

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 56

def self.openapi_types
  {
    :'meta_minutes' => :'Integer',
    :'meta_cost_usd' => :'Float',
    :'telnyx_cost_usd' => :'Float',
    :'recording_cost_usd' => :'Float',
    :'billable_cost_usd' => :'Float',
    :'total_cost_usd' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
138
139
140
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      meta_minutes == o.meta_minutes &&
      meta_cost_usd == o.meta_cost_usd &&
      telnyx_cost_usd == o.telnyx_cost_usd &&
      recording_cost_usd == o.recording_cost_usd &&
      billable_cost_usd == o.billable_cost_usd &&
      total_cost_usd == o.total_cost_usd
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


144
145
146
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 144

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



150
151
152
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 150

def hash
  [meta_minutes, meta_cost_usd, telnyx_cost_usd, recording_cost_usd, billable_cost_usd, total_cost_usd].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
# File 'lib/zernio-sdk/models/get_whats_app_call_estimate200_response_breakdown.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end