Class: Zernio::GetWhatsAppDisplayName200ResponseDisplayName
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetWhatsAppDisplayName200ResponseDisplayName
- Defined in:
- lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#name ⇒ Object
Current verified display name.
-
#phone_number ⇒ Object
Display phone number.
-
#status ⇒ Object
Meta review status for the display name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetWhatsAppDisplayName200ResponseDisplayName
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetWhatsAppDisplayName200ResponseDisplayName
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppDisplayName200ResponseDisplayName` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppDisplayName200ResponseDisplayName`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end end |
Instance Attribute Details
#name ⇒ Object
Current verified display name
19 20 21 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 19 def name @name end |
#phone_number ⇒ Object
Display phone number
25 26 27 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 25 def phone_number @phone_number end |
#status ⇒ Object
Meta review status for the display name
22 23 24 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 22 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 50 def self.attribute_map { :'name' => :'name', :'status' => :'status', :'phone_number' => :'phoneNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 69 def self.openapi_types { :'name' => :'String', :'status' => :'String', :'phone_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 141 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && status == o.status && phone_number == o.phone_number end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 157 def hash [name, status, phone_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 127 |
# File 'lib/zernio-sdk/models/get_whats_app_display_name200_response_display_name.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["APPROVED", "PENDING_REVIEW", "DECLINED", "NONE"]) return false unless status_validator.valid?(@status) true end |