Class: Zernio::GetWhatsAppGroupChat200ResponseGroup

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppGroupChat200ResponseGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppGroupChat200ResponseGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppGroupChat200ResponseGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'join_approval_mode')
    self.join_approval_mode = attributes[:'join_approval_mode']
  end

  if attributes.key?(:'participants')
    if (value = attributes[:'participants']).is_a?(Array)
      self.participants = value
    end
  end

  if attributes.key?(:'participant_count')
    self.participant_count = attributes[:'participant_count']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'is_suspended')
    self.is_suspended = attributes[:'is_suspended']
  end
end

Instance Attribute Details

#created_atObject

UNIX timestamp



31
32
33
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 31

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 22

def description
  @description
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 18

def id
  @id
end

#is_suspendedObject

Returns the value of attribute is_suspended.



33
34
35
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 33

def is_suspended
  @is_suspended
end

#join_approval_modeObject

Returns the value of attribute join_approval_mode.



24
25
26
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 24

def join_approval_mode
  @join_approval_mode
end

#participant_countObject

Returns the value of attribute participant_count.



28
29
30
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 28

def participant_count
  @participant_count
end

#participantsObject

Returns the value of attribute participants.



26
27
28
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 26

def participants
  @participants
end

#subjectObject

Returns the value of attribute subject.



20
21
22
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 20

def subject
  @subject
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
47
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'subject' => :'subject',
    :'description' => :'description',
    :'join_approval_mode' => :'joinApprovalMode',
    :'participants' => :'participants',
    :'participant_count' => :'participantCount',
    :'created_at' => :'createdAt',
    :'is_suspended' => :'isSuspended'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 60

def self.openapi_types
  {
    :'id' => :'String',
    :'subject' => :'String',
    :'description' => :'String',
    :'join_approval_mode' => :'String',
    :'participants' => :'Array<GetWhatsAppGroupChat200ResponseGroupParticipantsInner>',
    :'participant_count' => :'Integer',
    :'created_at' => :'Integer',
    :'is_suspended' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      subject == o.subject &&
      description == o.description &&
      join_approval_mode == o.join_approval_mode &&
      participants == o.participants &&
      participant_count == o.participant_count &&
      created_at == o.created_at &&
      is_suspended == o.is_suspended
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 168

def hash
  [id, subject, description, join_approval_mode, participants, participant_count, created_at, is_suspended].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
# File 'lib/zernio-sdk/models/get_whats_app_group_chat200_response_group.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end