Class: Zernio::GetWhatsAppTemplate200ResponseTemplate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_whats_app_template200_response_template.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppTemplate200ResponseTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppTemplate200ResponseTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppTemplate200ResponseTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'components')
    if (value = attributes[:'components']).is_a?(Array)
      self.components = value
    end
  end

  if attributes.key?(:'message_send_ttl_seconds')
    self.message_send_ttl_seconds = attributes[:'message_send_ttl_seconds']
  end

  if attributes.key?(:'rejected_reason')
    self.rejected_reason = attributes[:'rejected_reason']
  end

  if attributes.key?(:'quality_score')
    self.quality_score = attributes[:'quality_score']
  end
end

Instance Attribute Details

#categoryObject

Returns the value of attribute category.



25
26
27
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 25

def category
  @category
end

#componentsObject

Returns the value of attribute components.



30
31
32
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 30

def components
  @components
end

#idObject

Meta template id. Unique per language variant; usable on /v1/whatsapp/templates/id/templateId.



19
20
21
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 19

def id
  @id
end

#languageObject

The variant actually returned.



28
29
30
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 28

def language
  @language
end

#message_send_ttl_secondsObject

Only when a custom TTL is set; absent while the category default applies.



33
34
35
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 33

def message_send_ttl_seconds
  @message_send_ttl_seconds
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 21

def name
  @name
end

#quality_scoreObject

Post-approval quality (GREEN/YELLOW/RED), when Meta reports one.



39
40
41
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 39

def quality_score
  @quality_score
end

#rejected_reasonObject

Only when status is REJECTED.



36
37
38
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 36

def rejected_reason
  @rejected_reason
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 23

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'status' => :'status',
    :'category' => :'category',
    :'language' => :'language',
    :'components' => :'components',
    :'message_send_ttl_seconds' => :'message_send_ttl_seconds',
    :'rejected_reason' => :'rejected_reason',
    :'quality_score' => :'quality_score'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 67

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'category' => :'String',
    :'language' => :'String',
    :'components' => :'Array<Object>',
    :'message_send_ttl_seconds' => :'Integer',
    :'rejected_reason' => :'String',
    :'quality_score' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 159

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      status == o.status &&
      category == o.category &&
      language == o.language &&
      components == o.components &&
      message_send_ttl_seconds == o.message_send_ttl_seconds &&
      rejected_reason == o.rejected_reason &&
      quality_score == o.quality_score
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 181

def hash
  [id, name, status, category, language, components, message_send_ttl_seconds, rejected_reason, quality_score].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
# File 'lib/zernio-sdk/models/get_whats_app_template200_response_template.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end