Class: Zernio::GetWhatsAppTemplates200ResponseTemplatesInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppTemplates200ResponseTemplatesInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppTemplates200ResponseTemplatesInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppTemplates200ResponseTemplatesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'message_send_ttl_seconds')
    self.message_send_ttl_seconds = attributes[:'message_send_ttl_seconds']
  end

  if attributes.key?(:'components')
    if (value = attributes[:'components']).is_a?(Array)
      self.components = value
    end
  end
end

Instance Attribute Details

#categoryObject

Returns the value of attribute category.



25
26
27
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 25

def category
  @category
end

#componentsObject

Returns the value of attribute components.



32
33
34
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 32

def components
  @components
end

#idObject

WhatsApp template ID



19
20
21
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 19

def id
  @id
end

#languageObject

Returns the value of attribute language.



27
28
29
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 27

def language
  @language
end

#message_send_ttl_secondsObject

Only when a custom TTL is set; absent while the category default applies.



30
31
32
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 30

def message_send_ttl_seconds
  @message_send_ttl_seconds
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 21

def name
  @name
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 23

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 57

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'status' => :'status',
    :'category' => :'category',
    :'language' => :'language',
    :'message_send_ttl_seconds' => :'message_send_ttl_seconds',
    :'components' => :'components'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 80

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'category' => :'String',
    :'language' => :'String',
    :'message_send_ttl_seconds' => :'Integer',
    :'components' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
194
195
196
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      status == o.status &&
      category == o.category &&
      language == o.language &&
      message_send_ttl_seconds == o.message_send_ttl_seconds &&
      components == o.components
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 206

def hash
  [id, name, status, category, language, message_send_ttl_seconds, components].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
160
161
162
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["APPROVED", "PENDING", "REJECTED"])
  return false unless status_validator.valid?(@status)
  category_validator = EnumAttributeValidator.new('String', ["AUTHENTICATION", "MARKETING", "UTILITY"])
  return false unless category_validator.valid?(@category)
  true
end