Class: Zernio::GetWhatsappBusinessUsername200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetWhatsappBusinessUsername200Response
- Defined in:
- lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#status ⇒ Object
Approval state of the username.
-
#success ⇒ Object
Returns the value of attribute success.
-
#username ⇒ Object
The current username, or null if none is set.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetWhatsappBusinessUsername200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetWhatsappBusinessUsername200Response
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsappBusinessUsername200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsappBusinessUsername200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#status ⇒ Object
Approval state of the username
24 25 26 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 24 def status @status end |
#success ⇒ Object
Returns the value of attribute success.
18 19 20 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 18 def success @success end |
#username ⇒ Object
The current username, or null if none is set
21 22 23 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 21 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 49 def self.attribute_map { :'success' => :'success', :'username' => :'username', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 81 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 77 def self.openapi_nullable Set.new([ :'username', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 68 def self.openapi_types { :'success' => :'Boolean', :'username' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
141 142 143 144 145 146 147 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 141 def ==(o) return true if self.equal?(o) self.class == o.class && success == o.success && username == o.username && status == o.status end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 157 def hash [success, username, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 127 |
# File 'lib/zernio-sdk/models/get_whatsapp_business_username200_response.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["approved", "reserved", "none"]) return false unless status_validator.valid?(@status) true end |