Class: Zernio::GetWorkflowVersion200ResponseVersion

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_workflow_version200_response_version.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWorkflowVersion200ResponseVersion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWorkflowVersion200ResponseVersion` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWorkflowVersion200ResponseVersion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'entry_node_id')
    self.entry_node_id = attributes[:'entry_node_id']
  end

  if attributes.key?(:'nodes')
    if (value = attributes[:'nodes']).is_a?(Array)
      self.nodes = value
    end
  end

  if attributes.key?(:'edges')
    if (value = attributes[:'edges']).is_a?(Array)
      self.edges = value
    end
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'created_by')
    self.created_by = attributes[:'created_by']
  end

  if attributes.key?(:'created_by_email')
    self.created_by_email = attributes[:'created_by_email']
  end

  if attributes.key?(:'restored_from_version')
    self.restored_from_version = attributes[:'restored_from_version']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



32
33
34
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 32

def 
  @account_id
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 42

def created_at
  @created_at
end

#created_byObject

Returns the value of attribute created_by.



36
37
38
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 36

def created_by
  @created_by
end

#created_by_emailObject

Returns the value of attribute created_by_email.



38
39
40
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 38

def created_by_email
  @created_by_email
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 22

def description
  @description
end

#edgesObject

Returns the value of attribute edges.



28
29
30
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 28

def edges
  @edges
end

#entry_node_idObject

Returns the value of attribute entry_node_id.



24
25
26
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 24

def entry_node_id
  @entry_node_id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 20

def name
  @name
end

#nodesObject

Returns the value of attribute nodes.



26
27
28
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 26

def nodes
  @nodes
end

#platformObject

Returns the value of attribute platform.



30
31
32
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 30

def platform
  @platform
end

#profile_idObject

Returns the value of attribute profile_id.



34
35
36
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 34

def profile_id
  @profile_id
end

#restored_from_versionObject

Returns the value of attribute restored_from_version.



40
41
42
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 40

def restored_from_version
  @restored_from_version
end

#versionObject

Returns the value of attribute version.



18
19
20
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 18

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 45

def self.attribute_map
  {
    :'version' => :'version',
    :'name' => :'name',
    :'description' => :'description',
    :'entry_node_id' => :'entryNodeId',
    :'nodes' => :'nodes',
    :'edges' => :'edges',
    :'platform' => :'platform',
    :'account_id' => :'accountId',
    :'profile_id' => :'profileId',
    :'created_by' => :'createdBy',
    :'created_by_email' => :'createdByEmail',
    :'restored_from_version' => :'restoredFromVersion',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 226

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
101
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 93

def self.openapi_nullable
  Set.new([
    :'description',
    :'entry_node_id',
    :'created_by',
    :'created_by_email',
    :'restored_from_version',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 74

def self.openapi_types
  {
    :'version' => :'Integer',
    :'name' => :'String',
    :'description' => :'String',
    :'entry_node_id' => :'String',
    :'nodes' => :'Array<WorkflowNode>',
    :'edges' => :'Array<WorkflowEdge>',
    :'platform' => :'String',
    :'account_id' => :'String',
    :'profile_id' => :'String',
    :'created_by' => :'String',
    :'created_by_email' => :'String',
    :'restored_from_version' => :'Integer',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      version == o.version &&
      name == o.name &&
      description == o.description &&
      entry_node_id == o.entry_node_id &&
      nodes == o.nodes &&
      edges == o.edges &&
      platform == o.platform &&
       == o. &&
      profile_id == o.profile_id &&
      created_by == o.created_by &&
      created_by_email == o.created_by_email &&
      restored_from_version == o.restored_from_version &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 213

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



219
220
221
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 219

def hash
  [version, name, description, entry_node_id, nodes, edges, platform, , profile_id, created_by, created_by_email, restored_from_version, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
# File 'lib/zernio-sdk/models/get_workflow_version200_response_version.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end