Class: Zernio::GoogleAssetUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/google_asset_update.rb

Overview

Supply fields for exactly one asset type per update. finalUrls may accompany sitelinkAsset. Shared asset edits affect every attachment using the asset.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GoogleAssetUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GoogleAssetUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GoogleAssetUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'asset_resource_name')
    self.asset_resource_name = attributes[:'asset_resource_name']
  else
    self.asset_resource_name = nil
  end

  if attributes.key?(:'sitelink_asset')
    self.sitelink_asset = attributes[:'sitelink_asset']
  end

  if attributes.key?(:'final_urls')
    if (value = attributes[:'final_urls']).is_a?(Array)
      self.final_urls = value
    end
  end

  if attributes.key?(:'callout_asset')
    self.callout_asset = attributes[:'callout_asset']
  end

  if attributes.key?(:'structured_snippet_asset')
    self.structured_snippet_asset = attributes[:'structured_snippet_asset']
  end
end

Instance Attribute Details

#asset_resource_nameObject

Asset resource name returned by a list operation. Must belong to the selected customer.



20
21
22
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 20

def asset_resource_name
  @asset_resource_name
end

#callout_assetObject

Returns the value of attribute callout_asset.



26
27
28
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 26

def callout_asset
  @callout_asset
end

#final_urlsObject

Returns the value of attribute final_urls.



24
25
26
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 24

def final_urls
  @final_urls
end

Returns the value of attribute sitelink_asset.



22
23
24
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 22

def sitelink_asset
  @sitelink_asset
end

#structured_snippet_assetObject

Returns the value of attribute structured_snippet_asset.



28
29
30
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 28

def structured_snippet_asset
  @structured_snippet_asset
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 31

def self.attribute_map
  {
    :'asset_resource_name' => :'assetResourceName',
    :'sitelink_asset' => :'sitelinkAsset',
    :'final_urls' => :'finalUrls',
    :'callout_asset' => :'calloutAsset',
    :'structured_snippet_asset' => :'structuredSnippetAsset'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 52

def self.openapi_types
  {
    :'asset_resource_name' => :'String',
    :'sitelink_asset' => :'UpdateAccountSitelinksRequestUpdatesInnerSitelinkAsset',
    :'final_urls' => :'Array<String>',
    :'callout_asset' => :'UpdateAccountCalloutsRequestUpdatesInnerCalloutAsset',
    :'structured_snippet_asset' => :'GoogleStructuredSnippet'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      asset_resource_name == o.asset_resource_name &&
      sitelink_asset == o.sitelink_asset &&
      final_urls == o.final_urls &&
      callout_asset == o.callout_asset &&
      structured_snippet_asset == o.structured_snippet_asset
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 189

def hash
  [asset_resource_name, sitelink_asset, final_urls, callout_asset, structured_snippet_asset].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @asset_resource_name.nil?
    invalid_properties.push('invalid value for "asset_resource_name", asset_resource_name cannot be nil.')
  end

  pattern = Regexp.new(/^customers\/\d+\/assets\/\d+$/)
  if @asset_resource_name !~ pattern
    invalid_properties.push("invalid value for \"asset_resource_name\", must conform to the pattern #{pattern}.")
  end

  if !@final_urls.nil? && @final_urls.length < 1
    invalid_properties.push('invalid value for "final_urls", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
137
138
# File 'lib/zernio-sdk/models/google_asset_update.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @asset_resource_name.nil?
  return false if @asset_resource_name !~ Regexp.new(/^customers\/\d+\/assets\/\d+$/)
  return false if !@final_urls.nil? && @final_urls.length < 1
  true
end