Class: Zernio::GoogleBusinessPlatformDataEventScheduleEndTime

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb

Overview

Optional end time as { hours, minutes } in 24h format

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GoogleBusinessPlatformDataEventScheduleEndTime

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 57

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GoogleBusinessPlatformDataEventScheduleEndTime` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GoogleBusinessPlatformDataEventScheduleEndTime`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'hours')
    self.hours = attributes[:'hours']
  end

  if attributes.key?(:'minutes')
    self.minutes = attributes[:'minutes']
  end
end

Instance Attribute Details

#hoursObject

Returns the value of attribute hours.



19
20
21
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 19

def hours
  @hours
end

#minutesObject

Returns the value of attribute minutes.



21
22
23
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 21

def minutes
  @minutes
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



32
33
34
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 32

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



37
38
39
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 37

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



24
25
26
27
28
29
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 24

def self.attribute_map
  {
    :'hours' => :'hours',
    :'minutes' => :'minutes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



50
51
52
53
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 50

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



42
43
44
45
46
47
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 42

def self.openapi_types
  {
    :'hours' => :'Integer',
    :'minutes' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      hours == o.hours &&
      minutes == o.minutes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 168

def hash
  [hours, minutes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 82

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@hours.nil? && @hours > 23
    invalid_properties.push('invalid value for "hours", must be smaller than or equal to 23.')
  end

  if !@hours.nil? && @hours < 0
    invalid_properties.push('invalid value for "hours", must be greater than or equal to 0.')
  end

  if !@minutes.nil? && @minutes > 59
    invalid_properties.push('invalid value for "minutes", must be smaller than or equal to 59.')
  end

  if !@minutes.nil? && @minutes < 0
    invalid_properties.push('invalid value for "minutes", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



106
107
108
109
110
111
112
113
# File 'lib/zernio-sdk/models/google_business_platform_data_event_schedule_end_time.rb', line 106

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@hours.nil? && @hours > 23
  return false if !@hours.nil? && @hours < 0
  return false if !@minutes.nil? && @minutes > 59
  return false if !@minutes.nil? && @minutes < 0
  true
end