Class: Zernio::GoogleBusinessReview
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GoogleBusinessReview
- Defined in:
- lib/zernio-sdk/models/google_business_review.rb
Overview
A Google Business Profile review, as returned by every gmb-reviews read endpoint.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#comment ⇒ Object
Review text.
-
#create_time ⇒ Object
Returns the value of attribute create_time.
-
#id ⇒ Object
Review ID.
-
#name ⇒ Object
Full resource name.
-
#photo_count ⇒ Object
Number of photos attached to the review (photos only, videos are not counted).
-
#photos ⇒ Object
Photos attached to the review by the reviewer.
-
#rating ⇒ Object
Numeric star rating (0 when Google sends no rating).
-
#review_reply ⇒ Object
Returns the value of attribute review_reply.
-
#reviewer ⇒ Object
Returns the value of attribute reviewer.
-
#star_rating ⇒ Object
Google's string rating.
-
#update_time ⇒ Object
Returns the value of attribute update_time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GoogleBusinessReview
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GoogleBusinessReview
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GoogleBusinessReview` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GoogleBusinessReview`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'reviewer') self.reviewer = attributes[:'reviewer'] end if attributes.key?(:'rating') self. = attributes[:'rating'] end if attributes.key?(:'star_rating') self. = attributes[:'star_rating'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] end if attributes.key?(:'update_time') self.update_time = attributes[:'update_time'] end if attributes.key?(:'review_reply') self.review_reply = attributes[:'review_reply'] end if attributes.key?(:'photo_count') self.photo_count = attributes[:'photo_count'] end if attributes.key?(:'photos') if (value = attributes[:'photos']).is_a?(Array) self.photos = value end end end |
Instance Attribute Details
#comment ⇒ Object
Review text
34 35 36 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 34 def comment @comment end |
#create_time ⇒ Object
Returns the value of attribute create_time.
36 37 38 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 36 def create_time @create_time end |
#id ⇒ Object
Review ID
20 21 22 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 20 def id @id end |
#name ⇒ Object
Full resource name
23 24 25 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 23 def name @name end |
#photo_count ⇒ Object
Number of photos attached to the review (photos only, videos are not counted)
43 44 45 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 43 def photo_count @photo_count end |
#photos ⇒ Object
Photos attached to the review by the reviewer
46 47 48 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 46 def photos @photos end |
#rating ⇒ Object
Numeric star rating (0 when Google sends no rating)
28 29 30 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 28 def @rating end |
#review_reply ⇒ Object
Returns the value of attribute review_reply.
40 41 42 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 40 def review_reply @review_reply end |
#reviewer ⇒ Object
Returns the value of attribute reviewer.
25 26 27 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 25 def reviewer @reviewer end |
#star_rating ⇒ Object
Google's string rating
31 32 33 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 31 def @star_rating end |
#update_time ⇒ Object
Returns the value of attribute update_time.
38 39 40 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 38 def update_time @update_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 71 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'reviewer' => :'reviewer', :'rating' => :'rating', :'star_rating' => :'starRating', :'comment' => :'comment', :'create_time' => :'createTime', :'update_time' => :'updateTime', :'review_reply' => :'reviewReply', :'photo_count' => :'photoCount', :'photos' => :'photos' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 115 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 98 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'reviewer' => :'GoogleBusinessReviewReviewer', :'rating' => :'Integer', :'star_rating' => :'String', :'comment' => :'String', :'create_time' => :'Time', :'update_time' => :'Time', :'review_reply' => :'GoogleBusinessReviewReviewReply', :'photo_count' => :'Integer', :'photos' => :'Array<ListInboxReviews200ResponseDataInnerPhotosInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 240 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && reviewer == o.reviewer && == o. && == o. && comment == o.comment && create_time == o.create_time && update_time == o.update_time && review_reply == o.review_reply && photo_count == o.photo_count && photos == o.photos end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 264 def hash [id, name, reviewer, , , comment, create_time, update_time, review_reply, photo_count, photos].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@rating.nil? && @rating > 5 invalid_properties.push('invalid value for "rating", must be smaller than or equal to 5.') end if !@rating.nil? && @rating < 0 invalid_properties.push('invalid value for "rating", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 205 206 207 208 |
# File 'lib/zernio-sdk/models/google_business_review.rb', line 201 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@rating.nil? && @rating > 5 return false if !@rating.nil? && @rating < 0 = EnumAttributeValidator.new('String', ["ONE", "TWO", "THREE", "FOUR", "FIVE"]) return false unless .valid?(@star_rating) true end |