Class: Zernio::GooglePmaxAssetGroupInputImages
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GooglePmaxAssetGroupInputImages
- Defined in:
- lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb
Overview
Public HTTP(S) image URLs. GIF, JPEG or PNG, at most 5120 KB per image. Google validates dimensions and aspect ratios.
Instance Attribute Summary collapse
-
#landscape ⇒ Object
Landscape marketing images.
-
#logo ⇒ Object
Required square logos.
-
#square ⇒ Object
Square marketing images.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GooglePmaxAssetGroupInputImages
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GooglePmaxAssetGroupInputImages
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GooglePmaxAssetGroupInputImages` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GooglePmaxAssetGroupInputImages`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'landscape') if (value = attributes[:'landscape']).is_a?(Array) self.landscape = value end else self.landscape = nil end if attributes.key?(:'square') if (value = attributes[:'square']).is_a?(Array) self.square = value end else self.square = nil end if attributes.key?(:'logo') if (value = attributes[:'logo']).is_a?(Array) self.logo = value end else self.logo = nil end end |
Instance Attribute Details
#landscape ⇒ Object
Landscape marketing images. Aspect ratio 1.91:1, minimum 600 x 314 pixels.
20 21 22 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 20 def landscape @landscape end |
#logo ⇒ Object
Required square logos. Aspect ratio 1:1, minimum 128 x 128 pixels.
26 27 28 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 26 def logo @logo end |
#square ⇒ Object
Square marketing images. Aspect ratio 1:1, minimum 300 x 300 pixels.
23 24 25 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 23 def square @square end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 29 def self.attribute_map { :'landscape' => :'landscape', :'square' => :'square', :'logo' => :'logo' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 242 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 48 def self.openapi_types { :'landscape' => :'Array<String>', :'square' => :'Array<String>', :'logo' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && landscape == o.landscape && square == o.square && logo == o.logo end |
#eql?(o) ⇒ Boolean
229 230 231 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 229 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
235 236 237 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 235 def hash [landscape, square, logo].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @landscape.nil? invalid_properties.push('invalid value for "landscape", landscape cannot be nil.') end if @landscape.length > 20 invalid_properties.push('invalid value for "landscape", number of items must be less than or equal to 20.') end if @landscape.length < 1 invalid_properties.push('invalid value for "landscape", number of items must be greater than or equal to 1.') end if @square.nil? invalid_properties.push('invalid value for "square", square cannot be nil.') end if @square.length > 20 invalid_properties.push('invalid value for "square", number of items must be less than or equal to 20.') end if @square.length < 1 invalid_properties.push('invalid value for "square", number of items must be greater than or equal to 1.') end if @logo.nil? invalid_properties.push('invalid value for "logo", logo cannot be nil.') end if @logo.length > 5 invalid_properties.push('invalid value for "logo", number of items must be less than or equal to 5.') end if @logo.length < 1 invalid_properties.push('invalid value for "logo", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 264 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/zernio-sdk/models/google_pmax_asset_group_input_images.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @landscape.nil? return false if @landscape.length > 20 return false if @landscape.length < 1 return false if @square.nil? return false if @square.length > 20 return false if @square.length < 1 return false if @logo.nil? return false if @logo.length > 5 return false if @logo.length < 1 true end |