Class: Zernio::ImessageAudienceContact
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ImessageAudienceContact
- Defined in:
- lib/zernio-sdk/models/imessage_audience_contact.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#contact ⇒ Object
The contact handle (E.164 phone or email).
-
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
-
#first_seen_at ⇒ Object
Returns the value of attribute first_seen_at.
-
#last_message ⇒ Object
Returns the value of attribute last_message.
-
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
-
#name ⇒ Object
Returns the value of attribute name.
-
#opt_in ⇒ Object
Returns the value of attribute opt_in.
-
#subscribed ⇒ Object
Returns the value of attribute subscribed.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ImessageAudienceContact
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ImessageAudienceContact
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ImessageAudienceContact` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ImessageAudienceContact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'conversation_id') self.conversation_id = attributes[:'conversation_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'contact') self.contact = attributes[:'contact'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'subscribed') self.subscribed = attributes[:'subscribed'] end if attributes.key?(:'last_message') self. = attributes[:'last_message'] end if attributes.key?(:'last_message_at') self. = attributes[:'last_message_at'] end if attributes.key?(:'first_seen_at') self.first_seen_at = attributes[:'first_seen_at'] end if attributes.key?(:'opt_in') self.opt_in = attributes[:'opt_in'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
20 21 22 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 20 def account_id @account_id end |
#contact ⇒ Object
The contact handle (E.164 phone or email)
23 24 25 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 23 def contact @contact end |
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
18 19 20 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 18 def conversation_id @conversation_id end |
#first_seen_at ⇒ Object
Returns the value of attribute first_seen_at.
33 34 35 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 33 def first_seen_at @first_seen_at end |
#last_message ⇒ Object
Returns the value of attribute last_message.
29 30 31 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 29 def @last_message end |
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
31 32 33 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 31 def @last_message_at end |
#name ⇒ Object
Returns the value of attribute name.
25 26 27 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 25 def name @name end |
#opt_in ⇒ Object
Returns the value of attribute opt_in.
35 36 37 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 35 def opt_in @opt_in end |
#subscribed ⇒ Object
Returns the value of attribute subscribed.
27 28 29 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 27 def subscribed @subscribed end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 38 def self.attribute_map { :'conversation_id' => :'conversationId', :'account_id' => :'accountId', :'contact' => :'contact', :'name' => :'name', :'subscribed' => :'subscribed', :'last_message' => :'lastMessage', :'last_message_at' => :'lastMessageAt', :'first_seen_at' => :'firstSeenAt', :'opt_in' => :'optIn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 83 84 85 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 78 def self.openapi_nullable Set.new([ :'name', :'last_message', :'last_message_at', :'first_seen_at', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 63 def self.openapi_types { :'conversation_id' => :'String', :'account_id' => :'String', :'contact' => :'String', :'name' => :'String', :'subscribed' => :'Boolean', :'last_message' => :'String', :'last_message_at' => :'Time', :'first_seen_at' => :'Time', :'opt_in' => :'ImessageAudienceContactOptIn' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && conversation_id == o.conversation_id && account_id == o.account_id && contact == o.contact && name == o.name && subscribed == o.subscribed && == o. && == o. && first_seen_at == o.first_seen_at && opt_in == o.opt_in end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 179 def hash [conversation_id, account_id, contact, name, subscribed, , , first_seen_at, opt_in].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 |
# File 'lib/zernio-sdk/models/imessage_audience_contact.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |