Class: Zernio::ImessageSender

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/imessage_sender.rb

Overview

An iMessage sender registered as an account on a profile.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ImessageSender

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ImessageSender` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ImessageSender`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'sender')
    self.sender = attributes[:'sender']
  end

  if attributes.key?(:'opt_in_link')
    self.opt_in_link = attributes[:'opt_in_link']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'sender_verified')
    self.sender_verified = attributes[:'sender_verified']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end
end

Instance Attribute Details

#display_name ⇒ Object

Returns the value of attribute display_name.



30
31
32
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 30

def display_name
  @display_name
end

#id ⇒ Object

Account id (use it with the inbox endpoints' accountId)



20
21
22
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 20

def id
  @id
end

#is_active ⇒ Object

Returns the value of attribute is_active.



40
41
42
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 40

def is_active
  @is_active
end

imessage:// deep link that opens Messages on this sender with a prefilled text. Share it so contacts message you first (Apple only lets a sender reach contacts who wrote to it first).



28
29
30
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 28

def opt_in_link
  @opt_in_link
end

#platform ⇒ Object

Returns the value of attribute platform.



22
23
24
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 22

def platform
  @platform
end

#profile_id ⇒ Object

Returns the value of attribute profile_id.



32
33
34
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 32

def profile_id
  @profile_id
end

#provider ⇒ Object

Delivery provider backing this sender (e.g. loopmessage)



35
36
37
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 35

def provider
  @provider
end

#sender ⇒ Object

The sender handle (E.164 phone or email)



25
26
27
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 25

def sender
  @sender
end

#sender_verified ⇒ Object

Whether the provider confirmed the sender as active at registration time



38
39
40
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 38

def sender_verified
  @sender_verified
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



80
81
82
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 65

def self.attribute_map
  {
    :'id' => :'id',
    :'platform' => :'platform',
    :'sender' => :'sender',
    :'opt_in_link' => :'optInLink',
    :'display_name' => :'displayName',
    :'profile_id' => :'profileId',
    :'provider' => :'provider',
    :'sender_verified' => :'senderVerified',
    :'is_active' => :'isActive'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 223

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



105
106
107
108
109
110
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 105

def self.openapi_nullable
  Set.new([
    :'opt_in_link',
    :'profile_id',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 90

def self.openapi_types
  {
    :'id' => :'String',
    :'platform' => :'String',
    :'sender' => :'String',
    :'opt_in_link' => :'String',
    :'display_name' => :'String',
    :'profile_id' => :'String',
    :'provider' => :'String',
    :'sender_verified' => :'Boolean',
    :'is_active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      platform == o.platform &&
      sender == o.sender &&
      opt_in_link == o.opt_in_link &&
      display_name == o.display_name &&
      profile_id == o.profile_id &&
      provider == o.provider &&
      sender_verified == o.sender_verified &&
      is_active == o.is_active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 210

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



216
217
218
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 216

def hash
  [id, platform, sender, opt_in_link, display_name, profile_id, provider, sender_verified, is_active].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



175
176
177
178
179
180
# File 'lib/zernio-sdk/models/imessage_sender.rb', line 175

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["imessage"])
  return false unless platform_validator.valid?(@platform)
  true
end