Class: Zernio::InlineObject2

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/inline_object2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InlineObject2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/zernio-sdk/models/inline_object2.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::InlineObject2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::InlineObject2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  else
    self.error = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  else
    self.code = nil
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  else
    self.reason = nil
  end

  if attributes.key?(:'documentation_url')
    self.documentation_url = attributes[:'documentation_url']
  end

  if attributes.key?(:'dashboard_url')
    self.dashboard_url = attributes[:'dashboard_url']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end
end

Instance Attribute Details

#codeObject

Machine-readable error code. Stable across versions.



22
23
24
# File 'lib/zernio-sdk/models/inline_object2.rb', line 22

def code
  @code
end

#dashboard_urlObject

Deep-link to send the end-user to. For free_tier_exceeded and twitter_passthrough this is the Zernio billing tab. For enterprise_required this is the Zernio enterprise contact page.



31
32
33
# File 'lib/zernio-sdk/models/inline_object2.rb', line 31

def dashboard_url
  @dashboard_url
end

#detailsObject

Returns the value of attribute details.



33
34
35
# File 'lib/zernio-sdk/models/inline_object2.rb', line 33

def details
  @details
end

#documentation_urlObject

Link to the relevant documentation page.



28
29
30
# File 'lib/zernio-sdk/models/inline_object2.rb', line 28

def documentation_url
  @documentation_url
end

#errorObject

Human-readable error message suitable for end-user display.



19
20
21
# File 'lib/zernio-sdk/models/inline_object2.rb', line 19

def error
  @error
end

#reasonObject

Discriminator for which gate fired.



25
26
27
# File 'lib/zernio-sdk/models/inline_object2.rb', line 25

def reason
  @reason
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/zernio-sdk/models/inline_object2.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/zernio-sdk/models/inline_object2.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/inline_object2.rb', line 58

def self.attribute_map
  {
    :'error' => :'error',
    :'code' => :'code',
    :'reason' => :'reason',
    :'documentation_url' => :'documentation_url',
    :'dashboard_url' => :'dashboard_url',
    :'details' => :'details'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/zernio-sdk/models/inline_object2.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/zernio-sdk/models/inline_object2.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/inline_object2.rb', line 80

def self.openapi_types
  {
    :'error' => :'String',
    :'code' => :'String',
    :'reason' => :'String',
    :'documentation_url' => :'String',
    :'dashboard_url' => :'String',
    :'details' => :'InlineObject2Details'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
# File 'lib/zernio-sdk/models/inline_object2.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      error == o.error &&
      code == o.code &&
      reason == o.reason &&
      documentation_url == o.documentation_url &&
      dashboard_url == o.dashboard_url &&
      details == o.details
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/zernio-sdk/models/inline_object2.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/zernio-sdk/models/inline_object2.rb', line 229

def hash
  [error, code, reason, documentation_url, dashboard_url, details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/zernio-sdk/models/inline_object2.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @error.nil?
    invalid_properties.push('invalid value for "error", error cannot be nil.')
  end

  if @code.nil?
    invalid_properties.push('invalid value for "code", code cannot be nil.')
  end

  if @reason.nil?
    invalid_properties.push('invalid value for "reason", reason cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/zernio-sdk/models/inline_object2.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/inline_object2.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @error.nil?
  return false if @code.nil?
  code_validator = EnumAttributeValidator.new('String', ["PAYMENT_REQUIRED"])
  return false unless code_validator.valid?(@code)
  return false if @reason.nil?
  reason_validator = EnumAttributeValidator.new('String', ["free_tier_exceeded", "twitter_passthrough", "enterprise_required"])
  return false unless reason_validator.valid?(@reason)
  true
end