Class: Zernio::LikeInboxComment200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/like_inbox_comment200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LikeInboxComment200Response

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::LikeInboxComment200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::LikeInboxComment200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'comment_id')
    self.comment_id = attributes[:'comment_id']
  end

  if attributes.key?(:'liked')
    self.liked = attributes[:'liked']
  end

  if attributes.key?(:'like_uri')
    self.like_uri = attributes[:'like_uri']
  end

  if attributes.key?(:'already_reacted')
    self.already_reacted = attributes[:'already_reacted']
  end

  if attributes.key?(:'reaction_type')
    self.reaction_type = attributes[:'reaction_type']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end
end

Instance Attribute Details

#already_reactedObject

LinkedIn only: the account already had this exact reaction, so nothing was created



28
29
30
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 28

def already_reacted
  @already_reacted
end

#comment_idObject

Returns the value of attribute comment_id.



20
21
22
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 20

def comment_id
  @comment_id
end

#like_uriObject

(Bluesky only) URI to use for unliking



25
26
27
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 25

def like_uri
  @like_uri
end

#likedObject

Returns the value of attribute liked.



22
23
24
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 22

def liked
  @liked
end

#platformObject

Returns the value of attribute platform.



33
34
35
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 33

def platform
  @platform
end

#reaction_typeObject

LinkedIn only: the reaction type now in effect



31
32
33
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 31

def reaction_type
  @reaction_type
end

#statusObject

Returns the value of attribute status.



18
19
20
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 18

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 36

def self.attribute_map
  {
    :'status' => :'status',
    :'comment_id' => :'commentId',
    :'liked' => :'liked',
    :'like_uri' => :'likeUri',
    :'already_reacted' => :'alreadyReacted',
    :'reaction_type' => :'reactionType',
    :'platform' => :'platform'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 166

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 59

def self.openapi_types
  {
    :'status' => :'String',
    :'comment_id' => :'String',
    :'liked' => :'Boolean',
    :'like_uri' => :'String',
    :'already_reacted' => :'Boolean',
    :'reaction_type' => :'String',
    :'platform' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



139
140
141
142
143
144
145
146
147
148
149
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      status == o.status &&
      comment_id == o.comment_id &&
      liked == o.liked &&
      like_uri == o.like_uri &&
      already_reacted == o.already_reacted &&
      reaction_type == o.reaction_type &&
      platform == o.platform
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • to be compared

Returns:



153
154
155
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 153

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • Hash code



159
160
161
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 159

def hash
  [status, comment_id, liked, like_uri, already_reacted, reaction_type, platform].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



132
133
134
135
# File 'lib/zernio-sdk/models/like_inbox_comment200_response.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end