Class: Zernio::LinkedInAggregateAnalyticsDailyResponseAnalytics

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb

Overview

Daily breakdown of each metric as date/count pairs. Reach not available with DAILY aggregation.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LinkedInAggregateAnalyticsDailyResponseAnalytics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::LinkedInAggregateAnalyticsDailyResponseAnalytics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::LinkedInAggregateAnalyticsDailyResponseAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'impressions')
    if (value = attributes[:'impressions']).is_a?(Array)
      self.impressions = value
    end
  end

  if attributes.key?(:'reactions')
    if (value = attributes[:'reactions']).is_a?(Array)
      self.reactions = value
    end
  end

  if attributes.key?(:'comments')
    if (value = attributes[:'comments']).is_a?(Array)
      self.comments = value
    end
  end

  if attributes.key?(:'shares')
    if (value = attributes[:'shares']).is_a?(Array)
      self.shares = value
    end
  end

  if attributes.key?(:'saves')
    if (value = attributes[:'saves']).is_a?(Array)
      self.saves = value
    end
  end

  if attributes.key?(:'sends')
    if (value = attributes[:'sends']).is_a?(Array)
      self.sends = value
    end
  end
end

Instance Attribute Details

#commentsObject

Returns the value of attribute comments.



23
24
25
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 23

def comments
  @comments
end

#impressionsObject

Returns the value of attribute impressions.



19
20
21
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 19

def impressions
  @impressions
end

#reactionsObject

Returns the value of attribute reactions.



21
22
23
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 21

def reactions
  @reactions
end

#savesObject

Daily saves (personal accounts only)



28
29
30
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 28

def saves
  @saves
end

#sendsObject

Daily sends via LinkedIn messaging (personal accounts only)



31
32
33
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 31

def sends
  @sends
end

#sharesObject

Returns the value of attribute shares.



25
26
27
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 25

def shares
  @shares
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 34

def self.attribute_map
  {
    :'impressions' => :'impressions',
    :'reactions' => :'reactions',
    :'comments' => :'comments',
    :'shares' => :'shares',
    :'saves' => :'saves',
    :'sends' => :'sends'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 68

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 56

def self.openapi_types
  {
    :'impressions' => :'Array<LinkedInAggregateAnalyticsDailyResponseAnalyticsImpressionsInner>',
    :'reactions' => :'Array<LinkedInAggregateAnalyticsDailyResponseAnalyticsImpressionsInner>',
    :'comments' => :'Array<LinkedInAggregateAnalyticsDailyResponseAnalyticsImpressionsInner>',
    :'shares' => :'Array<LinkedInAggregateAnalyticsDailyResponseAnalyticsImpressionsInner>',
    :'saves' => :'Array<LinkedInAggregateAnalyticsDailyResponseAnalyticsImpressionsInner>',
    :'sends' => :'Array<LinkedInAggregateAnalyticsDailyResponseAnalyticsImpressionsInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
149
150
151
152
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      impressions == o.impressions &&
      reactions == o.reactions &&
      comments == o.comments &&
      shares == o.shares &&
      saves == o.saves &&
      sends == o.sends
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 162

def hash
  [impressions, reactions, comments, shares, saves, sends].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



136
137
138
139
# File 'lib/zernio-sdk/models/linked_in_aggregate_analytics_daily_response_analytics.rb', line 136

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end