Class: Zernio::ListAdAudiences200ResponseAudiencesInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListAdAudiences200ResponseAudiencesInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListAdAudiences200ResponseAudiencesInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListAdAudiences200ResponseAudiencesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform_audience_id')
    self.platform_audience_id = attributes[:'platform_audience_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'spec')
    self.spec = attributes[:'spec']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end
end

Instance Attribute Details

#account_idObject

Account the audience was created against. Returned for saved_targeting items.



22
23
24
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 22

def 
  @account_id
end

#descriptionObject

Returns the value of attribute description.



28
29
30
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 28

def description
  @description
end

#idObject

The Zernio audience id. Pass this as audienceId on GET /v1/ads/audiences/audienceId and the companies/users upload endpoints. Null when the audience was not created through Zernio.



19
20
21
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 19

def id
  @id
end

#nameObject

Returns the value of attribute name.



26
27
28
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 26

def name
  @name
end

#platformObject

Returns the value of attribute platform.



34
35
36
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 34

def platform
  @platform
end

#platform_audience_idObject

Returns the value of attribute platform_audience_id.



24
25
26
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 24

def platform_audience_id
  @platform_audience_id
end

#sizeObject

Returns the value of attribute size.



36
37
38
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 36

def size
  @size
end

#specObject

Returns the value of attribute spec.



32
33
34
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 32

def spec
  @spec
end

#statusObject

Returns the value of attribute status.



38
39
40
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 38

def status
  @status
end

#typeObject

Returns the value of attribute type.



30
31
32
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 30

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 63

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'platform_audience_id' => :'platformAudienceId',
    :'name' => :'name',
    :'description' => :'description',
    :'type' => :'type',
    :'spec' => :'spec',
    :'platform' => :'platform',
    :'size' => :'size',
    :'status' => :'status'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 228

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
110
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 105

def self.openapi_nullable
  Set.new([
    :'id',
    :'spec',
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 89

def self.openapi_types
  {
    :'id' => :'String',
    :'account_id' => :'String',
    :'platform_audience_id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'type' => :'String',
    :'spec' => :'TargetingSpec',
    :'platform' => :'String',
    :'size' => :'Integer',
    :'status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      platform_audience_id == o.platform_audience_id &&
      name == o.name &&
      description == o.description &&
      type == o.type &&
      spec == o.spec &&
      platform == o.platform &&
      size == o.size &&
      status == o.status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


215
216
217
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 215

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



221
222
223
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 221

def hash
  [id, , platform_audience_id, name, description, type, spec, platform, size, status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 250

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["customer_list", "company_list", "engagement", "meta_engagement", "website", "website_retargeting", "lookalike", "saved_targeting"])
  return false unless type_validator.valid?(@type)
  true
end