Class: Zernio::ListAdNegativeKeywordLists200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListAdNegativeKeywordLists200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListAdNegativeKeywordLists200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListAdNegativeKeywordLists200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'lists')
    if (value = attributes[:'lists']).is_a?(Array)
      self.lists = value
    end
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'cached_at')
    self.cached_at = attributes[:'cached_at']
  end

  if attributes.key?(:'stale')
    self.stale = attributes[:'stale']
  end
end

Instance Attribute Details

#cached_atObject

Last successful fetch time, or null without cache storage.



24
25
26
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 24

def cached_at
  @cached_at
end

#customer_idObject

Resolved Google Ads customer id.



21
22
23
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 21

def customer_id
  @customer_id
end

#listsObject

Returns the value of attribute lists.



18
19
20
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 18

def lists
  @lists
end

#staleObject

True when quota exhaustion caused the last successful cached result to be served.



27
28
29
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 27

def stale
  @stale
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 30

def self.attribute_map
  {
    :'lists' => :'lists',
    :'customer_id' => :'customerId',
    :'cached_at' => :'cachedAt',
    :'stale' => :'stale'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 163

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
64
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 60

def self.openapi_nullable
  Set.new([
    :'cached_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 50

def self.openapi_types
  {
    :'lists' => :'Array<AdNegativeKeywordList>',
    :'customer_id' => :'String',
    :'cached_at' => :'Time',
    :'stale' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      lists == o.lists &&
      customer_id == o.customer_id &&
      cached_at == o.cached_at &&
      stale == o.stale
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


150
151
152
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 150

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



156
157
158
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 156

def hash
  [lists, customer_id, cached_at, stale].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 103

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d+$/)
  if !@customer_id.nil? && @customer_id !~ pattern
    invalid_properties.push("invalid value for \"customer_id\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



116
117
118
119
120
# File 'lib/zernio-sdk/models/list_ad_negative_keyword_lists200_response.rb', line 116

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@customer_id.nil? && @customer_id !~ Regexp.new(/^\d+$/)
  true
end