Class: Zernio::ListBroadcastRecipients200ResponseRecipientsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListBroadcastRecipients200ResponseRecipientsInner
- Defined in:
- lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#channel_id ⇒ Object
Returns the value of attribute channel_id.
-
#contact_id ⇒ Object
Returns the value of attribute contact_id.
-
#contact_name ⇒ Object
Returns the value of attribute contact_name.
-
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
-
#error ⇒ Object
Returns the value of attribute error.
-
#error_code ⇒ Object
Meta WhatsApp error code (e.g. 131049 for antispam, 131021 for invalid phone, 131026 for re-engagement required).
-
#error_explanation ⇒ Object
Plain-language translation of errorCode (e.g. for 131026, that the recipient has likely opted out of marketing messages).
-
#error_trace_id ⇒ Object
Meta trace id (fbtrace_id) for the failed send.
-
#id ⇒ Object
Returns the value of attribute id.
-
#message_id ⇒ Object
Returns the value of attribute message_id.
-
#platform_identifier ⇒ Object
Returns the value of attribute platform_identifier.
-
#read_at ⇒ Object
Returns the value of attribute read_at.
-
#sent_at ⇒ Object
Returns the value of attribute sent_at.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListBroadcastRecipients200ResponseRecipientsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListBroadcastRecipients200ResponseRecipientsInner
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListBroadcastRecipients200ResponseRecipientsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListBroadcastRecipients200ResponseRecipientsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'contact_id') self.contact_id = attributes[:'contact_id'] end if attributes.key?(:'channel_id') self.channel_id = attributes[:'channel_id'] end if attributes.key?(:'platform_identifier') self.platform_identifier = attributes[:'platform_identifier'] end if attributes.key?(:'contact_name') self.contact_name = attributes[:'contact_name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'message_id') self. = attributes[:'message_id'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'error_code') self.error_code = attributes[:'error_code'] end if attributes.key?(:'error_explanation') self.error_explanation = attributes[:'error_explanation'] end if attributes.key?(:'error_trace_id') self.error_trace_id = attributes[:'error_trace_id'] end if attributes.key?(:'sent_at') self.sent_at = attributes[:'sent_at'] end if attributes.key?(:'delivered_at') self.delivered_at = attributes[:'delivered_at'] end if attributes.key?(:'read_at') self.read_at = attributes[:'read_at'] end end |
Instance Attribute Details
#channel_id ⇒ Object
Returns the value of attribute channel_id.
22 23 24 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 22 def channel_id @channel_id end |
#contact_id ⇒ Object
Returns the value of attribute contact_id.
20 21 22 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 20 def contact_id @contact_id end |
#contact_name ⇒ Object
Returns the value of attribute contact_name.
26 27 28 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 26 def contact_name @contact_name end |
#delivered_at ⇒ Object
Returns the value of attribute delivered_at.
45 46 47 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 45 def delivered_at @delivered_at end |
#error ⇒ Object
Returns the value of attribute error.
32 33 34 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 32 def error @error end |
#error_code ⇒ Object
Meta WhatsApp error code (e.g. 131049 for antispam, 131021 for invalid phone, 131026 for re-engagement required). Only populated for status=failed.
35 36 37 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 35 def error_code @error_code end |
#error_explanation ⇒ Object
Plain-language translation of errorCode (e.g. for 131026, that the recipient has likely opted out of marketing messages). Null for unmapped codes; fall back to error.
38 39 40 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 38 def error_explanation @error_explanation end |
#error_trace_id ⇒ Object
Meta trace id (fbtrace_id) for the failed send. Quote this when escalating to Meta Direct Support. Only populated for status=failed on Meta platforms.
41 42 43 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 41 def error_trace_id @error_trace_id end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 18 def id @id end |
#message_id ⇒ Object
Returns the value of attribute message_id.
30 31 32 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 30 def @message_id end |
#platform_identifier ⇒ Object
Returns the value of attribute platform_identifier.
24 25 26 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 24 def platform_identifier @platform_identifier end |
#read_at ⇒ Object
Returns the value of attribute read_at.
47 48 49 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 47 def read_at @read_at end |
#sent_at ⇒ Object
Returns the value of attribute sent_at.
43 44 45 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 43 def sent_at @sent_at end |
#status ⇒ Object
Returns the value of attribute status.
28 29 30 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 28 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
92 93 94 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 92 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
97 98 99 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 97 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 72 def self.attribute_map { :'id' => :'id', :'contact_id' => :'contactId', :'channel_id' => :'channelId', :'platform_identifier' => :'platformIdentifier', :'contact_name' => :'contactName', :'status' => :'status', :'message_id' => :'messageId', :'error' => :'error', :'error_code' => :'errorCode', :'error_explanation' => :'errorExplanation', :'error_trace_id' => :'errorTraceId', :'sent_at' => :'sentAt', :'delivered_at' => :'deliveredAt', :'read_at' => :'readAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 126 127 128 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 122 def self.openapi_nullable Set.new([ :'error_code', :'error_explanation', :'error_trace_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 102 def self.openapi_types { :'id' => :'String', :'contact_id' => :'String', :'channel_id' => :'String', :'platform_identifier' => :'String', :'contact_name' => :'String', :'status' => :'String', :'message_id' => :'String', :'error' => :'String', :'error_code' => :'Integer', :'error_explanation' => :'String', :'error_trace_id' => :'String', :'sent_at' => :'Time', :'delivered_at' => :'Time', :'read_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 232 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && contact_id == o.contact_id && channel_id == o.channel_id && platform_identifier == o.platform_identifier && contact_name == o.contact_name && status == o.status && == o. && error == o.error && error_code == o.error_code && error_explanation == o.error_explanation && error_trace_id == o.error_trace_id && sent_at == o.sent_at && delivered_at == o.delivered_at && read_at == o.read_at end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 259 def hash [id, contact_id, channel_id, platform_identifier, contact_name, status, , error, error_code, error_explanation, error_trace_id, sent_at, delivered_at, read_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 |
# File 'lib/zernio-sdk/models/list_broadcast_recipients200_response_recipients_inner.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["pending", "sent", "delivered", "read", "failed"]) return false unless status_validator.valid?(@status) true end |