Class: Zernio::ListCommentAutomations200ResponseAutomationsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListCommentAutomations200ResponseAutomationsInner
- Defined in:
- lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#also_match_in_dms ⇒ Object
Whether these keywords also fire on a plain inbound DM.
-
#buttons ⇒ Object
Inline DM buttons (up to 3).
-
#click_tag ⇒ Object
Tag applied to a contact when they click a tracked link.
-
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
-
#comment_reply_delay_seconds ⇒ Object
Seconds waited before the public reply is posted.
-
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#dm_delay_seconds ⇒ Object
Seconds waited after the trigger before the DM is sent.
-
#dm_message ⇒ Object
Returns the value of attribute dm_message.
-
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage.
-
#exclude_keywords ⇒ Object
Comments containing one of these never trigger the automation, even when a trigger keyword also matches.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#link_tracking ⇒ Object
Whether link buttons in the DM are wrapped in a tracked redirect to count clicks.
-
#match_mode ⇒ Object
How a keyword is compared with the comment.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
-
#post_title ⇒ Object
Returns the value of attribute post_title.
-
#stats ⇒ Object
Returns the value of attribute stats.
-
#template ⇒ Object
Returns the value of attribute template.
-
#trigger ⇒ Object
Returns the value of attribute trigger.
-
#typo_tolerance ⇒ Object
Only with matchMode=word: also fire on close misspellings of a keyword (one edit for 4-7 character keywords, two from 8 up).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListCommentAutomations200ResponseAutomationsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListCommentAutomations200ResponseAutomationsInner
Initializes the object
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 181 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListCommentAutomations200ResponseAutomationsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListCommentAutomations200ResponseAutomationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'post_title') self.post_title = attributes[:'post_title'] end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'match_mode') self.match_mode = attributes[:'match_mode'] end if attributes.key?(:'exclude_keywords') if (value = attributes[:'exclude_keywords']).is_a?(Array) self.exclude_keywords = value end end if attributes.key?(:'typo_tolerance') self.typo_tolerance = attributes[:'typo_tolerance'] end if attributes.key?(:'dm_message') self. = attributes[:'dm_message'] end if attributes.key?(:'buttons') if (value = attributes[:'buttons']).is_a?(Array) self. = value end end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'comment_reply') self.comment_reply = attributes[:'comment_reply'] end if attributes.key?(:'dm_message_variations') if (value = attributes[:'dm_message_variations']).is_a?(Array) self. = value end end if attributes.key?(:'comment_reply_variations') if (value = attributes[:'comment_reply_variations']).is_a?(Array) self.comment_reply_variations = value end end if attributes.key?(:'link_tracking') self.link_tracking = attributes[:'link_tracking'] end if attributes.key?(:'click_tag') self.click_tag = attributes[:'click_tag'] end if attributes.key?(:'dm_delay_seconds') self.dm_delay_seconds = attributes[:'dm_delay_seconds'] end if attributes.key?(:'comment_reply_delay_seconds') self.comment_reply_delay_seconds = attributes[:'comment_reply_delay_seconds'] end if attributes.key?(:'also_match_in_dms') self.also_match_in_dms = attributes[:'also_match_in_dms'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'stats') self.stats = attributes[:'stats'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
26 27 28 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 26 def account_id @account_id end |
#also_match_in_dms ⇒ Object
Whether these keywords also fire on a plain inbound DM.
71 72 73 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 71 def also_match_in_dms @also_match_in_dms end |
#buttons ⇒ Object
Inline DM buttons (up to 3). Omitted when none are set.
46 47 48 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 46 def @buttons end |
#click_tag ⇒ Object
Tag applied to a contact when they click a tracked link.
62 63 64 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 62 def click_tag @click_tag end |
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
50 51 52 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 50 def comment_reply @comment_reply end |
#comment_reply_delay_seconds ⇒ Object
Seconds waited before the public reply is posted. Absent when it follows the DM immediately.
68 69 70 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 68 def comment_reply_delay_seconds @comment_reply_delay_seconds end |
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply. Omitted when none.
56 57 58 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 56 def comment_reply_variations @comment_reply_variations end |
#created_at ⇒ Object
Returns the value of attribute created_at.
77 78 79 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 77 def created_at @created_at end |
#dm_delay_seconds ⇒ Object
Seconds waited after the trigger before the DM is sent. Absent when the DM goes out immediately.
65 66 67 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 65 def dm_delay_seconds @dm_delay_seconds end |
#dm_message ⇒ Object
Returns the value of attribute dm_message.
43 44 45 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 43 def @dm_message end |
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage. Omitted when none.
53 54 55 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 53 def @dm_message_variations end |
#exclude_keywords ⇒ Object
Comments containing one of these never trigger the automation, even when a trigger keyword also matches. Compared using the same matchMode.
38 39 40 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 38 def exclude_keywords @exclude_keywords end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
73 74 75 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 73 def is_active @is_active end |
#keywords ⇒ Object
Returns the value of attribute keywords.
32 33 34 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 32 def keywords @keywords end |
#link_tracking ⇒ Object
Whether link buttons in the DM are wrapped in a tracked redirect to count clicks.
59 60 61 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 59 def link_tracking @link_tracking end |
#match_mode ⇒ Object
How a keyword is compared with the comment. 'contains' (default) matches anywhere, even inside another word (keyword 'app' fires on 'happy'). 'word' matches the keyword only as a standalone word. 'exact' requires the whole comment to be exactly the keyword.
35 36 37 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 35 def match_mode @match_mode end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 20 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
22 23 24 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 22 def platform @platform end |
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
28 29 30 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 28 def platform_post_id @platform_post_id end |
#post_title ⇒ Object
Returns the value of attribute post_title.
30 31 32 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 30 def post_title @post_title end |
#stats ⇒ Object
Returns the value of attribute stats.
75 76 77 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 75 def stats @stats end |
#template ⇒ Object
Returns the value of attribute template.
48 49 50 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 48 def template @template end |
#trigger ⇒ Object
Returns the value of attribute trigger.
24 25 26 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 24 def trigger @trigger end |
#typo_tolerance ⇒ Object
Only with matchMode=word: also fire on close misspellings of a keyword (one edit for 4-7 character keywords, two from 8 up). Keywords shorter than 4 characters are never fuzzy-matched.
41 42 43 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 41 def typo_tolerance @typo_tolerance end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
133 134 135 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 133 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
138 139 140 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 138 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 102 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'platform' => :'platform', :'trigger' => :'trigger', :'account_id' => :'accountId', :'platform_post_id' => :'platformPostId', :'post_title' => :'postTitle', :'keywords' => :'keywords', :'match_mode' => :'matchMode', :'exclude_keywords' => :'excludeKeywords', :'typo_tolerance' => :'typoTolerance', :'dm_message' => :'dmMessage', :'buttons' => :'buttons', :'template' => :'template', :'comment_reply' => :'commentReply', :'dm_message_variations' => :'dmMessageVariations', :'comment_reply_variations' => :'commentReplyVariations', :'link_tracking' => :'linkTracking', :'click_tag' => :'clickTag', :'dm_delay_seconds' => :'dmDelaySeconds', :'comment_reply_delay_seconds' => :'commentReplyDelaySeconds', :'also_match_in_dms' => :'alsoMatchInDms', :'is_active' => :'isActive', :'stats' => :'stats', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 404 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
174 175 176 177 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 174 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 143 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'platform' => :'String', :'trigger' => :'String', :'account_id' => :'String', :'platform_post_id' => :'String', :'post_title' => :'String', :'keywords' => :'Array<String>', :'match_mode' => :'String', :'exclude_keywords' => :'Array<String>', :'typo_tolerance' => :'Boolean', :'dm_message' => :'String', :'buttons' => :'Array<DmButton>', :'template' => :'CommentAutomationTemplate', :'comment_reply' => :'String', :'dm_message_variations' => :'Array<String>', :'comment_reply_variations' => :'Array<String>', :'link_tracking' => :'Boolean', :'click_tag' => :'String', :'dm_delay_seconds' => :'Integer', :'comment_reply_delay_seconds' => :'Integer', :'also_match_in_dms' => :'Boolean', :'is_active' => :'Boolean', :'stats' => :'ListCommentAutomations200ResponseAutomationsInnerStats', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 359 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && platform == o.platform && trigger == o.trigger && account_id == o.account_id && platform_post_id == o.platform_post_id && post_title == o.post_title && keywords == o.keywords && match_mode == o.match_mode && exclude_keywords == o.exclude_keywords && typo_tolerance == o.typo_tolerance && == o. && == o. && template == o.template && comment_reply == o.comment_reply && == o. && comment_reply_variations == o.comment_reply_variations && link_tracking == o.link_tracking && click_tag == o.click_tag && dm_delay_seconds == o.dm_delay_seconds && comment_reply_delay_seconds == o.comment_reply_delay_seconds && also_match_in_dms == o.also_match_in_dms && is_active == o.is_active && stats == o.stats && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
391 392 393 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 391 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
397 398 399 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 397 def hash [id, name, platform, trigger, account_id, platform_post_id, post_title, keywords, match_mode, exclude_keywords, typo_tolerance, , , template, comment_reply, , comment_reply_variations, link_tracking, click_tag, dm_delay_seconds, comment_reply_delay_seconds, also_match_in_dms, is_active, stats, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
308 309 310 311 312 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 308 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
426 427 428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 426 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
316 317 318 319 320 321 322 323 324 325 |
# File 'lib/zernio-sdk/models/list_comment_automations200_response_automations_inner.rb', line 316 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook"]) return false unless platform_validator.valid?(@platform) trigger_validator = EnumAttributeValidator.new('String', ["comment", "story_reply"]) return false unless trigger_validator.valid?(@trigger) match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains", "word"]) return false unless match_mode_validator.valid?(@match_mode) true end |