Class: Zernio::ListInboxConversations200ResponseDataInnerInstagramProfile

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb

Overview

Instagram profile data for the participant. Only present for Instagram conversations.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListInboxConversations200ResponseDataInnerInstagramProfile

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListInboxConversations200ResponseDataInnerInstagramProfile` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListInboxConversations200ResponseDataInnerInstagramProfile`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'is_follower')
    self.is_follower = attributes[:'is_follower']
  end

  if attributes.key?(:'is_following')
    self.is_following = attributes[:'is_following']
  end

  if attributes.key?(:'follower_count')
    self.follower_count = attributes[:'follower_count']
  end

  if attributes.key?(:'is_verified')
    self.is_verified = attributes[:'is_verified']
  end

  if attributes.key?(:'fetched_at')
    self.fetched_at = attributes[:'fetched_at']
  end
end

Instance Attribute Details

#fetched_atObject

When this profile data was last fetched from Instagram



32
33
34
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 32

def fetched_at
  @fetched_at
end

#follower_countObject

The participant's follower count on Instagram



26
27
28
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 26

def follower_count
  @follower_count
end

#is_followerObject

Whether the participant follows your Instagram business account



20
21
22
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 20

def is_follower
  @is_follower
end

#is_followingObject

Whether your Instagram business account follows the participant



23
24
25
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 23

def is_following
  @is_following
end

#is_verifiedObject

Whether the participant is a verified Instagram user



29
30
31
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 29

def is_verified
  @is_verified
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 35

def self.attribute_map
  {
    :'is_follower' => :'isFollower',
    :'is_following' => :'isFollowing',
    :'follower_count' => :'followerCount',
    :'is_verified' => :'isVerified',
    :'fetched_at' => :'fetchedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 156

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
72
73
74
75
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 67

def self.openapi_nullable
  Set.new([
    :'is_follower',
    :'is_following',
    :'follower_count',
    :'is_verified',
    :'fetched_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 56

def self.openapi_types
  {
    :'is_follower' => :'Boolean',
    :'is_following' => :'Boolean',
    :'follower_count' => :'Integer',
    :'is_verified' => :'Boolean',
    :'fetched_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
138
139
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      is_follower == o.is_follower &&
      is_following == o.is_following &&
      follower_count == o.follower_count &&
      is_verified == o.is_verified &&
      fetched_at == o.fetched_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


143
144
145
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 143

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



149
150
151
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 149

def hash
  [is_follower, is_following, follower_count, is_verified, fetched_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 178

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner_instagram_profile.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end