Class: Zernio::ListLeads200ResponseLeadsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_leads200_response_leads_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListLeads200ResponseLeadsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListLeads200ResponseLeadsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListLeads200ResponseLeadsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'leadgen_id')
    self.leadgen_id = attributes[:'leadgen_id']
  end

  if attributes.key?(:'form_id')
    self.form_id = attributes[:'form_id']
  end

  if attributes.key?(:'form_name')
    self.form_name = attributes[:'form_name']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'ad_id')
    self.ad_id = attributes[:'ad_id']
  end

  if attributes.key?(:'adset_id')
    self.adset_id = attributes[:'adset_id']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'is_organic')
    self.is_organic = attributes[:'is_organic']
  end

  if attributes.key?(:'created_time')
    self.created_time = attributes[:'created_time']
  end

  if attributes.key?(:'fields')
    if (value = attributes[:'fields']).is_a?(Hash)
      self.fields = value
    end
  end

  if attributes.key?(:'field_data')
    if (value = attributes[:'field_data']).is_a?(Array)
      self.field_data = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



28
29
30
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 28

def 
  @account_id
end

#ad_idObject

Returns the value of attribute ad_id.



30
31
32
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 30

def ad_id
  @ad_id
end

#adset_idObject

Returns the value of attribute adset_id.



32
33
34
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 32

def adset_id
  @adset_id
end

#campaign_idObject

Returns the value of attribute campaign_id.



34
35
36
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 34

def campaign_id
  @campaign_id
end

#created_timeObject

ISO 8601.



39
40
41
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 39

def created_time
  @created_time
end

#field_dataObject

Raw Meta field_data.



45
46
47
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 45

def field_data
  @field_data
end

#fieldsObject

Question key → answer.



42
43
44
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 42

def fields
  @fields
end

#form_idObject

Returns the value of attribute form_id.



24
25
26
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 24

def form_id
  @form_id
end

#form_nameObject

Returns the value of attribute form_name.



26
27
28
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 26

def form_name
  @form_name
end

#idObject

Zernio lead id.



19
20
21
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 19

def id
  @id
end

#is_organicObject

Returns the value of attribute is_organic.



36
37
38
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 36

def is_organic
  @is_organic
end

#leadgen_idObject

Meta lead id.



22
23
24
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 22

def leadgen_id
  @leadgen_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 48

def self.attribute_map
  {
    :'id' => :'id',
    :'leadgen_id' => :'leadgenId',
    :'form_id' => :'formId',
    :'form_name' => :'formName',
    :'account_id' => :'accountId',
    :'ad_id' => :'adId',
    :'adset_id' => :'adsetId',
    :'campaign_id' => :'campaignId',
    :'is_organic' => :'isOrganic',
    :'created_time' => :'createdTime',
    :'fields' => :'fields',
    :'field_data' => :'fieldData'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 222

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
100
101
102
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 94

def self.openapi_nullable
  Set.new([
    :'form_name',
    :'ad_id',
    :'adset_id',
    :'campaign_id',
    :'created_time',
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 76

def self.openapi_types
  {
    :'id' => :'String',
    :'leadgen_id' => :'String',
    :'form_id' => :'String',
    :'form_name' => :'String',
    :'account_id' => :'String',
    :'ad_id' => :'String',
    :'adset_id' => :'String',
    :'campaign_id' => :'String',
    :'is_organic' => :'Boolean',
    :'created_time' => :'String',
    :'fields' => :'Hash<String, String>',
    :'field_data' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      leadgen_id == o.leadgen_id &&
      form_id == o.form_id &&
      form_name == o.form_name &&
       == o. &&
      ad_id == o.ad_id &&
      adset_id == o.adset_id &&
      campaign_id == o.campaign_id &&
      is_organic == o.is_organic &&
      created_time == o.created_time &&
      fields == o.fields &&
      field_data == o.field_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 215

def hash
  [id, leadgen_id, form_id, form_name, , ad_id, adset_id, campaign_id, is_organic, created_time, fields, field_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 244

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
# File 'lib/zernio-sdk/models/list_leads200_response_leads_inner.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end