Class: Zernio::ListPhoneNumberPortIns200ResponseOrdersInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListPhoneNumberPortIns200ResponseOrdersInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListPhoneNumberPortIns200ResponseOrdersInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListPhoneNumberPortIns200ResponseOrdersInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'telnyx_status_value')
    self.telnyx_status_value = attributes[:'telnyx_status_value']
  end

  if attributes.key?(:'phone_numbers')
    if (value = attributes[:'phone_numbers']).is_a?(Array)
      self.phone_numbers = value
    end
  end

  if attributes.key?(:'fast_port_eligible')
    self.fast_port_eligible = attributes[:'fast_port_eligible']
  end

  if attributes.key?(:'foc_datetime_requested')
    self.foc_datetime_requested = attributes[:'foc_datetime_requested']
  end

  if attributes.key?(:'foc_datetime_actual')
    self.foc_datetime_actual = attributes[:'foc_datetime_actual']
  end

  if attributes.key?(:'decline_reason')
    self.decline_reason = attributes[:'decline_reason']
  end

  if attributes.key?(:'submitted_at')
    self. = attributes[:'submitted_at']
  end

  if attributes.key?(:'ported_at')
    self.ported_at = attributes[:'ported_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



39
40
41
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 39

def created_at
  @created_at
end

#decline_reasonObject

Returns the value of attribute decline_reason.



33
34
35
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 33

def decline_reason
  @decline_reason
end

#fast_port_eligibleObject

Returns the value of attribute fast_port_eligible.



27
28
29
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 27

def fast_port_eligible
  @fast_port_eligible
end

#foc_datetime_actualObject

Returns the value of attribute foc_datetime_actual.



31
32
33
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 31

def foc_datetime_actual
  @foc_datetime_actual
end

#foc_datetime_requestedObject

Returns the value of attribute foc_datetime_requested.



29
30
31
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 29

def foc_datetime_requested
  @foc_datetime_requested
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 18

def id
  @id
end

#phone_numbersObject

Returns the value of attribute phone_numbers.



25
26
27
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 25

def phone_numbers
  @phone_numbers
end

#ported_atObject

Returns the value of attribute ported_at.



37
38
39
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 37

def ported_at
  @ported_at
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 20

def status
  @status
end

#submitted_atObject

Returns the value of attribute submitted_at.



35
36
37
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 35

def 
  @submitted_at
end

#telnyx_status_valueObject

Raw carrier status string.



23
24
25
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 23

def telnyx_status_value
  @telnyx_status_value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



81
82
83
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 81

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 86

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 64

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'telnyx_status_value' => :'telnyxStatusValue',
    :'phone_numbers' => :'phoneNumbers',
    :'fast_port_eligible' => :'fastPortEligible',
    :'foc_datetime_requested' => :'focDatetimeRequested',
    :'foc_datetime_actual' => :'focDatetimeActual',
    :'decline_reason' => :'declineReason',
    :'submitted_at' => :'submittedAt',
    :'ported_at' => :'portedAt',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
112
113
114
115
116
117
118
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 108

def self.openapi_nullable
  Set.new([
    :'telnyx_status_value',
    :'fast_port_eligible',
    :'foc_datetime_requested',
    :'foc_datetime_actual',
    :'decline_reason',
    :'submitted_at',
    :'ported_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 91

def self.openapi_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'telnyx_status_value' => :'String',
    :'phone_numbers' => :'Array<String>',
    :'fast_port_eligible' => :'Boolean',
    :'foc_datetime_requested' => :'Time',
    :'foc_datetime_actual' => :'Time',
    :'decline_reason' => :'String',
    :'submitted_at' => :'Time',
    :'ported_at' => :'Time',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      telnyx_status_value == o.telnyx_status_value &&
      phone_numbers == o.phone_numbers &&
      fast_port_eligible == o.fast_port_eligible &&
      foc_datetime_requested == o.foc_datetime_requested &&
      foc_datetime_actual == o.foc_datetime_actual &&
      decline_reason == o.decline_reason &&
       == o. &&
      ported_at == o.ported_at &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 236

def hash
  [id, status, telnyx_status_value, phone_numbers, fast_port_eligible, foc_datetime_requested, foc_datetime_actual, decline_reason, , ported_at, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 185

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



193
194
195
196
197
198
# File 'lib/zernio-sdk/models/list_phone_number_port_ins200_response_orders_inner.rb', line 193

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["draft", "pending", "foc_confirmed", "ported", "exception", "cancelled"])
  return false unless status_validator.valid?(@status)
  true
end