Class: Zernio::ListPhoneNumbers200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/list_phone_numbers200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListPhoneNumbers200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListPhoneNumbers200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListPhoneNumbers200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'numbers')
    if (value = attributes[:'numbers']).is_a?(Array)
      self.numbers = value
    end
  end

  if attributes.key?(:'connected')
    if (value = attributes[:'connected']).is_a?(Array)
      self.connected = value
    end
  end

  if attributes.key?(:'imessage')
    if (value = attributes[:'imessage']).is_a?(Array)
      self.imessage = value
    end
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end
end

Instance Attribute Details

#connected ⇒ Object

Connected (bring-your-own) WhatsApp numbers: your own WABA numbers linked via Embedded Signup. Not provisioned or billed by Zernio, so they are not in numbers; accountId is the social-account id used by the messaging and inbox endpoints. Included only on the default and status=active views.



21
22
23
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 21

def connected
  @connected
end

#imessage ⇒ Object

iMessage phone senders (see /v1/imessage/senders/order). Hosted by the iMessage provider, not on your Telnyx numbers: SMS and Calls can never be enabled on them, and they bill as iMessage senders. handle is null until the carrier assigns the number at activation. Included only on the default and status=active views.



24
25
26
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 24

def imessage
  @imessage
end

#numbers ⇒ Object

Returns the value of attribute numbers.



18
19
20
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 18

def numbers
  @numbers
end

#sandbox ⇒ Object

Returns the value of attribute sandbox.



26
27
28
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 26

def sandbox
  @sandbox
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



39
40
41
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 29

def self.attribute_map
  {
    :'numbers' => :'numbers',
    :'connected' => :'connected',
    :'imessage' => :'imessage',
    :'sandbox' => :'sandbox'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 144

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



59
60
61
62
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



49
50
51
52
53
54
55
56
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 49

def self.openapi_types
  {
    :'numbers' => :'Array<OwnedPhoneNumber>',
    :'connected' => :'Array<ListPhoneNumbers200ResponseConnectedInner>',
    :'imessage' => :'Array<ImessageSenderLifecycle>',
    :'sandbox' => :'ListPhoneNumbers200ResponseSandbox'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



120
121
122
123
124
125
126
127
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 120

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      numbers == o.numbers &&
      connected == o.connected &&
      imessage == o.imessage &&
      sandbox == o.sandbox
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


131
132
133
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 131

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



137
138
139
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 137

def hash
  [numbers, connected, imessage, sandbox].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



105
106
107
108
109
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 105

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 166

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



113
114
115
116
# File 'lib/zernio-sdk/models/list_phone_numbers200_response.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end