Class: Zernio::ListSequences200ResponseSequencesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListSequences200ResponseSequencesInner
- Defined in:
- lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_name ⇒ Object
Display name of the sending account.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#exit_on_reply ⇒ Object
Returns the value of attribute exit_on_reply.
-
#exit_on_unsubscribe ⇒ Object
Returns the value of attribute exit_on_unsubscribe.
-
#id ⇒ Object
Returns the value of attribute id.
-
#message_preview ⇒ Object
First step template name or message text snippet.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#status ⇒ Object
Returns the value of attribute status.
-
#steps_count ⇒ Object
Returns the value of attribute steps_count.
-
#total_completed ⇒ Object
Returns the value of attribute total_completed.
-
#total_enrolled ⇒ Object
Returns the value of attribute total_enrolled.
-
#total_exited ⇒ Object
Returns the value of attribute total_exited.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListSequences200ResponseSequencesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListSequences200ResponseSequencesInner
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListSequences200ResponseSequencesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListSequences200ResponseSequencesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_name') self.account_name = attributes[:'account_name'] end if attributes.key?(:'message_preview') self. = attributes[:'message_preview'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'steps_count') self.steps_count = attributes[:'steps_count'] end if attributes.key?(:'exit_on_reply') self.exit_on_reply = attributes[:'exit_on_reply'] end if attributes.key?(:'exit_on_unsubscribe') self.exit_on_unsubscribe = attributes[:'exit_on_unsubscribe'] end if attributes.key?(:'total_enrolled') self.total_enrolled = attributes[:'total_enrolled'] end if attributes.key?(:'total_completed') self.total_completed = attributes[:'total_completed'] end if attributes.key?(:'total_exited') self.total_exited = attributes[:'total_exited'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
26 27 28 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 26 def account_id @account_id end |
#account_name ⇒ Object
Display name of the sending account
29 30 31 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 29 def account_name @account_name end |
#created_at ⇒ Object
Returns the value of attribute created_at.
48 49 50 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 48 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 22 def description @description end |
#exit_on_reply ⇒ Object
Returns the value of attribute exit_on_reply.
38 39 40 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 38 def exit_on_reply @exit_on_reply end |
#exit_on_unsubscribe ⇒ Object
Returns the value of attribute exit_on_unsubscribe.
40 41 42 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 40 def exit_on_unsubscribe @exit_on_unsubscribe end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 18 def id @id end |
#message_preview ⇒ Object
First step template name or message text snippet
32 33 34 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 32 def @message_preview end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 20 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
24 25 26 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 24 def platform @platform end |
#status ⇒ Object
Returns the value of attribute status.
34 35 36 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 34 def status @status end |
#steps_count ⇒ Object
Returns the value of attribute steps_count.
36 37 38 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 36 def steps_count @steps_count end |
#total_completed ⇒ Object
Returns the value of attribute total_completed.
44 45 46 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 44 def total_completed @total_completed end |
#total_enrolled ⇒ Object
Returns the value of attribute total_enrolled.
42 43 44 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 42 def total_enrolled @total_enrolled end |
#total_exited ⇒ Object
Returns the value of attribute total_exited.
46 47 48 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 46 def total_exited @total_exited end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
94 95 96 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 94 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 99 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 73 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'platform' => :'platform', :'account_id' => :'accountId', :'account_name' => :'accountName', :'message_preview' => :'messagePreview', :'status' => :'status', :'steps_count' => :'stepsCount', :'exit_on_reply' => :'exitOnReply', :'exit_on_unsubscribe' => :'exitOnUnsubscribe', :'total_enrolled' => :'totalEnrolled', :'total_completed' => :'totalCompleted', :'total_exited' => :'totalExited', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 125 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 104 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'platform' => :'String', :'account_id' => :'String', :'account_name' => :'String', :'message_preview' => :'String', :'status' => :'String', :'steps_count' => :'Integer', :'exit_on_reply' => :'Boolean', :'exit_on_unsubscribe' => :'Boolean', :'total_enrolled' => :'Integer', :'total_completed' => :'Integer', :'total_exited' => :'Integer', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && platform == o.platform && account_id == o.account_id && account_name == o.account_name && == o. && status == o.status && steps_count == o.steps_count && exit_on_reply == o.exit_on_reply && exit_on_unsubscribe == o.exit_on_unsubscribe && total_enrolled == o.total_enrolled && total_completed == o.total_completed && total_exited == o.total_exited && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 264 def hash [id, name, description, platform, account_id, account_name, , status, steps_count, exit_on_reply, exit_on_unsubscribe, total_enrolled, total_completed, total_exited, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
209 210 211 212 213 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 209 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 |
# File 'lib/zernio-sdk/models/list_sequences200_response_sequences_inner.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["draft", "active", "paused"]) return false unless status_validator.valid?(@status) true end |