Class: Zernio::ListWhatsAppAccountEvents200ResponseEventsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListWhatsAppAccountEvents200ResponseEventsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWhatsAppAccountEvents200ResponseEventsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWhatsAppAccountEvents200ResponseEventsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'detail')
    self.detail = attributes[:'detail']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#account_idObject

WhatsApp social account the event belongs to



21
22
23
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 21

def 
  @account_id
end

#created_atObject

Returns the value of attribute created_at.



32
33
34
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 32

def created_at
  @created_at
end

#detailObject

Returns the value of attribute detail.



30
31
32
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 30

def detail
  @detail
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 18

def id
  @id
end

#severityObject

Returns the value of attribute severity.



26
27
28
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 26

def severity
  @severity
end

#titleObject

Returns the value of attribute title.



28
29
30
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 28

def title
  @title
end

#typeObject

Event kind, e.g. template_approved, template_rejected, account_restricted, account_disconnected



24
25
26
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 24

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 57

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'type' => :'type',
    :'severity' => :'severity',
    :'title' => :'title',
    :'detail' => :'detail',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 93

def self.openapi_nullable
  Set.new([
    :'detail',
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 80

def self.openapi_types
  {
    :'id' => :'String',
    :'account_id' => :'String',
    :'type' => :'String',
    :'severity' => :'String',
    :'title' => :'String',
    :'detail' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
183
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      type == o.type &&
      severity == o.severity &&
      title == o.title &&
      detail == o.detail &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 193

def hash
  [id, , type, severity, title, detail, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
# File 'lib/zernio-sdk/models/list_whats_app_account_events200_response_events_inner.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  severity_validator = EnumAttributeValidator.new('String', ["info", "success", "warning", "critical"])
  return false unless severity_validator.valid?(@severity)
  true
end