Class: Zernio::ListWhatsAppConversions200ResponseEventsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListWhatsAppConversions200ResponseEventsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWhatsAppConversions200ResponseEventsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWhatsAppConversions200ResponseEventsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'event_name')
    self.event_name = attributes[:'event_name']
  end

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  end

  if attributes.key?(:'events_received')
    self.events_received = attributes[:'events_received']
  end

  if attributes.key?(:'events_failed')
    self.events_failed = attributes[:'events_failed']
  end

  if attributes.key?(:'trace_id')
    self.trace_id = attributes[:'trace_id']
  end

  if attributes.key?(:'duration_ms')
    self.duration_ms = attributes[:'duration_ms']
  end
end

Instance Attribute Details

#conversation_idObject

Returns the value of attribute conversation_id.



24
25
26
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 24

def conversation_id
  @conversation_id
end

#duration_msObject

Returns the value of attribute duration_ms.



35
36
37
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 35

def duration_ms
  @duration_ms
end

#event_nameObject

One of LeadSubmitted, Purchase, AddToCart, InitiateCheckout, ViewContent.



22
23
24
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 22

def event_name
  @event_name
end

#events_failedObject

Number of events Meta rejected (usually 0).



30
31
32
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 30

def events_failed
  @events_failed
end

#events_receivedObject

Number of events Meta accepted on this send (usually 1).



27
28
29
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 27

def events_received
  @events_received
end

#timestampObject

When the event was sent to Meta.



19
20
21
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 19

def timestamp
  @timestamp
end

#trace_idObject

Meta fbtrace_id for cross-referencing in Events Manager.



33
34
35
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 33

def trace_id
  @trace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 38

def self.attribute_map
  {
    :'timestamp' => :'timestamp',
    :'event_name' => :'eventName',
    :'conversation_id' => :'conversationId',
    :'events_received' => :'eventsReceived',
    :'events_failed' => :'eventsFailed',
    :'trace_id' => :'traceId',
    :'duration_ms' => :'durationMs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
78
79
80
81
82
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 74

def self.openapi_nullable
  Set.new([
    :'conversation_id',
    :'events_received',
    :'events_failed',
    :'trace_id',
    :'duration_ms'
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 61

def self.openapi_types
  {
    :'timestamp' => :'Time',
    :'event_name' => :'String',
    :'conversation_id' => :'String',
    :'events_received' => :'Integer',
    :'events_failed' => :'Integer',
    :'trace_id' => :'String',
    :'duration_ms' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 146

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      timestamp == o.timestamp &&
      event_name == o.event_name &&
      conversation_id == o.conversation_id &&
      events_received == o.events_received &&
      events_failed == o.events_failed &&
      trace_id == o.trace_id &&
      duration_ms == o.duration_ms
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 166

def hash
  [timestamp, event_name, conversation_id, events_received, events_failed, trace_id, duration_ms].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
# File 'lib/zernio-sdk/models/list_whats_app_conversions200_response_events_inner.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end