Class: Zernio::ListWhatsAppFlowResponses200ResponseResponsesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListWhatsAppFlowResponses200ResponseResponsesInner
- Defined in:
- lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb
Instance Attribute Summary collapse
-
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
-
#data ⇒ Object
Submitted field values (flow_token removed).
-
#flow_token ⇒ Object
Returns the value of attribute flow_token.
-
#from ⇒ Object
Sender wa_id / phone.
-
#id ⇒ Object
Message ID.
-
#raw ⇒ Object
Raw response_json string.
-
#received_at ⇒ Object
Returns the value of attribute received_at.
-
#sender_name ⇒ Object
Returns the value of attribute sender_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListWhatsAppFlowResponses200ResponseResponsesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListWhatsAppFlowResponses200ResponseResponsesInner
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWhatsAppFlowResponses200ResponseResponsesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWhatsAppFlowResponses200ResponseResponsesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'received_at') self.received_at = attributes[:'received_at'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'sender_name') self.sender_name = attributes[:'sender_name'] end if attributes.key?(:'conversation_id') self.conversation_id = attributes[:'conversation_id'] end if attributes.key?(:'flow_token') self.flow_token = attributes[:'flow_token'] end if attributes.key?(:'data') self.data = attributes[:'data'] end if attributes.key?(:'raw') self.raw = attributes[:'raw'] end end |
Instance Attribute Details
#conversation_id ⇒ Object
Returns the value of attribute conversation_id.
28 29 30 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 28 def conversation_id @conversation_id end |
#data ⇒ Object
Submitted field values (flow_token removed)
33 34 35 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 33 def data @data end |
#flow_token ⇒ Object
Returns the value of attribute flow_token.
30 31 32 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 30 def flow_token @flow_token end |
#from ⇒ Object
Sender wa_id / phone
24 25 26 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 24 def from @from end |
#id ⇒ Object
Message ID
19 20 21 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 19 def id @id end |
#raw ⇒ Object
Raw response_json string
36 37 38 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 36 def raw @raw end |
#received_at ⇒ Object
Returns the value of attribute received_at.
21 22 23 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 21 def received_at @received_at end |
#sender_name ⇒ Object
Returns the value of attribute sender_name.
26 27 28 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 26 def sender_name @sender_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 39 def self.attribute_map { :'id' => :'id', :'received_at' => :'receivedAt', :'from' => :'from', :'sender_name' => :'senderName', :'conversation_id' => :'conversationId', :'flow_token' => :'flowToken', :'data' => :'data', :'raw' => :'raw' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 81 82 83 84 85 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 77 def self.openapi_nullable Set.new([ :'from', :'sender_name', :'conversation_id', :'flow_token', :'raw' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 63 def self.openapi_types { :'id' => :'String', :'received_at' => :'Time', :'from' => :'String', :'sender_name' => :'String', :'conversation_id' => :'String', :'flow_token' => :'String', :'data' => :'Object', :'raw' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && received_at == o.received_at && from == o.from && sender_name == o.sender_name && conversation_id == o.conversation_id && flow_token == o.flow_token && data == o.data && raw == o.raw end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 174 def hash [id, received_at, from, sender_name, conversation_id, flow_token, data, raw].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 |
# File 'lib/zernio-sdk/models/list_whats_app_flow_responses200_response_responses_inner.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |