Class: Zernio::ListWhatsAppFlowVersions200ResponseVersionsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListWhatsAppFlowVersions200ResponseVersionsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWhatsAppFlowVersions200ResponseVersionsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWhatsAppFlowVersions200ResponseVersionsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flow_id')
    self.flow_id = attributes[:'flow_id']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'parent_flow_id')
    self.parent_flow_id = attributes[:'parent_flow_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'missing')
    self.missing = attributes[:'missing']
  end
end

Instance Attribute Details

#flow_idObject

Returns the value of attribute flow_id.



18
19
20
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 18

def flow_id
  @flow_id
end

#missingObject

True when Meta no longer has this flow



29
30
31
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 29

def missing
  @missing
end

#nameObject

Returns the value of attribute name.



24
25
26
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 24

def name
  @name
end

#parent_flow_idObject

Returns the value of attribute parent_flow_id.



22
23
24
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 22

def parent_flow_id
  @parent_flow_id
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 26

def status
  @status
end

#versionObject

Returns the value of attribute version.



20
21
22
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 20

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 32

def self.attribute_map
  {
    :'flow_id' => :'flowId',
    :'version' => :'version',
    :'parent_flow_id' => :'parentFlowId',
    :'name' => :'name',
    :'status' => :'status',
    :'missing' => :'missing'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 158

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
72
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 66

def self.openapi_nullable
  Set.new([
    :'parent_flow_id',
    :'name',
    :'status',
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 54

def self.openapi_types
  {
    :'flow_id' => :'String',
    :'version' => :'Integer',
    :'parent_flow_id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'missing' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



132
133
134
135
136
137
138
139
140
141
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 132

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flow_id == o.flow_id &&
      version == o.version &&
      parent_flow_id == o.parent_flow_id &&
      name == o.name &&
      status == o.status &&
      missing == o.missing
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 145

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 151

def hash
  [flow_id, version, parent_flow_id, name, status, missing].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
# File 'lib/zernio-sdk/models/list_whats_app_flow_versions200_response_versions_inner.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end