Class: Zernio::ListWhatsAppNumberCountries200ResponseCountriesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListWhatsAppNumberCountries200ResponseCountriesInner
- Defined in:
- lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#code ⇒ Object
ISO 3166-1 alpha-2.
-
#monthly_cents ⇒ Object
Price a NEW number in this country costs per month, in cents, for the default (first) type.
-
#needs_kyc ⇒ Object
Returns the value of attribute needs_kyc.
-
#outbound_calling_available ⇒ Object
Returns the value of attribute outbound_calling_available.
-
#tier ⇒ Object
Returns the value of attribute tier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListWhatsAppNumberCountries200ResponseCountriesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListWhatsAppNumberCountries200ResponseCountriesInner
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListWhatsAppNumberCountries200ResponseCountriesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListWhatsAppNumberCountries200ResponseCountriesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'code') self.code = attributes[:'code'] end if attributes.key?(:'tier') self.tier = attributes[:'tier'] end if attributes.key?(:'monthly_cents') self.monthly_cents = attributes[:'monthly_cents'] end if attributes.key?(:'needs_kyc') self.needs_kyc = attributes[:'needs_kyc'] end if attributes.key?(:'outbound_calling_available') self.outbound_calling_available = attributes[:'outbound_calling_available'] end end |
Instance Attribute Details
#code ⇒ Object
ISO 3166-1 alpha-2
19 20 21 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 19 def code @code end |
#monthly_cents ⇒ Object
Price a NEW number in this country costs per month, in cents, for the default (first) type. 1.5x the carrier's monthly cost, rounded up to a whole dollar, minimum $3.
24 25 26 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 24 def monthly_cents @monthly_cents end |
#needs_kyc ⇒ Object
Returns the value of attribute needs_kyc.
26 27 28 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 26 def needs_kyc @needs_kyc end |
#outbound_calling_available ⇒ Object
Returns the value of attribute outbound_calling_available.
28 29 30 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 28 def outbound_calling_available @outbound_calling_available end |
#tier ⇒ Object
Returns the value of attribute tier.
21 22 23 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 21 def tier @tier end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 53 def self.attribute_map { :'code' => :'code', :'tier' => :'tier', :'monthly_cents' => :'monthlyCents', :'needs_kyc' => :'needsKyc', :'outbound_calling_available' => :'outboundCallingAvailable' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 74 def self.openapi_types { :'code' => :'String', :'tier' => :'Integer', :'monthly_cents' => :'Integer', :'needs_kyc' => :'Boolean', :'outbound_calling_available' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 162 163 164 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 156 def ==(o) return true if self.equal?(o) self.class == o.class && code == o.code && tier == o.tier && monthly_cents == o.monthly_cents && needs_kyc == o.needs_kyc && outbound_calling_available == o.outbound_calling_available end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 174 def hash [code, tier, monthly_cents, needs_kyc, outbound_calling_available].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 |
# File 'lib/zernio-sdk/models/list_whats_app_number_countries200_response_countries_inner.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' tier_validator = EnumAttributeValidator.new('Integer', [1, 2, 3, 4]) return false unless tier_validator.valid?(@tier) true end |