Class: Zernio::MetaFeedUpload

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/meta_feed_upload.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetaFeedUpload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::MetaFeedUpload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::MetaFeedUpload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'error_count')
    self.error_count = attributes[:'error_count']
  end

  if attributes.key?(:'warning_count')
    self.warning_count = attributes[:'warning_count']
  end

  if attributes.key?(:'items_detected')
    self.items_detected = attributes[:'items_detected']
  end

  if attributes.key?(:'items_deleted')
    self.items_deleted = attributes[:'items_deleted']
  end
end

Instance Attribute Details

#end_timeObject

Returns the value of attribute end_time.



24
25
26
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 24

def end_time
  @end_time
end

#error_countObject

Returns the value of attribute error_count.



26
27
28
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 26

def error_count
  @error_count
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 18

def id
  @id
end

#items_deletedObject

Returns the value of attribute items_deleted.



32
33
34
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 32

def items_deleted
  @items_deleted
end

#items_detectedObject

Returns the value of attribute items_detected.



30
31
32
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 30

def items_detected
  @items_detected
end

#start_timeObject

Returns the value of attribute start_time.



22
23
24
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 22

def start_time
  @start_time
end

#urlObject

Returns the value of attribute url.



20
21
22
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 20

def url
  @url
end

#warning_countObject

Returns the value of attribute warning_count.



28
29
30
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 28

def warning_count
  @warning_count
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'url' => :'url',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'error_count' => :'errorCount',
    :'warning_count' => :'warningCount',
    :'items_detected' => :'itemsDetected',
    :'items_deleted' => :'itemsDeleted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 175

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 73

def self.openapi_nullable
  Set.new([
    :'url',
    :'start_time',
    :'end_time',
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 59

def self.openapi_types
  {
    :'id' => :'String',
    :'url' => :'String',
    :'start_time' => :'String',
    :'end_time' => :'String',
    :'error_count' => :'Integer',
    :'warning_count' => :'Integer',
    :'items_detected' => :'Integer',
    :'items_deleted' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      url == o.url &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      error_count == o.error_count &&
      warning_count == o.warning_count &&
      items_detected == o.items_detected &&
      items_deleted == o.items_deleted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


162
163
164
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 162

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



168
169
170
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 168

def hash
  [id, url, start_time, end_time, error_count, warning_count, items_detected, items_deleted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



132
133
134
135
136
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 132

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 197

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
# File 'lib/zernio-sdk/models/meta_feed_upload.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end