Class: Zernio::MetaLeadFormLegalContent

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/meta_lead_form_legal_content.rb

Overview

Privacy policy and custom disclaimer as Meta stores them.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetaLeadFormLegalContent

Initializes the object



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::MetaLeadFormLegalContent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::MetaLeadFormLegalContent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'privacy_policy')
    self.privacy_policy = attributes[:'privacy_policy']
  end

  if attributes.key?(:'custom_disclaimer')
    self.custom_disclaimer = attributes[:'custom_disclaimer']
  end
end

Instance Attribute Details

#custom_disclaimer ⇒ Object

Set in Meta form builder only; there is no create parameter for it.



24
25
26
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 24

def custom_disclaimer
  @custom_disclaimer
end

#id ⇒ Object

Returns the value of attribute id.



19
20
21
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 19

def id
  @id
end

#privacy_policy ⇒ Object

Returns the value of attribute privacy_policy.



21
22
23
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 21

def privacy_policy
  @privacy_policy
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



36
37
38
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 36

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 41

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 27

def self.attribute_map
  {
    :'id' => :'id',
    :'privacy_policy' => :'privacy_policy',
    :'custom_disclaimer' => :'custom_disclaimer'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 129

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



55
56
57
58
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



46
47
48
49
50
51
52
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 46

def self.openapi_types
  {
    :'id' => :'String',
    :'privacy_policy' => :'MetaLeadFormLegalContentPrivacyPolicy',
    :'custom_disclaimer' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 106

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      privacy_policy == o.privacy_policy &&
      custom_disclaimer == o.custom_disclaimer
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


116
117
118
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 116

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



122
123
124
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 122

def hash
  [id, privacy_policy, custom_disclaimer].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



91
92
93
94
95
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 91

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 151

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



99
100
101
102
# File 'lib/zernio-sdk/models/meta_lead_form_legal_content.rb', line 99

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end