Class: Zernio::MetaLeadFormThankYouPage

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb

Overview

The form's single ending page, mirroring the thankYou* create fields. Meta has exactly one per form; there is no multiple-ending-page API (thank_you_pages and ending_pages are not Graph fields).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetaLeadFormThankYouPage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::MetaLeadFormThankYouPage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::MetaLeadFormThankYouPage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'button_text')
    self.button_text = attributes[:'button_text']
  end

  if attributes.key?(:'button_type')
    self.button_type = attributes[:'button_type']
  end

  if attributes.key?(:'website_url')
    self.website_url = attributes[:'website_url']
  end

  if attributes.key?(:'enable_messenger')
    self.enable_messenger = attributes[:'enable_messenger']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'lead_gen_use_case')
    self.lead_gen_use_case = attributes[:'lead_gen_use_case']
  end

  if attributes.key?(:'business_phone_number')
    self.business_phone_number = attributes[:'business_phone_number']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  end
end

Instance Attribute Details

#bodyObject

Returns the value of attribute body.



23
24
25
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 23

def body
  @body
end

#business_phone_numberObject

Returns the value of attribute business_phone_number.



37
38
39
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 37

def business_phone_number
  @business_phone_number
end

#button_textObject

Returns the value of attribute button_text.



25
26
27
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 25

def button_text
  @button_text
end

#button_typeObject

Returns the value of attribute button_type.



27
28
29
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 27

def button_type
  @button_type
end

#country_codeObject

Returns the value of attribute country_code.



39
40
41
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 39

def country_code
  @country_code
end

#enable_messengerObject

Returns the value of attribute enable_messenger.



31
32
33
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 31

def enable_messenger
  @enable_messenger
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 19

def id
  @id
end

#lead_gen_use_caseObject

Returns the value of attribute lead_gen_use_case.



35
36
37
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 35

def lead_gen_use_case
  @lead_gen_use_case
end

#statusObject

Returns the value of attribute status.



33
34
35
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 33

def status
  @status
end

#titleObject

Returns the value of attribute title.



21
22
23
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 21

def title
  @title
end

#website_urlObject

Returns the value of attribute website_url.



29
30
31
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 29

def website_url
  @website_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



59
60
61
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 59

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 64

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 42

def self.attribute_map
  {
    :'id' => :'id',
    :'title' => :'title',
    :'body' => :'body',
    :'button_text' => :'button_text',
    :'button_type' => :'button_type',
    :'website_url' => :'website_url',
    :'enable_messenger' => :'enable_messenger',
    :'status' => :'status',
    :'lead_gen_use_case' => :'lead_gen_use_case',
    :'business_phone_number' => :'business_phone_number',
    :'country_code' => :'country_code'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 69

def self.openapi_types
  {
    :'id' => :'String',
    :'title' => :'String',
    :'body' => :'String',
    :'button_text' => :'String',
    :'button_type' => :'String',
    :'website_url' => :'String',
    :'enable_messenger' => :'Boolean',
    :'status' => :'String',
    :'lead_gen_use_case' => :'String',
    :'business_phone_number' => :'String',
    :'country_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      title == o.title &&
      body == o.body &&
      button_text == o.button_text &&
      button_type == o.button_type &&
      website_url == o.website_url &&
      enable_messenger == o.enable_messenger &&
      status == o.status &&
      lead_gen_use_case == o.lead_gen_use_case &&
      business_phone_number == o.business_phone_number &&
      country_code == o.country_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 193

def hash
  [id, title, body, button_text, button_type, website_url, enable_messenger, status, lead_gen_use_case, business_phone_number, country_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
# File 'lib/zernio-sdk/models/meta_lead_form_thank_you_page.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end