Class: Zernio::MetaPromotion

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/meta_promotion.rb

Overview

Meta explicit Promotion offer. Maps to creative_sourcing_spec.promotion_metadata_spec with promotion_source ADVERTISER_INPUT. Dates become Unix seconds. Send null to omit an explicit offer on a new creative or remove it when rebuilding. Creation success alone does not confirm application: inspect promotionStatus in the response.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetaPromotion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::MetaPromotion` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::MetaPromotion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'code')
    self.code = attributes[:'code']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end
end

Instance Attribute Details

#code ⇒ Object

Optional promotion code.



26
27
28
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 26

def code
  @code
end

#end_date ⇒ Object

Optional ISO 8601 end timestamp with a timezone offset or Z. Must be after startDate when both are set.



32
33
34
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 32

def end_date
  @end_date
end

#start_date ⇒ Object

Optional ISO 8601 start timestamp with a timezone offset or Z.



29
30
31
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 29

def start_date
  @start_date
end

#type ⇒ Object

Promotion type accepted by Meta. PERCENTAGE_OFF values cannot exceed 100.



20
21
22
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 20

def type
  @type
end

#value ⇒ Object

Nonnegative promotion value passed to Meta unchanged. AMOUNT_OFF units are not confirmed, including major versus minor currency units. For PERCENTAGE_OFF this is the percentage discount, at most 100.



23
24
25
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 23

def value
  @value
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



68
69
70
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 57

def self.attribute_map
  {
    :'type' => :'type',
    :'value' => :'value',
    :'code' => :'code',
    :'start_date' => :'startDate',
    :'end_date' => :'endDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



89
90
91
92
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



78
79
80
81
82
83
84
85
86
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 78

def self.openapi_types
  {
    :'type' => :'String',
    :'value' => :'Float',
    :'code' => :'String',
    :'start_date' => :'Time',
    :'end_date' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



212
213
214
215
216
217
218
219
220
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      value == o.value &&
      code == o.code &&
      start_date == o.start_date &&
      end_date == o.end_date
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 224

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



230
231
232
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 230

def hash
  [type, value, code, start_date, end_date].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  if @value < 0
    invalid_properties.push('invalid value for "value", must be greater than or equal to 0.')
  end

  if !@code.nil? && @code.to_s.length < 1
    invalid_properties.push('invalid value for "code", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



161
162
163
164
165
166
167
168
169
170
# File 'lib/zernio-sdk/models/meta_promotion.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["AMOUNT_OFF", "FREE_RETURN", "FREE_SHIPPING", "PERCENTAGE_OFF", "PROMO_CODE"])
  return false unless type_validator.valid?(@type)
  return false if @value.nil?
  return false if @value < 0
  return false if !@code.nil? && @code.to_s.length < 1
  true
end