Class: Zernio::OnWhatsAppAutomaticEventRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OnWhatsAppAutomaticEventRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 115

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::OnWhatsAppAutomaticEventRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::OnWhatsAppAutomaticEventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  end

  if attributes.key?(:'platform_message_id')
    self.platform_message_id = attributes[:'platform_message_id']
  end

  if attributes.key?(:'event_name')
    self.event_name = attributes[:'event_name']
  end

  if attributes.key?(:'ctwa_clid')
    self.ctwa_clid = attributes[:'ctwa_clid']
  end

  if attributes.key?(:'custom_data')
    self.custom_data = attributes[:'custom_data']
  end

  if attributes.key?(:'detected_at')
    self.detected_at = attributes[:'detected_at']
  end
end

Instance Attribute Details

#account_idObject

SocialAccount id of the WhatsApp number whose conversation was flagged.



25
26
27
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 25

def 
  @account_id
end

#conversation_idObject

Zernio conversation id, when the thread could be resolved.



28
29
30
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 28

def conversation_id
  @conversation_id
end

#ctwa_clidObject

Meta's CTWA click id, the Conversions API match key.



37
38
39
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 37

def ctwa_clid
  @ctwa_clid
end

#custom_dataObject

Returns the value of attribute custom_data.



39
40
41
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 39

def custom_data
  @custom_data
end

#detected_atObject

Returns the value of attribute detected_at.



41
42
43
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 41

def detected_at
  @detected_at
end

#eventObject

Returns the value of attribute event.



20
21
22
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 20

def event
  @event
end

#event_nameObject

Meta-detected event: LeadSubmitted | Purchase.



34
35
36
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 34

def event_name
  @event_name
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 18

def id
  @id
end

#platform_message_idObject

The wamid of the message Meta's analysis flagged.



31
32
33
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 31

def platform_message_id
  @platform_message_id
end

#timestampObject

Returns the value of attribute timestamp.



22
23
24
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 22

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 66

def self.attribute_map
  {
    :'id' => :'id',
    :'event' => :'event',
    :'timestamp' => :'timestamp',
    :'account_id' => :'accountId',
    :'conversation_id' => :'conversationId',
    :'platform_message_id' => :'platformMessageId',
    :'event_name' => :'eventName',
    :'ctwa_clid' => :'ctwaClid',
    :'custom_data' => :'customData',
    :'detected_at' => :'detectedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 229

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



108
109
110
111
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 108

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 92

def self.openapi_types
  {
    :'id' => :'String',
    :'event' => :'String',
    :'timestamp' => :'Time',
    :'account_id' => :'String',
    :'conversation_id' => :'String',
    :'platform_message_id' => :'String',
    :'event_name' => :'String',
    :'ctwa_clid' => :'String',
    :'custom_data' => :'OnWhatsAppAutomaticEventRequestCustomData',
    :'detected_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 199

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      event == o.event &&
      timestamp == o.timestamp &&
       == o. &&
      conversation_id == o.conversation_id &&
      platform_message_id == o.platform_message_id &&
      event_name == o.event_name &&
      ctwa_clid == o.ctwa_clid &&
      custom_data == o.custom_data &&
      detected_at == o.detected_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


216
217
218
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 216

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



222
223
224
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 222

def hash
  [id, event, timestamp, , conversation_id, platform_message_id, event_name, ctwa_clid, custom_data, detected_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 172

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
184
185
# File 'lib/zernio-sdk/models/on_whats_app_automatic_event_request.rb', line 180

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  event_validator = EnumAttributeValidator.new('String', ["whatsapp.automatic_event"])
  return false unless event_validator.valid?(@event)
  true
end