Class: Zernio::PreflightSmsRegistrationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::PreflightSmsRegistrationRequest
- Defined in:
- lib/zernio-sdk/models/preflight_sms_registration_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#brand ⇒ Object
Same shape as the registration
brand. -
#campaign ⇒ Object
Same shape as the registration
campaign. -
#messaging_brand_name ⇒ Object
Returns the value of attribute messaging_brand_name.
-
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
-
#registration_type ⇒ Object
Returns the value of attribute registration_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PreflightSmsRegistrationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PreflightSmsRegistrationRequest
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::PreflightSmsRegistrationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::PreflightSmsRegistrationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'registration_type') self.registration_type = attributes[:'registration_type'] else self.registration_type = nil end if attributes.key?(:'phone_numbers') if (value = attributes[:'phone_numbers']).is_a?(Array) self.phone_numbers = value end end if attributes.key?(:'brand') self.brand = attributes[:'brand'] else self.brand = nil end if attributes.key?(:'campaign') self.campaign = attributes[:'campaign'] else self.campaign = nil end if attributes.key?(:'messaging_brand_name') self.messaging_brand_name = attributes[:'messaging_brand_name'] end end |
Instance Attribute Details
#brand ⇒ Object
Same shape as the registration brand.
23 24 25 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 23 def brand @brand end |
#campaign ⇒ Object
Same shape as the registration campaign.
26 27 28 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 26 def campaign @campaign end |
#messaging_brand_name ⇒ Object
Returns the value of attribute messaging_brand_name.
28 29 30 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 28 def messaging_brand_name @messaging_brand_name end |
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
20 21 22 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 20 def phone_numbers @phone_numbers end |
#registration_type ⇒ Object
Returns the value of attribute registration_type.
18 19 20 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 18 def registration_type @registration_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 53 def self.attribute_map { :'registration_type' => :'registrationType', :'phone_numbers' => :'phoneNumbers', :'brand' => :'brand', :'campaign' => :'campaign', :'messaging_brand_name' => :'messagingBrandName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 252 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 74 def self.openapi_types { :'registration_type' => :'String', :'phone_numbers' => :'Array<String>', :'brand' => :'Object', :'campaign' => :'Object', :'messaging_brand_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && registration_type == o.registration_type && phone_numbers == o.phone_numbers && brand == o.brand && campaign == o.campaign && messaging_brand_name == o.messaging_brand_name end |
#eql?(o) ⇒ Boolean
239 240 241 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 239 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
245 246 247 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 245 def hash [registration_type, phone_numbers, brand, campaign, messaging_brand_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @registration_type.nil? invalid_properties.push('invalid value for "registration_type", registration_type cannot be nil.') end if @brand.nil? invalid_properties.push('invalid value for "brand", brand cannot be nil.') end if @campaign.nil? invalid_properties.push('invalid value for "campaign", campaign cannot be nil.') end if !@messaging_brand_name.nil? && @messaging_brand_name.to_s.length > 60 invalid_properties.push('invalid value for "messaging_brand_name", the character length must be smaller than or equal to 60.') end if !@messaging_brand_name.nil? && @messaging_brand_name.to_s.length < 2 invalid_properties.push('invalid value for "messaging_brand_name", the character length must be greater than or equal to 2.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 274 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zernio-sdk/models/preflight_sms_registration_request.rb', line 165 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @registration_type.nil? registration_type_validator = EnumAttributeValidator.new('String', ["standard_10dlc", "sole_prop_10dlc"]) return false unless registration_type_validator.valid?(@registration_type) return false if @brand.nil? return false if @campaign.nil? return false if !@messaging_brand_name.nil? && @messaging_brand_name.to_s.length > 60 return false if !@messaging_brand_name.nil? && @messaging_brand_name.to_s.length < 2 true end |