Class: Zernio::ProfilesApi
- Inherits:
-
Object
- Object
- Zernio::ProfilesApi
- Defined in:
- lib/zernio-sdk/api/profiles_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_profile(create_profile_request, opts = {}) ⇒ ProfileCreateResponse
Create profile Creates a new profile with a name, optional description, and color.
-
#create_profile_with_http_info(create_profile_request, opts = {}) ⇒ Array<(ProfileCreateResponse, Integer, Hash)>
Create profile Creates a new profile with a name, optional description, and color.
-
#delete_profile(profile_id, opts = {}) ⇒ ProfileDeleteResponse
Delete profile Permanently deletes a profile.
-
#delete_profile_with_http_info(profile_id, opts = {}) ⇒ Array<(ProfileDeleteResponse, Integer, Hash)>
Delete profile Permanently deletes a profile.
-
#get_profile(profile_id, opts = {}) ⇒ ProfileGetResponse
Get profile Returns a single profile by ID, including its name, color, and default status.
-
#get_profile_with_http_info(profile_id, opts = {}) ⇒ Array<(ProfileGetResponse, Integer, Hash)>
Get profile Returns a single profile by ID, including its name, color, and default status.
-
#initialize(api_client = ApiClient.default) ⇒ ProfilesApi
constructor
A new instance of ProfilesApi.
-
#list_profiles(opts = {}) ⇒ ProfilesListResponse
List profiles Returns profiles sorted by creation date.
-
#list_profiles_with_http_info(opts = {}) ⇒ Array<(ProfilesListResponse, Integer, Hash)>
List profiles Returns profiles sorted by creation date.
-
#update_profile(profile_id, update_profile_request, opts = {}) ⇒ ProfileUpdateResponse
Update profile Updates a profile's name, description, color, or default status.
-
#update_profile_with_http_info(profile_id, update_profile_request, opts = {}) ⇒ Array<(ProfileUpdateResponse, Integer, Hash)>
Update profile Updates a profile's name, description, color, or default status.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ProfilesApi
Returns a new instance of ProfilesApi.
19 20 21 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_profile(create_profile_request, opts = {}) ⇒ ProfileCreateResponse
Create profile Creates a new profile with a name, optional description, and color.
27 28 29 30 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 27 def create_profile(create_profile_request, opts = {}) data, _status_code, _headers = create_profile_with_http_info(create_profile_request, opts) data end |
#create_profile_with_http_info(create_profile_request, opts = {}) ⇒ Array<(ProfileCreateResponse, Integer, Hash)>
Create profile Creates a new profile with a name, optional description, and color.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 37 def create_profile_with_http_info(create_profile_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProfilesApi.create_profile ...' end # verify the required parameter 'create_profile_request' is set if @api_client.config.client_side_validation && create_profile_request.nil? fail ArgumentError, "Missing the required parameter 'create_profile_request' when calling ProfilesApi.create_profile" end # resource path local_var_path = '/v1/profiles' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_profile_request) # return_type return_type = opts[:debug_return_type] || 'ProfileCreateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ProfilesApi.create_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#create_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_profile(profile_id, opts = {}) ⇒ ProfileDeleteResponse
Delete profile Permanently deletes a profile. Active connected accounts block deletion (returns 400) - disconnect them first. Any remaining disconnected accounts and provisioned WhatsApp numbers are moved to another of your profiles (a new one is created only if needed), never deleted.
95 96 97 98 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 95 def delete_profile(profile_id, opts = {}) data, _status_code, _headers = delete_profile_with_http_info(profile_id, opts) data end |
#delete_profile_with_http_info(profile_id, opts = {}) ⇒ Array<(ProfileDeleteResponse, Integer, Hash)>
Delete profile Permanently deletes a profile. Active connected accounts block deletion (returns 400) - disconnect them first. Any remaining disconnected accounts and provisioned WhatsApp numbers are moved to another of your profiles (a new one is created only if needed), never deleted.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 105 def delete_profile_with_http_info(profile_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProfilesApi.delete_profile ...' end # verify the required parameter 'profile_id' is set if @api_client.config.client_side_validation && profile_id.nil? fail ArgumentError, "Missing the required parameter 'profile_id' when calling ProfilesApi.delete_profile" end # resource path local_var_path = '/v1/profiles/{profileId}'.sub('{' + 'profileId' + '}', CGI.escape(profile_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ProfileDeleteResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ProfilesApi.delete_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#delete_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_profile(profile_id, opts = {}) ⇒ ProfileGetResponse
Get profile Returns a single profile by ID, including its name, color, and default status.
158 159 160 161 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 158 def get_profile(profile_id, opts = {}) data, _status_code, _headers = get_profile_with_http_info(profile_id, opts) data end |
#get_profile_with_http_info(profile_id, opts = {}) ⇒ Array<(ProfileGetResponse, Integer, Hash)>
Get profile Returns a single profile by ID, including its name, color, and default status.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 168 def get_profile_with_http_info(profile_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProfilesApi.get_profile ...' end # verify the required parameter 'profile_id' is set if @api_client.config.client_side_validation && profile_id.nil? fail ArgumentError, "Missing the required parameter 'profile_id' when calling ProfilesApi.get_profile" end # resource path local_var_path = '/v1/profiles/{profileId}'.sub('{' + 'profileId' + '}', CGI.escape(profile_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ProfileGetResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ProfilesApi.get_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#get_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_profiles(opts = {}) ⇒ ProfilesListResponse
List profiles Returns profiles sorted by creation date. Use includeOverLimit=true to include profiles that exceed the plan limit.
221 222 223 224 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 221 def list_profiles(opts = {}) data, _status_code, _headers = list_profiles_with_http_info(opts) data end |
#list_profiles_with_http_info(opts = {}) ⇒ Array<(ProfilesListResponse, Integer, Hash)>
List profiles Returns profiles sorted by creation date. Use includeOverLimit=true to include profiles that exceed the plan limit.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 231 def list_profiles_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProfilesApi.list_profiles ...' end # resource path local_var_path = '/v1/profiles' # query parameters query_params = opts[:query_params] || {} query_params[:'includeOverLimit'] = opts[:'include_over_limit'] if !opts[:'include_over_limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ProfilesListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ProfilesApi.list_profiles", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#list_profiles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_profile(profile_id, update_profile_request, opts = {}) ⇒ ProfileUpdateResponse
Update profile Updates a profile's name, description, color, or default status.
282 283 284 285 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 282 def update_profile(profile_id, update_profile_request, opts = {}) data, _status_code, _headers = update_profile_with_http_info(profile_id, update_profile_request, opts) data end |
#update_profile_with_http_info(profile_id, update_profile_request, opts = {}) ⇒ Array<(ProfileUpdateResponse, Integer, Hash)>
Update profile Updates a profile's name, description, color, or default status.
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/zernio-sdk/api/profiles_api.rb', line 293 def update_profile_with_http_info(profile_id, update_profile_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ProfilesApi.update_profile ...' end # verify the required parameter 'profile_id' is set if @api_client.config.client_side_validation && profile_id.nil? fail ArgumentError, "Missing the required parameter 'profile_id' when calling ProfilesApi.update_profile" end # verify the required parameter 'update_profile_request' is set if @api_client.config.client_side_validation && update_profile_request.nil? fail ArgumentError, "Missing the required parameter 'update_profile_request' when calling ProfilesApi.update_profile" end # resource path local_var_path = '/v1/profiles/{profileId}'.sub('{' + 'profileId' + '}', CGI.escape(profile_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_profile_request) # return_type return_type = opts[:debug_return_type] || 'ProfileUpdateResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"ProfilesApi.update_profile", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ProfilesApi#update_profile\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |