Class: Zernio::QueryAdInsights200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::QueryAdInsights200Response
- Defined in:
- lib/zernio-sdk/models/query_ad_insights200_response.rb
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
TikTok responses only: the advertiser queried.
-
#customer_id ⇒ Object
Google responses only: the customer the query ran against.
-
#data ⇒ Object
Returns the value of attribute data.
-
#field_mask ⇒ Object
Google responses only: the selected fields echoed by Google.
-
#object_id ⇒ Object
Meta responses only.
-
#paging ⇒ Object
Returns the value of attribute paging.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueryAdInsights200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ QueryAdInsights200Response
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::QueryAdInsights200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::QueryAdInsights200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'object_id') self.object_id = attributes[:'object_id'] end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'field_mask') self.field_mask = attributes[:'field_mask'] end if attributes.key?(:'data') if (value = attributes[:'data']).is_a?(Array) self.data = value end end if attributes.key?(:'paging') self.paging = attributes[:'paging'] end end |
Instance Attribute Details
#ad_account_id ⇒ Object
TikTok responses only: the advertiser queried.
22 23 24 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 22 def ad_account_id @ad_account_id end |
#customer_id ⇒ Object
Google responses only: the customer the query ran against.
25 26 27 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 25 def customer_id @customer_id end |
#data ⇒ Object
Returns the value of attribute data.
30 31 32 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 30 def data @data end |
#field_mask ⇒ Object
Google responses only: the selected fields echoed by Google.
28 29 30 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 28 def field_mask @field_mask end |
#object_id ⇒ Object
Meta responses only.
19 20 21 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 19 def object_id @object_id end |
#paging ⇒ Object
Returns the value of attribute paging.
32 33 34 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 32 def paging @paging end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 35 def self.attribute_map { :'object_id' => :'objectId', :'ad_account_id' => :'adAccountId', :'customer_id' => :'customerId', :'field_mask' => :'fieldMask', :'data' => :'data', :'paging' => :'paging' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 161 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 73 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 69 def self.openapi_nullable Set.new([ :'field_mask', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 57 def self.openapi_types { :'object_id' => :'String', :'ad_account_id' => :'String', :'customer_id' => :'String', :'field_mask' => :'String', :'data' => :'Array<Object>', :'paging' => :'QueryAdInsights200ResponsePaging' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && object_id == o.object_id && ad_account_id == o.ad_account_id && customer_id == o.customer_id && field_mask == o.field_mask && data == o.data && paging == o.paging end |
#eql?(o) ⇒ Boolean
148 149 150 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 148 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 154 def hash [object_id, ad_account_id, customer_id, field_mask, data, paging].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 |
# File 'lib/zernio-sdk/models/query_ad_insights200_response.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |