Class: Zernio::QueueSchedule
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::QueueSchedule
- Defined in:
- lib/zernio-sdk/models/queue_schedule.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
Unique queue identifier.
-
#active ⇒ Object
Whether the queue is active.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#is_default ⇒ Object
Whether this is the default queue for the profile (used when no queueId specified).
-
#name ⇒ Object
Queue name (e.g., "Morning Posts", "Evening Content").
-
#profile_id ⇒ Object
Profile ID this queue belongs to.
-
#slots ⇒ Object
Returns the value of attribute slots.
-
#timezone ⇒ Object
IANA timezone (e.g., America/New_York).
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ QueueSchedule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ QueueSchedule
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::QueueSchedule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::QueueSchedule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] end if attributes.key?(:'slots') if (value = attributes[:'slots']).is_a?(Array) self.slots = value end end if attributes.key?(:'active') self.active = attributes[:'active'] end if attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#_id ⇒ Object
Unique queue identifier
19 20 21 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 19 def _id @_id end |
#active ⇒ Object
Whether the queue is active
33 34 35 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 33 def active @active end |
#created_at ⇒ Object
Returns the value of attribute created_at.
38 39 40 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 38 def created_at @created_at end |
#is_default ⇒ Object
Whether this is the default queue for the profile (used when no queueId specified)
36 37 38 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 36 def is_default @is_default end |
#name ⇒ Object
Queue name (e.g., "Morning Posts", "Evening Content")
25 26 27 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 25 def name @name end |
#profile_id ⇒ Object
Profile ID this queue belongs to
22 23 24 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 22 def profile_id @profile_id end |
#slots ⇒ Object
Returns the value of attribute slots.
30 31 32 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 30 def slots @slots end |
#timezone ⇒ Object
IANA timezone (e.g., America/New_York)
28 29 30 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 28 def timezone @timezone end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
40 41 42 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 40 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 43 def self.attribute_map { :'_id' => :'_id', :'profile_id' => :'profileId', :'name' => :'name', :'timezone' => :'timezone', :'slots' => :'slots', :'active' => :'active', :'is_default' => :'isDefault', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 189 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 68 def self.openapi_types { :'_id' => :'String', :'profile_id' => :'String', :'name' => :'String', :'timezone' => :'String', :'slots' => :'Array<QueueSlot>', :'active' => :'Boolean', :'is_default' => :'Boolean', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && profile_id == o.profile_id && name == o.name && timezone == o.timezone && slots == o.slots && active == o.active && is_default == o.is_default && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
176 177 178 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 176 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
182 183 184 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 182 def hash [_id, profile_id, name, timezone, slots, active, is_default, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 211 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 |
# File 'lib/zernio-sdk/models/queue_schedule.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |