Class: Zernio::QueueSlot

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/queue_slot.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ QueueSlot

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/queue_slot.rb', line 58

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::QueueSlot` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::QueueSlot`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'day_of_week')
    self.day_of_week = attributes[:'day_of_week']
  end

  if attributes.key?(:'time')
    self.time = attributes[:'time']
  end
end

Instance Attribute Details

#day_of_weekObject

Day of week (0=Sunday, 6=Saturday)



19
20
21
# File 'lib/zernio-sdk/models/queue_slot.rb', line 19

def day_of_week
  @day_of_week
end

#timeObject

Time in HH:mm format (24-hour)



22
23
24
# File 'lib/zernio-sdk/models/queue_slot.rb', line 22

def time
  @time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/zernio-sdk/models/queue_slot.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/zernio-sdk/models/queue_slot.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
# File 'lib/zernio-sdk/models/queue_slot.rb', line 25

def self.attribute_map
  {
    :'day_of_week' => :'dayOfWeek',
    :'time' => :'time'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/zernio-sdk/models/queue_slot.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
# File 'lib/zernio-sdk/models/queue_slot.rb', line 51

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
# File 'lib/zernio-sdk/models/queue_slot.rb', line 43

def self.openapi_types
  {
    :'day_of_week' => :'Integer',
    :'time' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



147
148
149
150
151
152
# File 'lib/zernio-sdk/models/queue_slot.rb', line 147

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      day_of_week == o.day_of_week &&
      time == o.time
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/zernio-sdk/models/queue_slot.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/zernio-sdk/models/queue_slot.rb', line 162

def hash
  [day_of_week, time].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zernio-sdk/models/queue_slot.rb', line 83

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@day_of_week.nil? && @day_of_week > 6
    invalid_properties.push('invalid value for "day_of_week", must be smaller than or equal to 6.')
  end

  if !@day_of_week.nil? && @day_of_week < 0
    invalid_properties.push('invalid value for "day_of_week", must be greater than or equal to 0.')
  end

  pattern = Regexp.new(/^([0-1][0-9]|2[0-3]):[0-5][0-9]$/)
  if !@time.nil? && @time !~ pattern
    invalid_properties.push("invalid value for \"time\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/zernio-sdk/models/queue_slot.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



104
105
106
107
108
109
110
# File 'lib/zernio-sdk/models/queue_slot.rb', line 104

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@day_of_week.nil? && @day_of_week > 6
  return false if !@day_of_week.nil? && @day_of_week < 0
  return false if !@time.nil? && @time !~ Regexp.new(/^([0-1][0-9]|2[0-3]):[0-5][0-9]$/)
  true
end