Class: Zernio::RemoveAdGroupAssetsRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/remove_ad_group_assets_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RemoveAdGroupAssetsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::RemoveAdGroupAssetsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::RemoveAdGroupAssetsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'asset_resource_names')
    if (value = attributes[:'asset_resource_names']).is_a?(Array)
      self.asset_resource_names = value
    end
  else
    self.asset_resource_names = nil
  end

  if attributes.key?(:'ad_group_asset_resource_names')
    if (value = attributes[:'ad_group_asset_resource_names']).is_a?(Array)
      self.ad_group_asset_resource_names = value
    end
  else
    self.ad_group_asset_resource_names = nil
  end
end

Instance Attribute Details

#account_idObject

Zernio Google Ads connection id.



19
20
21
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 19

def 
  @account_id
end

#ad_group_asset_resource_namesObject

Returns the value of attribute ad_group_asset_resource_names.



26
27
28
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 26

def ad_group_asset_resource_names
  @ad_group_asset_resource_names
end

#asset_resource_namesObject

Returns the value of attribute asset_resource_names.



24
25
26
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 24

def asset_resource_names
  @asset_resource_names
end

#customer_idObject

Google customer id without dashes. Required when the connection has multiple customers.



22
23
24
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 22

def customer_id
  @customer_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



39
40
41
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 39

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



44
45
46
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 44

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 29

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'customer_id' => :'customerId',
    :'asset_resource_names' => :'assetResourceNames',
    :'ad_group_asset_resource_names' => :'adGroupAssetResourceNames'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



59
60
61
62
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 59

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



49
50
51
52
53
54
55
56
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 49

def self.openapi_types
  {
    :'account_id' => :'String',
    :'customer_id' => :'String',
    :'asset_resource_names' => :'Array<String>',
    :'ad_group_asset_resource_names' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      customer_id == o.customer_id &&
      asset_resource_names == o.asset_resource_names &&
      ad_group_asset_resource_names == o.ad_group_asset_resource_names
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 236

def hash
  [, customer_id, asset_resource_names, ad_group_asset_resource_names].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  pattern = Regexp.new(/^[a-fA-F0-9]{24}$/)
  if @account_id !~ pattern
    invalid_properties.push("invalid value for \"account_id\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^\d+$/)
  if !@customer_id.nil? && @customer_id !~ pattern
    invalid_properties.push("invalid value for \"customer_id\", must conform to the pattern #{pattern}.")
  end

  if @asset_resource_names.nil?
    invalid_properties.push('invalid value for "asset_resource_names", asset_resource_names cannot be nil.')
  end

  if @asset_resource_names.length < 1
    invalid_properties.push('invalid value for "asset_resource_names", number of items must be greater than or equal to 1.')
  end

  if @ad_group_asset_resource_names.nil?
    invalid_properties.push('invalid value for "ad_group_asset_resource_names", ad_group_asset_resource_names cannot be nil.')
  end

  if @ad_group_asset_resource_names.length < 1
    invalid_properties.push('invalid value for "ad_group_asset_resource_names", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
156
157
# File 'lib/zernio-sdk/models/remove_ad_group_assets_request.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @account_id !~ Regexp.new(/^[a-fA-F0-9]{24}$/)
  return false if !@customer_id.nil? && @customer_id !~ Regexp.new(/^\d+$/)
  return false if @asset_resource_names.nil?
  return false if @asset_resource_names.length < 1
  return false if @ad_group_asset_resource_names.nil?
  return false if @ad_group_asset_resource_names.length < 1
  true
end