Class: Zernio::ReplyToInboxPostRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/reply_to_inbox_post_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReplyToInboxPostRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ReplyToInboxPostRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ReplyToInboxPostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'attachment_url')
    self.attachment_url = attributes[:'attachment_url']
  end

  if attributes.key?(:'comment_id')
    self.comment_id = attributes[:'comment_id']
  end

  if attributes.key?(:'parent_cid')
    self.parent_cid = attributes[:'parent_cid']
  end

  if attributes.key?(:'root_uri')
    self.root_uri = attributes[:'root_uri']
  end

  if attributes.key?(:'root_cid')
    self.root_cid = attributes[:'root_cid']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 18

def 
  @account_id
end

#attachment_urlObject

(Facebook only) URL of an image to attach, publishing a photo comment alongside the text. The URL must be publicly accessible so Meta can fetch it. Returns 400 for other platforms.



23
24
25
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 23

def attachment_url
  @attachment_url
end

#comment_idObject

Reply to specific comment (optional)



26
27
28
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 26

def comment_id
  @comment_id
end

#messageObject

Returns the value of attribute message.



20
21
22
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 20

def message
  @message
end

#parent_cidObject

(Bluesky only) Parent content identifier



29
30
31
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 29

def parent_cid
  @parent_cid
end

#root_cidObject

(Bluesky only) Root post CID



35
36
37
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 35

def root_cid
  @root_cid
end

#root_uriObject

(Bluesky only) Root post URI



32
33
34
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 32

def root_uri
  @root_uri
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 38

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'message' => :'message',
    :'attachment_url' => :'attachmentUrl',
    :'comment_id' => :'commentId',
    :'parent_cid' => :'parentCid',
    :'root_uri' => :'rootUri',
    :'root_cid' => :'rootCid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 202

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 61

def self.openapi_types
  {
    :'account_id' => :'String',
    :'message' => :'String',
    :'attachment_url' => :'String',
    :'comment_id' => :'String',
    :'parent_cid' => :'String',
    :'root_uri' => :'String',
    :'root_cid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



175
176
177
178
179
180
181
182
183
184
185
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 175

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      message == o.message &&
      attachment_url == o.attachment_url &&
      comment_id == o.comment_id &&
      parent_cid == o.parent_cid &&
      root_uri == o.root_uri &&
      root_cid == o.root_cid
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


189
190
191
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 189

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



195
196
197
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 195

def hash
  [, message, attachment_url, comment_id, parent_cid, root_uri, root_cid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 224

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @message.nil?
  true
end