Class: Zernio::RespondToSmsRegistrationReviewRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::RespondToSmsRegistrationReviewRequest
- Defined in:
- lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb
Instance Attribute Summary collapse
-
#answers ⇒ Object
One answer per point of the open
reviewRequest, each point at most once. -
#files ⇒ Object
Hosted document URLs returned by POST /v1/sms/opt-in-proof.
-
#note ⇒ Object
Answer for the reviewer.
-
#request_id ⇒ Object
The
reviewRequest.idyou are answering.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RespondToSmsRegistrationReviewRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RespondToSmsRegistrationReviewRequest
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::RespondToSmsRegistrationReviewRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::RespondToSmsRegistrationReviewRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'note') self.note = attributes[:'note'] end if attributes.key?(:'files') if (value = attributes[:'files']).is_a?(Array) self.files = value end end if attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] end if attributes.key?(:'answers') if (value = attributes[:'answers']).is_a?(Array) self.answers = value end end end |
Instance Attribute Details
#answers ⇒ Object
One answer per point of the open reviewRequest, each point at most once. Required (every point) when the request has points; a missing, repeated or unknown point is a 400 naming the point ids. At most 10 files per reply.
28 29 30 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 28 def answers @answers end |
#files ⇒ Object
Hosted document URLs returned by POST /v1/sms/opt-in-proof.
22 23 24 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 22 def files @files end |
#note ⇒ Object
Answer for the reviewer. Required when no files are sent.
19 20 21 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 19 def note @note end |
#request_id ⇒ Object
The reviewRequest.id you are answering. When it no longer matches the open request the reply is refused with 409.
25 26 27 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 25 def request_id @request_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 31 def self.attribute_map { :'note' => :'note', :'files' => :'files', :'request_id' => :'requestId', :'answers' => :'answers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 51 def self.openapi_types { :'note' => :'String', :'files' => :'Array<String>', :'request_id' => :'String', :'answers' => :'Array<RespondToSmsRegistrationReviewRequestAnswersInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
177 178 179 180 181 182 183 184 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 177 def ==(o) return true if self.equal?(o) self.class == o.class && note == o.note && files == o.files && request_id == o.request_id && answers == o.answers end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 194 def hash [note, files, request_id, answers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 105 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@note.nil? && @note.to_s.length > 2000 invalid_properties.push('invalid value for "note", the character length must be smaller than or equal to 2000.') end if !@files.nil? && @files.length > 5 invalid_properties.push('invalid value for "files", number of items must be less than or equal to 5.') end if !@answers.nil? && @answers.length > 20 invalid_properties.push('invalid value for "answers", number of items must be less than or equal to 20.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 129 130 131 |
# File 'lib/zernio-sdk/models/respond_to_sms_registration_review_request.rb', line 125 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@note.nil? && @note.to_s.length > 2000 return false if !@files.nil? && @files.length > 5 return false if !@answers.nil? && @answers.length > 20 true end |