Class: Zernio::RfPrediction

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/rf_prediction.rb

Overview

A Meta Reach & Frequency prediction. Money values in whole units of the ad account currency.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RfPrediction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::RfPrediction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::RfPrediction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'prediction_id')
    self.prediction_id = attributes[:'prediction_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'budget')
    self.budget = attributes[:'budget']
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  end

  if attributes.key?(:'impressions')
    self.impressions = attributes[:'impressions']
  end

  if attributes.key?(:'min_budget')
    self.min_budget = attributes[:'min_budget']
  end

  if attributes.key?(:'max_budget')
    self.max_budget = attributes[:'max_budget']
  end

  if attributes.key?(:'min_reach')
    self.min_reach = attributes[:'min_reach']
  end

  if attributes.key?(:'max_reach')
    self.max_reach = attributes[:'max_reach']
  end

  if attributes.key?(:'frequency_cap')
    self.frequency_cap = attributes[:'frequency_cap']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'stop_time')
    self.stop_time = attributes[:'stop_time']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end
end

Instance Attribute Details

#budgetObject

Quoted (or provided) lifetime budget for the window.



25
26
27
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 25

def budget
  @budget
end

#expires_atObject

When the reservation's locked price expires (set after reserving).



49
50
51
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 49

def expires_at
  @expires_at
end

#frequency_capObject

Returns the value of attribute frequency_cap.



41
42
43
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 41

def frequency_cap
  @frequency_cap
end

#impressionsObject

Returns the value of attribute impressions.



30
31
32
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 30

def impressions
  @impressions
end

#max_budgetObject

Returns the value of attribute max_budget.



35
36
37
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 35

def max_budget
  @max_budget
end

#max_reachObject

Returns the value of attribute max_reach.



39
40
41
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 39

def max_reach
  @max_reach
end

#min_budgetObject

Meta's allowed lower bound for this spec.



33
34
35
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 33

def min_budget
  @min_budget
end

#min_reachObject

Returns the value of attribute min_reach.



37
38
39
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 37

def min_reach
  @min_reach
end

#prediction_idObject

Returns the value of attribute prediction_id.



19
20
21
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 19

def prediction_id
  @prediction_id
end

#reachObject

Predicted (or requested) unique reach.



28
29
30
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 28

def reach
  @reach
end

#start_timeObject

Unix seconds; the reserved window the R&F ad set will run on.



44
45
46
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 44

def start_time
  @start_time
end

#statusObject

ready | pending | failed:



22
23
24
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 22

def status
  @status
end

#stop_timeObject

Returns the value of attribute stop_time.



46
47
48
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 46

def stop_time
  @stop_time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 52

def self.attribute_map
  {
    :'prediction_id' => :'predictionId',
    :'status' => :'status',
    :'budget' => :'budget',
    :'reach' => :'reach',
    :'impressions' => :'impressions',
    :'min_budget' => :'minBudget',
    :'max_budget' => :'maxBudget',
    :'min_reach' => :'minReach',
    :'max_reach' => :'maxReach',
    :'frequency_cap' => :'frequencyCap',
    :'start_time' => :'startTime',
    :'stop_time' => :'stopTime',
    :'expires_at' => :'expiresAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 235

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 100

def self.openapi_nullable
  Set.new([
    :'budget',
    :'reach',
    :'impressions',
    :'min_budget',
    :'max_budget',
    :'min_reach',
    :'max_reach',
    :'frequency_cap',
    :'start_time',
    :'stop_time',
    :'expires_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 81

def self.openapi_types
  {
    :'prediction_id' => :'String',
    :'status' => :'String',
    :'budget' => :'Float',
    :'reach' => :'Integer',
    :'impressions' => :'Integer',
    :'min_budget' => :'Float',
    :'max_budget' => :'Float',
    :'min_reach' => :'Integer',
    :'max_reach' => :'Integer',
    :'frequency_cap' => :'Integer',
    :'start_time' => :'Integer',
    :'stop_time' => :'Integer',
    :'expires_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      prediction_id == o.prediction_id &&
      status == o.status &&
      budget == o.budget &&
      reach == o.reach &&
      impressions == o.impressions &&
      min_budget == o.min_budget &&
      max_budget == o.max_budget &&
      min_reach == o.min_reach &&
      max_reach == o.max_reach &&
      frequency_cap == o.frequency_cap &&
      start_time == o.start_time &&
      stop_time == o.stop_time &&
      expires_at == o.expires_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



228
229
230
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 228

def hash
  [prediction_id, status, budget, reach, impressions, min_budget, max_budget, min_reach, max_reach, frequency_cap, start_time, stop_time, expires_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
# File 'lib/zernio-sdk/models/rf_prediction.rb', line 195

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end