Class: Zernio::SelectFacebookPageRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/select_facebook_page_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SelectFacebookPageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SelectFacebookPageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SelectFacebookPageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  else
    self.profile_id = nil
  end

  if attributes.key?(:'page_id')
    self.page_id = attributes[:'page_id']
  else
    self.page_id = nil
  end

  if attributes.key?(:'temp_token')
    self.temp_token = attributes[:'temp_token']
  else
    self.temp_token = nil
  end

  if attributes.key?(:'user_profile')
    self. = attributes[:'user_profile']
  else
    self. = nil
  end

  if attributes.key?(:'redirect_url')
    self.redirect_url = attributes[:'redirect_url']
  end
end

Instance Attribute Details

#page_idObject

The Facebook Page ID selected by the user



22
23
24
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 22

def page_id
  @page_id
end

#profile_idObject

Profile ID from your connection flow



19
20
21
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 19

def profile_id
  @profile_id
end

#redirect_urlObject

Optional custom redirect URL to return to after selection



30
31
32
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 30

def redirect_url
  @redirect_url
end

#temp_tokenObject

Temporary Facebook access token from OAuth



25
26
27
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 25

def temp_token
  @temp_token
end

#user_profileObject

Returns the value of attribute user_profile.



27
28
29
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 27

def 
  @user_profile
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 33

def self.attribute_map
  {
    :'profile_id' => :'profileId',
    :'page_id' => :'pageId',
    :'temp_token' => :'tempToken',
    :'user_profile' => :'userProfile',
    :'redirect_url' => :'redirect_url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 54

def self.openapi_types
  {
    :'profile_id' => :'String',
    :'page_id' => :'String',
    :'temp_token' => :'String',
    :'user_profile' => :'SelectFacebookPageRequestUserProfile',
    :'redirect_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
199
200
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      profile_id == o.profile_id &&
      page_id == o.page_id &&
      temp_token == o.temp_token &&
       == o. &&
      redirect_url == o.redirect_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 210

def hash
  [profile_id, page_id, temp_token, , redirect_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @profile_id.nil?
    invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.')
  end

  if @page_id.nil?
    invalid_properties.push('invalid value for "page_id", page_id cannot be nil.')
  end

  if @temp_token.nil?
    invalid_properties.push('invalid value for "temp_token", temp_token cannot be nil.')
  end

  if @user_profile.nil?
    invalid_properties.push('invalid value for "user_profile", user_profile cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
# File 'lib/zernio-sdk/models/select_facebook_page_request.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @profile_id.nil?
  return false if @page_id.nil?
  return false if @temp_token.nil?
  return false if @user_profile.nil?
  true
end