Class: Zernio::SelectGoogleBusinessLocation200ResponseAccount

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/select_google_business_location200_response_account.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SelectGoogleBusinessLocation200ResponseAccount

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SelectGoogleBusinessLocation200ResponseAccount` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SelectGoogleBusinessLocation200ResponseAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'selected_location_name')
    self.selected_location_name = attributes[:'selected_location_name']
  end

  if attributes.key?(:'selected_location_id')
    self.selected_location_id = attributes[:'selected_location_id']
  end
end

Instance Attribute Details

#account_idObject

ID of the created SocialAccount



19
20
21
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 19

def 
  @account_id
end

#display_nameObject

Returns the value of attribute display_name.



25
26
27
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 25

def display_name
  @display_name
end

#is_activeObject

Returns the value of attribute is_active.



27
28
29
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 27

def is_active
  @is_active
end

#platformObject

Returns the value of attribute platform.



21
22
23
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 21

def platform
  @platform
end

#selected_location_idObject

Returns the value of attribute selected_location_id.



31
32
33
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 31

def selected_location_id
  @selected_location_id
end

#selected_location_nameObject

Returns the value of attribute selected_location_name.



29
30
31
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 29

def selected_location_name
  @selected_location_name
end

#usernameObject

Returns the value of attribute username.



23
24
25
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 23

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



69
70
71
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 69

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 74

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 56

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'username' => :'username',
    :'display_name' => :'displayName',
    :'is_active' => :'isActive',
    :'selected_location_name' => :'selectedLocationName',
    :'selected_location_id' => :'selectedLocationId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 198

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 79

def self.openapi_types
  {
    :'account_id' => :'String',
    :'platform' => :'String',
    :'username' => :'String',
    :'display_name' => :'String',
    :'is_active' => :'Boolean',
    :'selected_location_name' => :'String',
    :'selected_location_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      platform == o.platform &&
      username == o.username &&
      display_name == o.display_name &&
      is_active == o.is_active &&
      selected_location_name == o.selected_location_name &&
      selected_location_id == o.selected_location_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 185

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 191

def hash
  [, platform, username, display_name, is_active, selected_location_name, selected_location_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



152
153
154
155
156
157
# File 'lib/zernio-sdk/models/select_google_business_location200_response_account.rb', line 152

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["googlebusiness"])
  return false unless platform_validator.valid?(@platform)
  true
end