Class: Zernio::SendBroadcast200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/send_broadcast200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendBroadcast200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendBroadcast200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendBroadcast200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'sent')
    self.sent = attributes[:'sent']
  end

  if attributes.key?(:'failed')
    self.failed = attributes[:'failed']
  end

  if attributes.key?(:'recipient_count')
    self.recipient_count = attributes[:'recipient_count']
  end
end

Instance Attribute Details

#failedObject

Recipients failed in this batch



27
28
29
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 27

def failed
  @failed
end

#recipient_countObject

Total recipient count



30
31
32
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 30

def recipient_count
  @recipient_count
end

#sentObject

Recipients sent in this batch



24
25
26
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 24

def sent
  @sent
end

#statusObject

Current broadcast status after processing first batch



21
22
23
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 21

def status
  @status
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 18

def success
  @success
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 55

def self.attribute_map
  {
    :'success' => :'success',
    :'status' => :'status',
    :'sent' => :'sent',
    :'failed' => :'failed',
    :'recipient_count' => :'recipientCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 76

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'status' => :'String',
    :'sent' => :'Integer',
    :'failed' => :'Integer',
    :'recipient_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
166
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
      status == o.status &&
      sent == o.sent &&
      failed == o.failed &&
      recipient_count == o.recipient_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 176

def hash
  [success, status, sent, failed, recipient_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
# File 'lib/zernio-sdk/models/send_broadcast200_response.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["sending", "completed", "failed"])
  return false unless status_validator.valid?(@status)
  true
end