Class: Zernio::SendConversionsRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/send_conversions_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendConversionsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendConversionsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendConversionsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'destination_id')
    self.destination_id = attributes[:'destination_id']
  else
    self.destination_id = nil
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  else
    self.events = nil
  end

  if attributes.key?(:'test_code')
    self.test_code = attributes[:'test_code']
  end

  if attributes.key?(:'consent')
    self.consent = attributes[:'consent']
  end
end

Instance Attribute Details

#account_idObject

SocialAccount ID (metaads, googleads, linkedinads, or tiktokads).



19
20
21
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 19

def 
  @account_id
end

Returns the value of attribute consent.



29
30
31
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 29

def consent
  @consent
end

#destination_idObject

Platform destination identifier. For Meta, the pixel/dataset ID. For Google, the conversion action resource name. For LinkedIn, the conversion rule ID or full urn:lla:llaPartnerConversion:{id} URN.



22
23
24
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 22

def destination_id
  @destination_id
end

#eventsObject

Returns the value of attribute events.



24
25
26
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 24

def events
  @events
end

#test_codeObject

Meta test_event_code passthrough. Ignored by Google and LinkedIn.



27
28
29
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 27

def test_code
  @test_code
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 32

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'destination_id' => :'destinationId',
    :'events' => :'events',
    :'test_code' => :'testCode',
    :'consent' => :'consent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



64
65
66
67
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 64

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 53

def self.openapi_types
  {
    :'account_id' => :'String',
    :'destination_id' => :'String',
    :'events' => :'Array<ConversionEvent>',
    :'test_code' => :'String',
    :'consent' => :'SendConversionsRequestConsent'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      destination_id == o.destination_id &&
      events == o.events &&
      test_code == o.test_code &&
      consent == o.consent
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 203

def hash
  [, destination_id, events, test_code, consent].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @destination_id.nil?
    invalid_properties.push('invalid value for "destination_id", destination_id cannot be nil.')
  end

  if @events.nil?
    invalid_properties.push('invalid value for "events", events cannot be nil.')
  end

  if @events.length < 1
    invalid_properties.push('invalid value for "events", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
144
145
146
147
# File 'lib/zernio-sdk/models/send_conversions_request.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @destination_id.nil?
  return false if @events.nil?
  return false if @events.length < 1
  true
end