Class: Zernio::SendDiscordDirectMessage200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SendDiscordDirectMessage200Response
- Defined in:
- lib/zernio-sdk/models/send_discord_direct_message200_response.rb
Instance Attribute Summary collapse
-
#account ⇒ Object
Returns the value of attribute account.
-
#channel_id ⇒ Object
DM channel snowflake (Discord auto-creates one per recipient pair).
-
#message_id ⇒ Object
Discord message snowflake ID.
-
#recipient ⇒ Object
Returns the value of attribute recipient.
-
#timestamp ⇒ Object
Returns the value of attribute timestamp.
-
#url ⇒ Object
Direct link to the message — uses Discord's @me path for DMs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendDiscordDirectMessage200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendDiscordDirectMessage200Response
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendDiscordDirectMessage200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendDiscordDirectMessage200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'message_id') self. = attributes[:'message_id'] end if attributes.key?(:'channel_id') self.channel_id = attributes[:'channel_id'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'recipient') self.recipient = attributes[:'recipient'] end if attributes.key?(:'account') self.account = attributes[:'account'] end end |
Instance Attribute Details
#account ⇒ Object
Returns the value of attribute account.
31 32 33 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 31 def account @account end |
#channel_id ⇒ Object
DM channel snowflake (Discord auto-creates one per recipient pair)
22 23 24 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 22 def channel_id @channel_id end |
#message_id ⇒ Object
Discord message snowflake ID
19 20 21 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 19 def @message_id end |
#recipient ⇒ Object
Returns the value of attribute recipient.
29 30 31 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 29 def recipient @recipient end |
#timestamp ⇒ Object
Returns the value of attribute timestamp.
27 28 29 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 27 def @timestamp end |
#url ⇒ Object
Direct link to the message — uses Discord's @me path for DMs
25 26 27 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 25 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 34 def self.attribute_map { :'message_id' => :'messageId', :'channel_id' => :'channelId', :'url' => :'url', :'timestamp' => :'timestamp', :'recipient' => :'recipient', :'account' => :'account' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 157 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 56 def self.openapi_types { :'message_id' => :'String', :'channel_id' => :'String', :'url' => :'String', :'timestamp' => :'Time', :'recipient' => :'SendDiscordDirectMessage200ResponseRecipient', :'account' => :'SendDiscordDirectMessage200ResponseAccount' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 137 138 139 140 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && channel_id == o.channel_id && url == o.url && == o. && recipient == o.recipient && account == o.account end |
#eql?(o) ⇒ Boolean
144 145 146 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 144 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
150 151 152 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 150 def hash [, channel_id, url, , recipient, account].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 179 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 |
# File 'lib/zernio-sdk/models/send_discord_direct_message200_response.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |