Class: Zernio::SendInboxMessageRequestInteractiveActionOneOf3Parameters

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendInboxMessageRequestInteractiveActionOneOf3Parameters

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendInboxMessageRequestInteractiveActionOneOf3Parameters` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendInboxMessageRequestInteractiveActionOneOf3Parameters`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flow_message_version')
    self.flow_message_version = attributes[:'flow_message_version']
  end

  if attributes.key?(:'flow_token')
    self.flow_token = attributes[:'flow_token']
  else
    self.flow_token = nil
  end

  if attributes.key?(:'flow_id')
    self.flow_id = attributes[:'flow_id']
  else
    self.flow_id = nil
  end

  if attributes.key?(:'flow_cta')
    self.flow_cta = attributes[:'flow_cta']
  else
    self.flow_cta = nil
  end

  if attributes.key?(:'flow_action')
    self.flow_action = attributes[:'flow_action']
  else
    self.flow_action = nil
  end

  if attributes.key?(:'flow_action_payload')
    self.flow_action_payload = attributes[:'flow_action_payload']
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end
end

Instance Attribute Details

#flow_actionObject

navigate sends the user to flow_action_payload.screen; data_exchange posts data to your Flow endpoint.



31
32
33
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 31

def flow_action
  @flow_action
end

#flow_action_payloadObject

Returns the value of attribute flow_action_payload.



33
34
35
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 33

def flow_action_payload
  @flow_action_payload
end

#flow_ctaObject

Button label that opens the Flow (max 20 chars).



28
29
30
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 28

def flow_cta
  @flow_cta
end

#flow_idObject

Published Flow ID from Meta Business Manager.



25
26
27
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 25

def flow_id
  @flow_id
end

#flow_message_versionObject

Defaults to "3" when omitted.



19
20
21
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 19

def flow_message_version
  @flow_message_version
end

#flow_tokenObject

Opaque token you choose to correlate Flow responses with your own state (max 200 chars).



22
23
24
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 22

def flow_token
  @flow_token
end

#modeObject

Set to draft to test an unpublished Flow.



36
37
38
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 36

def mode
  @mode
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 61

def self.attribute_map
  {
    :'flow_message_version' => :'flow_message_version',
    :'flow_token' => :'flow_token',
    :'flow_id' => :'flow_id',
    :'flow_cta' => :'flow_cta',
    :'flow_action' => :'flow_action',
    :'flow_action_payload' => :'flow_action_payload',
    :'mode' => :'mode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 285

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 84

def self.openapi_types
  {
    :'flow_message_version' => :'String',
    :'flow_token' => :'String',
    :'flow_id' => :'String',
    :'flow_cta' => :'String',
    :'flow_action' => :'String',
    :'flow_action_payload' => :'SendInboxMessageRequestInteractiveActionOneOf3ParametersFlowActionPayload',
    :'mode' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



258
259
260
261
262
263
264
265
266
267
268
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 258

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flow_message_version == o.flow_message_version &&
      flow_token == o.flow_token &&
      flow_id == o.flow_id &&
      flow_cta == o.flow_cta &&
      flow_action == o.flow_action &&
      flow_action_payload == o.flow_action_payload &&
      mode == o.mode
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 278

def hash
  [flow_message_version, flow_token, flow_id, flow_cta, flow_action, flow_action_payload, mode].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @flow_token.nil?
    invalid_properties.push('invalid value for "flow_token", flow_token cannot be nil.')
  end

  if @flow_id.nil?
    invalid_properties.push('invalid value for "flow_id", flow_id cannot be nil.')
  end

  if @flow_cta.nil?
    invalid_properties.push('invalid value for "flow_cta", flow_cta cannot be nil.')
  end

  if @flow_action.nil?
    invalid_properties.push('invalid value for "flow_action", flow_action cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of3_parameters.rb', line 181

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  flow_message_version_validator = EnumAttributeValidator.new('String', ["3"])
  return false unless flow_message_version_validator.valid?(@flow_message_version)
  return false if @flow_token.nil?
  return false if @flow_id.nil?
  return false if @flow_cta.nil?
  return false if @flow_action.nil?
  flow_action_validator = EnumAttributeValidator.new('String', ["navigate", "data_exchange"])
  return false unless flow_action_validator.valid?(@flow_action)
  mode_validator = EnumAttributeValidator.new('String', ["draft"])
  return false unless mode_validator.valid?(@mode)
  true
end