Class: Zernio::SendInboxMessageRequestInteractiveActionOneOf7
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SendInboxMessageRequestInteractiveActionOneOf7
- Defined in:
- lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb
Overview
Catalog-message action. type on the parent must be catalog_message. May be omitted entirely; it is defaulted to { \"name\": \"catalog_message\" }. Requires a Meta catalog connected to the WhatsApp Business Account in Commerce Manager.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#name ⇒ Object
Returns the value of attribute name.
-
#parameters ⇒ Object
Returns the value of attribute parameters.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendInboxMessageRequestInteractiveActionOneOf7
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendInboxMessageRequestInteractiveActionOneOf7
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendInboxMessageRequestInteractiveActionOneOf7` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendInboxMessageRequestInteractiveActionOneOf7`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'parameters') self.parameters = attributes[:'parameters'] end end |
Instance Attribute Details
#name ⇒ Object
Returns the value of attribute name.
19 20 21 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 19 def name @name end |
#parameters ⇒ Object
Returns the value of attribute parameters.
21 22 23 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 21 def parameters @parameters end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 46 def self.attribute_map { :'name' => :'name', :'parameters' => :'parameters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 64 def self.openapi_types { :'name' => :'String', :'parameters' => :'SendInboxMessageRequestInteractiveActionOneOf7Parameters' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && parameters == o.parameters end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 153 def hash [name, parameters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 114 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
118 119 120 121 122 123 124 |
# File 'lib/zernio-sdk/models/send_inbox_message_request_interactive_action_one_of7.rb', line 118 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? name_validator = EnumAttributeValidator.new('String', ["catalog_message"]) return false unless name_validator.valid?(@name) true end |