Class: Zernio::SendPrivateReplyToCommentRequestButtonsInnerOneOf2

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendPrivateReplyToCommentRequestButtonsInnerOneOf2

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendPrivateReplyToCommentRequestButtonsInnerOneOf2` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendPrivateReplyToCommentRequestButtonsInnerOneOf2`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  else
    self.phone = nil
  end
end

Instance Attribute Details

#phoneObject

E.164 phone number dialed when tapped. Facebook only.



24
25
26
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 24

def phone
  @phone
end

#titleObject

Label shown on the button. Facebook only.



21
22
23
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 21

def title
  @title
end

#typeObject

Returns the value of attribute type.



18
19
20
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 18

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 49

def self.attribute_map
  {
    :'type' => :'type',
    :'title' => :'title',
    :'phone' => :'phone'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 68

def self.openapi_types
  {
    :'type' => :'String',
    :'title' => :'String',
    :'phone' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      title == o.title &&
      phone == o.phone
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 206

def hash
  [type, title, phone].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length > 20
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 20.')
  end

  if @phone.nil?
    invalid_properties.push('invalid value for "phone", phone cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
147
148
149
150
151
152
# File 'lib/zernio-sdk/models/send_private_reply_to_comment_request_buttons_inner_one_of2.rb', line 143

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["phone"])
  return false unless type_validator.valid?(@type)
  return false if @title.nil?
  return false if @title.to_s.length > 20
  return false if @phone.nil?
  true
end