Class: Zernio::SendRcsMessageRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/send_rcs_message_request.rb

Overview

Send exactly one of text or content.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SendRcsMessageRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendRcsMessageRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendRcsMessageRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'agent_id')
    self.agent_id = attributes[:'agent_id']
  else
    self.agent_id = nil
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  else
    self.to = nil
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'fallback_text')
    self.fallback_text = attributes[:'fallback_text']
  end

  if attributes.key?(:'ttl_seconds')
    self.ttl_seconds = attributes[:'ttl_seconds']
  end
end

Instance Attribute Details

#agent_id ⇒ Object

Returns the value of attribute agent_id.



19
20
21
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 19

def agent_id
  @agent_id
end

#content ⇒ Object

Returns the value of attribute content.



26
27
28
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 26

def content
  @content
end

#fallback_text ⇒ Object

Returns the value of attribute fallback_text.



28
29
30
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 28

def fallback_text
  @fallback_text
end

#text ⇒ Object

Returns the value of attribute text.



24
25
26
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 24

def text
  @text
end

#to ⇒ Object

Recipient number (E.164; formatting is normalized).



22
23
24
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 22

def to
  @to
end

#ttl_seconds ⇒ Object

Seconds before an undelivered message expires.



31
32
33
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 31

def ttl_seconds
  @ttl_seconds
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



46
47
48
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 34

def self.attribute_map
  {
    :'agent_id' => :'agentId',
    :'to' => :'to',
    :'text' => :'text',
    :'content' => :'content',
    :'fallback_text' => :'fallbackText',
    :'ttl_seconds' => :'ttlSeconds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 248

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



68
69
70
71
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 68

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 56

def self.openapi_types
  {
    :'agent_id' => :'String',
    :'to' => :'String',
    :'text' => :'String',
    :'content' => :'RcsContent',
    :'fallback_text' => :'String',
    :'ttl_seconds' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



222
223
224
225
226
227
228
229
230
231
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      agent_id == o.agent_id &&
      to == o.to &&
      text == o.text &&
      content == o.content &&
      fallback_text == o.fallback_text &&
      ttl_seconds == o.ttl_seconds
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


235
236
237
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 235

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



241
242
243
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 241

def hash
  [agent_id, to, text, content, fallback_text, ttl_seconds].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @agent_id.nil?
    invalid_properties.push('invalid value for "agent_id", agent_id cannot be nil.')
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if !@text.nil? && @text.to_s.length > 3072
    invalid_properties.push('invalid value for "text", the character length must be smaller than or equal to 3072.')
  end

  if !@fallback_text.nil? && @fallback_text.to_s.length > 3072
    invalid_properties.push('invalid value for "fallback_text", the character length must be smaller than or equal to 3072.')
  end

  if !@ttl_seconds.nil? && @ttl_seconds < 1
    invalid_properties.push('invalid value for "ttl_seconds", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 270

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



148
149
150
151
152
153
154
155
156
# File 'lib/zernio-sdk/models/send_rcs_message_request.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @agent_id.nil?
  return false if @to.nil?
  return false if !@text.nil? && @text.to_s.length > 3072
  return false if !@fallback_text.nil? && @fallback_text.to_s.length > 3072
  return false if !@ttl_seconds.nil? && @ttl_seconds < 1
  true
end