Class: Zernio::SendWhatsAppConversion200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SendWhatsAppConversion200Response
- Defined in:
- lib/zernio-sdk/models/send_whats_app_conversion200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#events_failed ⇒ Object
Events rejected by Meta (see failures).
-
#events_received ⇒ Object
Events accepted by Meta.
-
#failures ⇒ Object
Per-event failure detail.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#trace_id ⇒ Object
Meta
fbtrace_idfor debugging.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SendWhatsAppConversion200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SendWhatsAppConversion200Response
Initializes the object
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 94 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SendWhatsAppConversion200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SendWhatsAppConversion200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'events_received') self.events_received = attributes[:'events_received'] end if attributes.key?(:'events_failed') self.events_failed = attributes[:'events_failed'] end if attributes.key?(:'failures') if (value = attributes[:'failures']).is_a?(Array) self.failures = value end end if attributes.key?(:'trace_id') self.trace_id = attributes[:'trace_id'] end end |
Instance Attribute Details
#events_failed ⇒ Object
Events rejected by Meta (see failures).
24 25 26 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 24 def events_failed @events_failed end |
#events_received ⇒ Object
Events accepted by Meta.
21 22 23 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 21 def events_received @events_received end |
#failures ⇒ Object
Per-event failure detail. Empty when all events were accepted.
27 28 29 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 27 def failures @failures end |
#platform ⇒ Object
Returns the value of attribute platform.
18 19 20 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 18 def platform @platform end |
#trace_id ⇒ Object
Meta fbtrace_id for debugging. Surface in support tickets.
30 31 32 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 30 def trace_id @trace_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 55 def self.attribute_map { :'platform' => :'platform', :'events_received' => :'eventsReceived', :'events_failed' => :'eventsFailed', :'failures' => :'failures', :'trace_id' => :'traceId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 185 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 87 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 76 def self.openapi_types { :'platform' => :'String', :'events_received' => :'Integer', :'events_failed' => :'Integer', :'failures' => :'Array<SendConversions200ResponseFailuresInner>', :'trace_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && platform == o.platform && events_received == o.events_received && events_failed == o.events_failed && failures == o.failures && trace_id == o.trace_id end |
#eql?(o) ⇒ Boolean
172 173 174 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 172 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 178 def hash [platform, events_received, events_failed, failures, trace_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 207 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 145 146 |
# File 'lib/zernio-sdk/models/send_whats_app_conversion200_response.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' platform_validator = EnumAttributeValidator.new('String', ["metaads"]) return false unless platform_validator.valid?(@platform) true end |