Class: Zernio::SetWhatsappBusinessUsernameRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SetWhatsappBusinessUsernameRequest
- Defined in:
- lib/zernio-sdk/models/set_whatsapp_business_username_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
WhatsApp social account ID.
-
#transfer_action ⇒ Object
Pass
force_transferto request a transfer if the username is held by another account. -
#username ⇒ Object
Desired username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SetWhatsappBusinessUsernameRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SetWhatsappBusinessUsernameRequest
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SetWhatsappBusinessUsernameRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SetWhatsappBusinessUsernameRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'transfer_action') self.transfer_action = attributes[:'transfer_action'] else self.transfer_action = 'none' end end |
Instance Attribute Details
#account_id ⇒ Object
WhatsApp social account ID
19 20 21 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 19 def account_id @account_id end |
#transfer_action ⇒ Object
Pass force_transfer to request a transfer if the username is held by another account
25 26 27 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 25 def transfer_action @transfer_action end |
#username ⇒ Object
Desired username. Letters, digits, period, and underscore only. Must contain at least one letter. No leading, trailing, or consecutive periods. No www prefix. No domain TLD suffix.
22 23 24 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 22 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 50 def self.attribute_map { :'account_id' => :'accountId', :'username' => :'username', :'transfer_action' => :'transferAction' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 218 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 69 def self.openapi_types { :'account_id' => :'String', :'username' => :'String', :'transfer_action' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && username == o.username && transfer_action == o.transfer_action end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 211 def hash [account_id, username, transfer_action].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @username.to_s.length > 35 invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 35.') end if @username.to_s.length < 3 invalid_properties.push('invalid value for "username", the character length must be greater than or equal to 3.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/set_whatsapp_business_username_request.rb', line 144 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @username.nil? return false if @username.to_s.length > 35 return false if @username.to_s.length < 3 transfer_action_validator = EnumAttributeValidator.new('String', ["none", "force_transfer"]) return false unless transfer_action_validator.valid?(@transfer_action) true end |