Class: Zernio::SlackApi
- Inherits:
-
Object
- Object
- Zernio::SlackApi
- Defined in:
- lib/zernio-sdk/api/slack_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ SlackApi
constructor
A new instance of SlackApi.
-
#list_slack_members(account_id, opts = {}) ⇒ ListSlackMembers200Response
List Slack workspace members Members of the connected Slack workspace that can receive a direct message, for populating a recipient picker.
-
#list_slack_members_with_http_info(account_id, opts = {}) ⇒ Array<(ListSlackMembers200Response, Integer, Hash)>
List Slack workspace members Members of the connected Slack workspace that can receive a direct message, for populating a recipient picker.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/slack_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_slack_members(account_id, opts = {}) ⇒ ListSlackMembers200Response
List Slack workspace members
Members of the connected Slack workspace that can receive a direct message, for populating a recipient picker. Bots, deactivated members and Slackbot are excluded. Start a DM by passing a member id as participantId to POST /v1/inbox/conversations.
29 30 31 32 |
# File 'lib/zernio-sdk/api/slack_api.rb', line 29 def list_slack_members(account_id, opts = {}) data, _status_code, _headers = list_slack_members_with_http_info(account_id, opts) data end |
#list_slack_members_with_http_info(account_id, opts = {}) ⇒ Array<(ListSlackMembers200Response, Integer, Hash)>
List Slack workspace members Members of the connected Slack workspace that can receive a direct message, for populating a recipient picker. Bots, deactivated members and Slackbot are excluded. Start a DM by passing a member id as `participantId` to POST /v1/inbox/conversations.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zernio-sdk/api/slack_api.rb', line 41 def list_slack_members_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: SlackApi.list_slack_members ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling SlackApi.list_slack_members" end if @api_client.config.client_side_validation && !opts[:'query'].nil? && opts[:'query'].to_s.length > 100 fail ArgumentError, 'invalid value for "opts[:"query"]" when calling SlackApi.list_slack_members, the character length must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 2000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SlackApi.list_slack_members, must be smaller than or equal to 2000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling SlackApi.list_slack_members, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/accounts/{accountId}/slack-members'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'query'] = opts[:'query'] if !opts[:'query'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListSlackMembers200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"SlackApi.list_slack_members", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: SlackApi#list_slack_members\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |