Class: Zernio::StartGoogleBusinessVerificationRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/start_google_business_verification_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StartGoogleBusinessVerificationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::StartGoogleBusinessVerificationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::StartGoogleBusinessVerificationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  else
    self.method = nil
  end

  if attributes.key?(:'language_code')
    self.language_code = attributes[:'language_code']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'email_address')
    self.email_address = attributes[:'email_address']
  end

  if attributes.key?(:'mailer_contact')
    self.mailer_contact = attributes[:'mailer_contact']
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end
end

Instance Attribute Details

#contextObject

ServiceBusinessContext (e.g. service address). Required for service-area businesses.



33
34
35
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 33

def context
  @context
end

#email_addressObject

For EMAIL.



27
28
29
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 27

def email_address
  @email_address
end

#language_codeObject

Returns the value of attribute language_code.



21
22
23
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 21

def language_code
  @language_code
end

#mailer_contactObject

For ADDRESS (postcard) verification.



30
31
32
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 30

def mailer_contact
  @mailer_contact
end

#methodObject

The verification method. Selects which method-specific field below is required.



19
20
21
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 19

def method
  @method
end

#phone_numberObject

For PHONE_CALL / SMS.



24
25
26
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 24

def phone_number
  @phone_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 58

def self.attribute_map
  {
    :'method' => :'method',
    :'language_code' => :'languageCode',
    :'phone_number' => :'phoneNumber',
    :'email_address' => :'emailAddress',
    :'mailer_contact' => :'mailerContact',
    :'context' => :'context'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 80

def self.openapi_types
  {
    :'method' => :'String',
    :'language_code' => :'String',
    :'phone_number' => :'String',
    :'email_address' => :'String',
    :'mailer_contact' => :'Object',
    :'context' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
183
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      method == o.method &&
      language_code == o.language_code &&
      phone_number == o.phone_number &&
      email_address == o.email_address &&
      mailer_contact == o.mailer_contact &&
      context == o.context
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 193

def hash
  [method, language_code, phone_number, email_address, mailer_contact, context].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @method.nil?
    invalid_properties.push('invalid value for "method", method cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
# File 'lib/zernio-sdk/models/start_google_business_verification_request.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @method.nil?
  method_validator = EnumAttributeValidator.new('String', ["ADDRESS", "EMAIL", "PHONE_CALL", "SMS", "AUTO", "VETTED_PARTNER"])
  return false unless method_validator.valid?(@method)
  true
end