Class: Zernio::SubmitFeedbackRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/submit_feedback_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubmitFeedbackRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SubmitFeedbackRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SubmitFeedbackRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'summary')
    self.summary = attributes[:'summary']
  else
    self.summary = nil
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'endpoint')
    self.endpoint = attributes[:'endpoint']
  end

  if attributes.key?(:'request_id')
    self.request_id = attributes[:'request_id']
  end

  if attributes.key?(:'expected')
    self.expected = attributes[:'expected']
  end

  if attributes.key?(:'actual')
    self.actual = attributes[:'actual']
  end

  if attributes.key?(:'agent')
    self.agent = attributes[:'agent']
  end
end

Instance Attribute Details

#actual ⇒ Object

What actually happened, e.g. the error message.



37
38
39
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 37

def actual
  @actual
end

#agent ⇒ Object

Returns the value of attribute agent.



39
40
41
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 39

def agent
  @agent
end

#details ⇒ Object

Longer explanation: what you were trying to do, steps to reproduce, the use case.



25
26
27
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 25

def details
  @details
end

#endpoint ⇒ Object

The endpoint involved, e.g. POST /v1/posts.



28
29
30
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 28

def endpoint
  @endpoint
end

#expected ⇒ Object

What you expected to happen.



34
35
36
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 34

def expected
  @expected
end

#request_id ⇒ Object

The x-request-id header of the failing response, if any.



31
32
33
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 31

def request_id
  @request_id
end

#summary ⇒ Object

One line describing the problem or the missing capability. Also the dedup key.



22
23
24
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 22

def summary
  @summary
end

#type ⇒ Object

What kind of feedback this is.



19
20
21
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



78
79
80
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 64

def self.attribute_map
  {
    :'type' => :'type',
    :'summary' => :'summary',
    :'details' => :'details',
    :'endpoint' => :'endpoint',
    :'request_id' => :'requestId',
    :'expected' => :'expected',
    :'actual' => :'actual',
    :'agent' => :'agent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 350

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



102
103
104
105
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 88

def self.openapi_types
  {
    :'type' => :'String',
    :'summary' => :'String',
    :'details' => :'String',
    :'endpoint' => :'String',
    :'request_id' => :'String',
    :'expected' => :'String',
    :'actual' => :'String',
    :'agent' => :'SubmitFeedbackRequestAgent'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      summary == o.summary &&
      details == o.details &&
      endpoint == o.endpoint &&
      request_id == o.request_id &&
      expected == o.expected &&
      actual == o.actual &&
      agent == o.agent
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


337
338
339
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 337

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



343
344
345
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 343

def hash
  [type, summary, details, endpoint, request_id, expected, actual, agent].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @summary.nil?
    invalid_properties.push('invalid value for "summary", summary cannot be nil.')
  end

  if @summary.to_s.length > 200
    invalid_properties.push('invalid value for "summary", the character length must be smaller than or equal to 200.')
  end

  if @summary.to_s.length < 1
    invalid_properties.push('invalid value for "summary", the character length must be greater than or equal to 1.')
  end

  if !@details.nil? && @details.to_s.length > 5000
    invalid_properties.push('invalid value for "details", the character length must be smaller than or equal to 5000.')
  end

  if !@endpoint.nil? && @endpoint.to_s.length > 300
    invalid_properties.push('invalid value for "endpoint", the character length must be smaller than or equal to 300.')
  end

  if !@request_id.nil? && @request_id.to_s.length > 200
    invalid_properties.push('invalid value for "request_id", the character length must be smaller than or equal to 200.')
  end

  if !@expected.nil? && @expected.to_s.length > 2000
    invalid_properties.push('invalid value for "expected", the character length must be smaller than or equal to 2000.')
  end

  if !@actual.nil? && @actual.to_s.length > 2000
    invalid_properties.push('invalid value for "actual", the character length must be smaller than or equal to 2000.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 372

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/zernio-sdk/models/submit_feedback_request.rb', line 206

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["bug", "missing_feature", "docs", "other"])
  return false unless type_validator.valid?(@type)
  return false if @summary.nil?
  return false if @summary.to_s.length > 200
  return false if @summary.to_s.length < 1
  return false if !@details.nil? && @details.to_s.length > 5000
  return false if !@endpoint.nil? && @endpoint.to_s.length > 300
  return false if !@request_id.nil? && @request_id.to_s.length > 200
  return false if !@expected.nil? && @expected.to_s.length > 2000
  return false if !@actual.nil? && @actual.to_s.length > 2000
  true
end