Class: Zernio::TwitterPlatformDataPoll
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::TwitterPlatformDataPoll
- Defined in:
- lib/zernio-sdk/models/twitter_platform_data_poll.rb
Overview
Create a poll with this tweet. Mutually exclusive with media attachments and threads.
Instance Attribute Summary collapse
-
#duration_minutes ⇒ Object
Poll duration in minutes (5 min to 7 days).
-
#options ⇒ Object
Poll options (2-4 choices, max 25 characters each).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TwitterPlatformDataPoll
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TwitterPlatformDataPoll
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::TwitterPlatformDataPoll` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::TwitterPlatformDataPoll`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'options') if (value = attributes[:'options']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'duration_minutes') self.duration_minutes = attributes[:'duration_minutes'] else self.duration_minutes = nil end end |
Instance Attribute Details
#duration_minutes ⇒ Object
Poll duration in minutes (5 min to 7 days)
23 24 25 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 23 def duration_minutes @duration_minutes end |
#options ⇒ Object
Poll options (2-4 choices, max 25 characters each)
20 21 22 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 20 def @options end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 26 def self.attribute_map { :'options' => :'options', :'duration_minutes' => :'duration_minutes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 193 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 44 def self.openapi_types { :'options' => :'Array<String>', :'duration_minutes' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && duration_minutes == o.duration_minutes end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 186 def hash [, duration_minutes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 90 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @options.nil? invalid_properties.push('invalid value for "options", options cannot be nil.') end if @options.length > 4 invalid_properties.push('invalid value for "options", number of items must be less than or equal to 4.') end if @options.length < 2 invalid_properties.push('invalid value for "options", number of items must be greater than or equal to 2.') end if @duration_minutes.nil? invalid_properties.push('invalid value for "duration_minutes", duration_minutes cannot be nil.') end if @duration_minutes > 10080 invalid_properties.push('invalid value for "duration_minutes", must be smaller than or equal to 10080.') end if @duration_minutes < 5 invalid_properties.push('invalid value for "duration_minutes", must be greater than or equal to 5.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 127 128 129 130 131 |
# File 'lib/zernio-sdk/models/twitter_platform_data_poll.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @options.nil? return false if @options.length > 4 return false if @options.length < 2 return false if @duration_minutes.nil? return false if @duration_minutes > 10080 return false if @duration_minutes < 5 true end |