Class: Zernio::UpdateAccountCalloutsRequestUpdatesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAccountCalloutsRequestUpdatesInner
- Defined in:
- lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb
Overview
Provide at least one field belonging to this asset type.
Instance Attribute Summary collapse
-
#asset_resource_name ⇒ Object
Asset resource name returned by a list operation.
-
#callout_asset ⇒ Object
Returns the value of attribute callout_asset.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAccountCalloutsRequestUpdatesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAccountCalloutsRequestUpdatesInner
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAccountCalloutsRequestUpdatesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAccountCalloutsRequestUpdatesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset_resource_name') self.asset_resource_name = attributes[:'asset_resource_name'] else self.asset_resource_name = nil end if attributes.key?(:'callout_asset') self.callout_asset = attributes[:'callout_asset'] end end |
Instance Attribute Details
#asset_resource_name ⇒ Object
Asset resource name returned by a list operation. Must belong to the selected customer.
20 21 22 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 20 def asset_resource_name @asset_resource_name end |
#callout_asset ⇒ Object
Returns the value of attribute callout_asset.
22 23 24 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 22 def callout_asset @callout_asset end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 25 def self.attribute_map { :'asset_resource_name' => :'assetResourceName', :'callout_asset' => :'calloutAsset' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 148 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 43 def self.openapi_types { :'asset_resource_name' => :'String', :'callout_asset' => :'UpdateAccountCalloutsRequestUpdatesInnerCalloutAsset' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && asset_resource_name == o.asset_resource_name && callout_asset == o.callout_asset end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 141 def hash [asset_resource_name, callout_asset].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @asset_resource_name.nil? invalid_properties.push('invalid value for "asset_resource_name", asset_resource_name cannot be nil.') end pattern = Regexp.new(/^customers\/\d+\/assets\/\d+$/) if @asset_resource_name !~ pattern invalid_properties.push("invalid value for \"asset_resource_name\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
102 103 104 105 106 107 |
# File 'lib/zernio-sdk/models/update_account_callouts_request_updates_inner.rb', line 102 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @asset_resource_name.nil? return false if @asset_resource_name !~ Regexp.new(/^customers\/\d+\/assets\/\d+$/) true end |