Class: Zernio::UpdateAccountSitelinksRequestUpdatesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAccountSitelinksRequestUpdatesInner
- Defined in:
- lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb
Overview
Provide at least one field belonging to this asset type.
Instance Attribute Summary collapse
-
#asset_resource_name ⇒ Object
Asset resource name returned by a list operation.
-
#final_urls ⇒ Object
Returns the value of attribute final_urls.
-
#sitelink_asset ⇒ Object
Returns the value of attribute sitelink_asset.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAccountSitelinksRequestUpdatesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAccountSitelinksRequestUpdatesInner
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAccountSitelinksRequestUpdatesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAccountSitelinksRequestUpdatesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset_resource_name') self.asset_resource_name = attributes[:'asset_resource_name'] else self.asset_resource_name = nil end if attributes.key?(:'sitelink_asset') self.sitelink_asset = attributes[:'sitelink_asset'] end if attributes.key?(:'final_urls') if (value = attributes[:'final_urls']).is_a?(Array) self.final_urls = value end end end |
Instance Attribute Details
#asset_resource_name ⇒ Object
Asset resource name returned by a list operation. Must belong to the selected customer.
20 21 22 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 20 def asset_resource_name @asset_resource_name end |
#final_urls ⇒ Object
Returns the value of attribute final_urls.
24 25 26 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 24 def final_urls @final_urls end |
#sitelink_asset ⇒ Object
Returns the value of attribute sitelink_asset.
22 23 24 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 22 def sitelink_asset @sitelink_asset end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 27 def self.attribute_map { :'asset_resource_name' => :'assetResourceName', :'sitelink_asset' => :'sitelinkAsset', :'final_urls' => :'finalUrls' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 46 def self.openapi_types { :'asset_resource_name' => :'String', :'sitelink_asset' => :'UpdateAccountSitelinksRequestUpdatesInnerSitelinkAsset', :'final_urls' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && asset_resource_name == o.asset_resource_name && sitelink_asset == o.sitelink_asset && final_urls == o.final_urls end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 171 def hash [asset_resource_name, sitelink_asset, final_urls].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 95 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @asset_resource_name.nil? invalid_properties.push('invalid value for "asset_resource_name", asset_resource_name cannot be nil.') end pattern = Regexp.new(/^customers\/\d+\/assets\/\d+$/) if @asset_resource_name !~ pattern invalid_properties.push("invalid value for \"asset_resource_name\", must conform to the pattern #{pattern}.") end if !@final_urls.nil? && @final_urls.length < 1 invalid_properties.push('invalid value for "final_urls", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request_updates_inner.rb', line 116 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @asset_resource_name.nil? return false if @asset_resource_name !~ Regexp.new(/^customers\/\d+\/assets\/\d+$/) return false if !@final_urls.nil? && @final_urls.length < 1 true end |