Class: Zernio::UpdateAdCampaign200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_ad_campaign200_response.rb

Overview

Echoes back only the fields you sent, plus updated.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateAdCampaign200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdCampaign200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdCampaign200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  end

  if attributes.key?(:'budget')
    self.budget = attributes[:'budget']
  end

  if attributes.key?(:'budget_level')
    self.budget_level = attributes[:'budget_level']
  end

  if attributes.key?(:'bid_strategy')
    self.bid_strategy = attributes[:'bid_strategy']
  end

  if attributes.key?(:'bid_amount')
    self.bid_amount = attributes[:'bid_amount']
  end

  if attributes.key?(:'roas_average_floor')
    self.roas_average_floor = attributes[:'roas_average_floor']
  end

  if attributes.key?(:'portfolio_bid_strategy_id')
    self.portfolio_bid_strategy_id = attributes[:'portfolio_bid_strategy_id']
  end

  if attributes.key?(:'platform_specific_data')
    self.platform_specific_data = attributes[:'platform_specific_data']
  end
end

Instance Attribute Details

#bid_amountObject

Returns the value of attribute bid_amount.



28
29
30
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 28

def bid_amount
  @bid_amount
end

#bid_strategyObject

Returns the value of attribute bid_strategy.



26
27
28
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 26

def bid_strategy
  @bid_strategy
end

#budgetObject

Returns the value of attribute budget.



22
23
24
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 22

def budget
  @budget
end

#budget_levelObject

Returns the value of attribute budget_level.



24
25
26
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 24

def budget_level
  @budget_level
end

#platform_specific_dataObject

Returns the value of attribute platform_specific_data.



35
36
37
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 35

def platform_specific_data
  @platform_specific_data
end

#portfolio_bid_strategy_idObject

Google only. Echoed back, but NOT mirrored onto local Ad documents (no column for it yet).



33
34
35
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 33

def portfolio_bid_strategy_id
  @portfolio_bid_strategy_id
end

#roas_average_floorObject

Returns the value of attribute roas_average_floor.



30
31
32
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 30

def roas_average_floor
  @roas_average_floor
end

#updatedObject

Local Ad documents mirrored. 0 on the empty-campaign path.



20
21
22
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 20

def updated
  @updated
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 60

def self.attribute_map
  {
    :'updated' => :'updated',
    :'budget' => :'budget',
    :'budget_level' => :'budgetLevel',
    :'bid_strategy' => :'bidStrategy',
    :'bid_amount' => :'bidAmount',
    :'roas_average_floor' => :'roasAverageFloor',
    :'portfolio_bid_strategy_id' => :'portfolioBidStrategyId',
    :'platform_specific_data' => :'platformSpecificData'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 209

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 84

def self.openapi_types
  {
    :'updated' => :'Integer',
    :'budget' => :'AdCampaignBudget',
    :'budget_level' => :'String',
    :'bid_strategy' => :'BidStrategy',
    :'bid_amount' => :'Float',
    :'roas_average_floor' => :'Float',
    :'portfolio_bid_strategy_id' => :'String',
    :'platform_specific_data' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      updated == o.updated &&
      budget == o.budget &&
      budget_level == o.budget_level &&
      bid_strategy == o.bid_strategy &&
      bid_amount == o.bid_amount &&
      roas_average_floor == o.roas_average_floor &&
      portfolio_bid_strategy_id == o.portfolio_bid_strategy_id &&
      platform_specific_data == o.platform_specific_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


196
197
198
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 196

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



202
203
204
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 202

def hash
  [updated, budget, budget_level, bid_strategy, bid_amount, roas_average_floor, portfolio_bid_strategy_id, platform_specific_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 231

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
# File 'lib/zernio-sdk/models/update_ad_campaign200_response.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  budget_level_validator = EnumAttributeValidator.new('String', ["campaign"])
  return false unless budget_level_validator.valid?(@budget_level)
  true
end