Class: Zernio::UpdateAdRequestTargetingDevicesInnerOneOf
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAdRequestTargetingDevicesInnerOneOf
- Defined in:
- lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bid_modifier ⇒ Object
Google device bid modifier.
-
#device ⇒ Object
Returns the value of attribute device.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAdRequestTargetingDevicesInnerOneOf
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAdRequestTargetingDevicesInnerOneOf
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdRequestTargetingDevicesInnerOneOf` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdRequestTargetingDevicesInnerOneOf`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'device') self.device = attributes[:'device'] else self.device = nil end if attributes.key?(:'bid_modifier') self.bid_modifier = attributes[:'bid_modifier'] end end |
Instance Attribute Details
#bid_modifier ⇒ Object
Google device bid modifier. 0 switches the device off (minus 100%); otherwise 0.1 to 10 (minus 90% to plus 900%). Google rejects any value between 0 and 0.1.
21 22 23 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 21 def bid_modifier @bid_modifier end |
#device ⇒ Object
Returns the value of attribute device.
18 19 20 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 18 def device @device end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 46 def self.attribute_map { :'device' => :'device', :'bid_modifier' => :'bidModifier' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 64 def self.openapi_types { :'device' => :'String', :'bid_modifier' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && device == o.device && bid_modifier == o.bid_modifier end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 181 def hash [device, bid_modifier].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @device.nil? invalid_properties.push('invalid value for "device", device cannot be nil.') end if !@bid_modifier.nil? && @bid_modifier > 10 invalid_properties.push('invalid value for "bid_modifier", must be smaller than or equal to 10.') end if !@bid_modifier.nil? && @bid_modifier < 0 invalid_properties.push('invalid value for "bid_modifier", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/update_ad_request_targeting_devices_inner_one_of.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @device.nil? device_validator = EnumAttributeValidator.new('String', ["MOBILE", "DESKTOP", "TABLET", "CONNECTED_TV"]) return false unless device_validator.valid?(@device) return false if !@bid_modifier.nil? && @bid_modifier > 10 return false if !@bid_modifier.nil? && @bid_modifier < 0 true end |