Class: Zernio::UpdateBidStrategyRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_bid_strategy_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateBidStrategyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateBidStrategyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateBidStrategyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'target_cpa')
    self.target_cpa = attributes[:'target_cpa']
  end

  if attributes.key?(:'target_roas')
    self.target_roas = attributes[:'target_roas']
  end
end

Instance Attribute Details

#account_id ⇒ Object

Google ads SocialAccount id.



19
20
21
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 19

def 
  @account_id
end

#ad_account_id ⇒ Object

Platform ad account ID (Google customer ID, digits only). Defaults to the account's connected customer.



22
23
24
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 22

def 
  @ad_account_id
end

#customer_id ⇒ Object

Alias of adAccountId, kept for existing callers



25
26
27
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 25

def customer_id
  @customer_id
end

#name ⇒ Object

Returns the value of attribute name.



27
28
29
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 27

def name
  @name
end

#target_cpa ⇒ Object

Returns the value of attribute target_cpa.



31
32
33
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 31

def target_cpa
  @target_cpa
end

#target_roas ⇒ Object

Returns the value of attribute target_roas.



33
34
35
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 33

def target_roas
  @target_roas
end

#type ⇒ Object

Returns the value of attribute type.



29
30
31
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 29

def type
  @type
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 58

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'ad_account_id' => :'adAccountId',
    :'customer_id' => :'customerId',
    :'name' => :'name',
    :'type' => :'type',
    :'target_cpa' => :'targetCpa',
    :'target_roas' => :'targetRoas'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 245

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



94
95
96
97
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 81

def self.openapi_types
  {
    :'account_id' => :'String',
    :'ad_account_id' => :'String',
    :'customer_id' => :'String',
    :'name' => :'String',
    :'type' => :'String',
    :'target_cpa' => :'Float',
    :'target_roas' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



218
219
220
221
222
223
224
225
226
227
228
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      customer_id == o.customer_id &&
      name == o.name &&
      type == o.type &&
      target_cpa == o.target_cpa &&
      target_roas == o.target_roas
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 232

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



238
239
240
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 238

def hash
  [, , customer_id, name, type, target_cpa, target_roas].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 255
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 267

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



168
169
170
171
172
173
174
175
176
# File 'lib/zernio-sdk/models/update_bid_strategy_request.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if !@name.nil? && @name.to_s.length > 255
  return false if !@name.nil? && @name.to_s.length < 1
  type_validator = EnumAttributeValidator.new('String', ["TARGET_CPA", "TARGET_ROAS", "MAXIMIZE_CONVERSIONS", "MAXIMIZE_CONVERSION_VALUE"])
  return false unless type_validator.valid?(@type)
  true
end