Class: Zernio::UpdateCampaignTargeting200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_campaign_targeting200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCampaignTargeting200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateCampaignTargeting200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateCampaignTargeting200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'updated')
    if (value = attributes[:'updated']).is_a?(Array)
      self.updated = value
    end
  end

  if attributes.key?(:'location_targeting_type')
    self.location_targeting_type = attributes[:'location_targeting_type']
  end

  if attributes.key?(:'devices')
    if (value = attributes[:'devices']).is_a?(Array)
      self.devices = value
    end
  end

  if attributes.key?(:'locations')
    if (value = attributes[:'locations']).is_a?(Array)
      self.locations = value
    end
  end

  if attributes.key?(:'languages')
    if (value = attributes[:'languages']).is_a?(Array)
      self.languages = value
    end
  end
end

Instance Attribute Details

#campaign_id ⇒ Object

Returns the value of attribute campaign_id.



18
19
20
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 18

def campaign_id
  @campaign_id
end

#devices ⇒ Object

Returns the value of attribute devices.



26
27
28
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 26

def devices
  @devices
end

#languages ⇒ Object

Returns the value of attribute languages.



30
31
32
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 30

def languages
  @languages
end

#location_targeting_type ⇒ Object

The value read back from Google after the edit.



24
25
26
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 24

def location_targeting_type
  @location_targeting_type
end

#locations ⇒ Object

Returns the value of attribute locations.



28
29
30
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 28

def locations
  @locations
end

#updated ⇒ Object

Which targeting fields were applied.



21
22
23
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 21

def updated
  @updated
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



67
68
69
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 55

def self.attribute_map
  {
    :'campaign_id' => :'campaignId',
    :'updated' => :'updated',
    :'location_targeting_type' => :'locationTargetingType',
    :'devices' => :'devices',
    :'locations' => :'locations',
    :'languages' => :'languages'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 199

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



89
90
91
92
93
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 89

def self.openapi_nullable
  Set.new([
    :'location_targeting_type',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 77

def self.openapi_types
  {
    :'campaign_id' => :'String',
    :'updated' => :'Array<String>',
    :'location_targeting_type' => :'String',
    :'devices' => :'Array<UpdateCampaignTargeting200ResponseDevicesInner>',
    :'locations' => :'Array<UpdateCampaignTargeting200ResponseLocationsInner>',
    :'languages' => :'Array<UpdateCampaignTargeting200ResponseLanguagesInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



173
174
175
176
177
178
179
180
181
182
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      campaign_id == o.campaign_id &&
      updated == o.updated &&
      location_targeting_type == o.location_targeting_type &&
      devices == o.devices &&
      locations == o.locations &&
      languages == o.languages
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 186

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



192
193
194
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 192

def hash
  [campaign_id, updated, location_targeting_type, devices, locations, languages].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



154
155
156
157
158
159
# File 'lib/zernio-sdk/models/update_campaign_targeting200_response.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  location_targeting_type_validator = EnumAttributeValidator.new('String', ["presence", "presence_or_interest"])
  return false unless location_targeting_type_validator.valid?(@location_targeting_type)
  true
end