Class: Zernio::UpdateDiscordScheduledEventRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_discord_scheduled_event_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateDiscordScheduledEventRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateDiscordScheduledEventRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateDiscordScheduledEventRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'starts_at')
    self.starts_at = attributes[:'starts_at']
  end

  if attributes.key?(:'ends_at')
    self.ends_at = attributes[:'ends_at']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'image_data_uri')
    self.image_data_uri = attributes[:'image_data_uri']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 18

def 
  @account_id
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 22

def description
  @description
end

#ends_atObject

Returns the value of attribute ends_at.



26
27
28
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 26

def ends_at
  @ends_at
end

#image_data_uriObject

Returns the value of attribute image_data_uri.



34
35
36
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 34

def image_data_uri
  @image_data_uri
end

#locationObject

For external events.



29
30
31
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 29

def location
  @location
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 20

def name
  @name
end

#starts_atObject

Returns the value of attribute starts_at.



24
25
26
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 24

def starts_at
  @starts_at
end

#statusObject

Status transition. Most common: 'cancelled' to cancel an event.



32
33
34
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 32

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 59

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'name' => :'name',
    :'description' => :'description',
    :'starts_at' => :'startsAt',
    :'ends_at' => :'endsAt',
    :'location' => :'location',
    :'status' => :'status',
    :'image_data_uri' => :'imageDataUri'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 321

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 83

def self.openapi_types
  {
    :'account_id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'starts_at' => :'Time',
    :'ends_at' => :'Time',
    :'location' => :'String',
    :'status' => :'String',
    :'image_data_uri' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      description == o.description &&
      starts_at == o.starts_at &&
      ends_at == o.ends_at &&
      location == o.location &&
      status == o.status &&
      image_data_uri == o.image_data_uri
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


308
309
310
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 308

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



314
315
316
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 314

def hash
  [, name, description, starts_at, ends_at, location, status, image_data_uri].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if !@description.nil? && @description.to_s.length > 1000
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 1000.')
  end

  if !@location.nil? && @location.to_s.length > 100
    invalid_properties.push('invalid value for "location", the character length must be smaller than or equal to 100.')
  end

  if !@location.nil? && @location.to_s.length < 1
    invalid_properties.push('invalid value for "location", the character length must be greater than or equal to 1.')
  end

  pattern = Regexp.new(/^data:image\/(png|jpeg|gif);base64,/)
  if !@image_data_uri.nil? && @image_data_uri !~ pattern
    invalid_properties.push("invalid value for \"image_data_uri\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zernio-sdk/models/update_discord_scheduled_event_request.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if !@name.nil? && @name.to_s.length > 100
  return false if !@name.nil? && @name.to_s.length < 1
  return false if !@description.nil? && @description.to_s.length > 1000
  return false if !@location.nil? && @location.to_s.length > 100
  return false if !@location.nil? && @location.to_s.length < 1
  status_validator = EnumAttributeValidator.new('String', ["scheduled", "active", "completed", "cancelled"])
  return false unless status_validator.valid?(@status)
  return false if !@image_data_uri.nil? && @image_data_uri !~ Regexp.new(/^data:image\/(png|jpeg|gif);base64,/)
  true
end