Class: Zernio::UpdateGoogleAssetGroupRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateGoogleAssetGroupRequest
- Defined in:
- lib/zernio-sdk/models/update_google_asset_group_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#final_mobile_urls ⇒ Object
Returns the value of attribute final_mobile_urls.
-
#final_urls ⇒ Object
Returns the value of attribute final_urls.
-
#name ⇒ Object
Returns the value of attribute name.
-
#path1 ⇒ Object
Returns the value of attribute path1.
-
#path2 ⇒ Object
Returns the value of attribute path2.
-
#status ⇒ Object
Returns the value of attribute status.
-
#validate_only ⇒ Object
Returns the value of attribute validate_only.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateGoogleAssetGroupRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateGoogleAssetGroupRequest
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateGoogleAssetGroupRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateGoogleAssetGroupRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'final_urls') if (value = attributes[:'final_urls']).is_a?(Array) self.final_urls = value end end if attributes.key?(:'final_mobile_urls') if (value = attributes[:'final_mobile_urls']).is_a?(Array) self.final_mobile_urls = value end end if attributes.key?(:'path1') self.path1 = attributes[:'path1'] end if attributes.key?(:'path2') self.path2 = attributes[:'path2'] end if attributes.key?(:'validate_only') self.validate_only = attributes[:'validate_only'] else self.validate_only = false end end |
Instance Attribute Details
#final_mobile_urls ⇒ Object
Returns the value of attribute final_mobile_urls.
24 25 26 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 24 def final_mobile_urls @final_mobile_urls end |
#final_urls ⇒ Object
Returns the value of attribute final_urls.
22 23 24 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 22 def final_urls @final_urls end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 18 def name @name end |
#path1 ⇒ Object
Returns the value of attribute path1.
26 27 28 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 26 def path1 @path1 end |
#path2 ⇒ Object
Returns the value of attribute path2.
28 29 30 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 28 def path2 @path2 end |
#status ⇒ Object
Returns the value of attribute status.
20 21 22 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 20 def status @status end |
#validate_only ⇒ Object
Returns the value of attribute validate_only.
30 31 32 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 30 def validate_only @validate_only end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 55 def self.attribute_map { :'name' => :'name', :'status' => :'status', :'final_urls' => :'finalUrls', :'final_mobile_urls' => :'finalMobileUrls', :'path1' => :'path1', :'path2' => :'path2', :'validate_only' => :'validateOnly' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 319 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 95 96 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 91 def self.openapi_nullable Set.new([ :'path1', :'path2', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 78 def self.openapi_types { :'name' => :'String', :'status' => :'String', :'final_urls' => :'Array<String>', :'final_mobile_urls' => :'Array<String>', :'path1' => :'String', :'path2' => :'String', :'validate_only' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 292 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && status == o.status && final_urls == o.final_urls && final_mobile_urls == o.final_mobile_urls && path1 == o.path1 && path2 == o.path2 && validate_only == o.validate_only end |
#eql?(o) ⇒ Boolean
306 307 308 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 306 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
312 313 314 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 312 def hash [name, status, final_urls, final_mobile_urls, path1, path2, validate_only].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@final_urls.nil? && @final_urls.length > 10 invalid_properties.push('invalid value for "final_urls", number of items must be less than or equal to 10.') end if !@final_urls.nil? && @final_urls.length < 1 invalid_properties.push('invalid value for "final_urls", number of items must be greater than or equal to 1.') end if !@final_mobile_urls.nil? && @final_mobile_urls.length > 10 invalid_properties.push('invalid value for "final_mobile_urls", number of items must be less than or equal to 10.') end if !@final_mobile_urls.nil? && @final_mobile_urls.length < 1 invalid_properties.push('invalid value for "final_mobile_urls", number of items must be greater than or equal to 1.') end if !@path1.nil? && @path1.to_s.length > 15 invalid_properties.push('invalid value for "path1", the character length must be smaller than or equal to 15.') end if !@path2.nil? && @path2.to_s.length > 15 invalid_properties.push('invalid value for "path2", the character length must be smaller than or equal to 15.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 341 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/zernio-sdk/models/update_google_asset_group_request.rb', line 191 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 128 return false if !@name.nil? && @name.to_s.length < 1 status_validator = EnumAttributeValidator.new('String', ["ENABLED", "PAUSED"]) return false unless status_validator.valid?(@status) return false if !@final_urls.nil? && @final_urls.length > 10 return false if !@final_urls.nil? && @final_urls.length < 1 return false if !@final_mobile_urls.nil? && @final_mobile_urls.length > 10 return false if !@final_mobile_urls.nil? && @final_mobile_urls.length < 1 return false if !@path1.nil? && @path1.to_s.length > 15 return false if !@path2.nil? && @path2.to_s.length > 15 true end |