Class: Zernio::UpdateGoogleBusinessLocationDetailsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_google_business_location_details_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateGoogleBusinessLocationDetailsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateGoogleBusinessLocationDetailsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateGoogleBusinessLocationDetailsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'update_mask')
    self.update_mask = attributes[:'update_mask']
  else
    self.update_mask = nil
  end

  if attributes.key?(:'regular_hours')
    self.regular_hours = attributes[:'regular_hours']
  end

  if attributes.key?(:'special_hours')
    self.special_hours = attributes[:'special_hours']
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  end

  if attributes.key?(:'website_uri')
    self.website_uri = attributes[:'website_uri']
  end

  if attributes.key?(:'phone_numbers')
    self.phone_numbers = attributes[:'phone_numbers']
  end

  if attributes.key?(:'categories')
    self.categories = attributes[:'categories']
  end

  if attributes.key?(:'service_items')
    if (value = attributes[:'service_items']).is_a?(Array)
      self.service_items = value
    end
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'store_code')
    self.store_code = attributes[:'store_code']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end

  if attributes.key?(:'storefront_address')
    self.storefront_address = attributes[:'storefront_address']
  end

  if attributes.key?(:'service_area')
    self.service_area = attributes[:'service_area']
  end

  if attributes.key?(:'open_info')
    self.open_info = attributes[:'open_info']
  end

  if attributes.key?(:'more_hours')
    if (value = attributes[:'more_hours']).is_a?(Array)
      self.more_hours = value
    end
  end

  if attributes.key?(:'latlng')
    self.latlng = attributes[:'latlng']
  end

  if attributes.key?(:'ad_words_location_extensions')
    self.ad_words_location_extensions = attributes[:'ad_words_location_extensions']
  end
end

Instance Attribute Details

#ad_words_location_extensionsObject

Returns the value of attribute ad_words_location_extensions.



56
57
58
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 56

def ad_words_location_extensions
  @ad_words_location_extensions
end

#categoriesObject

Returns the value of attribute categories.



31
32
33
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 31

def categories
  @categories
end

#labelsObject

Free-form, internal-only labels for grouping (1-255 characters each). Use updateMask='labels'.



43
44
45
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 43

def labels
  @labels
end

#latlngObject

Returns the value of attribute latlng.



54
55
56
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 54

def latlng
  @latlng
end

#more_hoursObject

Additional hours for specific services (delivery, drive-through, etc.). Use updateMask='moreHours'.



52
53
54
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 52

def more_hours
  @more_hours
end

#open_infoObject

Returns the value of attribute open_info.



49
50
51
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 49

def open_info
  @open_info
end

#phone_numbersObject

Returns the value of attribute phone_numbers.



29
30
31
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 29

def phone_numbers
  @phone_numbers
end

#profileObject

Returns the value of attribute profile.



25
26
27
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 25

def profile
  @profile
end

#regular_hoursObject

Returns the value of attribute regular_hours.



21
22
23
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 21

def regular_hours
  @regular_hours
end

#service_areaObject

Returns the value of attribute service_area.



47
48
49
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 47

def service_area
  @service_area
end

#service_itemsObject

Services offered by the business. Use updateMask='serviceItems' to update.



34
35
36
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 34

def service_items
  @service_items
end

#special_hoursObject

Returns the value of attribute special_hours.



23
24
25
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 23

def special_hours
  @special_hours
end

#store_codeObject

External store identifier, unique within the account. Use updateMask='storeCode'.



40
41
42
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 40

def store_code
  @store_code
end

#storefront_addressObject

Returns the value of attribute storefront_address.



45
46
47
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 45

def storefront_address
  @storefront_address
end

#titleObject

Business name. Use updateMask='title'.



37
38
39
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 37

def title
  @title
end

#update_maskObject

Required. Comma-separated fields to update (e.g. 'regularHours', 'specialHours', 'profile.description', 'categories', 'serviceItems'). Any valid Google Business Information API updateMask field is supported.



19
20
21
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 19

def update_mask
  @update_mask
end

#website_uriObject

Returns the value of attribute website_uri.



27
28
29
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 27

def website_uri
  @website_uri
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 59

def self.attribute_map
  {
    :'update_mask' => :'updateMask',
    :'regular_hours' => :'regularHours',
    :'special_hours' => :'specialHours',
    :'profile' => :'profile',
    :'website_uri' => :'websiteUri',
    :'phone_numbers' => :'phoneNumbers',
    :'categories' => :'categories',
    :'service_items' => :'serviceItems',
    :'title' => :'title',
    :'store_code' => :'storeCode',
    :'labels' => :'labels',
    :'storefront_address' => :'storefrontAddress',
    :'service_area' => :'serviceArea',
    :'open_info' => :'openInfo',
    :'more_hours' => :'moreHours',
    :'latlng' => :'latlng',
    :'ad_words_location_extensions' => :'adWordsLocationExtensions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 282

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 92

def self.openapi_types
  {
    :'update_mask' => :'String',
    :'regular_hours' => :'UpdateGoogleBusinessLocationDetailsRequestRegularHours',
    :'special_hours' => :'GetGoogleBusinessLocationDetails200ResponseSpecialHours',
    :'profile' => :'UpdateGoogleBusinessLocationDetailsRequestProfile',
    :'website_uri' => :'String',
    :'phone_numbers' => :'GetGoogleBusinessLocationDetails200ResponsePhoneNumbers',
    :'categories' => :'UpdateGoogleBusinessLocationDetailsRequestCategories',
    :'service_items' => :'Array<UpdateGoogleBusinessLocationDetailsRequestServiceItemsInner>',
    :'title' => :'String',
    :'store_code' => :'String',
    :'labels' => :'Array<String>',
    :'storefront_address' => :'UpdateGoogleBusinessLocationDetailsRequestStorefrontAddress',
    :'service_area' => :'UpdateGoogleBusinessLocationDetailsRequestServiceArea',
    :'open_info' => :'UpdateGoogleBusinessLocationDetailsRequestOpenInfo',
    :'more_hours' => :'Array<UpdateGoogleBusinessLocationDetailsRequestMoreHoursInner>',
    :'latlng' => :'UpdateGoogleBusinessLocationDetailsRequestLatlng',
    :'ad_words_location_extensions' => :'UpdateGoogleBusinessLocationDetailsRequestAdWordsLocationExtensions'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      update_mask == o.update_mask &&
      regular_hours == o.regular_hours &&
      special_hours == o.special_hours &&
      profile == o.profile &&
      website_uri == o.website_uri &&
      phone_numbers == o.phone_numbers &&
      categories == o.categories &&
      service_items == o.service_items &&
      title == o.title &&
      store_code == o.store_code &&
      labels == o.labels &&
      storefront_address == o.storefront_address &&
      service_area == o.service_area &&
      open_info == o.open_info &&
      more_hours == o.more_hours &&
      latlng == o.latlng &&
      ad_words_location_extensions == o.ad_words_location_extensions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


269
270
271
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 269

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



275
276
277
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 275

def hash
  [update_mask, regular_hours, special_hours, profile, website_uri, phone_numbers, categories, service_items, title, store_code, labels, storefront_address, service_area, open_info, more_hours, latlng, ad_words_location_extensions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 215

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @update_mask.nil?
    invalid_properties.push('invalid value for "update_mask", update_mask cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 304

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



227
228
229
230
231
# File 'lib/zernio-sdk/models/update_google_business_location_details_request.rb', line 227

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @update_mask.nil?
  true
end