Class: Zernio::UpdateGoogleBusinessPlaceActionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateGoogleBusinessPlaceActionRequest
- Defined in:
- lib/zernio-sdk/models/update_google_business_place_action_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#name ⇒ Object
Resource name of the place action link (e.g. locations/123/placeActionLinks/456).
-
#place_action_type ⇒ Object
New action type.
-
#uri ⇒ Object
New action URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateGoogleBusinessPlaceActionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateGoogleBusinessPlaceActionRequest
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateGoogleBusinessPlaceActionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateGoogleBusinessPlaceActionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'uri') self.uri = attributes[:'uri'] end if attributes.key?(:'place_action_type') self.place_action_type = attributes[:'place_action_type'] end end |
Instance Attribute Details
#name ⇒ Object
Resource name of the place action link (e.g. locations/123/placeActionLinks/456)
19 20 21 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 19 def name @name end |
#place_action_type ⇒ Object
New action type
25 26 27 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 25 def place_action_type @place_action_type end |
#uri ⇒ Object
New action URL
22 23 24 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 22 def uri @uri end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
59 60 61 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 59 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
64 65 66 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 64 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 50 def self.attribute_map { :'name' => :'name', :'uri' => :'uri', :'place_action_type' => :'placeActionType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 69 def self.openapi_types { :'name' => :'String', :'uri' => :'String', :'place_action_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 158 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && uri == o.uri && place_action_type == o.place_action_type end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 174 def hash [name, uri, place_action_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/update_google_business_place_action_request.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? place_action_type_validator = EnumAttributeValidator.new('String', ["APPOINTMENT", "ONLINE_APPOINTMENT", "DINING_RESERVATION", "FOOD_ORDERING", "FOOD_DELIVERY", "FOOD_TAKEOUT", "SHOP_ONLINE"]) return false unless place_action_type_validator.valid?(@place_action_type) true end |