Class: Zernio::UpdateImessageSenderRequestContact
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateImessageSenderRequestContact
- Defined in:
- lib/zernio-sdk/models/update_imessage_sender_request_contact.rb
Instance Attribute Summary collapse
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#photo_url ⇒ Object
Square image.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateImessageSenderRequestContact
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateImessageSenderRequestContact
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateImessageSenderRequestContact` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateImessageSenderRequestContact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] else self.first_name = nil end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'photo_url') self.photo_url = attributes[:'photo_url'] end end |
Instance Attribute Details
#first_name ⇒ Object
Returns the value of attribute first_name.
18 19 20 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 18 def first_name @first_name end |
#last_name ⇒ Object
Returns the value of attribute last_name.
20 21 22 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 20 def last_name @last_name end |
#photo_url ⇒ Object
Square image
23 24 25 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 23 def photo_url @photo_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
35 36 37 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 35 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
40 41 42 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 40 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 32 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 26 def self.attribute_map { :'first_name' => :'firstName', :'last_name' => :'lastName', :'photo_url' => :'photoUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 173 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
54 55 56 57 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 54 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
45 46 47 48 49 50 51 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 45 def self.openapi_types { :'first_name' => :'String', :'last_name' => :'String', :'photo_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && first_name == o.first_name && last_name == o.last_name && photo_url == o.photo_url end |
#eql?(o) ⇒ Boolean
160 161 162 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 160 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
166 167 168 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 166 def hash [first_name, last_name, photo_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 92 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @first_name.nil? invalid_properties.push('invalid value for "first_name", first_name cannot be nil.') end if @first_name.to_s.length > 64 invalid_properties.push('invalid value for "first_name", the character length must be smaller than or equal to 64.') end if !@last_name.nil? && @last_name.to_s.length > 64 invalid_properties.push('invalid value for "last_name", the character length must be smaller than or equal to 64.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 195 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 117 118 |
# File 'lib/zernio-sdk/models/update_imessage_sender_request_contact.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @first_name.nil? return false if @first_name.to_s.length > 64 return false if !@last_name.nil? && @last_name.to_s.length > 64 true end |