Class: Zernio::UpdateRcsAgentRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_rcs_agent_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateRcsAgentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateRcsAgentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateRcsAgentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'use_case')
    self.use_case = attributes[:'use_case']
  end

  if attributes.key?(:'profile')
    self.profile = attributes[:'profile']
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'sms_fallback_from')
    self.sms_fallback_from = attributes[:'sms_fallback_from']
  end
end

Instance Attribute Details

#brand ⇒ Object

Returns the value of attribute brand.



24
25
26
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 24

def brand
  @brand
end

#display_name ⇒ Object

Returns the value of attribute display_name.



18
19
20
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 18

def display_name
  @display_name
end

#profile ⇒ Object

Returns the value of attribute profile.



22
23
24
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 22

def profile
  @profile
end

#sms_fallback_from ⇒ Object

Returns the value of attribute sms_fallback_from.



26
27
28
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 26

def sms_fallback_from
  @sms_fallback_from
end

#use_case ⇒ Object

Returns the value of attribute use_case.



20
21
22
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 20

def use_case
  @use_case
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



62
63
64
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
59
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 51

def self.attribute_map
  {
    :'display_name' => :'displayName',
    :'use_case' => :'useCase',
    :'profile' => :'profile',
    :'brand' => :'brand',
    :'sms_fallback_from' => :'smsFallbackFrom'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 199

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



83
84
85
86
87
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 83

def self.openapi_nullable
  Set.new([
    :'sms_fallback_from'
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 72

def self.openapi_types
  {
    :'display_name' => :'String',
    :'use_case' => :'String',
    :'profile' => :'RcsAgentProfile',
    :'brand' => :'RcsBrandInput',
    :'sms_fallback_from' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



174
175
176
177
178
179
180
181
182
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_name == o.display_name &&
      use_case == o.use_case &&
      profile == o.profile &&
      brand == o.brand &&
      sms_fallback_from == o.sms_fallback_from
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 186

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



192
193
194
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 192

def hash
  [display_name, use_case, profile, brand, sms_fallback_from].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
133
134
135
136
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@display_name.nil? && @display_name.to_s.length > 40
    invalid_properties.push('invalid value for "display_name", the character length must be smaller than or equal to 40.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



140
141
142
143
144
145
146
# File 'lib/zernio-sdk/models/update_rcs_agent_request.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@display_name.nil? && @display_name.to_s.length > 40
  use_case_validator = EnumAttributeValidator.new('String', ["MULTI_USE", "PROMOTIONAL", "TRANSACTIONAL", "OTP"])
  return false unless use_case_validator.valid?(@use_case)
  true
end