Class: Zernio::UpdateWhatsAppCallingLegacyRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateWhatsAppCallingLegacyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateWhatsAppCallingLegacyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateWhatsAppCallingLegacyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'forward_to')
    self.forward_to = attributes[:'forward_to']
  end

  if attributes.key?(:'sip_auth_username')
    self.sip_auth_username = attributes[:'sip_auth_username']
  end

  if attributes.key?(:'sip_auth_password')
    self.sip_auth_password = attributes[:'sip_auth_password']
  end

  if attributes.key?(:'recording_enabled')
    self.recording_enabled = attributes[:'recording_enabled']
  end

  if attributes.key?(:'call_icon_countries')
    if (value = attributes[:'call_icon_countries']).is_a?(Array)
      self.call_icon_countries = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 18

def 
  @account_id
end

#call_icon_countriesObject

Returns the value of attribute call_icon_countries.



28
29
30
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 28

def call_icon_countries
  @call_icon_countries
end

#forward_toObject

Returns the value of attribute forward_to.



20
21
22
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 20

def forward_to
  @forward_to
end

#recording_enabledObject

Returns the value of attribute recording_enabled.



26
27
28
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 26

def recording_enabled
  @recording_enabled
end

#sip_auth_passwordObject

Returns the value of attribute sip_auth_password.



24
25
26
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 24

def sip_auth_password
  @sip_auth_password
end

#sip_auth_usernameObject

Returns the value of attribute sip_auth_username.



22
23
24
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 22

def sip_auth_username
  @sip_auth_username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 31

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'forward_to' => :'forwardTo',
    :'sip_auth_username' => :'sipAuthUsername',
    :'sip_auth_password' => :'sipAuthPassword',
    :'recording_enabled' => :'recordingEnabled',
    :'call_icon_countries' => :'callIconCountries'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
69
70
71
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 65

def self.openapi_nullable
  Set.new([
    :'sip_auth_username',
    :'sip_auth_password',
    :'call_icon_countries'
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 53

def self.openapi_types
  {
    :'account_id' => :'String',
    :'forward_to' => :'String',
    :'sip_auth_username' => :'String',
    :'sip_auth_password' => :'String',
    :'recording_enabled' => :'Boolean',
    :'call_icon_countries' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



150
151
152
153
154
155
156
157
158
159
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 150

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      forward_to == o.forward_to &&
      sip_auth_username == o.sip_auth_username &&
      sip_auth_password == o.sip_auth_password &&
      recording_enabled == o.recording_enabled &&
      call_icon_countries == o.call_icon_countries
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 169

def hash
  [, forward_to, sip_auth_username, sip_auth_password, recording_enabled, call_icon_countries].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
136
# File 'lib/zernio-sdk/models/update_whats_app_calling_legacy_request.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  true
end