Class: Zernio::UpdateWhatsAppFlowRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateWhatsAppFlowRequest
- Defined in:
- lib/zernio-sdk/models/update_whats_app_flow_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
WhatsApp social account ID.
-
#categories ⇒ Object
Returns the value of attribute categories.
-
#endpoint_uri ⇒ Object
HTTPS-only data exchange endpoint for the flow.
-
#name ⇒ Object
New flow name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWhatsAppFlowRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWhatsAppFlowRequest
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateWhatsAppFlowRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateWhatsAppFlowRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'categories') if (value = attributes[:'categories']).is_a?(Array) self.categories = value end end if attributes.key?(:'endpoint_uri') self.endpoint_uri = attributes[:'endpoint_uri'] end end |
Instance Attribute Details
#account_id ⇒ Object
WhatsApp social account ID
19 20 21 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 19 def account_id @account_id end |
#categories ⇒ Object
Returns the value of attribute categories.
24 25 26 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 24 def categories @categories end |
#endpoint_uri ⇒ Object
HTTPS-only data exchange endpoint for the flow. Settable only while the flow is in DRAFT, and the flow's uploaded Flow JSON must declare data_api_version "3.0" for the endpoint to be used.
27 28 29 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 27 def endpoint_uri @endpoint_uri end |
#name ⇒ Object
New flow name
22 23 24 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 22 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 52 def self.attribute_map { :'account_id' => :'accountId', :'name' => :'name', :'categories' => :'categories', :'endpoint_uri' => :'endpointUri' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 204 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 72 def self.openapi_types { :'account_id' => :'String', :'name' => :'String', :'categories' => :'Array<String>', :'endpoint_uri' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && name == o.name && categories == o.categories && endpoint_uri == o.endpoint_uri end |
#eql?(o) ⇒ Boolean
191 192 193 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 191 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
197 198 199 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 197 def hash [account_id, name, categories, endpoint_uri].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 126 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if !@name.nil? && @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end if !@categories.nil? && @categories.length < 1 invalid_properties.push('invalid value for "categories", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 226 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 150 151 152 |
# File 'lib/zernio-sdk/models/update_whats_app_flow_request.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if !@name.nil? && @name.to_s.length > 128 return false if !@categories.nil? && @categories.length < 1 true end |