Class: Zernio::UpdateWhatsAppGroupChatRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateWhatsAppGroupChatRequest
- Defined in:
- lib/zernio-sdk/models/update_whats_app_group_chat_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#join_approval_mode ⇒ Object
Returns the value of attribute join_approval_mode.
-
#subject ⇒ Object
Returns the value of attribute subject.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWhatsAppGroupChatRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWhatsAppGroupChatRequest
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateWhatsAppGroupChatRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateWhatsAppGroupChatRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'join_approval_mode') self.join_approval_mode = attributes[:'join_approval_mode'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
20 21 22 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 20 def description @description end |
#join_approval_mode ⇒ Object
Returns the value of attribute join_approval_mode.
22 23 24 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 22 def join_approval_mode @join_approval_mode end |
#subject ⇒ Object
Returns the value of attribute subject.
18 19 20 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 18 def subject @subject end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 47 def self.attribute_map { :'subject' => :'subject', :'description' => :'description', :'join_approval_mode' => :'joinApprovalMode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 199 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 66 def self.openapi_types { :'subject' => :'String', :'description' => :'String', :'join_approval_mode' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && subject == o.subject && description == o.description && join_approval_mode == o.join_approval_mode end |
#eql?(o) ⇒ Boolean
186 187 188 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 186 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
192 193 194 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 192 def hash [subject, description, join_approval_mode].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@subject.nil? && @subject.to_s.length > 128 invalid_properties.push('invalid value for "subject", the character length must be smaller than or equal to 128.') end if !@description.nil? && @description.to_s.length > 2048 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 2048.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 221 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/update_whats_app_group_chat_request.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@subject.nil? && @subject.to_s.length > 128 return false if !@description.nil? && @description.to_s.length > 2048 join_approval_mode_validator = EnumAttributeValidator.new('String', ["approval_required", "auto_approve"]) return false unless join_approval_mode_validator.valid?(@join_approval_mode) true end |