Class: Zernio::UsageMeteringDaysInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UsageMeteringDaysInner
- Defined in:
- lib/zernio-sdk/models/usage_metering_days_inner.rb
Instance Attribute Summary collapse
-
#accounts ⇒ Object
Returns the value of attribute accounts.
-
#ads ⇒ Object
Managed ads fees.
-
#calls ⇒ Object
Returns the value of attribute calls.
-
#credits ⇒ Object
Applied credits/discounts (negative).
-
#date ⇒ Object
Returns the value of attribute date.
-
#dlc ⇒ Object
10DLC registration (brand + campaign) fees.
-
#imessage ⇒ Object
iMessage sender fees.
-
#messages ⇒ Object
Managed outbound message fees.
-
#numbers ⇒ Object
Returns the value of attribute numbers.
-
#other ⇒ Object
Returns the value of attribute other.
-
#sms ⇒ Object
Returns the value of attribute sms.
-
#verify ⇒ Object
Verify (per verification) fees.
-
#x_api ⇒ Object
Returns the value of attribute x_api.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UsageMeteringDaysInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UsageMeteringDaysInner
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UsageMeteringDaysInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UsageMeteringDaysInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'accounts') self.accounts = attributes[:'accounts'] end if attributes.key?(:'numbers') self.numbers = attributes[:'numbers'] end if attributes.key?(:'imessage') self. = attributes[:'imessage'] end if attributes.key?(:'calls') self.calls = attributes[:'calls'] end if attributes.key?(:'sms') self.sms = attributes[:'sms'] end if attributes.key?(:'messages') self. = attributes[:'messages'] end if attributes.key?(:'verify') self.verify = attributes[:'verify'] end if attributes.key?(:'dlc') self.dlc = attributes[:'dlc'] end if attributes.key?(:'x_api') self.x_api = attributes[:'x_api'] end if attributes.key?(:'ads') self.ads = attributes[:'ads'] end if attributes.key?(:'credits') self.credits = attributes[:'credits'] end if attributes.key?(:'other') self.other = attributes[:'other'] end end |
Instance Attribute Details
#accounts ⇒ Object
Returns the value of attribute accounts.
20 21 22 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 20 def accounts @accounts end |
#ads ⇒ Object
Managed ads fees.
43 44 45 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 43 def ads @ads end |
#calls ⇒ Object
Returns the value of attribute calls.
27 28 29 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 27 def calls @calls end |
#credits ⇒ Object
Applied credits/discounts (negative).
46 47 48 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 46 def credits @credits end |
#date ⇒ Object
Returns the value of attribute date.
18 19 20 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 18 def date @date end |
#dlc ⇒ Object
10DLC registration (brand + campaign) fees.
38 39 40 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 38 def dlc @dlc end |
#imessage ⇒ Object
iMessage sender fees.
25 26 27 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 25 def @imessage end |
#messages ⇒ Object
Managed outbound message fees.
32 33 34 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 32 def @messages end |
#numbers ⇒ Object
Returns the value of attribute numbers.
22 23 24 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 22 def numbers @numbers end |
#other ⇒ Object
Returns the value of attribute other.
48 49 50 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 48 def other @other end |
#sms ⇒ Object
Returns the value of attribute sms.
29 30 31 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 29 def sms @sms end |
#verify ⇒ Object
Verify (per verification) fees.
35 36 37 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 35 def verify @verify end |
#x_api ⇒ Object
Returns the value of attribute x_api.
40 41 42 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 40 def x_api @x_api end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 51 def self.attribute_map { :'date' => :'date', :'accounts' => :'accounts', :'numbers' => :'numbers', :'imessage' => :'imessage', :'calls' => :'calls', :'sms' => :'sms', :'messages' => :'messages', :'verify' => :'verify', :'dlc' => :'dlc', :'x_api' => :'xApi', :'ads' => :'ads', :'credits' => :'credits', :'other' => :'other' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 80 def self.openapi_types { :'date' => :'Date', :'accounts' => :'Float', :'numbers' => :'Float', :'imessage' => :'Float', :'calls' => :'Float', :'sms' => :'Float', :'messages' => :'Float', :'verify' => :'Float', :'dlc' => :'Float', :'x_api' => :'Float', :'ads' => :'Float', :'credits' => :'Float', :'other' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 190 def ==(o) return true if self.equal?(o) self.class == o.class && date == o.date && accounts == o.accounts && numbers == o.numbers && == o. && calls == o.calls && sms == o.sms && == o. && verify == o.verify && dlc == o.dlc && x_api == o.x_api && ads == o.ads && credits == o.credits && other == o.other end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 216 def hash [date, accounts, numbers, , calls, sms, , verify, dlc, x_api, ads, credits, other].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
183 184 185 186 |
# File 'lib/zernio-sdk/models/usage_metering_days_inner.rb', line 183 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |