Class: Zernio::UsersApi
- Inherits:
-
Object
- Object
- Zernio::UsersApi
- Defined in:
- lib/zernio-sdk/api/users_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_user(user_id, opts = {}) ⇒ GetUser200Response
Get user Returns a single user's details by ID, including name, email, and role.
-
#get_user_with_http_info(user_id, opts = {}) ⇒ Array<(GetUser200Response, Integer, Hash)>
Get user Returns a single user's details by ID, including name, email, and role.
-
#initialize(api_client = ApiClient.default) ⇒ UsersApi
constructor
A new instance of UsersApi.
-
#list_users(opts = {}) ⇒ ListUsers200Response
List users Returns all users in the workspace including roles and profile access.
-
#list_users_with_http_info(opts = {}) ⇒ Array<(ListUsers200Response, Integer, Hash)>
List users Returns all users in the workspace including roles and profile access.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/users_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_user(user_id, opts = {}) ⇒ GetUser200Response
Get user Returns a single user's details by ID, including name, email, and role.
27 28 29 30 |
# File 'lib/zernio-sdk/api/users_api.rb', line 27 def get_user(user_id, opts = {}) data, _status_code, _headers = get_user_with_http_info(user_id, opts) data end |
#get_user_with_http_info(user_id, opts = {}) ⇒ Array<(GetUser200Response, Integer, Hash)>
Get user Returns a single user's details by ID, including name, email, and role.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zernio-sdk/api/users_api.rb', line 37 def get_user_with_http_info(user_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_user ...' end # verify the required parameter 'user_id' is set if @api_client.config.client_side_validation && user_id.nil? fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersApi.get_user" end # resource path local_var_path = '/v1/users/{userId}'.sub('{' + 'userId' + '}', CGI.escape(user_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetUser200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"UsersApi.get_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_users(opts = {}) ⇒ ListUsers200Response
List users Returns all users in the workspace including roles and profile access. Also returns the currentUserId of the caller.
89 90 91 92 |
# File 'lib/zernio-sdk/api/users_api.rb', line 89 def list_users(opts = {}) data, _status_code, _headers = list_users_with_http_info(opts) data end |
#list_users_with_http_info(opts = {}) ⇒ Array<(ListUsers200Response, Integer, Hash)>
List users Returns all users in the workspace including roles and profile access. Also returns the currentUserId of the caller.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/zernio-sdk/api/users_api.rb', line 98 def list_users_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.list_users ...' end # resource path local_var_path = '/v1/users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListUsers200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"UsersApi.list_users", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#list_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |