Class: Zernio::Verification

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/verification.rb

Overview

A managed OTP verification. The code itself is never returned or stored (hash only).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Verification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/zernio-sdk/models/verification.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::Verification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::Verification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'channel')
    self.channel = attributes[:'channel']
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'attempts')
    self.attempts = attributes[:'attempts']
  end

  if attributes.key?(:'max_attempts')
    self.max_attempts = attributes[:'max_attempts']
  end

  if attributes.key?(:'send_count')
    self.send_count = attributes[:'send_count']
  end

  if attributes.key?(:'last_sent_at')
    self.last_sent_at = attributes[:'last_sent_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'resend')
    self.resend = attributes[:'resend']
  end
end

Instance Attribute Details

#attemptsObject

Returns the value of attribute attempts.



29
30
31
# File 'lib/zernio-sdk/models/verification.rb', line 29

def attempts
  @attempts
end

#channelObject

Returns the value of attribute channel.



23
24
25
# File 'lib/zernio-sdk/models/verification.rb', line 23

def channel
  @channel
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/zernio-sdk/models/verification.rb', line 38

def created_at
  @created_at
end

#expires_atObject

Returns the value of attribute expires_at.



27
28
29
# File 'lib/zernio-sdk/models/verification.rb', line 27

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/zernio-sdk/models/verification.rb', line 19

def id
  @id
end

#last_sent_atObject

Returns the value of attribute last_sent_at.



36
37
38
# File 'lib/zernio-sdk/models/verification.rb', line 36

def last_sent_at
  @last_sent_at
end

#max_attemptsObject

Returns the value of attribute max_attempts.



31
32
33
# File 'lib/zernio-sdk/models/verification.rb', line 31

def max_attempts
  @max_attempts
end

#resendObject

Present on create responses: true when an active verification was resent instead of created.



41
42
43
# File 'lib/zernio-sdk/models/verification.rb', line 41

def resend
  @resend
end

#send_countObject

Accepted deliveries (initial send + resends); each bills one verification fee.



34
35
36
# File 'lib/zernio-sdk/models/verification.rb', line 34

def send_count
  @send_count
end

#statusObject

Returns the value of attribute status.



21
22
23
# File 'lib/zernio-sdk/models/verification.rb', line 21

def status
  @status
end

#toObject

Returns the value of attribute to.



25
26
27
# File 'lib/zernio-sdk/models/verification.rb', line 25

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/zernio-sdk/models/verification.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/zernio-sdk/models/verification.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/verification.rb', line 66

def self.attribute_map
  {
    :'id' => :'id',
    :'status' => :'status',
    :'channel' => :'channel',
    :'to' => :'to',
    :'expires_at' => :'expiresAt',
    :'attempts' => :'attempts',
    :'max_attempts' => :'maxAttempts',
    :'send_count' => :'sendCount',
    :'last_sent_at' => :'lastSentAt',
    :'created_at' => :'createdAt',
    :'resend' => :'resend'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/zernio-sdk/models/verification.rb', line 249

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
114
# File 'lib/zernio-sdk/models/verification.rb', line 110

def self.openapi_nullable
  Set.new([
    :'last_sent_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/verification.rb', line 93

def self.openapi_types
  {
    :'id' => :'String',
    :'status' => :'String',
    :'channel' => :'String',
    :'to' => :'String',
    :'expires_at' => :'Time',
    :'attempts' => :'Integer',
    :'max_attempts' => :'Integer',
    :'send_count' => :'Integer',
    :'last_sent_at' => :'Time',
    :'created_at' => :'Time',
    :'resend' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/zernio-sdk/models/verification.rb', line 218

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      status == o.status &&
      channel == o.channel &&
      to == o.to &&
      expires_at == o.expires_at &&
      attempts == o.attempts &&
      max_attempts == o.max_attempts &&
      send_count == o.send_count &&
      last_sent_at == o.last_sent_at &&
      created_at == o.created_at &&
      resend == o.resend
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/zernio-sdk/models/verification.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/zernio-sdk/models/verification.rb', line 242

def hash
  [id, status, channel, to, expires_at, attempts, max_attempts, send_count, last_sent_at, created_at, resend].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
# File 'lib/zernio-sdk/models/verification.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/zernio-sdk/models/verification.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/verification.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending", "approved", "expired", "max_attempts_reached", "canceled", "delivery_failed"])
  return false unless status_validator.valid?(@status)
  channel_validator = EnumAttributeValidator.new('String', ["sms"])
  return false unless channel_validator.valid?(@channel)
  true
end