Class: Zernio::VerifyCredential200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::VerifyCredential200Response
- Defined in:
- lib/zernio-sdk/models/verify_credential200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auth_type ⇒ Object
Returns the value of attribute auth_type.
-
#email ⇒ Object
Email of the credential's owner.
-
#name ⇒ Object
Display name of the credential's owner.
-
#scope ⇒ Object
Granted OAuth scopes, space-separated.
-
#user_id ⇒ Object
Returns the value of attribute user_id.
-
#valid ⇒ Object
Returns the value of attribute valid.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VerifyCredential200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ VerifyCredential200Response
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::VerifyCredential200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::VerifyCredential200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'valid') self.valid = attributes[:'valid'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'auth_type') self.auth_type = attributes[:'auth_type'] end if attributes.key?(:'scope') self.scope = attributes[:'scope'] end end |
Instance Attribute Details
#auth_type ⇒ Object
Returns the value of attribute auth_type.
28 29 30 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 28 def auth_type @auth_type end |
#email ⇒ Object
Email of the credential's owner.
26 27 28 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 26 def email @email end |
#name ⇒ Object
Display name of the credential's owner.
23 24 25 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 23 def name @name end |
#scope ⇒ Object
Granted OAuth scopes, space-separated. Null for API keys.
31 32 33 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 31 def scope @scope end |
#user_id ⇒ Object
Returns the value of attribute user_id.
20 21 22 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 20 def user_id @user_id end |
#valid ⇒ Object
Returns the value of attribute valid.
18 19 20 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 18 def valid @valid end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 56 def self.attribute_map { :'valid' => :'valid', :'user_id' => :'userId', :'name' => :'name', :'email' => :'email', :'auth_type' => :'authType', :'scope' => :'scope' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 94 95 96 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 90 def self.openapi_nullable Set.new([ :'name', :'email', :'scope' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 78 def self.openapi_types { :'valid' => :'Boolean', :'user_id' => :'String', :'name' => :'String', :'email' => :'String', :'auth_type' => :'String', :'scope' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && valid == o.valid && user_id == o.user_id && name == o.name && email == o.email && auth_type == o.auth_type && scope == o.scope end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 187 def hash [valid, user_id, name, email, auth_type, scope].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 |
# File 'lib/zernio-sdk/models/verify_credential200_response.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' auth_type_validator = EnumAttributeValidator.new('String', ["api_key", "oauth", "session"]) return false unless auth_type_validator.valid?(@auth_type) true end |