Class: Zernio::WebhookPayloadCommentPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadCommentPost
- Defined in:
- lib/zernio-sdk/models/webhook_payload_comment_post.rb
Instance Attribute Summary collapse
-
#content ⇒ Object
Post text, from our synced copy — no platform call is made on the comment path, so null when the post was never synced.
-
#id ⇒ Object
Internal post ID (null for posts not published through Zernio).
-
#image_url ⇒ Object
Post thumbnail or first media item URL.
-
#permalink ⇒ Object
Public URL of the post.
-
#platform_post_id ⇒ Object
Platform's post ID.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadCommentPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadCommentPost
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadCommentPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadCommentPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] else self.platform_post_id = nil end if attributes.key?(:'content') self.content = attributes[:'content'] else self.content = nil end if attributes.key?(:'image_url') self.image_url = attributes[:'image_url'] else self.image_url = nil end if attributes.key?(:'permalink') self.permalink = attributes[:'permalink'] else self.permalink = nil end end |
Instance Attribute Details
#content ⇒ Object
Post text, from our synced copy — no platform call is made on the comment path, so null when the post was never synced.
25 26 27 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 25 def content @content end |
#id ⇒ Object
Internal post ID (null for posts not published through Zernio)
19 20 21 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 19 def id @id end |
#image_url ⇒ Object
Post thumbnail or first media item URL. Platform CDN URLs expire, fetch promptly.
28 29 30 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 28 def image_url @image_url end |
#permalink ⇒ Object
Public URL of the post. Null for posts published through Zernio that were never re-synced.
31 32 33 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 31 def permalink @permalink end |
#platform_post_id ⇒ Object
Platform's post ID
22 23 24 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 22 def platform_post_id @platform_post_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 34 def self.attribute_map { :'id' => :'id', :'platform_post_id' => :'platformPostId', :'content' => :'content', :'image_url' => :'imageUrl', :'permalink' => :'permalink' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 179 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 66 def self.openapi_nullable Set.new([ :'id', :'content', :'image_url', :'permalink' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 55 def self.openapi_types { :'id' => :'String', :'platform_post_id' => :'String', :'content' => :'String', :'image_url' => :'String', :'permalink' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
154 155 156 157 158 159 160 161 162 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 154 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && platform_post_id == o.platform_post_id && content == o.content && image_url == o.image_url && permalink == o.permalink end |
#eql?(o) ⇒ Boolean
166 167 168 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 166 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
172 173 174 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 172 def hash [id, platform_post_id, content, image_url, permalink].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
124 125 126 127 128 129 130 131 132 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 124 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @platform_post_id.nil? invalid_properties.push('invalid value for "platform_post_id", platform_post_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 201 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_post.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @platform_post_id.nil? true end |