Class: Zernio::WebhookPayloadMessage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadMessage
- Defined in:
- lib/zernio-sdk/models/webhook_payload_message.rb
Overview
Webhook payload for message received events
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account ⇒ Object
Returns the value of attribute account.
-
#conversation ⇒ Object
Returns the value of attribute conversation.
-
#event ⇒ Object
Returns the value of attribute event.
-
#id ⇒ Object
Stable webhook event ID.
-
#message ⇒ Object
Returns the value of attribute message.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#timestamp ⇒ Object
Returns the value of attribute timestamp.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadMessage
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'event') self.event = attributes[:'event'] else self.event = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end if attributes.key?(:'conversation') self.conversation = attributes[:'conversation'] else self.conversation = nil end if attributes.key?(:'account') self.account = attributes[:'account'] else self.account = nil end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] else self. = nil end end |
Instance Attribute Details
#account ⇒ Object
Returns the value of attribute account.
28 29 30 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 28 def account @account end |
#conversation ⇒ Object
Returns the value of attribute conversation.
26 27 28 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 26 def conversation @conversation end |
#event ⇒ Object
Returns the value of attribute event.
22 23 24 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 22 def event @event end |
#id ⇒ Object
Stable webhook event ID
20 21 22 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 20 def id @id end |
#message ⇒ Object
Returns the value of attribute message.
24 25 26 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 24 def @message end |
#metadata ⇒ Object
Returns the value of attribute metadata.
30 31 32 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 30 def @metadata end |
#timestamp ⇒ Object
Returns the value of attribute timestamp.
32 33 34 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 32 def @timestamp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 57 def self.attribute_map { :'id' => :'id', :'event' => :'event', :'message' => :'message', :'conversation' => :'conversation', :'account' => :'account', :'metadata' => :'metadata', :'timestamp' => :'timestamp' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 291 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 80 def self.openapi_types { :'id' => :'String', :'event' => :'String', :'message' => :'WebhookPayloadMessageMessage', :'conversation' => :'InboxWebhookConversation', :'account' => :'InboxWebhookAccount', :'metadata' => :'WebhookPayloadMessageMetadata', :'timestamp' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 264 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && event == o.event && == o. && conversation == o.conversation && account == o.account && == o. && == o. end |
#eql?(o) ⇒ Boolean
278 279 280 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 278 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
284 285 286 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 284 def hash [id, event, , conversation, account, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @event.nil? invalid_properties.push('invalid value for "event", event cannot be nil.') end if @message.nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end if @conversation.nil? invalid_properties.push('invalid value for "conversation", conversation cannot be nil.') end if @account.nil? invalid_properties.push('invalid value for "account", account cannot be nil.') end if @timestamp.nil? invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/zernio-sdk/models/webhook_payload_message.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @event.nil? event_validator = EnumAttributeValidator.new('String', ["message.received"]) return false unless event_validator.valid?(@event) return false if @message.nil? return false if @conversation.nil? return false if @account.nil? return false if @timestamp.nil? true end |