Class: Zernio::WebhookPayloadPostPlatformPost

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_post_platform_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadPostPlatformPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadPostPlatformPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadPostPlatformPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  else
    self.content = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'scheduled_for')
    self.scheduled_for = attributes[:'scheduled_for']
  else
    self.scheduled_for = nil
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'platforms')
    if (value = attributes[:'platforms']).is_a?(Array)
      self.platforms = value
    end
  else
    self.platforms = nil
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#contentObject

Returns the value of attribute content.



20
21
22
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 20

def content
  @content
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 18

def id
  @id
end

#metadataObject

The free-form metadata object supplied when the post was created, echoed back so you can map events onto your own records. Omitted when the post was created without it.



32
33
34
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 32

def 
  @metadata
end

#platformsObject

Returns the value of attribute platforms.



29
30
31
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 29

def platforms
  @platforms
end

#published_atObject

Returns the value of attribute published_at.



27
28
29
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 27

def published_at
  @published_at
end

#scheduled_forObject

Returns the value of attribute scheduled_for.



25
26
27
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 25

def scheduled_for
  @scheduled_for
end

#statusObject

Post-level status AT FIRE TIME. May still be publishing if other platforms haven't terminated; check this field rather than assuming.



23
24
25
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 23

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'content' => :'content',
    :'status' => :'status',
    :'scheduled_for' => :'scheduledFor',
    :'published_at' => :'publishedAt',
    :'platforms' => :'platforms',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 254

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 58

def self.openapi_types
  {
    :'id' => :'String',
    :'content' => :'String',
    :'status' => :'String',
    :'scheduled_for' => :'Time',
    :'published_at' => :'Time',
    :'platforms' => :'Array<WebhookPayloadPostPlatformPostPlatformsInner>',
    :'metadata' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



227
228
229
230
231
232
233
234
235
236
237
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 227

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      content == o.content &&
      status == o.status &&
      scheduled_for == o.scheduled_for &&
      published_at == o.published_at &&
      platforms == o.platforms &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


241
242
243
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 241

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



247
248
249
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 247

def hash
  [id, content, status, scheduled_for, published_at, platforms, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @content.nil?
    invalid_properties.push('invalid value for "content", content cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @scheduled_for.nil?
    invalid_properties.push('invalid value for "scheduled_for", scheduled_for cannot be nil.')
  end

  if @platforms.nil?
    invalid_properties.push('invalid value for "platforms", platforms cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 276

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
169
170
171
172
173
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @content.nil?
  return false if @status.nil?
  return false if @scheduled_for.nil?
  return false if @platforms.nil?
  true
end