Class: Zernio::WebhookPayloadPostPlatformPostPlatformsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadPostPlatformPostPlatformsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadPostPlatformPostPlatformsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadPostPlatformPostPlatformsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  else
    self.platform = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform_post_id')
    self.platform_post_id = attributes[:'platform_post_id']
  end

  if attributes.key?(:'published_url')
    self.published_url = attributes[:'published_url']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'error_category')
    self.error_category = attributes[:'error_category']
  end

  if attributes.key?(:'error_source')
    self.error_source = attributes[:'error_source']
  end

  if attributes.key?(:'platform_error')
    self.platform_error = attributes[:'platform_error']
  end
end

Instance Attribute Details

#account_id ⇒ Object

SocialAccount id this platform target published through. On post.platform.* events see also the top-level account block.



23
24
25
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 23

def 
  @account_id
end

#error ⇒ Object

Returns the value of attribute error.



29
30
31
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 29

def error
  @error
end

#error_category ⇒ Object

Present when this target failed. Same taxonomy as platforms[].errorCategory on GET /v1/posts.



32
33
34
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 32

def error_category
  @error_category
end

#error_source ⇒ Object

Present when this target failed. Who must act: user, platform or system (Zernio).



35
36
37
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 35

def error_source
  @error_source
end

#platform ⇒ Object

Returns the value of attribute platform.



18
19
20
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 18

def platform
  @platform
end

#platform_error ⇒ Object

Returns the value of attribute platform_error.



37
38
39
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 37

def platform_error
  @platform_error
end

#platform_post_id ⇒ Object

Returns the value of attribute platform_post_id.



25
26
27
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 25

def platform_post_id
  @platform_post_id
end

#published_url ⇒ Object

Returns the value of attribute published_url.



27
28
29
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 27

def published_url
  @published_url
end

#status ⇒ Object

Returns the value of attribute status.



20
21
22
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 20

def status
  @status
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



77
78
79
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 62

def self.attribute_map
  {
    :'platform' => :'platform',
    :'status' => :'status',
    :'account_id' => :'accountId',
    :'platform_post_id' => :'platformPostId',
    :'published_url' => :'publishedUrl',
    :'error' => :'error',
    :'error_category' => :'errorCategory',
    :'error_source' => :'errorSource',
    :'platform_error' => :'platformError'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 264

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



102
103
104
105
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 87

def self.openapi_types
  {
    :'platform' => :'String',
    :'status' => :'String',
    :'account_id' => :'String',
    :'platform_post_id' => :'String',
    :'published_url' => :'String',
    :'error' => :'String',
    :'error_category' => :'String',
    :'error_source' => :'String',
    :'platform_error' => :'PostPlatformError'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 235

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      platform == o.platform &&
      status == o.status &&
       == o. &&
      platform_post_id == o.platform_post_id &&
      published_url == o.published_url &&
      error == o.error &&
      error_category == o.error_category &&
      error_source == o.error_source &&
      platform_error == o.platform_error
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


251
252
253
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 251

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



257
258
259
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 257

def hash
  [platform, status, , platform_post_id, published_url, error, error_category, error_source, platform_error].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 286

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
# File 'lib/zernio-sdk/models/webhook_payload_post_platform_post_platforms_inner.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @platform.nil?
  return false if @status.nil?
  error_category_validator = EnumAttributeValidator.new('String', ["auth_expired", "user_content", "user_abuse", "account_issue", "platform_rejected", "platform_error", "platform_rate_limit", "quota_exhausted", "system_error", "unknown"])
  return false unless error_category_validator.valid?(@error_category)
  error_source_validator = EnumAttributeValidator.new('String', ["user", "platform", "system"])
  return false unless error_source_validator.valid?(@error_source)
  true
end