Class: Zernio::WebhookPayloadWhatsAppTemplateCategoryUpdatedTemplate

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadWhatsAppTemplateCategoryUpdatedTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadWhatsAppTemplateCategoryUpdatedTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadWhatsAppTemplateCategoryUpdatedTemplate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  else
    self.template_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  else
    self.language = nil
  end

  if attributes.key?(:'change_type')
    self.change_type = attributes[:'change_type']
  else
    self.change_type = nil
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = nil
  end

  if attributes.key?(:'previous_category')
    self.previous_category = attributes[:'previous_category']
  end

  if attributes.key?(:'scheduled_category')
    self.scheduled_category = attributes[:'scheduled_category']
  end

  if attributes.key?(:'effective_at')
    self.effective_at = attributes[:'effective_at']
  end
end

Instance Attribute Details

#categoryObject

The category right now, regardless of changeType.



31
32
33
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 31

def category
  @category
end

#change_typeObject

scheduled is Meta's 24h advance notice of an upcoming reclassification; applied is the change taking effect.



28
29
30
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 28

def change_type
  @change_type
end

#effective_atObject

Present only when changeType is scheduled. ISO-8601 timestamp when the scheduled category takes effect.



40
41
42
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 40

def effective_at
  @effective_at
end

#languageObject

Meta's message_template_language (e.g. en_US).



25
26
27
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 25

def language
  @language
end

#nameObject

Meta's message_template_name.



22
23
24
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 22

def name
  @name
end

#previous_categoryObject

Present only when changeType is applied. The category before this change.



34
35
36
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 34

def previous_category
  @previous_category
end

#scheduled_categoryObject

Present only when changeType is scheduled. The category that will take effect at effectiveAt.



37
38
39
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 37

def scheduled_category
  @scheduled_category
end

#template_idObject

Meta's message_template_id, returned as a string.



19
20
21
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 19

def template_id
  @template_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



79
80
81
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 79

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 84

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 65

def self.attribute_map
  {
    :'template_id' => :'templateId',
    :'name' => :'name',
    :'language' => :'language',
    :'change_type' => :'changeType',
    :'category' => :'category',
    :'previous_category' => :'previousCategory',
    :'scheduled_category' => :'scheduledCategory',
    :'effective_at' => :'effectiveAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 315

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 89

def self.openapi_types
  {
    :'template_id' => :'String',
    :'name' => :'String',
    :'language' => :'String',
    :'change_type' => :'String',
    :'category' => :'String',
    :'previous_category' => :'String',
    :'scheduled_category' => :'String',
    :'effective_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 287

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      template_id == o.template_id &&
      name == o.name &&
      language == o.language &&
      change_type == o.change_type &&
      category == o.category &&
      previous_category == o.previous_category &&
      scheduled_category == o.scheduled_category &&
      effective_at == o.effective_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


302
303
304
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 302

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



308
309
310
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 308

def hash
  [template_id, name, language, change_type, category, previous_category, scheduled_category, effective_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @template_id.nil?
    invalid_properties.push('invalid value for "template_id", template_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @language.nil?
    invalid_properties.push('invalid value for "language", language cannot be nil.')
  end

  if @change_type.nil?
    invalid_properties.push('invalid value for "change_type", change_type cannot be nil.')
  end

  if @category.nil?
    invalid_properties.push('invalid value for "category", category cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/zernio-sdk/models/webhook_payload_whats_app_template_category_updated_template.rb', line 197

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @template_id.nil?
  return false if @name.nil?
  return false if @language.nil?
  return false if @change_type.nil?
  change_type_validator = EnumAttributeValidator.new('String', ["scheduled", "applied"])
  return false unless change_type_validator.valid?(@change_type)
  return false if @category.nil?
  category_validator = EnumAttributeValidator.new('String', ["UTILITY", "MARKETING", "AUTHENTICATION"])
  return false unless category_validator.valid?(@category)
  previous_category_validator = EnumAttributeValidator.new('String', ["UTILITY", "MARKETING", "AUTHENTICATION"])
  return false unless previous_category_validator.valid?(@previous_category)
  scheduled_category_validator = EnumAttributeValidator.new('String', ["UTILITY", "MARKETING", "AUTHENTICATION"])
  return false unless scheduled_category_validator.valid?(@scheduled_category)
  true
end