Class: Zernio::WhatsAppTemplatesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/zernio-sdk/api/whats_app_templates_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ WhatsAppTemplatesApi

Returns a new instance of WhatsAppTemplatesApi.



19
20
21
# File 'lib/zernio-sdk/api/whats_app_templates_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/zernio-sdk/api/whats_app_templates_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_whats_app_library_template(account_id, name, opts = {}) ⇒ GetWhatsAppLibraryTemplate200Response

Look up a library template Look up a single pre-approved Template Library template by its exact name, to introspect its structure before importing it. Most importantly it returns the template's buttons: a library template with URL / PHONE_NUMBER buttons must be created with a matching library_template_button_inputs array (see Create Template), or Meta rejects it. Use this to discover which inputs to collect.

Parameters:

  • account_id (String)

    WhatsApp social account ID

  • name (String)

    Exact library template name

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



28
29
30
31
# File 'lib/zernio-sdk/api/whats_app_templates_api.rb', line 28

def get_whats_app_library_template(, name, opts = {})
  data, _status_code, _headers = get_whats_app_library_template_with_http_info(, name, opts)
  data
end

#get_whats_app_library_template_with_http_info(account_id, name, opts = {}) ⇒ Array<(GetWhatsAppLibraryTemplate200Response, Integer, Hash)>

Look up a library template Look up a single pre-approved Template Library template by its exact name, to introspect its structure before importing it. Most importantly it returns the template's `buttons`: a library template with `URL` / `PHONE_NUMBER` buttons must be created with a matching `library_template_button_inputs` array (see Create Template), or Meta rejects it. Use this to discover which inputs to collect.

Parameters:

  • account_id (String)

    WhatsApp social account ID

  • name (String)

    Exact library template name

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/api/whats_app_templates_api.rb', line 39

def get_whats_app_library_template_with_http_info(, name, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WhatsAppTemplatesApi.get_whats_app_library_template ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling WhatsAppTemplatesApi.get_whats_app_library_template"
  end
  # verify the required parameter 'name' is set
  if @api_client.config.client_side_validation && name.nil?
    fail ArgumentError, "Missing the required parameter 'name' when calling WhatsAppTemplatesApi.get_whats_app_library_template"
  end
  # resource path
  local_var_path = '/v1/whatsapp/template-library'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'accountId'] = 
  query_params[:'name'] = name

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetWhatsAppLibraryTemplate200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WhatsAppTemplatesApi.get_whats_app_library_template",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WhatsAppTemplatesApi#get_whats_app_library_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end