Class: Zernio::XArticleEntityRange

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/x_article_entity_range.rb

Overview

The referenced entity must exist, and offset plus length must not exceed the containing block's text length.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ XArticleEntityRange

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 62

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::XArticleEntityRange` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::XArticleEntityRange`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'offset')
    self.offset = attributes[:'offset']
  else
    self.offset = nil
  end

  if attributes.key?(:'length')
    self.length = attributes[:'length']
  else
    self.length = nil
  end
end

Instance Attribute Details

#keyObject

Zero-based index into content_state.entities.



20
21
22
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 20

def key
  @key
end

#lengthObject

Returns the value of attribute length.



24
25
26
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 24

def length
  @length
end

#offsetObject

Returns the value of attribute offset.



22
23
24
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 22

def offset
  @offset
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



36
37
38
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 36

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



41
42
43
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 41

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



27
28
29
30
31
32
33
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 27

def self.attribute_map
  {
    :'key' => :'key',
    :'offset' => :'offset',
    :'length' => :'length'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 207

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



55
56
57
58
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 55

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



46
47
48
49
50
51
52
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 46

def self.openapi_types
  {
    :'key' => :'Integer',
    :'offset' => :'Integer',
    :'length' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



184
185
186
187
188
189
190
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 184

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      offset == o.offset &&
      length == o.length
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 194

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



200
201
202
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 200

def hash
  [key, offset, length].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @key < 0
    invalid_properties.push('invalid value for "key", must be greater than or equal to 0.')
  end

  if @offset.nil?
    invalid_properties.push('invalid value for "offset", offset cannot be nil.')
  end

  if @offset < 0
    invalid_properties.push('invalid value for "offset", must be greater than or equal to 0.')
  end

  if @length.nil?
    invalid_properties.push('invalid value for "length", length cannot be nil.')
  end

  if @length < 0
    invalid_properties.push('invalid value for "length", must be greater than or equal to 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
134
135
136
137
138
# File 'lib/zernio-sdk/models/x_article_entity_range.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @key < 0
  return false if @offset.nil?
  return false if @offset < 0
  return false if @length.nil?
  return false if @length < 0
  true
end