Class: Zernio::YouTubeDailyViewsResponseDailyViewsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ YouTubeDailyViewsResponseDailyViewsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::YouTubeDailyViewsResponseDailyViewsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::YouTubeDailyViewsResponseDailyViewsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'views')
    self.views = attributes[:'views']
  end

  if attributes.key?(:'estimated_minutes_watched')
    self.estimated_minutes_watched = attributes[:'estimated_minutes_watched']
  end

  if attributes.key?(:'average_view_duration')
    self.average_view_duration = attributes[:'average_view_duration']
  end

  if attributes.key?(:'average_view_percentage')
    self.average_view_percentage = attributes[:'average_view_percentage']
  end

  if attributes.key?(:'subscribers_gained')
    self.subscribers_gained = attributes[:'subscribers_gained']
  end

  if attributes.key?(:'subscribers_lost')
    self.subscribers_lost = attributes[:'subscribers_lost']
  end

  if attributes.key?(:'likes')
    self.likes = attributes[:'likes']
  end

  if attributes.key?(:'comments')
    self.comments = attributes[:'comments']
  end

  if attributes.key?(:'shares')
    self.shares = attributes[:'shares']
  end
end

Instance Attribute Details

#average_view_durationObject

Average view duration in seconds



25
26
27
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 25

def average_view_duration
  @average_view_duration
end

#average_view_percentageObject

Average percentage of the video watched per view. Can exceed 100 on Shorts (looping rewatches), so do not clamp it client-side.



28
29
30
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 28

def average_view_percentage
  @average_view_percentage
end

#commentsObject

Returns the value of attribute comments.



36
37
38
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 36

def comments
  @comments
end

#dateObject

Returns the value of attribute date.



18
19
20
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 18

def date
  @date
end

#estimated_minutes_watchedObject

Returns the value of attribute estimated_minutes_watched.



22
23
24
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 22

def estimated_minutes_watched
  @estimated_minutes_watched
end

#likesObject

Returns the value of attribute likes.



34
35
36
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 34

def likes
  @likes
end

#sharesObject

Returns the value of attribute shares.



38
39
40
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 38

def shares
  @shares
end

#subscribers_gainedObject

Returns the value of attribute subscribers_gained.



30
31
32
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 30

def subscribers_gained
  @subscribers_gained
end

#subscribers_lostObject

Returns the value of attribute subscribers_lost.



32
33
34
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 32

def subscribers_lost
  @subscribers_lost
end

#viewsObject

Returns the value of attribute views.



20
21
22
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 20

def views
  @views
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 41

def self.attribute_map
  {
    :'date' => :'date',
    :'views' => :'views',
    :'estimated_minutes_watched' => :'estimatedMinutesWatched',
    :'average_view_duration' => :'averageViewDuration',
    :'average_view_percentage' => :'averageViewPercentage',
    :'subscribers_gained' => :'subscribersGained',
    :'subscribers_lost' => :'subscribersLost',
    :'likes' => :'likes',
    :'comments' => :'comments',
    :'shares' => :'shares'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



83
84
85
86
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 83

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 67

def self.openapi_types
  {
    :'date' => :'Date',
    :'views' => :'Integer',
    :'estimated_minutes_watched' => :'Float',
    :'average_view_duration' => :'Float',
    :'average_view_percentage' => :'Float',
    :'subscribers_gained' => :'Integer',
    :'subscribers_lost' => :'Integer',
    :'likes' => :'Integer',
    :'comments' => :'Integer',
    :'shares' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date == o.date &&
      views == o.views &&
      estimated_minutes_watched == o.estimated_minutes_watched &&
      average_view_duration == o.average_view_duration &&
      average_view_percentage == o.average_view_percentage &&
      subscribers_gained == o.subscribers_gained &&
      subscribers_lost == o.subscribers_lost &&
      likes == o.likes &&
      comments == o.comments &&
      shares == o.shares
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 185

def hash
  [date, views, estimated_minutes_watched, average_view_duration, average_view_percentage, subscribers_gained, subscribers_lost, likes, comments, shares].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/zernio-sdk/models/you_tube_daily_views_response_daily_views_inner.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end