Class: Zernio::YouTubeDemographicsResponse

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/you_tube_demographics_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ YouTubeDemographicsResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::YouTubeDemographicsResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::YouTubeDemographicsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'video_id')
    self.video_id = attributes[:'video_id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'demographics')
    if (value = attributes[:'demographics']).is_a?(Hash)
      self.demographics = value
    end
  end

  if attributes.key?(:'date_range')
    self.date_range = attributes[:'date_range']
  end

  if attributes.key?(:'provisional_since')
    self.provisional_since = attributes[:'provisional_since']
  end

  if attributes.key?(:'note')
    self.note = attributes[:'note']
  end
end

Instance Attribute Details

#account_idObject

The Zernio SocialAccount ID



21
22
23
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 21

def 
  @account_id
end

#date_rangeObject

Returns the value of attribute date_range.



37
38
39
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 37

def date_range
  @date_range
end

#demographicsObject

Object keyed by breakdown dimension (age, gender, country)



35
36
37
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 35

def demographics
  @demographics
end

#noteObject

Returns the value of attribute note.



42
43
44
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 42

def note
  @note
end

#platformObject

Returns the value of attribute platform.



23
24
25
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 23

def platform
  @platform
end

#provisional_sinceObject

Present only when the range reaches into YouTube's ~3-day processing window: the first date whose numbers are provisional and may still be revised by YouTube.



40
41
42
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 40

def provisional_since
  @provisional_since
end

#published_atObject

Video publish date (video mode only)



32
33
34
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 32

def published_at
  @published_at
end

#successObject

Returns the value of attribute success.



18
19
20
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 18

def success
  @success
end

#titleObject

Video title (video mode only)



29
30
31
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 29

def title
  @title
end

#video_idObject

Present only when demographics are scoped to a single video



26
27
28
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 26

def video_id
  @video_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 45

def self.attribute_map
  {
    :'success' => :'success',
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'video_id' => :'videoId',
    :'title' => :'title',
    :'published_at' => :'publishedAt',
    :'demographics' => :'demographics',
    :'date_range' => :'dateRange',
    :'provisional_since' => :'provisionalSince',
    :'note' => :'note'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
91
92
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 87

def self.openapi_nullable
  Set.new([
    :'title',
    :'published_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 71

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'account_id' => :'String',
    :'platform' => :'String',
    :'video_id' => :'String',
    :'title' => :'String',
    :'published_at' => :'Time',
    :'demographics' => :'Hash<String, Array<YouTubeDemographicsResponseDemographicsValueInner>>',
    :'date_range' => :'YouTubeDemographicsResponseDateRange',
    :'provisional_since' => :'Date',
    :'note' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
       == o. &&
      platform == o.platform &&
      video_id == o.video_id &&
      title == o.title &&
      published_at == o.published_at &&
      demographics == o.demographics &&
      date_range == o.date_range &&
      provisional_since == o.provisional_since &&
      note == o.note
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 193

def hash
  [success, , platform, video_id, title, published_at, demographics, date_range, provisional_since, note].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
# File 'lib/zernio-sdk/models/you_tube_demographics_response.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end