Class: Late::AccountWithFollowerStats

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/account_with_follower_stats.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountWithFollowerStats

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::AccountWithFollowerStats` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::AccountWithFollowerStats`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'profile_url')
    self.profile_url = attributes[:'profile_url']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'followers_count')
    self.followers_count = attributes[:'followers_count']
  end

  if attributes.key?(:'followers_last_updated')
    self.followers_last_updated = attributes[:'followers_last_updated']
  end

  if attributes.key?(:'profile_picture')
    self.profile_picture = attributes[:'profile_picture']
  end

  if attributes.key?(:'current_followers')
    self.current_followers = attributes[:'current_followers']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end

  if attributes.key?(:'growth')
    self.growth = attributes[:'growth']
  end

  if attributes.key?(:'growth_percentage')
    self.growth_percentage = attributes[:'growth_percentage']
  end

  if attributes.key?(:'data_points')
    self.data_points = attributes[:'data_points']
  end

  if attributes.key?(:'account_stats')
    self. = attributes[:'account_stats']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 18

def _id
  @_id
end

#account_statsObject

Returns the value of attribute account_stats.



55
56
57
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 55

def 
  @account_stats
end

#current_followersObject

Current follower count



42
43
44
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 42

def current_followers
  @current_followers
end

#data_pointsObject

Number of historical snapshots



53
54
55
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 53

def data_points
  @data_points
end

#display_nameObject

Returns the value of attribute display_name.



26
27
28
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 26

def display_name
  @display_name
end

#followers_countObject

Follower count (only included if user has analytics add-on)



34
35
36
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 34

def followers_count
  @followers_count
end

#followers_last_updatedObject

Last time follower count was updated (only included if user has analytics add-on)



37
38
39
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 37

def followers_last_updated
  @followers_last_updated
end

#growthObject

Follower change over period



47
48
49
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 47

def growth
  @growth
end

#growth_percentageObject

Percentage growth



50
51
52
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 50

def growth_percentage
  @growth_percentage
end

#is_activeObject

Returns the value of attribute is_active.



31
32
33
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 31

def is_active
  @is_active
end

#last_updatedObject

Returns the value of attribute last_updated.



44
45
46
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 44

def last_updated
  @last_updated
end

#platformObject

Returns the value of attribute platform.



20
21
22
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 20

def platform
  @platform
end

#profile_idObject

Returns the value of attribute profile_id.



22
23
24
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 22

def profile_id
  @profile_id
end

#profile_pictureObject

Returns the value of attribute profile_picture.



39
40
41
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 39

def profile_picture
  @profile_picture
end

#profile_urlObject

Full profile URL for the connected account on its platform.



29
30
31
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 29

def profile_url
  @profile_url
end

#usernameObject

Returns the value of attribute username.



24
25
26
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 24

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 58

def self.attribute_map
  {
    :'_id' => :'_id',
    :'platform' => :'platform',
    :'profile_id' => :'profileId',
    :'username' => :'username',
    :'display_name' => :'displayName',
    :'profile_url' => :'profileUrl',
    :'is_active' => :'isActive',
    :'followers_count' => :'followersCount',
    :'followers_last_updated' => :'followersLastUpdated',
    :'profile_picture' => :'profilePicture',
    :'current_followers' => :'currentFollowers',
    :'last_updated' => :'lastUpdated',
    :'growth' => :'growth',
    :'growth_percentage' => :'growthPercentage',
    :'data_points' => :'dataPoints',
    :'account_stats' => :'accountStats'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



118
119
120
121
122
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 118

def self.openapi_all_of
  [
  :'SocialAccount'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 90

def self.openapi_types
  {
    :'_id' => :'String',
    :'platform' => :'String',
    :'profile_id' => :'SocialAccountProfileId',
    :'username' => :'String',
    :'display_name' => :'String',
    :'profile_url' => :'String',
    :'is_active' => :'Boolean',
    :'followers_count' => :'Float',
    :'followers_last_updated' => :'Time',
    :'profile_picture' => :'String',
    :'current_followers' => :'Float',
    :'last_updated' => :'Time',
    :'growth' => :'Float',
    :'growth_percentage' => :'Float',
    :'data_points' => :'Float',
    :'account_stats' => :'AccountWithFollowerStatsAllOfAccountStats'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 222

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      platform == o.platform &&
      profile_id == o.profile_id &&
      username == o.username &&
      display_name == o.display_name &&
      profile_url == o.profile_url &&
      is_active == o.is_active &&
      followers_count == o.followers_count &&
      followers_last_updated == o.followers_last_updated &&
      profile_picture == o.profile_picture &&
      current_followers == o.current_followers &&
      last_updated == o.last_updated &&
      growth == o.growth &&
      growth_percentage == o.growth_percentage &&
      data_points == o.data_points &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 251

def hash
  [_id, platform, profile_id, username, display_name, profile_url, is_active, followers_count, followers_last_updated, profile_picture, current_followers, last_updated, growth, growth_percentage, data_points, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



207
208
209
210
211
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 207

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



215
216
217
218
# File 'lib/late-sdk/models/account_with_follower_stats.rb', line 215

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end