Class: Late::AdMetrics
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::AdMetrics
- Defined in:
- lib/late-sdk/models/ad_metrics.rb
Instance Attribute Summary collapse
-
#clicks ⇒ Object
Returns the value of attribute clicks.
-
#cpc ⇒ Object
Cost per click.
-
#cpm ⇒ Object
Cost per 1000 impressions.
-
#ctr ⇒ Object
Click-through rate (%).
-
#engagement ⇒ Object
Returns the value of attribute engagement.
-
#impressions ⇒ Object
Returns the value of attribute impressions.
-
#last_synced_at ⇒ Object
Returns the value of attribute last_synced_at.
-
#reach ⇒ Object
Returns the value of attribute reach.
-
#spend ⇒ Object
Returns the value of attribute spend.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AdMetrics
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AdMetrics
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::AdMetrics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::AdMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'spend') self.spend = attributes[:'spend'] end if attributes.key?(:'impressions') self.impressions = attributes[:'impressions'] end if attributes.key?(:'reach') self.reach = attributes[:'reach'] end if attributes.key?(:'clicks') self.clicks = attributes[:'clicks'] end if attributes.key?(:'ctr') self.ctr = attributes[:'ctr'] end if attributes.key?(:'cpc') self.cpc = attributes[:'cpc'] end if attributes.key?(:'cpm') self.cpm = attributes[:'cpm'] end if attributes.key?(:'engagement') self.engagement = attributes[:'engagement'] end if attributes.key?(:'last_synced_at') self.last_synced_at = attributes[:'last_synced_at'] end end |
Instance Attribute Details
#clicks ⇒ Object
Returns the value of attribute clicks.
24 25 26 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 24 def clicks @clicks end |
#cpc ⇒ Object
Cost per click
30 31 32 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 30 def cpc @cpc end |
#cpm ⇒ Object
Cost per 1000 impressions
33 34 35 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 33 def cpm @cpm end |
#ctr ⇒ Object
Click-through rate (%)
27 28 29 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 27 def ctr @ctr end |
#engagement ⇒ Object
Returns the value of attribute engagement.
35 36 37 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 35 def engagement @engagement end |
#impressions ⇒ Object
Returns the value of attribute impressions.
20 21 22 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 20 def impressions @impressions end |
#last_synced_at ⇒ Object
Returns the value of attribute last_synced_at.
37 38 39 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 37 def last_synced_at @last_synced_at end |
#reach ⇒ Object
Returns the value of attribute reach.
22 23 24 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 22 def reach @reach end |
#spend ⇒ Object
Returns the value of attribute spend.
18 19 20 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 18 def spend @spend end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 40 def self.attribute_map { :'spend' => :'spend', :'impressions' => :'impressions', :'reach' => :'reach', :'clicks' => :'clicks', :'ctr' => :'ctr', :'cpc' => :'cpc', :'cpm' => :'cpm', :'engagement' => :'engagement', :'last_synced_at' => :'lastSyncedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
80 81 82 83 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 80 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 65 def self.openapi_types { :'spend' => :'Float', :'impressions' => :'Integer', :'reach' => :'Integer', :'clicks' => :'Integer', :'ctr' => :'Float', :'cpc' => :'Float', :'cpm' => :'Float', :'engagement' => :'Integer', :'last_synced_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && spend == o.spend && impressions == o.impressions && reach == o.reach && clicks == o.clicks && ctr == o.ctr && cpc == o.cpc && cpm == o.cpm && engagement == o.engagement && last_synced_at == o.last_synced_at end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 177 def hash [spend, impressions, reach, clicks, ctr, cpc, cpm, engagement, last_synced_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 |
# File 'lib/late-sdk/models/ad_metrics.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |