Class: Late::AnalyticsSinglePostResponse

Inherits:
ApiModelBase show all
Defined in:
lib/late-sdk/models/analytics_single_post_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AnalyticsSinglePostResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::AnalyticsSinglePostResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::AnalyticsSinglePostResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'post_id')
    self.post_id = attributes[:'post_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'scheduled_for')
    self.scheduled_for = attributes[:'scheduled_for']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'analytics')
    self.analytics = attributes[:'analytics']
  end

  if attributes.key?(:'platform_analytics')
    if (value = attributes[:'platform_analytics']).is_a?(Array)
      self.platform_analytics = value
    end
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_post_url')
    self.platform_post_url = attributes[:'platform_post_url']
  end

  if attributes.key?(:'is_external')
    self.is_external = attributes[:'is_external']
  end
end

Instance Attribute Details

#analyticsObject

Returns the value of attribute analytics.



28
29
30
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 28

def analytics
  @analytics
end

#contentObject

Returns the value of attribute content.



22
23
24
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 22

def content
  @content
end

#is_externalObject

Returns the value of attribute is_external.



36
37
38
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 36

def is_external
  @is_external
end

#platformObject

Returns the value of attribute platform.



32
33
34
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 32

def platform
  @platform
end

#platform_analyticsObject

Returns the value of attribute platform_analytics.



30
31
32
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 30

def platform_analytics
  @platform_analytics
end

#platform_post_urlObject

Returns the value of attribute platform_post_url.



34
35
36
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 34

def platform_post_url
  @platform_post_url
end

#post_idObject

Returns the value of attribute post_id.



18
19
20
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 18

def post_id
  @post_id
end

#published_atObject

Returns the value of attribute published_at.



26
27
28
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 26

def published_at
  @published_at
end

#scheduled_forObject

Returns the value of attribute scheduled_for.



24
25
26
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 24

def scheduled_for
  @scheduled_for
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 20

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 39

def self.attribute_map
  {
    :'post_id' => :'postId',
    :'status' => :'status',
    :'content' => :'content',
    :'scheduled_for' => :'scheduledFor',
    :'published_at' => :'publishedAt',
    :'analytics' => :'analytics',
    :'platform_analytics' => :'platformAnalytics',
    :'platform' => :'platform',
    :'platform_post_url' => :'platformPostUrl',
    :'is_external' => :'isExternal'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 65

def self.openapi_types
  {
    :'post_id' => :'String',
    :'status' => :'String',
    :'content' => :'String',
    :'scheduled_for' => :'Time',
    :'published_at' => :'Time',
    :'analytics' => :'PostAnalytics',
    :'platform_analytics' => :'Array<PlatformAnalytics>',
    :'platform' => :'String',
    :'platform_post_url' => :'String',
    :'is_external' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      post_id == o.post_id &&
      status == o.status &&
      content == o.content &&
      scheduled_for == o.scheduled_for &&
      published_at == o.published_at &&
      analytics == o.analytics &&
      platform_analytics == o.platform_analytics &&
      platform == o.platform &&
      platform_post_url == o.platform_post_url &&
      is_external == o.is_external
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 185

def hash
  [post_id, status, content, scheduled_for, published_at, analytics, platform_analytics, platform, platform_post_url, is_external].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/late-sdk/models/analytics_single_post_response.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end