Class: Late::GetInboxConversationMessages200ResponseMessagesInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetInboxConversationMessages200ResponseMessagesInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Late::GetInboxConversationMessages200ResponseMessagesInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Late::GetInboxConversationMessages200ResponseMessagesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'sender_id')
    self.sender_id = attributes[:'sender_id']
  end

  if attributes.key?(:'sender_name')
    self.sender_name = attributes[:'sender_name']
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'story_reply')
    self.story_reply = attributes[:'story_reply']
  end

  if attributes.key?(:'is_story_mention')
    self.is_story_mention = attributes[:'is_story_mention']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



22
23
24
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 22

def 
  @account_id
end

#attachmentsObject

Returns the value of attribute attachments.



36
37
38
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 36

def attachments
  @attachments
end

#conversation_idObject

Returns the value of attribute conversation_id.



20
21
22
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 20

def conversation_id
  @conversation_id
end

#created_atObject

Returns the value of attribute created_at.



34
35
36
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 34

def created_at
  @created_at
end

#directionObject

Returns the value of attribute direction.



32
33
34
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 32

def direction
  @direction
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 18

def id
  @id
end

#is_story_mentionObject

Instagram story mention



45
46
47
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 45

def is_story_mention
  @is_story_mention
end

#messageObject

Returns the value of attribute message.



26
27
28
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 26

def message
  @message
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 24

def platform
  @platform
end

#sender_idObject

Returns the value of attribute sender_id.



28
29
30
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 28

def sender_id
  @sender_id
end

#sender_nameObject

Returns the value of attribute sender_name.



30
31
32
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 30

def sender_name
  @sender_name
end

#story_replyObject

Instagram story reply



42
43
44
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 42

def story_reply
  @story_reply
end

#subjectObject

Reddit message subject



39
40
41
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 39

def subject
  @subject
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 70

def self.attribute_map
  {
    :'id' => :'id',
    :'conversation_id' => :'conversationId',
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'message' => :'message',
    :'sender_id' => :'senderId',
    :'sender_name' => :'senderName',
    :'direction' => :'direction',
    :'created_at' => :'createdAt',
    :'attachments' => :'attachments',
    :'subject' => :'subject',
    :'story_reply' => :'storyReply',
    :'is_story_mention' => :'isStoryMention'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 118

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 99

def self.openapi_types
  {
    :'id' => :'String',
    :'conversation_id' => :'String',
    :'account_id' => :'String',
    :'platform' => :'String',
    :'message' => :'String',
    :'sender_id' => :'String',
    :'sender_name' => :'String',
    :'direction' => :'String',
    :'created_at' => :'Time',
    :'attachments' => :'Array<GetInboxConversationMessages200ResponseMessagesInnerAttachmentsInner>',
    :'subject' => :'String',
    :'story_reply' => :'Boolean',
    :'is_story_mention' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      conversation_id == o.conversation_id &&
       == o. &&
      platform == o.platform &&
      message == o.message &&
      sender_id == o.sender_id &&
      sender_name == o.sender_name &&
      direction == o.direction &&
      created_at == o.created_at &&
      attachments == o.attachments &&
      subject == o.subject &&
      story_reply == o.story_reply &&
      is_story_mention == o.is_story_mention
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 249

def hash
  [id, conversation_id, , platform, message, sender_id, sender_name, direction, created_at, attachments, subject, story_reply, is_story_mention].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 196

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
208
209
# File 'lib/late-sdk/models/get_inbox_conversation_messages200_response_messages_inner.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  direction_validator = EnumAttributeValidator.new('String', ["incoming", "outgoing"])
  return false unless direction_validator.valid?(@direction)
  true
end