Class: Late::GetWhatsAppContacts200ResponseContactsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Late::GetWhatsAppContacts200ResponseContactsInner
- Defined in:
- lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb
Instance Attribute Summary collapse
-
#company ⇒ Object
Returns the value of attribute company.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
-
#email ⇒ Object
Returns the value of attribute email.
-
#groups ⇒ Object
Returns the value of attribute groups.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_opted_in ⇒ Object
Returns the value of attribute is_opted_in.
-
#last_message_received_at ⇒ Object
Returns the value of attribute last_message_received_at.
-
#last_message_sent_at ⇒ Object
Returns the value of attribute last_message_sent_at.
-
#messages_received_count ⇒ Object
Returns the value of attribute messages_received_count.
-
#messages_sent_count ⇒ Object
Returns the value of attribute messages_sent_count.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#wa_id ⇒ Object
Returns the value of attribute wa_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetWhatsAppContacts200ResponseContactsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetWhatsAppContacts200ResponseContactsInner
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Late::GetWhatsAppContacts200ResponseContactsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Late::GetWhatsAppContacts200ResponseContactsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'wa_id') self.wa_id = attributes[:'wa_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'is_opted_in') self.is_opted_in = attributes[:'is_opted_in'] end if attributes.key?(:'last_message_sent_at') self. = attributes[:'last_message_sent_at'] end if attributes.key?(:'last_message_received_at') self. = attributes[:'last_message_received_at'] end if attributes.key?(:'messages_sent_count') self. = attributes[:'messages_sent_count'] end if attributes.key?(:'messages_received_count') self. = attributes[:'messages_received_count'] end if attributes.key?(:'custom_fields') self.custom_fields = attributes[:'custom_fields'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#company ⇒ Object
Returns the value of attribute company.
28 29 30 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 28 def company @company end |
#created_at ⇒ Object
Returns the value of attribute created_at.
48 49 50 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 48 def created_at @created_at end |
#custom_fields ⇒ Object
Returns the value of attribute custom_fields.
44 45 46 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 44 def custom_fields @custom_fields end |
#email ⇒ Object
Returns the value of attribute email.
26 27 28 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 26 def email @email end |
#groups ⇒ Object
Returns the value of attribute groups.
32 33 34 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 32 def groups @groups end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 18 def id @id end |
#is_opted_in ⇒ Object
Returns the value of attribute is_opted_in.
34 35 36 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 34 def is_opted_in @is_opted_in end |
#last_message_received_at ⇒ Object
Returns the value of attribute last_message_received_at.
38 39 40 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 38 def @last_message_received_at end |
#last_message_sent_at ⇒ Object
Returns the value of attribute last_message_sent_at.
36 37 38 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 36 def @last_message_sent_at end |
#messages_received_count ⇒ Object
Returns the value of attribute messages_received_count.
42 43 44 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 42 def @messages_received_count end |
#messages_sent_count ⇒ Object
Returns the value of attribute messages_sent_count.
40 41 42 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 40 def @messages_sent_count end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 24 def name @name end |
#notes ⇒ Object
Returns the value of attribute notes.
46 47 48 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 46 def notes @notes end |
#phone ⇒ Object
Returns the value of attribute phone.
20 21 22 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 20 def phone @phone end |
#tags ⇒ Object
Returns the value of attribute tags.
30 31 32 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 30 def @tags end |
#wa_id ⇒ Object
Returns the value of attribute wa_id.
22 23 24 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 22 def wa_id @wa_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 51 def self.attribute_map { :'id' => :'id', :'phone' => :'phone', :'wa_id' => :'waId', :'name' => :'name', :'email' => :'email', :'company' => :'company', :'tags' => :'tags', :'groups' => :'groups', :'is_opted_in' => :'isOptedIn', :'last_message_sent_at' => :'lastMessageSentAt', :'last_message_received_at' => :'lastMessageReceivedAt', :'messages_sent_count' => :'messagesSentCount', :'messages_received_count' => :'messagesReceivedCount', :'custom_fields' => :'customFields', :'notes' => :'notes', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 248 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 83 def self.openapi_types { :'id' => :'String', :'phone' => :'String', :'wa_id' => :'String', :'name' => :'String', :'email' => :'String', :'company' => :'String', :'tags' => :'Array<String>', :'groups' => :'Array<String>', :'is_opted_in' => :'Boolean', :'last_message_sent_at' => :'Time', :'last_message_received_at' => :'Time', :'messages_sent_count' => :'Integer', :'messages_received_count' => :'Integer', :'custom_fields' => :'Object', :'notes' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && phone == o.phone && wa_id == o.wa_id && name == o.name && email == o.email && company == o.company && == o. && groups == o.groups && is_opted_in == o.is_opted_in && == o. && == o. && == o. && == o. && custom_fields == o.custom_fields && notes == o.notes && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
235 236 237 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 235 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
241 242 243 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 241 def hash [id, phone, wa_id, name, email, company, , groups, is_opted_in, , , , , custom_fields, notes, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
197 198 199 200 201 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 197 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 270 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
205 206 207 208 |
# File 'lib/late-sdk/models/get_whats_app_contacts200_response_contacts_inner.rb', line 205 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |