Class: Late::WebhookEventsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/late-sdk/api/webhook_events_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ WebhookEventsApi

Returns a new instance of WebhookEventsApi.



19
20
21
# File 'lib/late-sdk/api/webhook_events_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/late-sdk/api/webhook_events_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#on_account_connected(webhook_payload_account_connected, opts = {}) ⇒ nil

Account connected event Fired when a social account is successfully connected.

Parameters:

Returns:

  • (nil)


27
28
29
30
# File 'lib/late-sdk/api/webhook_events_api.rb', line 27

def (, opts = {})
  (, opts)
  nil
end

#on_account_connected_with_http_info(webhook_payload_account_connected, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Account connected event Fired when a social account is successfully connected.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/late-sdk/api/webhook_events_api.rb', line 37

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_account_connected ...'
  end
  # verify the required parameter 'webhook_payload_account_connected' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_account_connected' when calling WebhookEventsApi.on_account_connected"
  end
  # resource path
  local_var_path = '/account.connected'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_account_connected",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_account_connected\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_account_disconnected(webhook_payload_account_disconnected, opts = {}) ⇒ nil

Account disconnected event Fired when a connected social account becomes disconnected.

Parameters:

Returns:

  • (nil)


93
94
95
96
# File 'lib/late-sdk/api/webhook_events_api.rb', line 93

def (, opts = {})
  (, opts)
  nil
end

#on_account_disconnected_with_http_info(webhook_payload_account_disconnected, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Account disconnected event Fired when a connected social account becomes disconnected.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/late-sdk/api/webhook_events_api.rb', line 103

def (, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_account_disconnected ...'
  end
  # verify the required parameter 'webhook_payload_account_disconnected' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_account_disconnected' when calling WebhookEventsApi.on_account_disconnected"
  end
  # resource path
  local_var_path = '/account.disconnected'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body()

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_account_disconnected",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_account_disconnected\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_comment_received(webhook_payload_comment, opts = {}) ⇒ nil

Comment received event Fired when a new comment is received on a tracked post.

Parameters:

  • webhook_payload_comment (WebhookPayloadComment)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


159
160
161
162
# File 'lib/late-sdk/api/webhook_events_api.rb', line 159

def on_comment_received(webhook_payload_comment, opts = {})
  on_comment_received_with_http_info(webhook_payload_comment, opts)
  nil
end

#on_comment_received_with_http_info(webhook_payload_comment, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Comment received event Fired when a new comment is received on a tracked post.

Parameters:

  • webhook_payload_comment (WebhookPayloadComment)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/late-sdk/api/webhook_events_api.rb', line 169

def on_comment_received_with_http_info(webhook_payload_comment, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_comment_received ...'
  end
  # verify the required parameter 'webhook_payload_comment' is set
  if @api_client.config.client_side_validation && webhook_payload_comment.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_comment' when calling WebhookEventsApi.on_comment_received"
  end
  # resource path
  local_var_path = '/comment.received'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_comment)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_comment_received",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_comment_received\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_message_received(webhook_payload_message, opts = {}) ⇒ nil

Message received event Fired when a new inbox message is received.

Parameters:

  • webhook_payload_message (WebhookPayloadMessage)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


225
226
227
228
# File 'lib/late-sdk/api/webhook_events_api.rb', line 225

def on_message_received(webhook_payload_message, opts = {})
  on_message_received_with_http_info(webhook_payload_message, opts)
  nil
end

#on_message_received_with_http_info(webhook_payload_message, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Message received event Fired when a new inbox message is received.

Parameters:

  • webhook_payload_message (WebhookPayloadMessage)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/late-sdk/api/webhook_events_api.rb', line 235

def on_message_received_with_http_info(webhook_payload_message, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_message_received ...'
  end
  # verify the required parameter 'webhook_payload_message' is set
  if @api_client.config.client_side_validation && webhook_payload_message.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_message' when calling WebhookEventsApi.on_message_received"
  end
  # resource path
  local_var_path = '/message.received'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_message)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_message_received",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_message_received\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_post_cancelled(webhook_payload_post, opts = {}) ⇒ nil

Post cancelled event Fired when a post publishing job is cancelled.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


291
292
293
294
# File 'lib/late-sdk/api/webhook_events_api.rb', line 291

def on_post_cancelled(webhook_payload_post, opts = {})
  on_post_cancelled_with_http_info(webhook_payload_post, opts)
  nil
end

#on_post_cancelled_with_http_info(webhook_payload_post, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Post cancelled event Fired when a post publishing job is cancelled.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/late-sdk/api/webhook_events_api.rb', line 301

def on_post_cancelled_with_http_info(webhook_payload_post, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_post_cancelled ...'
  end
  # verify the required parameter 'webhook_payload_post' is set
  if @api_client.config.client_side_validation && webhook_payload_post.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_post' when calling WebhookEventsApi.on_post_cancelled"
  end
  # resource path
  local_var_path = '/post.cancelled'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_post)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_post_cancelled",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_post_cancelled\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_post_failed(webhook_payload_post, opts = {}) ⇒ nil

Post failed event Fired when a post fails to publish on all target platforms.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


357
358
359
360
# File 'lib/late-sdk/api/webhook_events_api.rb', line 357

def on_post_failed(webhook_payload_post, opts = {})
  on_post_failed_with_http_info(webhook_payload_post, opts)
  nil
end

#on_post_failed_with_http_info(webhook_payload_post, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Post failed event Fired when a post fails to publish on all target platforms.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/late-sdk/api/webhook_events_api.rb', line 367

def on_post_failed_with_http_info(webhook_payload_post, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_post_failed ...'
  end
  # verify the required parameter 'webhook_payload_post' is set
  if @api_client.config.client_side_validation && webhook_payload_post.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_post' when calling WebhookEventsApi.on_post_failed"
  end
  # resource path
  local_var_path = '/post.failed'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_post)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_post_failed",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_post_failed\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_post_partial(webhook_payload_post, opts = {}) ⇒ nil

Post partial event Fired when a post publishes on some platforms and fails on others.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


423
424
425
426
# File 'lib/late-sdk/api/webhook_events_api.rb', line 423

def on_post_partial(webhook_payload_post, opts = {})
  on_post_partial_with_http_info(webhook_payload_post, opts)
  nil
end

#on_post_partial_with_http_info(webhook_payload_post, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Post partial event Fired when a post publishes on some platforms and fails on others.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/late-sdk/api/webhook_events_api.rb', line 433

def on_post_partial_with_http_info(webhook_payload_post, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_post_partial ...'
  end
  # verify the required parameter 'webhook_payload_post' is set
  if @api_client.config.client_side_validation && webhook_payload_post.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_post' when calling WebhookEventsApi.on_post_partial"
  end
  # resource path
  local_var_path = '/post.partial'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_post)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_post_partial",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_post_partial\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_post_published(webhook_payload_post, opts = {}) ⇒ nil

Post published event Fired when a post is successfully published.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


489
490
491
492
# File 'lib/late-sdk/api/webhook_events_api.rb', line 489

def (webhook_payload_post, opts = {})
  (webhook_payload_post, opts)
  nil
end

#on_post_published_with_http_info(webhook_payload_post, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Post published event Fired when a post is successfully published.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/late-sdk/api/webhook_events_api.rb', line 499

def (webhook_payload_post, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_post_published ...'
  end
  # verify the required parameter 'webhook_payload_post' is set
  if @api_client.config.client_side_validation && webhook_payload_post.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_post' when calling WebhookEventsApi.on_post_published"
  end
  # resource path
  local_var_path = '/post.published'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_post)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_post_published",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_post_published\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_post_recycled(webhook_payload_post, opts = {}) ⇒ nil

Post recycled event Fired when a post is recycled (cloned and re-scheduled for publishing).

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


555
556
557
558
# File 'lib/late-sdk/api/webhook_events_api.rb', line 555

def on_post_recycled(webhook_payload_post, opts = {})
  on_post_recycled_with_http_info(webhook_payload_post, opts)
  nil
end

#on_post_recycled_with_http_info(webhook_payload_post, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Post recycled event Fired when a post is recycled (cloned and re-scheduled for publishing).

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/late-sdk/api/webhook_events_api.rb', line 565

def on_post_recycled_with_http_info(webhook_payload_post, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_post_recycled ...'
  end
  # verify the required parameter 'webhook_payload_post' is set
  if @api_client.config.client_side_validation && webhook_payload_post.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_post' when calling WebhookEventsApi.on_post_recycled"
  end
  # resource path
  local_var_path = '/post.recycled'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_post)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_post_recycled",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_post_recycled\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_post_scheduled(webhook_payload_post, opts = {}) ⇒ nil

Post scheduled event Fired when a post is created and scheduled for publishing.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


621
622
623
624
# File 'lib/late-sdk/api/webhook_events_api.rb', line 621

def on_post_scheduled(webhook_payload_post, opts = {})
  on_post_scheduled_with_http_info(webhook_payload_post, opts)
  nil
end

#on_post_scheduled_with_http_info(webhook_payload_post, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Post scheduled event Fired when a post is created and scheduled for publishing.

Parameters:

  • webhook_payload_post (WebhookPayloadPost)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
# File 'lib/late-sdk/api/webhook_events_api.rb', line 631

def on_post_scheduled_with_http_info(webhook_payload_post, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_post_scheduled ...'
  end
  # verify the required parameter 'webhook_payload_post' is set
  if @api_client.config.client_side_validation && webhook_payload_post.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_post' when calling WebhookEventsApi.on_post_scheduled"
  end
  # resource path
  local_var_path = '/post.scheduled'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_post)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_post_scheduled",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_post_scheduled\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#on_webhook_test(webhook_payload_test, opts = {}) ⇒ nil

Webhook test event Fired when sending a test webhook to verify the endpoint configuration.

Parameters:

  • webhook_payload_test (WebhookPayloadTest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


687
688
689
690
# File 'lib/late-sdk/api/webhook_events_api.rb', line 687

def on_webhook_test(webhook_payload_test, opts = {})
  on_webhook_test_with_http_info(webhook_payload_test, opts)
  nil
end

#on_webhook_test_with_http_info(webhook_payload_test, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Webhook test event Fired when sending a test webhook to verify the endpoint configuration.

Parameters:

  • webhook_payload_test (WebhookPayloadTest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
# File 'lib/late-sdk/api/webhook_events_api.rb', line 697

def on_webhook_test_with_http_info(webhook_payload_test, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: WebhookEventsApi.on_webhook_test ...'
  end
  # verify the required parameter 'webhook_payload_test' is set
  if @api_client.config.client_side_validation && webhook_payload_test.nil?
    fail ArgumentError, "Missing the required parameter 'webhook_payload_test' when calling WebhookEventsApi.on_webhook_test"
  end
  # resource path
  local_var_path = '/webhook.test'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(webhook_payload_test)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"WebhookEventsApi.on_webhook_test",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: WebhookEventsApi#on_webhook_test\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end