Class: Late::WebhooksApi
- Inherits:
-
Object
- Object
- Late::WebhooksApi
- Defined in:
- lib/late-sdk/api/webhooks_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_webhook_settings(create_webhook_settings_request, opts = {}) ⇒ UpdateWebhookSettings200Response
Create webhook Create a new webhook configuration.
-
#create_webhook_settings_with_http_info(create_webhook_settings_request, opts = {}) ⇒ Array<(UpdateWebhookSettings200Response, Integer, Hash)>
Create webhook Create a new webhook configuration.
-
#delete_webhook_settings(id, opts = {}) ⇒ UpdateYoutubeDefaultPlaylist200Response
Delete webhook Permanently delete a webhook configuration.
-
#delete_webhook_settings_with_http_info(id, opts = {}) ⇒ Array<(UpdateYoutubeDefaultPlaylist200Response, Integer, Hash)>
Delete webhook Permanently delete a webhook configuration.
-
#get_webhook_logs(opts = {}) ⇒ GetWebhookLogs200Response
Get delivery logs Deprecated. Use ‘GET /v1/logs?type=webhooks` instead.
-
#get_webhook_logs_with_http_info(opts = {}) ⇒ Array<(GetWebhookLogs200Response, Integer, Hash)>
Get delivery logs Deprecated. Use `GET /v1/logs?type=webhooks` instead.
-
#get_webhook_settings(opts = {}) ⇒ GetWebhookSettings200Response
List webhooks Retrieve all configured webhooks for the authenticated user.
-
#get_webhook_settings_with_http_info(opts = {}) ⇒ Array<(GetWebhookSettings200Response, Integer, Hash)>
List webhooks Retrieve all configured webhooks for the authenticated user.
-
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
constructor
A new instance of WebhooksApi.
-
#test_webhook(test_webhook_request, opts = {}) ⇒ UnpublishPost200Response
Send test webhook Send a test webhook to verify your endpoint is configured correctly.
-
#test_webhook_with_http_info(test_webhook_request, opts = {}) ⇒ Array<(UnpublishPost200Response, Integer, Hash)>
Send test webhook Send a test webhook to verify your endpoint is configured correctly.
-
#update_webhook_settings(update_webhook_settings_request, opts = {}) ⇒ UpdateWebhookSettings200Response
Update webhook Update an existing webhook configuration.
-
#update_webhook_settings_with_http_info(update_webhook_settings_request, opts = {}) ⇒ Array<(UpdateWebhookSettings200Response, Integer, Hash)>
Update webhook Update an existing webhook configuration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WebhooksApi
Returns a new instance of WebhooksApi.
19 20 21 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_webhook_settings(create_webhook_settings_request, opts = {}) ⇒ UpdateWebhookSettings200Response
Create webhook Create a new webhook configuration. Maximum 10 webhooks per user. Webhooks are automatically disabled after 10 consecutive delivery failures.
27 28 29 30 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 27 def create_webhook_settings(create_webhook_settings_request, opts = {}) data, _status_code, _headers = create_webhook_settings_with_http_info(create_webhook_settings_request, opts) data end |
#create_webhook_settings_with_http_info(create_webhook_settings_request, opts = {}) ⇒ Array<(UpdateWebhookSettings200Response, Integer, Hash)>
Create webhook Create a new webhook configuration. Maximum 10 webhooks per user. Webhooks are automatically disabled after 10 consecutive delivery failures.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 37 def create_webhook_settings_with_http_info(create_webhook_settings_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.create_webhook_settings ...' end # verify the required parameter 'create_webhook_settings_request' is set if @api_client.config.client_side_validation && create_webhook_settings_request.nil? fail ArgumentError, "Missing the required parameter 'create_webhook_settings_request' when calling WebhooksApi.create_webhook_settings" end # resource path local_var_path = '/v1/webhooks/settings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_webhook_settings_request) # return_type return_type = opts[:debug_return_type] || 'UpdateWebhookSettings200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.create_webhook_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#create_webhook_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_webhook_settings(id, opts = {}) ⇒ UpdateYoutubeDefaultPlaylist200Response
Delete webhook Permanently delete a webhook configuration.
95 96 97 98 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 95 def delete_webhook_settings(id, opts = {}) data, _status_code, _headers = delete_webhook_settings_with_http_info(id, opts) data end |
#delete_webhook_settings_with_http_info(id, opts = {}) ⇒ Array<(UpdateYoutubeDefaultPlaylist200Response, Integer, Hash)>
Delete webhook Permanently delete a webhook configuration.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 105 def delete_webhook_settings_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.delete_webhook_settings ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling WebhooksApi.delete_webhook_settings" end # resource path local_var_path = '/v1/webhooks/settings' # query parameters query_params = opts[:query_params] || {} query_params[:'id'] = id # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UpdateYoutubeDefaultPlaylist200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.delete_webhook_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#delete_webhook_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_webhook_logs(opts = {}) ⇒ GetWebhookLogs200Response
Get delivery logs Deprecated. Use ‘GET /v1/logs?type=webhooks` instead. Retrieve webhook delivery history. Logs are retained for 90 days.
162 163 164 165 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 162 def get_webhook_logs(opts = {}) data, _status_code, _headers = get_webhook_logs_with_http_info(opts) data end |
#get_webhook_logs_with_http_info(opts = {}) ⇒ Array<(GetWebhookLogs200Response, Integer, Hash)>
Get delivery logs Deprecated. Use `GET /v1/logs?type=webhooks` instead. Retrieve webhook delivery history. Logs are retained for 90 days.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 175 def get_webhook_logs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.get_webhook_logs ...' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.get_webhook_logs, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling WebhooksApi.get_webhook_logs, must be greater than or equal to 1.' end allowable_values = ["success", "failed"] if @api_client.config.client_side_validation && opts[:'status'] && !allowable_values.include?(opts[:'status']) fail ArgumentError, "invalid value for \"status\", must be one of #{allowable_values}" end allowable_values = ["post.scheduled", "post.published", "post.failed", "post.partial", "post.cancelled", "post.recycled", "account.connected", "account.disconnected", "message.received", "comment.received", "webhook.test"] if @api_client.config.client_side_validation && opts[:'event'] && !allowable_values.include?(opts[:'event']) fail ArgumentError, "invalid value for \"event\", must be one of #{allowable_values}" end # resource path local_var_path = '/v1/webhooks/logs' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'status'] = opts[:'status'] if !opts[:'status'].nil? query_params[:'event'] = opts[:'event'] if !opts[:'event'].nil? query_params[:'webhookId'] = opts[:'webhook_id'] if !opts[:'webhook_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWebhookLogs200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.get_webhook_logs", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#get_webhook_logs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_webhook_settings(opts = {}) ⇒ GetWebhookSettings200Response
List webhooks Retrieve all configured webhooks for the authenticated user. Supports up to 10 webhooks per user.
243 244 245 246 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 243 def get_webhook_settings(opts = {}) data, _status_code, _headers = get_webhook_settings_with_http_info(opts) data end |
#get_webhook_settings_with_http_info(opts = {}) ⇒ Array<(GetWebhookSettings200Response, Integer, Hash)>
List webhooks Retrieve all configured webhooks for the authenticated user. Supports up to 10 webhooks per user.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 252 def get_webhook_settings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.get_webhook_settings ...' end # resource path local_var_path = '/v1/webhooks/settings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetWebhookSettings200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.get_webhook_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#get_webhook_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#test_webhook(test_webhook_request, opts = {}) ⇒ UnpublishPost200Response
Send test webhook Send a test webhook to verify your endpoint is configured correctly. The test payload includes event: "webhook.test" to distinguish it from real events.
301 302 303 304 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 301 def test_webhook(test_webhook_request, opts = {}) data, _status_code, _headers = test_webhook_with_http_info(test_webhook_request, opts) data end |
#test_webhook_with_http_info(test_webhook_request, opts = {}) ⇒ Array<(UnpublishPost200Response, Integer, Hash)>
Send test webhook Send a test webhook to verify your endpoint is configured correctly. The test payload includes event: "webhook.test" to distinguish it from real events.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 311 def test_webhook_with_http_info(test_webhook_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.test_webhook ...' end # verify the required parameter 'test_webhook_request' is set if @api_client.config.client_side_validation && test_webhook_request.nil? fail ArgumentError, "Missing the required parameter 'test_webhook_request' when calling WebhooksApi.test_webhook" end # resource path local_var_path = '/v1/webhooks/test' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(test_webhook_request) # return_type return_type = opts[:debug_return_type] || 'UnpublishPost200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.test_webhook", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#test_webhook\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_webhook_settings(update_webhook_settings_request, opts = {}) ⇒ UpdateWebhookSettings200Response
Update webhook Update an existing webhook configuration. All fields except _id are optional; only provided fields will be updated. Webhooks are automatically disabled after 10 consecutive delivery failures.
369 370 371 372 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 369 def update_webhook_settings(update_webhook_settings_request, opts = {}) data, _status_code, _headers = update_webhook_settings_with_http_info(update_webhook_settings_request, opts) data end |
#update_webhook_settings_with_http_info(update_webhook_settings_request, opts = {}) ⇒ Array<(UpdateWebhookSettings200Response, Integer, Hash)>
Update webhook Update an existing webhook configuration. All fields except _id are optional; only provided fields will be updated. Webhooks are automatically disabled after 10 consecutive delivery failures.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/late-sdk/api/webhooks_api.rb', line 379 def update_webhook_settings_with_http_info(update_webhook_settings_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebhooksApi.update_webhook_settings ...' end # verify the required parameter 'update_webhook_settings_request' is set if @api_client.config.client_side_validation && update_webhook_settings_request.nil? fail ArgumentError, "Missing the required parameter 'update_webhook_settings_request' when calling WebhooksApi.update_webhook_settings" end # resource path local_var_path = '/v1/webhooks/settings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_webhook_settings_request) # return_type return_type = opts[:debug_return_type] || 'UpdateWebhookSettings200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"WebhooksApi.update_webhook_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebhooksApi#update_webhook_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |