Class: Zernio::AdKeyword

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/ad_keyword.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AdKeyword

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 152

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AdKeyword` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AdKeyword`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  end

  if attributes.key?(:'campaign_id')
    self.campaign_id = attributes[:'campaign_id']
  end

  if attributes.key?(:'campaign_name')
    self.campaign_name = attributes[:'campaign_name']
  end

  if attributes.key?(:'campaign_status')
    self.campaign_status = attributes[:'campaign_status']
  end

  if attributes.key?(:'ad_set_id')
    self.ad_set_id = attributes[:'ad_set_id']
  end

  if attributes.key?(:'ad_set_name')
    self.ad_set_name = attributes[:'ad_set_name']
  end

  if attributes.key?(:'ad_set_status')
    self.ad_set_status = attributes[:'ad_set_status']
  end

  if attributes.key?(:'keyword')
    self.keyword = attributes[:'keyword']
  end

  if attributes.key?(:'match_type')
    self.match_type = attributes[:'match_type']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'negative')
    self.negative = attributes[:'negative']
  end

  if attributes.key?(:'quality_score')
    self.quality_score = attributes[:'quality_score']
  end

  if attributes.key?(:'synced_at')
    self.synced_at = attributes[:'synced_at']
  end

  if attributes.key?(:'metrics')
    self.metrics = attributes[:'metrics']
  end
end

Instance Attribute Details

#account_id ⇒ Object

Account ID owning the sync



21
22
23
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 21

def 
  @account_id
end

#ad_account_id ⇒ Object

Google customer ID



28
29
30
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 28

def 
  @ad_account_id
end

#ad_set_id ⇒ Object

Google ad group ID



37
38
39
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 37

def ad_set_id
  @ad_set_id
end

#ad_set_name ⇒ Object

Returns the value of attribute ad_set_name.



39
40
41
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 39

def ad_set_name
  @ad_set_name
end

#ad_set_status ⇒ Object

Returns the value of attribute ad_set_status.



41
42
43
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 41

def ad_set_status
  @ad_set_status
end

#campaign_id ⇒ Object

Returns the value of attribute campaign_id.



30
31
32
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 30

def campaign_id
  @campaign_id
end

#campaign_name ⇒ Object

Returns the value of attribute campaign_name.



32
33
34
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 32

def campaign_name
  @campaign_name
end

#campaign_status ⇒ Object

Returns the value of attribute campaign_status.



34
35
36
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 34

def campaign_status
  @campaign_status
end

#id ⇒ Object

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 18

def id
  @id
end

#keyword ⇒ Object

Returns the value of attribute keyword.



43
44
45
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 43

def keyword
  @keyword
end

#match_type ⇒ Object

Returns the value of attribute match_type.



45
46
47
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 45

def match_type
  @match_type
end

#metrics ⇒ Object

Returns the value of attribute metrics.



56
57
58
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 56

def metrics
  @metrics
end

#negative ⇒ Object

Returns the value of attribute negative.



49
50
51
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 49

def negative
  @negative
end

#platform ⇒ Object

Returns the value of attribute platform.



25
26
27
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 25

def platform
  @platform
end

#profile_id ⇒ Object

Returns the value of attribute profile_id.



23
24
25
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 23

def profile_id
  @profile_id
end

#quality_score ⇒ Object

Google Quality Score, 1-10. Null when unrated.



52
53
54
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 52

def quality_score
  @quality_score
end

#status ⇒ Object

Returns the value of attribute status.



47
48
49
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 47

def status
  @status
end

#synced_at ⇒ Object

Returns the value of attribute synced_at.



54
55
56
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 54

def synced_at
  @synced_at
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



105
106
107
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 105

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 110

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 81

def self.attribute_map
  {
    :'id' => :'id',
    :'account_id' => :'accountId',
    :'profile_id' => :'profileId',
    :'platform' => :'platform',
    :'ad_account_id' => :'adAccountId',
    :'campaign_id' => :'campaignId',
    :'campaign_name' => :'campaignName',
    :'campaign_status' => :'campaignStatus',
    :'ad_set_id' => :'adSetId',
    :'ad_set_name' => :'adSetName',
    :'ad_set_status' => :'adSetStatus',
    :'keyword' => :'keyword',
    :'match_type' => :'matchType',
    :'status' => :'status',
    :'negative' => :'negative',
    :'quality_score' => :'qualityScore',
    :'synced_at' => :'syncedAt',
    :'metrics' => :'metrics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 330

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



139
140
141
142
143
144
145
146
147
148
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 139

def self.openapi_nullable
  Set.new([
    :'campaign_name',
    :'campaign_status',
    :'ad_set_name',
    :'ad_set_status',
    :'quality_score',
    :'synced_at',
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 115

def self.openapi_types
  {
    :'id' => :'String',
    :'account_id' => :'String',
    :'profile_id' => :'String',
    :'platform' => :'String',
    :'ad_account_id' => :'String',
    :'campaign_id' => :'String',
    :'campaign_name' => :'String',
    :'campaign_status' => :'String',
    :'ad_set_id' => :'String',
    :'ad_set_name' => :'String',
    :'ad_set_status' => :'String',
    :'keyword' => :'String',
    :'match_type' => :'String',
    :'status' => :'String',
    :'negative' => :'Boolean',
    :'quality_score' => :'Integer',
    :'synced_at' => :'Time',
    :'metrics' => :'AdKeywordMetrics'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
       == o. &&
      profile_id == o.profile_id &&
      platform == o.platform &&
       == o. &&
      campaign_id == o.campaign_id &&
      campaign_name == o.campaign_name &&
      campaign_status == o.campaign_status &&
      ad_set_id == o.ad_set_id &&
      ad_set_name == o.ad_set_name &&
      ad_set_status == o.ad_set_status &&
      keyword == o.keyword &&
      match_type == o.match_type &&
      status == o.status &&
      negative == o.negative &&
      quality_score == o.quality_score &&
      synced_at == o.synced_at &&
      metrics == o.metrics
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 317

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



323
324
325
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 323

def hash
  [id, , profile_id, platform, , campaign_id, campaign_name, campaign_status, ad_set_id, ad_set_name, ad_set_status, keyword, match_type, status, negative, quality_score, synced_at, metrics].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



241
242
243
244
245
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 241

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 352

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



249
250
251
252
253
254
255
256
257
258
# File 'lib/zernio-sdk/models/ad_keyword.rb', line 249

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  platform_validator = EnumAttributeValidator.new('String', ["google"])
  return false unless platform_validator.valid?(@platform)
  match_type_validator = EnumAttributeValidator.new('String', ["exact", "phrase", "broad", "unknown"])
  return false unless match_type_validator.valid?(@match_type)
  status_validator = EnumAttributeValidator.new('String', ["active", "paused"])
  return false unless status_validator.valid?(@status)
  true
end