Class: Zernio::AnalyticsListResponsePostsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AnalyticsListResponsePostsInner
- Defined in:
- lib/zernio-sdk/models/analytics_list_response_posts_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#analytics ⇒ Object
Returns the value of attribute analytics.
-
#content ⇒ Object
Returns the value of attribute content.
-
#is_external ⇒ Object
Returns the value of attribute is_external.
-
#late_post_id ⇒ Object
Original Zernio post ID if scheduled via Zernio.
-
#media_items ⇒ Object
All media items for this post.
-
#media_type ⇒ Object
Returns the value of attribute media_type.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
-
#platforms ⇒ Object
Returns the value of attribute platforms.
-
#profile_id ⇒ Object
Returns the value of attribute profile_id.
-
#published_at ⇒ Object
Returns the value of attribute published_at.
-
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
-
#status ⇒ Object
Returns the value of attribute status.
-
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnalyticsListResponsePostsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AnalyticsListResponsePostsInner
Initializes the object
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 134 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AnalyticsListResponsePostsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AnalyticsListResponsePostsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'late_post_id') self.late_post_id = attributes[:'late_post_id'] end if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'scheduled_for') self.scheduled_for = attributes[:'scheduled_for'] end if attributes.key?(:'published_at') self.published_at = attributes[:'published_at'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'analytics') self.analytics = attributes[:'analytics'] end if attributes.key?(:'platforms') if (value = attributes[:'platforms']).is_a?(Array) self.platforms = value end end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'platform_post_url') self.platform_post_url = attributes[:'platform_post_url'] end if attributes.key?(:'is_external') self.is_external = attributes[:'is_external'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'thumbnail_url') self.thumbnail_url = attributes[:'thumbnail_url'] end if attributes.key?(:'media_type') self.media_type = attributes[:'media_type'] end if attributes.key?(:'media_items') if (value = attributes[:'media_items']).is_a?(Array) self.media_items = value end end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 18 def _id @_id end |
#analytics ⇒ Object
Returns the value of attribute analytics.
31 32 33 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 31 def analytics @analytics end |
#content ⇒ Object
Returns the value of attribute content.
23 24 25 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 23 def content @content end |
#is_external ⇒ Object
Returns the value of attribute is_external.
39 40 41 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 39 def is_external @is_external end |
#late_post_id ⇒ Object
Original Zernio post ID if scheduled via Zernio
21 22 23 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 21 def late_post_id @late_post_id end |
#media_items ⇒ Object
All media items for this post. Carousel posts contain one entry per slide.
48 49 50 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 48 def media_items @media_items end |
#media_type ⇒ Object
Returns the value of attribute media_type.
45 46 47 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 45 def media_type @media_type end |
#platform ⇒ Object
Returns the value of attribute platform.
35 36 37 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 35 def platform @platform end |
#platform_post_url ⇒ Object
Returns the value of attribute platform_post_url.
37 38 39 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 37 def platform_post_url @platform_post_url end |
#platforms ⇒ Object
Returns the value of attribute platforms.
33 34 35 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 33 def platforms @platforms end |
#profile_id ⇒ Object
Returns the value of attribute profile_id.
41 42 43 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 41 def profile_id @profile_id end |
#published_at ⇒ Object
Returns the value of attribute published_at.
27 28 29 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 27 def published_at @published_at end |
#scheduled_for ⇒ Object
Returns the value of attribute scheduled_for.
25 26 27 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 25 def scheduled_for @scheduled_for end |
#status ⇒ Object
Returns the value of attribute status.
29 30 31 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 29 def status @status end |
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
43 44 45 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 43 def thumbnail_url @thumbnail_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
94 95 96 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 94 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 99 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 73 def self.attribute_map { :'_id' => :'_id', :'late_post_id' => :'latePostId', :'content' => :'content', :'scheduled_for' => :'scheduledFor', :'published_at' => :'publishedAt', :'status' => :'status', :'analytics' => :'analytics', :'platforms' => :'platforms', :'platform' => :'platform', :'platform_post_url' => :'platformPostUrl', :'is_external' => :'isExternal', :'profile_id' => :'profileId', :'thumbnail_url' => :'thumbnailUrl', :'media_type' => :'mediaType', :'media_items' => :'mediaItems' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 277 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 129 130 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 125 def self.openapi_nullable Set.new([ :'late_post_id', :'profile_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 104 def self.openapi_types { :'_id' => :'String', :'late_post_id' => :'String', :'content' => :'String', :'scheduled_for' => :'Time', :'published_at' => :'Time', :'status' => :'String', :'analytics' => :'PostAnalytics', :'platforms' => :'Array<PlatformAnalytics>', :'platform' => :'String', :'platform_post_url' => :'String', :'is_external' => :'Boolean', :'profile_id' => :'String', :'thumbnail_url' => :'String', :'media_type' => :'String', :'media_items' => :'Array<AnalyticsSinglePostResponseMediaItemsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && late_post_id == o.late_post_id && content == o.content && scheduled_for == o.scheduled_for && published_at == o.published_at && status == o.status && analytics == o.analytics && platforms == o.platforms && platform == o.platform && platform_post_url == o.platform_post_url && is_external == o.is_external && profile_id == o.profile_id && thumbnail_url == o.thumbnail_url && media_type == o.media_type && media_items == o.media_items end |
#eql?(o) ⇒ Boolean
264 265 266 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 264 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
270 271 272 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 270 def hash [_id, late_post_id, content, scheduled_for, published_at, status, analytics, platforms, platform, platform_post_url, is_external, profile_id, thumbnail_url, media_type, media_items].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
215 216 217 218 219 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 215 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 227 228 |
# File 'lib/zernio-sdk/models/analytics_list_response_posts_inner.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' media_type_validator = EnumAttributeValidator.new('String', ["image", "video", "gif", "document", "carousel", "text"]) return false unless media_type_validator.valid?(@media_type) true end |