Class: Zernio::AttachCampaignAssetsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AttachCampaignAssetsRequest
- Defined in:
- lib/zernio-sdk/models/attach_campaign_assets_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio Google Ads SocialAccount id — resolves the customer id + refresh token.
-
#callouts ⇒ Object
Returns the value of attribute callouts.
-
#sitelinks ⇒ Object
See POST /v1/ads/create sitelinks — same shape.
-
#structured_snippets ⇒ Object
Returns the value of attribute structured_snippets.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachCampaignAssetsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AttachCampaignAssetsRequest
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AttachCampaignAssetsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AttachCampaignAssetsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'sitelinks') if (value = attributes[:'sitelinks']).is_a?(Array) self.sitelinks = value end end if attributes.key?(:'callouts') if (value = attributes[:'callouts']).is_a?(Array) self.callouts = value end end if attributes.key?(:'structured_snippets') if (value = attributes[:'structured_snippets']).is_a?(Array) self.structured_snippets = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio Google Ads SocialAccount id — resolves the customer id + refresh token.
19 20 21 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 19 def account_id @account_id end |
#callouts ⇒ Object
Returns the value of attribute callouts.
24 25 26 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 24 def callouts @callouts end |
#sitelinks ⇒ Object
See POST /v1/ads/create sitelinks — same shape.
22 23 24 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 22 def sitelinks @sitelinks end |
#structured_snippets ⇒ Object
Returns the value of attribute structured_snippets.
26 27 28 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 26 def structured_snippets @structured_snippets end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
39 40 41 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 39 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
44 45 46 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 44 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 36 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 29 def self.attribute_map { :'account_id' => :'accountId', :'sitelinks' => :'sitelinks', :'callouts' => :'callouts', :'structured_snippets' => :'structuredSnippets' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 245 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
59 60 61 62 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 59 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
49 50 51 52 53 54 55 56 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 49 def self.openapi_types { :'account_id' => :'String', :'sitelinks' => :'Array<AttachCampaignAssetsRequestSitelinksInner>', :'callouts' => :'Array<String>', :'structured_snippets' => :'Array<AttachCampaignAssetsRequestStructuredSnippetsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
221 222 223 224 225 226 227 228 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 221 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && sitelinks == o.sitelinks && callouts == o.callouts && structured_snippets == o.structured_snippets end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 238 def hash [account_id, sitelinks, callouts, structured_snippets].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if !@sitelinks.nil? && @sitelinks.length > 20 invalid_properties.push('invalid value for "sitelinks", number of items must be less than or equal to 20.') end if !@sitelinks.nil? && @sitelinks.length < 2 invalid_properties.push('invalid value for "sitelinks", number of items must be greater than or equal to 2.') end if !@callouts.nil? && @callouts.length > 20 invalid_properties.push('invalid value for "callouts", number of items must be less than or equal to 20.') end if !@callouts.nil? && @callouts.length < 1 invalid_properties.push('invalid value for "callouts", number of items must be greater than or equal to 1.') end if !@structured_snippets.nil? && @structured_snippets.length > 20 invalid_properties.push('invalid value for "structured_snippets", number of items must be less than or equal to 20.') end if !@structured_snippets.nil? && @structured_snippets.length < 1 invalid_properties.push('invalid value for "structured_snippets", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if !@sitelinks.nil? && @sitelinks.length > 20 return false if !@sitelinks.nil? && @sitelinks.length < 2 return false if !@callouts.nil? && @callouts.length > 20 return false if !@callouts.nil? && @callouts.length < 1 return false if !@structured_snippets.nil? && @structured_snippets.length > 20 return false if !@structured_snippets.nil? && @structured_snippets.length < 1 true end |