Class: Zernio::AttachCampaignAssetsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::AttachCampaignAssetsRequest
- Defined in:
- lib/zernio-sdk/models/attach_campaign_assets_request.rb
Overview
Provide at least one of sitelinks, callouts or structuredSnippets. Sitelink description1 and description2 must be supplied together.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio Google Ads connection id.
-
#ad_account_id ⇒ Object
Platform ad account ID (Google customer ID, digits only).
-
#callouts ⇒ Object
Returns the value of attribute callouts.
-
#customer_id ⇒ Object
Alias of adAccountId, kept for existing callers.
-
#sitelinks ⇒ Object
Returns the value of attribute sitelinks.
-
#structured_snippets ⇒ Object
Returns the value of attribute structured_snippets.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AttachCampaignAssetsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AttachCampaignAssetsRequest
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::AttachCampaignAssetsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::AttachCampaignAssetsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'sitelinks') if (value = attributes[:'sitelinks']).is_a?(Array) self.sitelinks = value end end if attributes.key?(:'callouts') if (value = attributes[:'callouts']).is_a?(Array) self.callouts = value end end if attributes.key?(:'structured_snippets') if (value = attributes[:'structured_snippets']).is_a?(Array) self.structured_snippets = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio Google Ads connection id.
20 21 22 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 20 def account_id @account_id end |
#ad_account_id ⇒ Object
Platform ad account ID (Google customer ID, digits only). Required when the connection has multiple customers.
23 24 25 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 23 def ad_account_id @ad_account_id end |
#callouts ⇒ Object
Returns the value of attribute callouts.
30 31 32 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 30 def callouts @callouts end |
#customer_id ⇒ Object
Alias of adAccountId, kept for existing callers
26 27 28 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 26 def customer_id @customer_id end |
#sitelinks ⇒ Object
Returns the value of attribute sitelinks.
28 29 30 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 28 def sitelinks @sitelinks end |
#structured_snippets ⇒ Object
Returns the value of attribute structured_snippets.
32 33 34 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 32 def structured_snippets @structured_snippets end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 35 def self.attribute_map { :'account_id' => :'accountId', :'ad_account_id' => :'adAccountId', :'customer_id' => :'customerId', :'sitelinks' => :'sitelinks', :'callouts' => :'callouts', :'structured_snippets' => :'structuredSnippets' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 318 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 57 def self.openapi_types { :'account_id' => :'String', :'ad_account_id' => :'String', :'customer_id' => :'String', :'sitelinks' => :'Array<GoogleSitelink>', :'callouts' => :'Array<String>', :'structured_snippets' => :'Array<GoogleStructuredSnippet>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
292 293 294 295 296 297 298 299 300 301 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 292 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && ad_account_id == o.ad_account_id && customer_id == o.customer_id && sitelinks == o.sitelinks && callouts == o.callouts && structured_snippets == o.structured_snippets end |
#eql?(o) ⇒ Boolean
305 306 307 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 305 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
311 312 313 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 311 def hash [account_id, ad_account_id, customer_id, sitelinks, callouts, structured_snippets].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end pattern = Regexp.new(/^[a-fA-F0-9]{24}$/) if @account_id !~ pattern invalid_properties.push("invalid value for \"account_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@customer_id.nil? && @customer_id !~ pattern invalid_properties.push("invalid value for \"customer_id\", must conform to the pattern #{pattern}.") end if !@sitelinks.nil? && @sitelinks.length > 20 invalid_properties.push('invalid value for "sitelinks", number of items must be less than or equal to 20.') end if !@sitelinks.nil? && @sitelinks.length < 2 invalid_properties.push('invalid value for "sitelinks", number of items must be greater than or equal to 2.') end if !@callouts.nil? && @callouts.length > 20 invalid_properties.push('invalid value for "callouts", number of items must be less than or equal to 20.') end if !@callouts.nil? && @callouts.length < 1 invalid_properties.push('invalid value for "callouts", number of items must be greater than or equal to 1.') end if !@structured_snippets.nil? && @structured_snippets.length > 20 invalid_properties.push('invalid value for "structured_snippets", number of items must be less than or equal to 20.') end if !@structured_snippets.nil? && @structured_snippets.length < 1 invalid_properties.push('invalid value for "structured_snippets", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 340 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/attach_campaign_assets_request.rb', line 176 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @account_id !~ Regexp.new(/^[a-fA-F0-9]{24}$/) return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) return false if !@customer_id.nil? && @customer_id !~ Regexp.new(/^\d+$/) return false if !@sitelinks.nil? && @sitelinks.length > 20 return false if !@sitelinks.nil? && @sitelinks.length < 2 return false if !@callouts.nil? && @callouts.length > 20 return false if !@callouts.nil? && @callouts.length < 1 return false if !@structured_snippets.nil? && @structured_snippets.length > 20 return false if !@structured_snippets.nil? && @structured_snippets.length < 1 true end |