Class: Zernio::BrandedCallingReference
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::BrandedCallingReference
- Defined in:
- lib/zernio-sdk/models/branded_calling_reference.rb
Overview
A person the carrier vetting team phones to confirm the business. Business references are senior contacts at a vendor, partner or client; the financial reference is a CPA or a bank contact. Calls are placed in the reference's local 8am-9pm window.
Instance Attribute Summary collapse
-
#email ⇒ Object
Returns the value of attribute email.
-
#full_name ⇒ Object
Returns the value of attribute full_name.
-
#job_title ⇒ Object
Returns the value of attribute job_title.
-
#organization ⇒ Object
Returns the value of attribute organization.
-
#phone_number ⇒ Object
E.164 with a leading +.
-
#relationship_to_registrant ⇒ Object
Returns the value of attribute relationship_to_registrant.
-
#timezone ⇒ Object
IANA timezone id, e.g.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BrandedCallingReference
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BrandedCallingReference
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BrandedCallingReference` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BrandedCallingReference`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] else self.full_name = nil end if attributes.key?(:'job_title') self.job_title = attributes[:'job_title'] end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'relationship_to_registrant') self.relationship_to_registrant = attributes[:'relationship_to_registrant'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] else self.phone_number = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'timezone') self.timezone = attributes[:'timezone'] else self.timezone = nil end end |
Instance Attribute Details
#email ⇒ Object
Returns the value of attribute email.
30 31 32 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 30 def email @email end |
#full_name ⇒ Object
Returns the value of attribute full_name.
19 20 21 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 19 def full_name @full_name end |
#job_title ⇒ Object
Returns the value of attribute job_title.
21 22 23 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 21 def job_title @job_title end |
#organization ⇒ Object
Returns the value of attribute organization.
23 24 25 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 23 def organization @organization end |
#phone_number ⇒ Object
E.164 with a leading +.
28 29 30 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 28 def phone_number @phone_number end |
#relationship_to_registrant ⇒ Object
Returns the value of attribute relationship_to_registrant.
25 26 27 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 25 def relationship_to_registrant @relationship_to_registrant end |
#timezone ⇒ Object
IANA timezone id, e.g. America/New_York.
33 34 35 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 33 def timezone @timezone end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 36 def self.attribute_map { :'full_name' => :'fullName', :'job_title' => :'jobTitle', :'organization' => :'organization', :'relationship_to_registrant' => :'relationshipToRegistrant', :'phone_number' => :'phoneNumber', :'email' => :'email', :'timezone' => :'timezone' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 300 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 59 def self.openapi_types { :'full_name' => :'String', :'job_title' => :'String', :'organization' => :'String', :'relationship_to_registrant' => :'String', :'phone_number' => :'String', :'email' => :'String', :'timezone' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 273 def ==(o) return true if self.equal?(o) self.class == o.class && full_name == o.full_name && job_title == o.job_title && organization == o.organization && relationship_to_registrant == o.relationship_to_registrant && phone_number == o.phone_number && email == o.email && timezone == o.timezone end |
#eql?(o) ⇒ Boolean
287 288 289 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 287 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
293 294 295 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 293 def hash [full_name, job_title, organization, relationship_to_registrant, phone_number, email, timezone].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @full_name.nil? invalid_properties.push('invalid value for "full_name", full_name cannot be nil.') end if @full_name.to_s.length > 255 invalid_properties.push('invalid value for "full_name", the character length must be smaller than or equal to 255.') end if !@job_title.nil? && @job_title.to_s.length > 255 invalid_properties.push('invalid value for "job_title", the character length must be smaller than or equal to 255.') end if !@organization.nil? && @organization.to_s.length > 255 invalid_properties.push('invalid value for "organization", the character length must be smaller than or equal to 255.') end if !@relationship_to_registrant.nil? && @relationship_to_registrant.to_s.length > 255 invalid_properties.push('invalid value for "relationship_to_registrant", the character length must be smaller than or equal to 255.') end if @phone_number.nil? invalid_properties.push('invalid value for "phone_number", phone_number cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @timezone.nil? invalid_properties.push('invalid value for "timezone", timezone cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/zernio-sdk/models/branded_calling_reference.rb', line 172 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @full_name.nil? return false if @full_name.to_s.length > 255 return false if !@job_title.nil? && @job_title.to_s.length > 255 return false if !@organization.nil? && @organization.to_s.length > 255 return false if !@relationship_to_registrant.nil? && @relationship_to_registrant.to_s.length > 255 return false if @phone_number.nil? return false if @email.nil? return false if @timezone.nil? true end |