Class: Zernio::BusinessAgentWebsiteInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::BusinessAgentWebsiteInput
- Defined in:
- lib/zernio-sdk/models/business_agent_website_input.rb
Instance Attribute Summary collapse
-
#excluded_sub_domains ⇒ Object
Returns the value of attribute excluded_sub_domains.
-
#excluded_url_patterns ⇒ Object
Returns the value of attribute excluded_url_patterns.
-
#included_sub_domains ⇒ Object
Returns the value of attribute included_sub_domains.
-
#included_url_patterns ⇒ Object
Only URLs containing one of these substrings are ingested.
-
#single_urls ⇒ Object
Crawl only these exact pages instead of the whole site.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BusinessAgentWebsiteInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BusinessAgentWebsiteInput
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::BusinessAgentWebsiteInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::BusinessAgentWebsiteInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'included_sub_domains') if (value = attributes[:'included_sub_domains']).is_a?(Array) self.included_sub_domains = value end end if attributes.key?(:'included_url_patterns') if (value = attributes[:'included_url_patterns']).is_a?(Array) self.included_url_patterns = value end end if attributes.key?(:'excluded_sub_domains') if (value = attributes[:'excluded_sub_domains']).is_a?(Array) self.excluded_sub_domains = value end end if attributes.key?(:'excluded_url_patterns') if (value = attributes[:'excluded_url_patterns']).is_a?(Array) self.excluded_url_patterns = value end end if attributes.key?(:'single_urls') if (value = attributes[:'single_urls']).is_a?(Array) self.single_urls = value end end end |
Instance Attribute Details
#excluded_sub_domains ⇒ Object
Returns the value of attribute excluded_sub_domains.
25 26 27 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 25 def excluded_sub_domains @excluded_sub_domains end |
#excluded_url_patterns ⇒ Object
Returns the value of attribute excluded_url_patterns.
27 28 29 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 27 def excluded_url_patterns @excluded_url_patterns end |
#included_sub_domains ⇒ Object
Returns the value of attribute included_sub_domains.
20 21 22 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 20 def included_sub_domains @included_sub_domains end |
#included_url_patterns ⇒ Object
Only URLs containing one of these substrings are ingested.
23 24 25 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 23 def included_url_patterns @included_url_patterns end |
#single_urls ⇒ Object
Crawl only these exact pages instead of the whole site.
30 31 32 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 30 def single_urls @single_urls end |
#url ⇒ Object
Returns the value of attribute url.
18 19 20 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 18 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 33 def self.attribute_map { :'url' => :'url', :'included_sub_domains' => :'included_sub_domains', :'included_url_patterns' => :'included_url_patterns', :'excluded_sub_domains' => :'excluded_sub_domains', :'excluded_url_patterns' => :'excluded_url_patterns', :'single_urls' => :'single_urls' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 183 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 55 def self.openapi_types { :'url' => :'String', :'included_sub_domains' => :'Array<String>', :'included_url_patterns' => :'Array<String>', :'excluded_sub_domains' => :'Array<String>', :'excluded_url_patterns' => :'Array<String>', :'single_urls' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
157 158 159 160 161 162 163 164 165 166 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 157 def ==(o) return true if self.equal?(o) self.class == o.class && url == o.url && included_sub_domains == o.included_sub_domains && included_url_patterns == o.included_url_patterns && excluded_sub_domains == o.excluded_sub_domains && excluded_url_patterns == o.excluded_url_patterns && single_urls == o.single_urls end |
#eql?(o) ⇒ Boolean
170 171 172 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 170 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
176 177 178 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 176 def hash [url, included_sub_domains, included_url_patterns, excluded_sub_domains, excluded_url_patterns, single_urls].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
127 128 129 130 131 132 133 134 135 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 127 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 205 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
139 140 141 142 143 |
# File 'lib/zernio-sdk/models/business_agent_website_input.rb', line 139 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @url.nil? true end |