Class: Zernio::CheckPhoneNumberAvailability200Response

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/check_phone_number_availability200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CheckPhoneNumberAvailability200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CheckPhoneNumberAvailability200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CheckPhoneNumberAvailability200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'number_type')
    self.number_type = attributes[:'number_type']
  end

  if attributes.key?(:'available')
    self.available = attributes[:'available']
  end

  if attributes.key?(:'address_constraint')
    self.address_constraint = attributes[:'address_constraint']
  end

  if attributes.key?(:'areas')
    if (value = attributes[:'areas']).is_a?(Array)
      self.areas = value
    end
  end
end

Instance Attribute Details

#address_constraintObject

Returns the value of attribute address_constraint.



25
26
27
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 25

def address_constraint
  @address_constraint
end

#areasObject

For geo only — the area(s) the registered address must be in.



28
29
30
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 28

def areas
  @areas
end

#availableObject

Whether deliverable voice inventory exists right now.



23
24
25
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 23

def available
  @available
end

#countryObject

Returns the value of attribute country.



18
19
20
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 18

def country
  @country
end

#number_typeObject

Returns the value of attribute number_type.



20
21
22
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 20

def number_type
  @number_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 53

def self.attribute_map
  {
    :'country' => :'country',
    :'number_type' => :'numberType',
    :'available' => :'available',
    :'address_constraint' => :'addressConstraint',
    :'areas' => :'areas'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 74

def self.openapi_types
  {
    :'country' => :'String',
    :'number_type' => :'String',
    :'available' => :'Boolean',
    :'address_constraint' => :'String',
    :'areas' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



158
159
160
161
162
163
164
165
166
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 158

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      country == o.country &&
      number_type == o.number_type &&
      available == o.available &&
      address_constraint == o.address_constraint &&
      areas == o.areas
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 176

def hash
  [country, number_type, available, address_constraint, areas].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
# File 'lib/zernio-sdk/models/check_phone_number_availability200_response.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  address_constraint_validator = EnumAttributeValidator.new('String', ["geo", "country", "none"])
  return false unless address_constraint_validator.valid?(@address_constraint)
  true
end