Class: Zernio::CreateCommentAutomation200ResponseAutomation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateCommentAutomation200ResponseAutomation
- Defined in:
- lib/zernio-sdk/models/create_comment_automation200_response_automation.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#buttons ⇒ Object
Inline DM buttons (up to 3).
-
#click_tag ⇒ Object
Returns the value of attribute click_tag.
-
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
-
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#dm_message ⇒ Object
Returns the value of attribute dm_message.
-
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#link_tracking ⇒ Object
Returns the value of attribute link_tracking.
-
#match_mode ⇒ Object
Returns the value of attribute match_mode.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
-
#stats ⇒ Object
Returns the value of attribute stats.
-
#trigger ⇒ Object
Returns the value of attribute trigger.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCommentAutomation200ResponseAutomation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCommentAutomation200ResponseAutomation
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateCommentAutomation200ResponseAutomation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateCommentAutomation200ResponseAutomation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'match_mode') self.match_mode = attributes[:'match_mode'] end if attributes.key?(:'dm_message') self. = attributes[:'dm_message'] end if attributes.key?(:'buttons') if (value = attributes[:'buttons']).is_a?(Array) self. = value end end if attributes.key?(:'comment_reply') self.comment_reply = attributes[:'comment_reply'] end if attributes.key?(:'dm_message_variations') if (value = attributes[:'dm_message_variations']).is_a?(Array) self. = value end end if attributes.key?(:'comment_reply_variations') if (value = attributes[:'comment_reply_variations']).is_a?(Array) self.comment_reply_variations = value end end if attributes.key?(:'link_tracking') self.link_tracking = attributes[:'link_tracking'] end if attributes.key?(:'click_tag') self.click_tag = attributes[:'click_tag'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'stats') self.stats = attributes[:'stats'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#buttons ⇒ Object
Inline DM buttons (up to 3). Omitted when none are set.
35 36 37 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 35 def @buttons end |
#click_tag ⇒ Object
Returns the value of attribute click_tag.
47 48 49 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 47 def click_tag @click_tag end |
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
37 38 39 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 37 def comment_reply @comment_reply end |
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply. Omitted when none.
43 44 45 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 43 def comment_reply_variations @comment_reply_variations end |
#created_at ⇒ Object
Returns the value of attribute created_at.
53 54 55 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 53 def created_at @created_at end |
#dm_message ⇒ Object
Returns the value of attribute dm_message.
32 33 34 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 32 def @dm_message end |
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage. Omitted when none.
40 41 42 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 40 def @dm_message_variations end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
49 50 51 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 49 def is_active @is_active end |
#keywords ⇒ Object
Returns the value of attribute keywords.
28 29 30 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 28 def keywords @keywords end |
#link_tracking ⇒ Object
Returns the value of attribute link_tracking.
45 46 47 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 45 def link_tracking @link_tracking end |
#match_mode ⇒ Object
Returns the value of attribute match_mode.
30 31 32 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 30 def match_mode @match_mode end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 20 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
22 23 24 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 22 def platform @platform end |
#platform_post_id ⇒ Object
Returns the value of attribute platform_post_id.
26 27 28 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 26 def platform_post_id @platform_post_id end |
#stats ⇒ Object
Returns the value of attribute stats.
51 52 53 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 51 def stats @stats end |
#trigger ⇒ Object
Returns the value of attribute trigger.
24 25 26 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 24 def trigger @trigger end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
101 102 103 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 101 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
106 107 108 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 106 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 78 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'platform' => :'platform', :'trigger' => :'trigger', :'platform_post_id' => :'platformPostId', :'keywords' => :'keywords', :'match_mode' => :'matchMode', :'dm_message' => :'dmMessage', :'buttons' => :'buttons', :'comment_reply' => :'commentReply', :'dm_message_variations' => :'dmMessageVariations', :'comment_reply_variations' => :'commentReplyVariations', :'link_tracking' => :'linkTracking', :'click_tag' => :'clickTag', :'is_active' => :'isActive', :'stats' => :'stats', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 310 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
134 135 136 137 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 134 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 111 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'platform' => :'String', :'trigger' => :'String', :'platform_post_id' => :'String', :'keywords' => :'Array<String>', :'match_mode' => :'String', :'dm_message' => :'String', :'buttons' => :'Array<DmButton>', :'comment_reply' => :'String', :'dm_message_variations' => :'Array<String>', :'comment_reply_variations' => :'Array<String>', :'link_tracking' => :'Boolean', :'click_tag' => :'String', :'is_active' => :'Boolean', :'stats' => :'CreateCommentAutomation200ResponseAutomationStats', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 273 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && platform == o.platform && trigger == o.trigger && platform_post_id == o.platform_post_id && keywords == o.keywords && match_mode == o.match_mode && == o. && == o. && comment_reply == o.comment_reply && == o. && comment_reply_variations == o.comment_reply_variations && link_tracking == o.link_tracking && click_tag == o.click_tag && is_active == o.is_active && stats == o.stats && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
297 298 299 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 297 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
303 304 305 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 303 def hash [id, name, platform, trigger, platform_post_id, keywords, match_mode, , , comment_reply, , comment_reply_variations, link_tracking, click_tag, is_active, stats, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
234 235 236 237 238 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 234 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 332 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
242 243 244 245 246 247 248 249 |
# File 'lib/zernio-sdk/models/create_comment_automation200_response_automation.rb', line 242 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' trigger_validator = EnumAttributeValidator.new('String', ["comment", "story_reply"]) return false unless trigger_validator.valid?(@trigger) match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains"]) return false unless match_mode_validator.valid?(@match_mode) true end |