Class: Zernio::CreateRfPredictionRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_rf_prediction_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateRfPredictionRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateRfPredictionRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateRfPredictionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'budget_amount')
    self.budget_amount = attributes[:'budget_amount']
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  else
    self.start_date = nil
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  else
    self.end_date = nil
  end

  if attributes.key?(:'frequency_cap')
    self.frequency_cap = attributes[:'frequency_cap']
  end

  if attributes.key?(:'targeting')
    self.targeting = attributes[:'targeting']
  end

  if attributes.key?(:'placements')
    self.placements = attributes[:'placements']
  end
end

Instance Attribute Details

#account_idObject

Zernio SocialAccount id (posting or ads variant).



19
20
21
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 19

def 
  @account_id
end

#ad_account_idObject

Meta ad account id (act_).



22
23
24
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 22

def 
  @ad_account_id
end

#budget_amountObject

Whole currency units. Exactly one of budgetAmount / reach.



25
26
27
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 25

def budget_amount
  @budget_amount
end

#end_dateObject

Returns the value of attribute end_date.



33
34
35
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 33

def end_date
  @end_date
end

#frequency_capObject

Max impressions per person over the window.



36
37
38
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 36

def frequency_cap
  @frequency_cap
end

#placementsObject

Meta placements object (same shape as /v1/ads/create's placements).



42
43
44
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 42

def placements
  @placements
end

#reachObject

Target unique reach. Exactly one of budgetAmount / reach.



28
29
30
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 28

def reach
  @reach
end

#start_dateObject

Campaign window start (must be in the future).



31
32
33
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 31

def start_date
  @start_date
end

#targetingObject

Canonical camelCase TargetingSpec (same shape as /v1/ads/create's targeting). Defaults to countries: [US].



39
40
41
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 39

def targeting
  @targeting
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 45

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'ad_account_id' => :'adAccountId',
    :'budget_amount' => :'budgetAmount',
    :'reach' => :'reach',
    :'start_date' => :'startDate',
    :'end_date' => :'endDate',
    :'frequency_cap' => :'frequencyCap',
    :'targeting' => :'targeting',
    :'placements' => :'placements'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 285

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 70

def self.openapi_types
  {
    :'account_id' => :'String',
    :'ad_account_id' => :'String',
    :'budget_amount' => :'Float',
    :'reach' => :'Integer',
    :'start_date' => :'Time',
    :'end_date' => :'Time',
    :'frequency_cap' => :'Integer',
    :'targeting' => :'Object',
    :'placements' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 256

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      budget_amount == o.budget_amount &&
      reach == o.reach &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      frequency_cap == o.frequency_cap &&
      targeting == o.targeting &&
      placements == o.placements
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


272
273
274
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 272

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



278
279
280
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 278

def hash
  [, , budget_amount, reach, start_date, end_date, frequency_cap, targeting, placements].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  if @start_date.nil?
    invalid_properties.push('invalid value for "start_date", start_date cannot be nil.')
  end

  if @end_date.nil?
    invalid_properties.push('invalid value for "end_date", end_date cannot be nil.')
  end

  if !@frequency_cap.nil? && @frequency_cap > 90
    invalid_properties.push('invalid value for "frequency_cap", must be smaller than or equal to 90.')
  end

  if !@frequency_cap.nil? && @frequency_cap < 1
    invalid_properties.push('invalid value for "frequency_cap", must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 307

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/create_rf_prediction_request.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @ad_account_id.nil?
  return false if @start_date.nil?
  return false if @end_date.nil?
  return false if !@frequency_cap.nil? && @frequency_cap > 90
  return false if !@frequency_cap.nil? && @frequency_cap < 1
  true
end