Class: Zernio::CreateStandaloneAdRequestDynamicCreative
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::CreateStandaloneAdRequestDynamicCreative
- Defined in:
- lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb
Overview
Meta only. Dynamic Creative: supply a POOL of assets and Meta auto-combines and optimises them into the best-performing variations within a single ad (mapped to the creative's asset_feed_spec). When set, the top-level single-creative fields (imageUrl, headline, body, linkUrl, callToAction) are ignored. Mutually exclusive with the creatives[] multi-creative shape. Meta limits: ≤10 images, ≤5 bodies / titles / descriptions.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_format ⇒ Object
Asset-feed ad format.
-
#bodies ⇒ Object
Primary-text variations (the body copy).
-
#call_to_action_types ⇒ Object
CTA-button variations.
-
#descriptions ⇒ Object
Description (link caption) variations.
-
#image_urls ⇒ Object
Pool of image URLs (1-10).
-
#link_urls ⇒ Object
Destination URL variations.
-
#titles ⇒ Object
Headline variations.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestDynamicCreative
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateStandaloneAdRequestDynamicCreative
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateStandaloneAdRequestDynamicCreative` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateStandaloneAdRequestDynamicCreative`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'image_urls') if (value = attributes[:'image_urls']).is_a?(Array) self.image_urls = value end else self.image_urls = nil end if attributes.key?(:'bodies') if (value = attributes[:'bodies']).is_a?(Array) self.bodies = value end end if attributes.key?(:'titles') if (value = attributes[:'titles']).is_a?(Array) self.titles = value end end if attributes.key?(:'descriptions') if (value = attributes[:'descriptions']).is_a?(Array) self.descriptions = value end end if attributes.key?(:'link_urls') if (value = attributes[:'link_urls']).is_a?(Array) self.link_urls = value end end if attributes.key?(:'call_to_action_types') if (value = attributes[:'call_to_action_types']).is_a?(Array) self.call_to_action_types = value end end if attributes.key?(:'ad_format') self.ad_format = attributes[:'ad_format'] else self.ad_format = 'SINGLE_IMAGE' end end |
Instance Attribute Details
#ad_format ⇒ Object
Asset-feed ad format. Defaults to SINGLE_IMAGE.
38 39 40 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 38 def ad_format @ad_format end |
#bodies ⇒ Object
Primary-text variations (the body copy).
23 24 25 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 23 def bodies @bodies end |
#call_to_action_types ⇒ Object
CTA-button variations. Required.
35 36 37 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 35 def call_to_action_types @call_to_action_types end |
#descriptions ⇒ Object
Description (link caption) variations.
29 30 31 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 29 def descriptions @descriptions end |
#image_urls ⇒ Object
Pool of image URLs (1-10). Uploaded to the ad account and referenced by hash in the asset feed.
20 21 22 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 20 def image_urls @image_urls end |
#link_urls ⇒ Object
Destination URL variations. At least one is required unless goal is lead_generation.
32 33 34 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 32 def link_urls @link_urls end |
#titles ⇒ Object
Headline variations.
26 27 28 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 26 def titles @titles end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 63 def self.attribute_map { :'image_urls' => :'imageUrls', :'bodies' => :'bodies', :'titles' => :'titles', :'descriptions' => :'descriptions', :'link_urls' => :'linkUrls', :'call_to_action_types' => :'callToActionTypes', :'ad_format' => :'adFormat' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 311 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 86 def self.openapi_types { :'image_urls' => :'Array<String>', :'bodies' => :'Array<String>', :'titles' => :'Array<String>', :'descriptions' => :'Array<String>', :'link_urls' => :'Array<String>', :'call_to_action_types' => :'Array<String>', :'ad_format' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 284 def ==(o) return true if self.equal?(o) self.class == o.class && image_urls == o.image_urls && bodies == o.bodies && titles == o.titles && descriptions == o.descriptions && link_urls == o.link_urls && call_to_action_types == o.call_to_action_types && ad_format == o.ad_format end |
#eql?(o) ⇒ Boolean
298 299 300 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 298 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 304 def hash [image_urls, bodies, titles, descriptions, link_urls, call_to_action_types, ad_format].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @image_urls.nil? invalid_properties.push('invalid value for "image_urls", image_urls cannot be nil.') end if @image_urls.length > 10 invalid_properties.push('invalid value for "image_urls", number of items must be less than or equal to 10.') end if @image_urls.length < 1 invalid_properties.push('invalid value for "image_urls", number of items must be greater than or equal to 1.') end if !@bodies.nil? && @bodies.length > 5 invalid_properties.push('invalid value for "bodies", number of items must be less than or equal to 5.') end if !@titles.nil? && @titles.length > 5 invalid_properties.push('invalid value for "titles", number of items must be less than or equal to 5.') end if !@descriptions.nil? && @descriptions.length > 5 invalid_properties.push('invalid value for "descriptions", number of items must be less than or equal to 5.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/zernio-sdk/models/create_standalone_ad_request_dynamic_creative.rb', line 199 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @image_urls.nil? return false if @image_urls.length > 10 return false if @image_urls.length < 1 return false if !@bodies.nil? && @bodies.length > 5 return false if !@titles.nil? && @titles.length > 5 return false if !@descriptions.nil? && @descriptions.length > 5 ad_format_validator = EnumAttributeValidator.new('String', ["SINGLE_IMAGE", "CAROUSEL_IMAGE"]) return false unless ad_format_validator.valid?(@ad_format) true end |