Class: Zernio::CreateTrackingTagRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/create_tracking_tag_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateTrackingTagRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CreateTrackingTagRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CreateTrackingTagRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_account_id')
    self. = attributes[:'ad_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'default_event_type')
    self.default_event_type = attributes[:'default_event_type']
  end
end

Instance Attribute Details

#ad_account_idObject

Meta ad account id, e.g. act_123456789. Required by this endpoint but ignored for OpenAI Ads.



19
20
21
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 19

def 
  @ad_account_id
end

#default_event_typeObject

OpenAI Ads only (ignored by Meta). When set, also provisions a standard conversion event setting wired to the new pixel, so goal: conversions ad creates on POST /v1/ads/create have an event to reference immediately.



24
25
26
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 24

def default_event_type
  @default_event_type
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 21

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 49

def self.attribute_map
  {
    :'ad_account_id' => :'adAccountId',
    :'name' => :'name',
    :'default_event_type' => :'defaultEventType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 215

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 68

def self.openapi_types
  {
    :'ad_account_id' => :'String',
    :'name' => :'String',
    :'default_event_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



192
193
194
195
196
197
198
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 192

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      name == o.name &&
      default_event_type == o.default_event_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


202
203
204
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 202

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



208
209
210
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 208

def hash
  [, name, default_event_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ad_account_id.nil?
    invalid_properties.push('invalid value for "ad_account_id", ad_account_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 200
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 200.')
  end

  if @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 237

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/create_tracking_tag_request.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ad_account_id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 200
  return false if @name.to_s.length < 1
  default_event_type_validator = EnumAttributeValidator.new('String', ["order_created", "lead_created", "items_added", "contents_viewed", "checkout_started", "registration_completed", "subscription_created", "trial_started", "appointment_scheduled", "page_viewed", "app_installed", "app_opened"])
  return false unless default_event_type_validator.valid?(@default_event_type)
  true
end