Class: Zernio::CustomConversion

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/custom_conversion.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomConversion

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::CustomConversion` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::CustomConversion`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'rule')
    self.rule = attributes[:'rule']
  end

  if attributes.key?(:'custom_event_type')
    self.custom_event_type = attributes[:'custom_event_type']
  end

  if attributes.key?(:'pixel_id')
    self.pixel_id = attributes[:'pixel_id']
  end

  if attributes.key?(:'is_archived')
    self.is_archived = attributes[:'is_archived']
  end
end

Instance Attribute Details

#custom_event_typeObject

Returns the value of attribute custom_event_type.



25
26
27
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 25

def custom_event_type
  @custom_event_type
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 18

def id
  @id
end

#is_archivedObject

Returns the value of attribute is_archived.



30
31
32
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 30

def is_archived
  @is_archived
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 20

def name
  @name
end

#pixel_idObject

Meta's event_source_id — the pixel the rule reads from.



28
29
30
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 28

def pixel_id
  @pixel_id
end

#ruleObject

Meta's rule, parsed back from the string Meta stores.



23
24
25
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 23

def rule
  @rule
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 33

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'rule' => :'rule',
    :'custom_event_type' => :'customEventType',
    :'pixel_id' => :'pixelId',
    :'is_archived' => :'isArchived'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
72
73
74
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 67

def self.openapi_nullable
  Set.new([
    :'name',
    :'rule',
    :'custom_event_type',
    :'pixel_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 55

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'rule' => :'Object',
    :'custom_event_type' => :'String',
    :'pixel_id' => :'String',
    :'is_archived' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



134
135
136
137
138
139
140
141
142
143
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 134

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      rule == o.rule &&
      custom_event_type == o.custom_event_type &&
      pixel_id == o.pixel_id &&
      is_archived == o.is_archived
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 153

def hash
  [id, name, rule, custom_event_type, pixel_id, is_archived].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
# File 'lib/zernio-sdk/models/custom_conversion.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end