Class: Zernio::DiscordPlatformDataThreadFromMessage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::DiscordPlatformDataThreadFromMessage
- Defined in:
- lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb
Overview
Create a follow-up thread under the published message.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auto_archive_duration ⇒ Object
Auto-archive after inactivity (minutes).
-
#name ⇒ Object
Thread name (1-100 chars).
-
#rate_limit_per_user ⇒ Object
Slow-mode duration in seconds (0-21600).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DiscordPlatformDataThreadFromMessage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DiscordPlatformDataThreadFromMessage
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::DiscordPlatformDataThreadFromMessage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::DiscordPlatformDataThreadFromMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'auto_archive_duration') self.auto_archive_duration = attributes[:'auto_archive_duration'] end if attributes.key?(:'rate_limit_per_user') self.rate_limit_per_user = attributes[:'rate_limit_per_user'] end end |
Instance Attribute Details
#auto_archive_duration ⇒ Object
Auto-archive after inactivity (minutes)
23 24 25 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 23 def auto_archive_duration @auto_archive_duration end |
#name ⇒ Object
Thread name (1-100 chars)
20 21 22 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 20 def name @name end |
#rate_limit_per_user ⇒ Object
Slow-mode duration in seconds (0-21600)
26 27 28 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 26 def rate_limit_per_user @rate_limit_per_user end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 51 def self.attribute_map { :'name' => :'name', :'auto_archive_duration' => :'autoArchiveDuration', :'rate_limit_per_user' => :'rateLimitPerUser' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 193 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 70 def self.openapi_types { :'name' => :'String', :'auto_archive_duration' => :'Integer', :'rate_limit_per_user' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && auto_archive_duration == o.auto_archive_duration && rate_limit_per_user == o.rate_limit_per_user end |
#eql?(o) ⇒ Boolean
180 181 182 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 180 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
186 187 188 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 186 def hash [name, auto_archive_duration, rate_limit_per_user].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@rate_limit_per_user.nil? && @rate_limit_per_user > 21600 invalid_properties.push('invalid value for "rate_limit_per_user", must be smaller than or equal to 21600.') end if !@rate_limit_per_user.nil? && @rate_limit_per_user < 0 invalid_properties.push('invalid value for "rate_limit_per_user", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 215 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 135 136 137 138 |
# File 'lib/zernio-sdk/models/discord_platform_data_thread_from_message.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' auto_archive_duration_validator = EnumAttributeValidator.new('Integer', [60, 1440, 4320, 10080]) return false unless auto_archive_duration_validator.valid?(@auto_archive_duration) return false if !@rate_limit_per_user.nil? && @rate_limit_per_user > 21600 return false if !@rate_limit_per_user.nil? && @rate_limit_per_user < 0 true end |