Class: Zernio::EnableWhatsAppCallingLegacyRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EnableWhatsAppCallingLegacyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::EnableWhatsAppCallingLegacyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::EnableWhatsAppCallingLegacyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'forward_to')
    self.forward_to = attributes[:'forward_to']
  else
    self.forward_to = nil
  end

  if attributes.key?(:'sip_auth_username')
    self.sip_auth_username = attributes[:'sip_auth_username']
  end

  if attributes.key?(:'sip_auth_password')
    self.sip_auth_password = attributes[:'sip_auth_password']
  end

  if attributes.key?(:'recording_enabled')
    self.recording_enabled = attributes[:'recording_enabled']
  else
    self.recording_enabled = false
  end

  if attributes.key?(:'call_icon_countries')
    if (value = attributes[:'call_icon_countries']).is_a?(Array)
      self.call_icon_countries = value
    end
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 18

def 
  @account_id
end

#call_icon_countriesObject

Returns the value of attribute call_icon_countries.



30
31
32
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 30

def call_icon_countries
  @call_icon_countries
end

#forward_toObject

tel:+E164 / sip:... / wss://... destination



21
22
23
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 21

def forward_to
  @forward_to
end

#recording_enabledObject

Returns the value of attribute recording_enabled.



28
29
30
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 28

def recording_enabled
  @recording_enabled
end

#sip_auth_passwordObject

Stored encrypted, never returned by any endpoint.



26
27
28
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 26

def sip_auth_password
  @sip_auth_password
end

#sip_auth_usernameObject

Returns the value of attribute sip_auth_username.



23
24
25
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 23

def sip_auth_username
  @sip_auth_username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 33

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'forward_to' => :'forwardTo',
    :'sip_auth_username' => :'sipAuthUsername',
    :'sip_auth_password' => :'sipAuthPassword',
    :'recording_enabled' => :'recordingEnabled',
    :'call_icon_countries' => :'callIconCountries'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 194

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 55

def self.openapi_types
  {
    :'account_id' => :'String',
    :'forward_to' => :'String',
    :'sip_auth_username' => :'String',
    :'sip_auth_password' => :'String',
    :'recording_enabled' => :'Boolean',
    :'call_icon_countries' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
175
176
177
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      forward_to == o.forward_to &&
      sip_auth_username == o.sip_auth_username &&
      sip_auth_password == o.sip_auth_password &&
      recording_enabled == o.recording_enabled &&
      call_icon_countries == o.call_icon_countries
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


181
182
183
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 181

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



187
188
189
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 187

def hash
  [, forward_to, sip_auth_username, sip_auth_password, recording_enabled, call_icon_countries].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 123

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @forward_to.nil?
    invalid_properties.push('invalid value for "forward_to", forward_to cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
# File 'lib/zernio-sdk/models/enable_whats_app_calling_legacy_request.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @forward_to.nil?
  true
end