Class: Zernio::ExternalPostSummary

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/external_post_summary.rb

Overview

A post synced from a platform (published directly on the platform, not through Zernio). Returned by GET /v1/posts?source=external and POST /v1/posts/sync-external. Analytics are exposed separately via GET /v1/analytics?source=external.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExternalPostSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ExternalPostSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ExternalPostSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_post_id')
    self.platform_post_id = attributes[:'platform_post_id']
  end

  if attributes.key?(:'platform_post_url')
    self.platform_post_url = attributes[:'platform_post_url']
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'published_at')
    self.published_at = attributes[:'published_at']
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  end

  if attributes.key?(:'media_url')
    self.media_url = attributes[:'media_url']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'media_items')
    if (value = attributes[:'media_items']).is_a?(Array)
      self.media_items = value
    end
  end

  if attributes.key?(:'analytics')
    self.analytics = attributes[:'analytics']
  end
end

Instance Attribute Details

#analyticsObject

Returns the value of attribute analytics.



46
47
48
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 46

def analytics
  @analytics
end

#contentObject

Post caption / text



29
30
31
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 29

def content
  @content
end

#media_itemsObject

Per-item media (for carousels / multi-media posts)



44
45
46
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 44

def media_items
  @media_items
end

#media_typeObject

Media type (e.g. image, video, carousel)



35
36
37
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 35

def media_type
  @media_type
end

#media_urlObject

Primary media URL



38
39
40
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 38

def media_url
  @media_url
end

#platformObject

Platform the post belongs to (e.g. instagram, youtube, tiktok)



20
21
22
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 20

def platform
  @platform
end

#platform_post_idObject

The platform's own post/media/video id



23
24
25
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 23

def platform_post_id
  @platform_post_id
end

#platform_post_urlObject

Canonical URL (permalink) of the post on the platform



26
27
28
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 26

def platform_post_url
  @platform_post_url
end

#published_atObject

When the post was published on the platform



32
33
34
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 32

def published_at
  @published_at
end

#thumbnail_urlObject

Thumbnail URL



41
42
43
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 41

def thumbnail_url
  @thumbnail_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 49

def self.attribute_map
  {
    :'platform' => :'platform',
    :'platform_post_id' => :'platformPostId',
    :'platform_post_url' => :'platformPostUrl',
    :'content' => :'content',
    :'published_at' => :'publishedAt',
    :'media_type' => :'mediaType',
    :'media_url' => :'mediaUrl',
    :'thumbnail_url' => :'thumbnailUrl',
    :'media_items' => :'mediaItems',
    :'analytics' => :'analytics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 202

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 75

def self.openapi_types
  {
    :'platform' => :'String',
    :'platform_post_id' => :'String',
    :'platform_post_url' => :'String',
    :'content' => :'String',
    :'published_at' => :'Time',
    :'media_type' => :'String',
    :'media_url' => :'String',
    :'thumbnail_url' => :'String',
    :'media_items' => :'Array<Object>',
    :'analytics' => :'ExternalPostSummaryAnalytics'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      platform == o.platform &&
      platform_post_id == o.platform_post_id &&
      platform_post_url == o.platform_post_url &&
      content == o.content &&
      published_at == o.published_at &&
      media_type == o.media_type &&
      media_url == o.media_url &&
      thumbnail_url == o.thumbnail_url &&
      media_items == o.media_items &&
      analytics == o.analytics
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


189
190
191
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 189

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



195
196
197
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 195

def hash
  [platform, platform_post_id, platform_post_url, content, published_at, media_type, media_url, thumbnail_url, media_items, analytics].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 224

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
# File 'lib/zernio-sdk/models/external_post_summary.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end