Class: Zernio::FoodMenuItemAttributes
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::FoodMenuItemAttributes
- Defined in:
- lib/zernio-sdk/models/food_menu_item_attributes.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#allergen ⇒ Object
Allergens (e.g. DAIRY, GLUTEN, SHELLFISH).
-
#dietary_restriction ⇒ Object
Dietary labels (e.g. VEGETARIAN, VEGAN, GLUTEN_FREE).
-
#media_keys ⇒ Object
Media references for item photos.
-
#preparation_methods ⇒ Object
Preparation methods (e.g. GRILLED, FRIED).
-
#price ⇒ Object
Returns the value of attribute price.
-
#serves_num_people ⇒ Object
Number of people the item serves.
-
#spiciness ⇒ Object
Spiciness level (e.g. MILD, MEDIUM, HOT).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FoodMenuItemAttributes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FoodMenuItemAttributes
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::FoodMenuItemAttributes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::FoodMenuItemAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'price') self.price = attributes[:'price'] end if attributes.key?(:'spiciness') self.spiciness = attributes[:'spiciness'] end if attributes.key?(:'allergen') if (value = attributes[:'allergen']).is_a?(Array) self.allergen = value end end if attributes.key?(:'dietary_restriction') if (value = attributes[:'dietary_restriction']).is_a?(Array) self.dietary_restriction = value end end if attributes.key?(:'serves_num_people') self.serves_num_people = attributes[:'serves_num_people'] end if attributes.key?(:'preparation_methods') if (value = attributes[:'preparation_methods']).is_a?(Array) self.preparation_methods = value end end if attributes.key?(:'media_keys') if (value = attributes[:'media_keys']).is_a?(Array) self.media_keys = value end end end |
Instance Attribute Details
#allergen ⇒ Object
Allergens (e.g. DAIRY, GLUTEN, SHELLFISH)
24 25 26 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 24 def allergen @allergen end |
#dietary_restriction ⇒ Object
Dietary labels (e.g. VEGETARIAN, VEGAN, GLUTEN_FREE)
27 28 29 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 27 def dietary_restriction @dietary_restriction end |
#media_keys ⇒ Object
Media references for item photos
36 37 38 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 36 def media_keys @media_keys end |
#preparation_methods ⇒ Object
Preparation methods (e.g. GRILLED, FRIED)
33 34 35 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 33 def preparation_methods @preparation_methods end |
#price ⇒ Object
Returns the value of attribute price.
18 19 20 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 18 def price @price end |
#serves_num_people ⇒ Object
Number of people the item serves
30 31 32 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 30 def serves_num_people @serves_num_people end |
#spiciness ⇒ Object
Spiciness level (e.g. MILD, MEDIUM, HOT)
21 22 23 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 21 def spiciness @spiciness end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 61 def self.attribute_map { :'price' => :'price', :'spiciness' => :'spiciness', :'allergen' => :'allergen', :'dietary_restriction' => :'dietaryRestriction', :'serves_num_people' => :'servesNumPeople', :'preparation_methods' => :'preparationMethods', :'media_keys' => :'mediaKeys' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 230 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 84 def self.openapi_types { :'price' => :'Money', :'spiciness' => :'String', :'allergen' => :'Array<String>', :'dietary_restriction' => :'Array<String>', :'serves_num_people' => :'Integer', :'preparation_methods' => :'Array<String>', :'media_keys' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && price == o.price && spiciness == o.spiciness && allergen == o.allergen && dietary_restriction == o.dietary_restriction && serves_num_people == o.serves_num_people && preparation_methods == o.preparation_methods && media_keys == o.media_keys end |
#eql?(o) ⇒ Boolean
217 218 219 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 217 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
223 224 225 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 223 def hash [price, spiciness, allergen, dietary_restriction, serves_num_people, preparation_methods, media_keys].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
157 158 159 160 161 162 163 164 165 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 157 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@serves_num_people.nil? && @serves_num_people < 1 invalid_properties.push('invalid value for "serves_num_people", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 252 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 173 174 175 |
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' spiciness_validator = EnumAttributeValidator.new('String', ["SPICINESS_UNSPECIFIED", "MILD", "MEDIUM", "HOT"]) return false unless spiciness_validator.valid?(@spiciness) return false if !@serves_num_people.nil? && @serves_num_people < 1 true end |