Class: Zernio::FoodMenuItemAttributes

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/food_menu_item_attributes.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FoodMenuItemAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::FoodMenuItemAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::FoodMenuItemAttributes`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  end

  if attributes.key?(:'spiciness')
    self.spiciness = attributes[:'spiciness']
  end

  if attributes.key?(:'allergen')
    if (value = attributes[:'allergen']).is_a?(Array)
      self.allergen = value
    end
  end

  if attributes.key?(:'dietary_restriction')
    if (value = attributes[:'dietary_restriction']).is_a?(Array)
      self.dietary_restriction = value
    end
  end

  if attributes.key?(:'serves_num_people')
    self.serves_num_people = attributes[:'serves_num_people']
  end

  if attributes.key?(:'preparation_methods')
    if (value = attributes[:'preparation_methods']).is_a?(Array)
      self.preparation_methods = value
    end
  end

  if attributes.key?(:'media_keys')
    if (value = attributes[:'media_keys']).is_a?(Array)
      self.media_keys = value
    end
  end
end

Instance Attribute Details

#allergenObject

Allergens (e.g. DAIRY, GLUTEN, SHELLFISH)



24
25
26
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 24

def allergen
  @allergen
end

#dietary_restrictionObject

Dietary labels (e.g. VEGETARIAN, VEGAN, GLUTEN_FREE)



27
28
29
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 27

def dietary_restriction
  @dietary_restriction
end

#media_keysObject

Media references for item photos



36
37
38
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 36

def media_keys
  @media_keys
end

#preparation_methodsObject

Preparation methods (e.g. GRILLED, FRIED)



33
34
35
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 33

def preparation_methods
  @preparation_methods
end

#priceObject

Returns the value of attribute price.



18
19
20
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 18

def price
  @price
end

#serves_num_peopleObject

Number of people the item serves



30
31
32
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 30

def serves_num_people
  @serves_num_people
end

#spicinessObject

Spiciness level (e.g. MILD, MEDIUM, HOT)



21
22
23
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 21

def spiciness
  @spiciness
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 39

def self.attribute_map
  {
    :'price' => :'price',
    :'spiciness' => :'spiciness',
    :'allergen' => :'allergen',
    :'dietary_restriction' => :'dietaryRestriction',
    :'serves_num_people' => :'servesNumPeople',
    :'preparation_methods' => :'preparationMethods',
    :'media_keys' => :'mediaKeys'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 177

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 62

def self.openapi_types
  {
    :'price' => :'Money',
    :'spiciness' => :'String',
    :'allergen' => :'Array<String>',
    :'dietary_restriction' => :'Array<String>',
    :'serves_num_people' => :'Integer',
    :'preparation_methods' => :'Array<String>',
    :'media_keys' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



150
151
152
153
154
155
156
157
158
159
160
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 150

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      price == o.price &&
      spiciness == o.spiciness &&
      allergen == o.allergen &&
      dietary_restriction == o.dietary_restriction &&
      serves_num_people == o.serves_num_people &&
      preparation_methods == o.preparation_methods &&
      media_keys == o.media_keys
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


164
165
166
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 164

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



170
171
172
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 170

def hash
  [price, spiciness, allergen, dietary_restriction, serves_num_people, preparation_methods, media_keys].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



135
136
137
138
139
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 135

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 199

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



143
144
145
146
# File 'lib/zernio-sdk/models/food_menu_item_attributes.rb', line 143

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end