Class: Zernio::GMBServicesApi
- Inherits:
-
Object
- Object
- Zernio::GMBServicesApi
- Defined in:
- lib/zernio-sdk/api/gmb_services_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_google_business_services(account_id, opts = {}) ⇒ GetGoogleBusinessServices200Response
Get services Gets the services offered by a Google Business Profile location.
-
#get_google_business_services_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessServices200Response, Integer, Hash)>
Get services Gets the services offered by a Google Business Profile location.
-
#initialize(api_client = ApiClient.default) ⇒ GMBServicesApi
constructor
A new instance of GMBServicesApi.
-
#update_google_business_services(account_id, update_google_business_services_request, opts = {}) ⇒ UpdateGoogleBusinessServices200Response
Replace services Replaces the entire service list for a location.
-
#update_google_business_services_with_http_info(account_id, update_google_business_services_request, opts = {}) ⇒ Array<(UpdateGoogleBusinessServices200Response, Integer, Hash)>
Replace services Replaces the entire service list for a location.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ GMBServicesApi
Returns a new instance of GMBServicesApi.
19 20 21 |
# File 'lib/zernio-sdk/api/gmb_services_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/gmb_services_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_google_business_services(account_id, opts = {}) ⇒ GetGoogleBusinessServices200Response
Get services Gets the services offered by a Google Business Profile location. Returns an array of service items (structured or free-form with optional price).
28 29 30 31 |
# File 'lib/zernio-sdk/api/gmb_services_api.rb', line 28 def get_google_business_services(account_id, opts = {}) data, _status_code, _headers = get_google_business_services_with_http_info(account_id, opts) data end |
#get_google_business_services_with_http_info(account_id, opts = {}) ⇒ Array<(GetGoogleBusinessServices200Response, Integer, Hash)>
Get services Gets the services offered by a Google Business Profile location. Returns an array of service items (structured or free-form with optional price).
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/zernio-sdk/api/gmb_services_api.rb', line 39 def get_google_business_services_with_http_info(account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBServicesApi.get_google_business_services ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBServicesApi.get_google_business_services" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-services'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetGoogleBusinessServices200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBServicesApi.get_google_business_services", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBServicesApi#get_google_business_services\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_google_business_services(account_id, update_google_business_services_request, opts = {}) ⇒ UpdateGoogleBusinessServices200Response
Replace services Replaces the entire service list for a location. Google's API requires full replacement; individual item updates are not supported. Each service can be structured (using a predefined serviceTypeId) or free-form (custom label).
95 96 97 98 |
# File 'lib/zernio-sdk/api/gmb_services_api.rb', line 95 def update_google_business_services(account_id, update_google_business_services_request, opts = {}) data, _status_code, _headers = update_google_business_services_with_http_info(account_id, update_google_business_services_request, opts) data end |
#update_google_business_services_with_http_info(account_id, update_google_business_services_request, opts = {}) ⇒ Array<(UpdateGoogleBusinessServices200Response, Integer, Hash)>
Replace services Replaces the entire service list for a location. Google's API requires full replacement; individual item updates are not supported. Each service can be structured (using a predefined serviceTypeId) or free-form (custom label).
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/api/gmb_services_api.rb', line 107 def update_google_business_services_with_http_info(account_id, update_google_business_services_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GMBServicesApi.update_google_business_services ...' end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling GMBServicesApi.update_google_business_services" end # verify the required parameter 'update_google_business_services_request' is set if @api_client.config.client_side_validation && update_google_business_services_request.nil? fail ArgumentError, "Missing the required parameter 'update_google_business_services_request' when calling GMBServicesApi.update_google_business_services" end # resource path local_var_path = '/v1/accounts/{accountId}/gmb-services'.sub('{' + 'accountId' + '}', CGI.escape(account_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'locationId'] = opts[:'location_id'] if !opts[:'location_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(update_google_business_services_request) # return_type return_type = opts[:debug_return_type] || 'UpdateGoogleBusinessServices200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"GMBServicesApi.update_google_business_services", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GMBServicesApi#update_google_business_services\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |