Class: Zernio::GenerateKeywordHistoricalMetricsRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GenerateKeywordHistoricalMetricsRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 107

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GenerateKeywordHistoricalMetricsRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GenerateKeywordHistoricalMetricsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Array)
      self.keywords = value
    end
  else
    self.keywords = nil
  end

  if attributes.key?(:'countries')
    if (value = attributes[:'countries']).is_a?(Array)
      self.countries = value
    end
  end

  if attributes.key?(:'language_constant_id')
    self.language_constant_id = attributes[:'language_constant_id']
  else
    self.language_constant_id = '1000'
  end

  if attributes.key?(:'network')
    self.network = attributes[:'network']
  else
    self.network = 'GOOGLE_SEARCH'
  end

  if attributes.key?(:'include_adult_keywords')
    self.include_adult_keywords = attributes[:'include_adult_keywords']
  end

  if attributes.key?(:'include_average_cpc')
    self.include_average_cpc = attributes[:'include_average_cpc']
  end
end

Instance Attribute Details

#account_idObject

Zernio googleads SocialAccount id.



19
20
21
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 19

def 
  @account_id
end

#countriesObject

ISO 3166-1 alpha-2 country codes. Omitted = worldwide.



27
28
29
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 27

def countries
  @countries
end

#customer_idObject

Numeric Google Ads customer id (no dashes); only needed when the connection has several accounts.



22
23
24
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 22

def customer_id
  @customer_id
end

#include_adult_keywordsObject

Returns the value of attribute include_adult_keywords.



34
35
36
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 34

def include_adult_keywords
  @include_adult_keywords
end

#include_average_cpcObject

Adds averageCpcMicros to each row's keywordMetrics.



37
38
39
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 37

def include_average_cpc
  @include_average_cpc
end

#keywordsObject

Returns the value of attribute keywords.



24
25
26
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 24

def keywords
  @keywords
end

#language_constant_idObject

Google languageConstant id (1000 = English).



30
31
32
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 30

def language_constant_id
  @language_constant_id
end

#networkObject

Returns the value of attribute network.



32
33
34
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 32

def network
  @network
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 62

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'customer_id' => :'customerId',
    :'keywords' => :'keywords',
    :'countries' => :'countries',
    :'language_constant_id' => :'languageConstantId',
    :'network' => :'network',
    :'include_adult_keywords' => :'includeAdultKeywords',
    :'include_average_cpc' => :'includeAverageCpc'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 299

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 100

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 86

def self.openapi_types
  {
    :'account_id' => :'String',
    :'customer_id' => :'String',
    :'keywords' => :'Array<String>',
    :'countries' => :'Array<String>',
    :'language_constant_id' => :'String',
    :'network' => :'String',
    :'include_adult_keywords' => :'Boolean',
    :'include_average_cpc' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 271

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      customer_id == o.customer_id &&
      keywords == o.keywords &&
      countries == o.countries &&
      language_constant_id == o.language_constant_id &&
      network == o.network &&
      include_adult_keywords == o.include_adult_keywords &&
      include_average_cpc == o.include_average_cpc
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 286

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



292
293
294
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 292

def hash
  [, customer_id, keywords, countries, language_constant_id, network, include_adult_keywords, include_average_cpc].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @keywords.nil?
    invalid_properties.push('invalid value for "keywords", keywords cannot be nil.')
  end

  if @keywords.length > 1000
    invalid_properties.push('invalid value for "keywords", number of items must be less than or equal to 1000.')
  end

  if @keywords.length < 1
    invalid_properties.push('invalid value for "keywords", number of items must be greater than or equal to 1.')
  end

  if !@countries.nil? && @countries.length > 10
    invalid_properties.push('invalid value for "countries", number of items must be less than or equal to 10.')
  end

  if !@countries.nil? && @countries.length < 1
    invalid_properties.push('invalid value for "countries", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/zernio-sdk/models/generate_keyword_historical_metrics_request.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @keywords.nil?
  return false if @keywords.length > 1000
  return false if @keywords.length < 1
  return false if !@countries.nil? && @countries.length > 10
  return false if !@countries.nil? && @countries.length < 1
  network_validator = EnumAttributeValidator.new('String', ["GOOGLE_SEARCH", "GOOGLE_SEARCH_AND_PARTNERS"])
  return false unless network_validator.valid?(@network)
  true
end