Class: Zernio::GetAccountHealth200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/get_account_health200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetAccountHealth200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {}) —

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetAccountHealth200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetAccountHealth200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'display_name')
    self.display_name = attributes[:'display_name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'token_status')
    self.token_status = attributes[:'token_status']
  end

  if attributes.key?(:'permissions')
    self.permissions = attributes[:'permissions']
  end

  if attributes.key?(:'issues')
    if (value = attributes[:'issues']).is_a?(Array)
      self.issues = value
    end
  end

  if attributes.key?(:'recommendations')
    if (value = attributes[:'recommendations']).is_a?(Array)
      self.recommendations = value
    end
  end

  if attributes.key?(:'messaging_restriction')
    self.messaging_restriction = attributes[:'messaging_restriction']
  end

  if attributes.key?(:'platform_connection')
    self.platform_connection = attributes[:'platform_connection']
  end
end

Instance Attribute Details

#account_id ⇒ Object

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 18

def 
  @account_id
end

#display_name ⇒ Object

Returns the value of attribute display_name.



24
25
26
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 24

def display_name
  @display_name
end

#issues ⇒ Object

List of issues found



34
35
36
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 34

def issues
  @issues
end

#messaging_restriction ⇒ Object

Returns the value of attribute messaging_restriction.



39
40
41
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 39

def messaging_restriction
  @messaging_restriction
end

#permissions ⇒ Object

Returns the value of attribute permissions.



31
32
33
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 31

def permissions
  @permissions
end

#platform ⇒ Object

Returns the value of attribute platform.



20
21
22
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 20

def platform
  @platform
end

#platform_connection ⇒ Object

Returns the value of attribute platform_connection.



41
42
43
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 41

def platform_connection
  @platform_connection
end

#recommendations ⇒ Object

Actionable recommendations to fix issues



37
38
39
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 37

def recommendations
  @recommendations
end

#status ⇒ Object

Overall health status



27
28
29
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 27

def status
  @status
end

#token_status ⇒ Object

Returns the value of attribute token_status.



29
30
31
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 29

def token_status
  @token_status
end

#username ⇒ Object

Returns the value of attribute username.



22
23
24
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 22

def username
  @username
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



83
84
85
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 66

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'platform' => :'platform',
    :'username' => :'username',
    :'display_name' => :'displayName',
    :'status' => :'status',
    :'token_status' => :'tokenStatus',
    :'permissions' => :'permissions',
    :'issues' => :'issues',
    :'recommendations' => :'recommendations',
    :'messaging_restriction' => :'messagingRestriction',
    :'platform_connection' => :'platformConnection'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash) —

    Model attributes in the form of hash

Returns:

  • (Object) —

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



110
111
112
113
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 110

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 93

def self.openapi_types
  {
    :'account_id' => :'String',
    :'platform' => :'String',
    :'username' => :'String',
    :'display_name' => :'String',
    :'status' => :'String',
    :'token_status' => :'GetAccountHealth200ResponseTokenStatus',
    :'permissions' => :'GetAccountHealth200ResponsePermissions',
    :'issues' => :'Array<String>',
    :'recommendations' => :'Array<String>',
    :'messaging_restriction' => :'GetAllAccountsHealth200ResponseAccountsInnerMessagingRestriction',
    :'platform_connection' => :'GetAccountHealth200ResponsePlatformConnection'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object) —

    to be compared



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      platform == o.platform &&
      username == o.username &&
      display_name == o.display_name &&
      status == o.status &&
      token_status == o.token_status &&
      permissions == o.permissions &&
      issues == o.issues &&
      recommendations == o.recommendations &&
      messaging_restriction == o.messaging_restriction &&
      platform_connection == o.platform_connection
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object) —

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 227

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.

Returns:

  • (Integer) —

    Hash code



233
234
235
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 233

def hash
  [, platform, username, display_name, status, token_status, permissions, issues, recommendations, messaging_restriction, platform_connection].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



182
183
184
185
186
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 182

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash

Returns:

  • (Hash) —

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean) —

    true if the model is valid



190
191
192
193
194
195
# File 'lib/zernio-sdk/models/get_account_health200_response.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["healthy", "warning", "error"])
  return false unless status_validator.valid?(@status)
  true
end