Class: Zernio::GetCommentAutomation200ResponseLogsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetCommentAutomation200ResponseLogsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetCommentAutomation200ResponseLogsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetCommentAutomation200ResponseLogsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'comment_id')
    self.comment_id = attributes[:'comment_id']
  end

  if attributes.key?(:'commenter_id')
    self.commenter_id = attributes[:'commenter_id']
  end

  if attributes.key?(:'commenter_name')
    self.commenter_name = attributes[:'commenter_name']
  end

  if attributes.key?(:'comment_text')
    self.comment_text = attributes[:'comment_text']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'audience_outcome')
    self.audience_outcome = attributes[:'audience_outcome']
  end

  if attributes.key?(:'commenter_is_follower')
    self.commenter_is_follower = attributes[:'commenter_is_follower']
  end

  if attributes.key?(:'commenter_follower_count')
    self.commenter_follower_count = attributes[:'commenter_follower_count']
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'comment_reply_status')
    self.comment_reply_status = attributes[:'comment_reply_status']
  end

  if attributes.key?(:'comment_reply_error')
    self.comment_reply_error = attributes[:'comment_reply_error']
  end

  if attributes.key?(:'next_due_at')
    self.next_due_at = attributes[:'next_due_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#audience_outcomeObject

How the audience rule resolved. Absent on automations without one.



32
33
34
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 32

def audience_outcome
  @audience_outcome
end

#comment_idObject

Returns the value of attribute comment_id.



20
21
22
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 20

def comment_id
  @comment_id
end

#comment_reply_errorObject

Public-reply error message if commentReplyStatus is failed



46
47
48
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 46

def comment_reply_error
  @comment_reply_error
end

#comment_reply_statusObject

Outcome of the optional public reply on the triggering comment. 'skipped' if no commentReply was configured or if the DM failed (the public reply is not attempted in that case).



43
44
45
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 43

def comment_reply_status
  @comment_reply_status
end

#comment_textObject

Returns the value of attribute comment_text.



26
27
28
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 26

def comment_text
  @comment_text
end

#commenter_follower_countObject

Returns the value of attribute commenter_follower_count.



37
38
39
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 37

def commenter_follower_count
  @commenter_follower_count
end

#commenter_idObject

Returns the value of attribute commenter_id.



22
23
24
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 22

def commenter_id
  @commenter_id
end

#commenter_is_followerObject

Follow relationship at decision time. Absent when Instagram would not tell us (the commenter never messaged the account).



35
36
37
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 35

def commenter_is_follower
  @commenter_is_follower
end

#commenter_nameObject

Returns the value of attribute commenter_name.



24
25
26
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 24

def commenter_name
  @commenter_name
end

#created_atObject

Returns the value of attribute created_at.



51
52
53
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 51

def created_at
  @created_at
end

#errorObject

DM error message if status is failed



40
41
42
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 40

def error
  @error
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 18

def id
  @id
end

#next_due_atObject

When the next queued send fires. Present only while something is still pending.



49
50
51
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 49

def next_due_at
  @next_due_at
end

#statusObject

DM outcome. 'pending' = the automation has a dmDelaySeconds and the response is queued but not sent yet. 'gated' = the follow-gate confirmation DM went out and we are waiting for the tap; it flips to 'sent' or 'skipped' when they tap.



29
30
31
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 29

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



96
97
98
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 96

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



101
102
103
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 101

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 76

def self.attribute_map
  {
    :'id' => :'id',
    :'comment_id' => :'commentId',
    :'commenter_id' => :'commenterId',
    :'commenter_name' => :'commenterName',
    :'comment_text' => :'commentText',
    :'status' => :'status',
    :'audience_outcome' => :'audienceOutcome',
    :'commenter_is_follower' => :'commenterIsFollower',
    :'commenter_follower_count' => :'commenterFollowerCount',
    :'error' => :'error',
    :'comment_reply_status' => :'commentReplyStatus',
    :'comment_reply_error' => :'commentReplyError',
    :'next_due_at' => :'nextDueAt',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 291

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 126

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 106

def self.openapi_types
  {
    :'id' => :'String',
    :'comment_id' => :'String',
    :'commenter_id' => :'String',
    :'commenter_name' => :'String',
    :'comment_text' => :'String',
    :'status' => :'String',
    :'audience_outcome' => :'String',
    :'commenter_is_follower' => :'Boolean',
    :'commenter_follower_count' => :'Integer',
    :'error' => :'String',
    :'comment_reply_status' => :'String',
    :'comment_reply_error' => :'String',
    :'next_due_at' => :'Time',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 257

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      comment_id == o.comment_id &&
      commenter_id == o.commenter_id &&
      commenter_name == o.commenter_name &&
      comment_text == o.comment_text &&
      status == o.status &&
      audience_outcome == o.audience_outcome &&
      commenter_is_follower == o.commenter_is_follower &&
      commenter_follower_count == o.commenter_follower_count &&
      error == o.error &&
      comment_reply_status == o.comment_reply_status &&
      comment_reply_error == o.comment_reply_error &&
      next_due_at == o.next_due_at &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


278
279
280
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 278

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



284
285
286
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 284

def hash
  [id, comment_id, commenter_id, commenter_name, comment_text, status, audience_outcome, commenter_is_follower, commenter_follower_count, error, comment_reply_status, comment_reply_error, next_due_at, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



206
207
208
209
210
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 206

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 313

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 214

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["pending", "sent", "failed", "skipped", "gated"])
  return false unless status_validator.valid?(@status)
  audience_outcome_validator = EnumAttributeValidator.new('String', ["passed", "blocked", "gate_sent", "gate_passed", "gate_failed"])
  return false unless audience_outcome_validator.valid?(@audience_outcome)
  comment_reply_status_validator = EnumAttributeValidator.new('String', ["sent", "failed", "skipped"])
  return false unless comment_reply_status_validator.valid?(@comment_reply_status)
  true
end