Class: Zernio::GetCommentAutomation200ResponseLogsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetCommentAutomation200ResponseLogsInner
- Defined in:
- lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#comment_id ⇒ Object
Returns the value of attribute comment_id.
-
#comment_reply_error ⇒ Object
Public-reply error message if commentReplyStatus is failed.
-
#comment_reply_status ⇒ Object
Outcome of the optional public reply on the triggering comment.
-
#comment_text ⇒ Object
Returns the value of attribute comment_text.
-
#commenter_id ⇒ Object
Returns the value of attribute commenter_id.
-
#commenter_name ⇒ Object
Returns the value of attribute commenter_name.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error ⇒ Object
DM error message if status is failed.
-
#id ⇒ Object
Returns the value of attribute id.
-
#status ⇒ Object
DM outcome.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetCommentAutomation200ResponseLogsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetCommentAutomation200ResponseLogsInner
Initializes the object
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 114 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetCommentAutomation200ResponseLogsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetCommentAutomation200ResponseLogsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'comment_id') self.comment_id = attributes[:'comment_id'] end if attributes.key?(:'commenter_id') self.commenter_id = attributes[:'commenter_id'] end if attributes.key?(:'commenter_name') self.commenter_name = attributes[:'commenter_name'] end if attributes.key?(:'comment_text') self.comment_text = attributes[:'comment_text'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'comment_reply_status') self.comment_reply_status = attributes[:'comment_reply_status'] end if attributes.key?(:'comment_reply_error') self.comment_reply_error = attributes[:'comment_reply_error'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#comment_id ⇒ Object
Returns the value of attribute comment_id.
20 21 22 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 20 def comment_id @comment_id end |
#comment_reply_error ⇒ Object
Public-reply error message if commentReplyStatus is failed
38 39 40 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 38 def comment_reply_error @comment_reply_error end |
#comment_reply_status ⇒ Object
Outcome of the optional public reply on the triggering comment. 'skipped' if no commentReply was configured or if the DM failed (the public reply is not attempted in that case).
35 36 37 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 35 def comment_reply_status @comment_reply_status end |
#comment_text ⇒ Object
Returns the value of attribute comment_text.
26 27 28 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 26 def comment_text @comment_text end |
#commenter_id ⇒ Object
Returns the value of attribute commenter_id.
22 23 24 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 22 def commenter_id @commenter_id end |
#commenter_name ⇒ Object
Returns the value of attribute commenter_name.
24 25 26 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 24 def commenter_name @commenter_name end |
#created_at ⇒ Object
Returns the value of attribute created_at.
40 41 42 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 40 def created_at @created_at end |
#error ⇒ Object
DM error message if status is failed
32 33 34 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 32 def error @error end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 18 def id @id end |
#status ⇒ Object
DM outcome
29 30 31 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 29 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 65 def self.attribute_map { :'id' => :'id', :'comment_id' => :'commentId', :'commenter_id' => :'commenterId', :'commenter_name' => :'commenterName', :'comment_text' => :'commentText', :'status' => :'status', :'error' => :'error', :'comment_reply_status' => :'commentReplyStatus', :'comment_reply_error' => :'commentReplyError', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 240 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 107 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 91 def self.openapi_types { :'id' => :'String', :'comment_id' => :'String', :'commenter_id' => :'String', :'commenter_name' => :'String', :'comment_text' => :'String', :'status' => :'String', :'error' => :'String', :'comment_reply_status' => :'String', :'comment_reply_error' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && comment_id == o.comment_id && commenter_id == o.commenter_id && commenter_name == o.commenter_name && comment_text == o.comment_text && status == o.status && error == o.error && comment_reply_status == o.comment_reply_status && comment_reply_error == o.comment_reply_error && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 233 def hash [id, comment_id, commenter_id, commenter_name, comment_text, status, error, comment_reply_status, comment_reply_error, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 |
# File 'lib/zernio-sdk/models/get_comment_automation200_response_logs_inner.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["sent", "failed", "skipped"]) return false unless status_validator.valid?(@status) comment_reply_status_validator = EnumAttributeValidator.new('String', ["sent", "failed", "skipped"]) return false unless comment_reply_status_validator.valid?(@comment_reply_status) true end |