Class: Zernio::GetInboxConversation200ResponseData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetInboxConversation200ResponseData
- Defined in:
- lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_username ⇒ Object
Returns the value of attribute account_username.
-
#id ⇒ Object
Returns the value of attribute id.
-
#instagram_profile ⇒ Object
Returns the value of attribute instagram_profile.
-
#last_message ⇒ Object
Returns the value of attribute last_message.
-
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
-
#participant_id ⇒ Object
Returns the value of attribute participant_id.
-
#participant_name ⇒ Object
Returns the value of attribute participant_name.
-
#participant_verified_type ⇒ Object
X/Twitter verified badge type.
-
#participants ⇒ Object
Returns the value of attribute participants.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_time ⇒ Object
Returns the value of attribute updated_time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetInboxConversation200ResponseData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetInboxConversation200ResponseData
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 124 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInboxConversation200ResponseData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInboxConversation200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_username') self.account_username = attributes[:'account_username'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'participant_name') self.participant_name = attributes[:'participant_name'] end if attributes.key?(:'participant_id') self.participant_id = attributes[:'participant_id'] end if attributes.key?(:'participant_verified_type') self.participant_verified_type = attributes[:'participant_verified_type'] end if attributes.key?(:'last_message') self. = attributes[:'last_message'] end if attributes.key?(:'last_message_at') self. = attributes[:'last_message_at'] end if attributes.key?(:'updated_time') self.updated_time = attributes[:'updated_time'] end if attributes.key?(:'participants') if (value = attributes[:'participants']).is_a?(Array) self.participants = value end end if attributes.key?(:'instagram_profile') self.instagram_profile = attributes[:'instagram_profile'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
20 21 22 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 20 def account_id @account_id end |
#account_username ⇒ Object
Returns the value of attribute account_username.
22 23 24 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 22 def account_username @account_username end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 18 def id @id end |
#instagram_profile ⇒ Object
Returns the value of attribute instagram_profile.
43 44 45 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 43 def instagram_profile @instagram_profile end |
#last_message ⇒ Object
Returns the value of attribute last_message.
35 36 37 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 35 def @last_message end |
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
37 38 39 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 37 def @last_message_at end |
#participant_id ⇒ Object
Returns the value of attribute participant_id.
30 31 32 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 30 def participant_id @participant_id end |
#participant_name ⇒ Object
Returns the value of attribute participant_name.
28 29 30 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 28 def participant_name @participant_name end |
#participant_verified_type ⇒ Object
X/Twitter verified badge type. Only present for Twitter/X conversations.
33 34 35 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 33 def participant_verified_type @participant_verified_type end |
#participants ⇒ Object
Returns the value of attribute participants.
41 42 43 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 41 def participants @participants end |
#platform ⇒ Object
Returns the value of attribute platform.
24 25 26 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 24 def platform @platform end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 26 def status @status end |
#updated_time ⇒ Object
Returns the value of attribute updated_time.
39 40 41 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 39 def updated_time @updated_time end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 68 def self.attribute_map { :'id' => :'id', :'account_id' => :'accountId', :'account_username' => :'accountUsername', :'platform' => :'platform', :'status' => :'status', :'participant_name' => :'participantName', :'participant_id' => :'participantId', :'participant_verified_type' => :'participantVerifiedType', :'last_message' => :'lastMessage', :'last_message_at' => :'lastMessageAt', :'updated_time' => :'updatedTime', :'participants' => :'participants', :'instagram_profile' => :'instagramProfile' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 116 def self.openapi_nullable Set.new([ :'participant_verified_type', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 97 def self.openapi_types { :'id' => :'String', :'account_id' => :'String', :'account_username' => :'String', :'platform' => :'String', :'status' => :'String', :'participant_name' => :'String', :'participant_id' => :'String', :'participant_verified_type' => :'String', :'last_message' => :'String', :'last_message_at' => :'Time', :'updated_time' => :'Time', :'participants' => :'Array<UpdateFacebookPage200ResponseSelectedPage>', :'instagram_profile' => :'ListInboxConversations200ResponseDataInnerInstagramProfile' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && account_id == o.account_id && account_username == o.account_username && platform == o.platform && status == o.status && participant_name == o.participant_name && participant_id == o.participant_id && participant_verified_type == o.participant_verified_type && == o. && == o. && updated_time == o.updated_time && participants == o.participants && instagram_profile == o.instagram_profile end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 260 def hash [id, account_id, account_username, platform, status, participant_name, participant_id, participant_verified_type, , , updated_time, participants, instagram_profile].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 |
# File 'lib/zernio-sdk/models/get_inbox_conversation200_response_data.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["active", "archived"]) return false unless status_validator.valid?(@status) participant_verified_type_validator = EnumAttributeValidator.new('String', ["blue", "government", "business", "none"]) return false unless participant_verified_type_validator.valid?(@participant_verified_type) true end |