Class: Zernio::GetInboxTopAccounts200ResponseAccountsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetInboxTopAccounts200ResponseAccountsInner
- Defined in:
- lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#conversations ⇒ Object
Returns the value of attribute conversations.
-
#display_name ⇒ Object
(disconnected) when the SocialAccount no longer exists.
-
#median_response_seconds ⇒ Object
Returns the value of attribute median_response_seconds.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#received ⇒ Object
Returns the value of attribute received.
-
#replied_count ⇒ Object
Distinguishes 'instant replies' from 'no replies at all' so a zero medianResponseSeconds with repliedCount=0 renders as '—' instead of '0s'.
-
#sent ⇒ Object
Returns the value of attribute sent.
-
#total ⇒ Object
Returns the value of attribute total.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetInboxTopAccounts200ResponseAccountsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetInboxTopAccounts200ResponseAccountsInner
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetInboxTopAccounts200ResponseAccountsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetInboxTopAccounts200ResponseAccountsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'username') self.username = attributes[:'username'] end if attributes.key?(:'received') self.received = attributes[:'received'] end if attributes.key?(:'sent') self.sent = attributes[:'sent'] end if attributes.key?(:'total') self.total = attributes[:'total'] end if attributes.key?(:'conversations') self.conversations = attributes[:'conversations'] end if attributes.key?(:'median_response_seconds') self.median_response_seconds = attributes[:'median_response_seconds'] end if attributes.key?(:'replied_count') self.replied_count = attributes[:'replied_count'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 18 def account_id @account_id end |
#conversations ⇒ Object
Returns the value of attribute conversations.
33 34 35 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 33 def conversations @conversations end |
#display_name ⇒ Object
(disconnected) when the SocialAccount no longer exists
23 24 25 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 23 def display_name @display_name end |
#median_response_seconds ⇒ Object
Returns the value of attribute median_response_seconds.
35 36 37 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 35 def median_response_seconds @median_response_seconds end |
#platform ⇒ Object
Returns the value of attribute platform.
20 21 22 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 20 def platform @platform end |
#received ⇒ Object
Returns the value of attribute received.
27 28 29 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 27 def received @received end |
#replied_count ⇒ Object
Distinguishes 'instant replies' from 'no replies at all' so a zero medianResponseSeconds with repliedCount=0 renders as '—' instead of '0s'
38 39 40 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 38 def replied_count @replied_count end |
#sent ⇒ Object
Returns the value of attribute sent.
29 30 31 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 29 def sent @sent end |
#total ⇒ Object
Returns the value of attribute total.
31 32 33 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 31 def total @total end |
#username ⇒ Object
Returns the value of attribute username.
25 26 27 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 25 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 41 def self.attribute_map { :'account_id' => :'accountId', :'platform' => :'platform', :'display_name' => :'displayName', :'username' => :'username', :'received' => :'received', :'sent' => :'sent', :'total' => :'total', :'conversations' => :'conversations', :'median_response_seconds' => :'medianResponseSeconds', :'replied_count' => :'repliedCount' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 192 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
83 84 85 86 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 83 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 67 def self.openapi_types { :'account_id' => :'String', :'platform' => :'String', :'display_name' => :'String', :'username' => :'String', :'received' => :'Integer', :'sent' => :'Integer', :'total' => :'Integer', :'conversations' => :'Integer', :'median_response_seconds' => :'Integer', :'replied_count' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && platform == o.platform && display_name == o.display_name && username == o.username && received == o.received && sent == o.sent && total == o.total && conversations == o.conversations && median_response_seconds == o.median_response_seconds && replied_count == o.replied_count end |
#eql?(o) ⇒ Boolean
179 180 181 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 179 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 185 def hash [account_id, platform, display_name, username, received, sent, total, conversations, median_response_seconds, replied_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 |
# File 'lib/zernio-sdk/models/get_inbox_top_accounts200_response_accounts_inner.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |