Class: Zernio::GetPostTimeline200ResponseTimelineInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetPostTimeline200ResponseTimelineInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetPostTimeline200ResponseTimelineInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetPostTimeline200ResponseTimelineInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  end

  if attributes.key?(:'platform_post_id')
    self.platform_post_id = attributes[:'platform_post_id']
  end

  if attributes.key?(:'impressions')
    self.impressions = attributes[:'impressions']
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  end

  if attributes.key?(:'likes')
    self.likes = attributes[:'likes']
  end

  if attributes.key?(:'comments')
    self.comments = attributes[:'comments']
  end

  if attributes.key?(:'shares')
    self.shares = attributes[:'shares']
  end

  if attributes.key?(:'saves')
    self.saves = attributes[:'saves']
  end

  if attributes.key?(:'clicks')
    self.clicks = attributes[:'clicks']
  end

  if attributes.key?(:'views')
    self.views = attributes[:'views']
  end

  if attributes.key?(:'follows')
    self.follows = attributes[:'follows']
  end

  if attributes.key?(:'completion_rate')
    self.completion_rate = attributes[:'completion_rate']
  end

  if attributes.key?(:'profile_views')
    self.profile_views = attributes[:'profile_views']
  end

  if attributes.key?(:'website_clicks')
    self.website_clicks = attributes[:'website_clicks']
  end

  if attributes.key?(:'impression_sources')
    if (value = attributes[:'impression_sources']).is_a?(Hash)
      self.impression_sources = value
    end
  end

  if attributes.key?(:'audience_types')
    if (value = attributes[:'audience_types']).is_a?(Hash)
      self.audience_types = value
    end
  end
end

Instance Attribute Details

#audience_typesObject

TikTok business lane: follower / nonFollower and newViewer / returnViewer shares on this date, fractions 0 to 1; empty object elsewhere



67
68
69
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 67

def audience_types
  @audience_types
end

#clicksObject

Total clicks on this date



46
47
48
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 46

def clicks
  @clicks
end

#commentsObject

Total comments on this date



37
38
39
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 37

def comments
  @comments
end

#completion_rateObject

TikTok business lane: share of viewers who watched to the end on this date, 0 to 1; 0 elsewhere



55
56
57
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 55

def completion_rate
  @completion_rate
end

#dateObject

Date in YYYY-MM-DD format



19
20
21
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 19

def date
  @date
end

#followsObject

Follows attributed to the post on this date (Instagram feed and stories, TikTok business lane); 0 elsewhere



52
53
54
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 52

def follows
  @follows
end

#impression_sourcesObject

TikTok business lane: share of views by surface on this date (forYou, follow, search, personalProfile, sound, directMessage, other), fractions 0 to 1; empty object elsewhere



64
65
66
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 64

def impression_sources
  @impression_sources
end

#impressionsObject

Total impressions on this date



28
29
30
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 28

def impressions
  @impressions
end

#likesObject

Total likes on this date



34
35
36
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 34

def likes
  @likes
end

#platformObject

Platform name (e.g. instagram, tiktok)



22
23
24
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 22

def platform
  @platform
end

#platform_post_idObject

Platform-specific post ID



25
26
27
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 25

def platform_post_id
  @platform_post_id
end

#profile_viewsObject

TikTok business lane: profile views attributed to the post on this date; 0 elsewhere



58
59
60
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 58

def profile_views
  @profile_views
end

#reachObject

Total reach on this date



31
32
33
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 31

def reach
  @reach
end

#savesObject

Total saves on this date



43
44
45
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 43

def saves
  @saves
end

#sharesObject

Total shares on this date



40
41
42
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 40

def shares
  @shares
end

#viewsObject

Total views on this date



49
50
51
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 49

def views
  @views
end

#website_clicksObject

TikTok business lane: website-link clicks attributed to the post on this date (also inside clicks); 0 elsewhere



61
62
63
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 61

def website_clicks
  @website_clicks
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



93
94
95
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 93

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 98

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 70

def self.attribute_map
  {
    :'date' => :'date',
    :'platform' => :'platform',
    :'platform_post_id' => :'platformPostId',
    :'impressions' => :'impressions',
    :'reach' => :'reach',
    :'likes' => :'likes',
    :'comments' => :'comments',
    :'shares' => :'shares',
    :'saves' => :'saves',
    :'clicks' => :'clicks',
    :'views' => :'views',
    :'follows' => :'follows',
    :'completion_rate' => :'completionRate',
    :'profile_views' => :'profileViews',
    :'website_clicks' => :'websiteClicks',
    :'impression_sources' => :'impressionSources',
    :'audience_types' => :'audienceTypes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 274

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 126

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 103

def self.openapi_types
  {
    :'date' => :'Date',
    :'platform' => :'String',
    :'platform_post_id' => :'String',
    :'impressions' => :'Integer',
    :'reach' => :'Integer',
    :'likes' => :'Integer',
    :'comments' => :'Integer',
    :'shares' => :'Integer',
    :'saves' => :'Integer',
    :'clicks' => :'Integer',
    :'views' => :'Integer',
    :'follows' => :'Integer',
    :'completion_rate' => :'Float',
    :'profile_views' => :'Integer',
    :'website_clicks' => :'Integer',
    :'impression_sources' => :'Hash<String, Float>',
    :'audience_types' => :'Hash<String, Float>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 237

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date == o.date &&
      platform == o.platform &&
      platform_post_id == o.platform_post_id &&
      impressions == o.impressions &&
      reach == o.reach &&
      likes == o.likes &&
      comments == o.comments &&
      shares == o.shares &&
      saves == o.saves &&
      clicks == o.clicks &&
      views == o.views &&
      follows == o.follows &&
      completion_rate == o.completion_rate &&
      profile_views == o.profile_views &&
      website_clicks == o.website_clicks &&
      impression_sources == o.impression_sources &&
      audience_types == o.audience_types
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


261
262
263
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 261

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



267
268
269
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 267

def hash
  [date, platform, platform_post_id, impressions, reach, likes, comments, shares, saves, clicks, views, follows, completion_rate, profile_views, website_clicks, impression_sources, audience_types].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



222
223
224
225
226
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 222

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 296

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



230
231
232
233
# File 'lib/zernio-sdk/models/get_post_timeline200_response_timeline_inner.rb', line 230

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end