Class: Zernio::GetSmsRegistration200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/get_sms_registration200_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetSmsRegistration200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetSmsRegistration200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetSmsRegistration200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'registration_type')
    self.registration_type = attributes[:'registration_type']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'brand_status')
    self.brand_status = attributes[:'brand_status']
  end

  if attributes.key?(:'campaign_status')
    self.campaign_status = attributes[:'campaign_status']
  end

  if attributes.key?(:'decline_reason')
    self.decline_reason = attributes[:'decline_reason']
  end

  if attributes.key?(:'phone_numbers')
    if (value = attributes[:'phone_numbers']).is_a?(Array)
      self.phone_numbers = value
    end
  end

  if attributes.key?(:'awaiting_otp')
    self.awaiting_otp = attributes[:'awaiting_otp']
  end

  if attributes.key?(:'campaign_content')
    self.campaign_content = attributes[:'campaign_content']
  end
end

Instance Attribute Details

#awaiting_otpObject

Returns the value of attribute awaiting_otp.



33
34
35
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 33

def awaiting_otp
  @awaiting_otp
end

#brand_statusObject

Returns the value of attribute brand_status.



25
26
27
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 25

def brand_status
  @brand_status
end

#campaign_contentObject

Returns the value of attribute campaign_content.



35
36
37
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 35

def campaign_content
  @campaign_content
end

#campaign_statusObject

Returns the value of attribute campaign_status.



27
28
29
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 27

def campaign_status
  @campaign_status
end

#decline_reasonObject

Returns the value of attribute decline_reason.



29
30
31
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 29

def decline_reason
  @decline_reason
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 18

def id
  @id
end

#phone_numbersObject

Returns the value of attribute phone_numbers.



31
32
33
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 31

def phone_numbers
  @phone_numbers
end

#registration_typeObject

Returns the value of attribute registration_type.



20
21
22
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 20

def registration_type
  @registration_type
end

#statusObject

requested/changes_requested = pre-submission review states; customers see them as pending / needs changes.



23
24
25
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 23

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 60

def self.attribute_map
  {
    :'id' => :'id',
    :'registration_type' => :'registrationType',
    :'status' => :'status',
    :'brand_status' => :'brandStatus',
    :'campaign_status' => :'campaignStatus',
    :'decline_reason' => :'declineReason',
    :'phone_numbers' => :'phoneNumbers',
    :'awaiting_otp' => :'awaitingOtp',
    :'campaign_content' => :'campaignContent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 100

def self.openapi_nullable
  Set.new([
    :'decline_reason',
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 85

def self.openapi_types
  {
    :'id' => :'String',
    :'registration_type' => :'String',
    :'status' => :'String',
    :'brand_status' => :'String',
    :'campaign_status' => :'String',
    :'decline_reason' => :'String',
    :'phone_numbers' => :'Array<String>',
    :'awaiting_otp' => :'Boolean',
    :'campaign_content' => :'GetSmsRegistration200ResponseCampaignContent'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      registration_type == o.registration_type &&
      status == o.status &&
      brand_status == o.brand_status &&
      campaign_status == o.campaign_status &&
      decline_reason == o.decline_reason &&
      phone_numbers == o.phone_numbers &&
      awaiting_otp == o.awaiting_otp &&
      campaign_content == o.campaign_content
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 224

def hash
  [id, registration_type, status, brand_status, campaign_status, decline_reason, phone_numbers, awaiting_otp, campaign_content].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
177
178
# File 'lib/zernio-sdk/models/get_sms_registration200_response.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  registration_type_validator = EnumAttributeValidator.new('String', ["standard_10dlc", "sole_prop_10dlc", "toll_free"])
  return false unless registration_type_validator.valid?(@registration_type)
  status_validator = EnumAttributeValidator.new('String', ["pending", "approved", "rejected", "requested", "changes_requested", "deactivated"])
  return false unless status_validator.valid?(@status)
  true
end