Class: Zernio::GetTikTokSmartPlusMaterialReport200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetTikTokSmartPlusMaterialReport200Response
- Defined in:
- lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad_account_id ⇒ Object
Returns the value of attribute ad_account_id.
-
#end_date ⇒ Object
Returns the value of attribute end_date.
-
#level ⇒ Object
Returns the value of attribute level.
-
#page ⇒ Object
Returns the value of attribute page.
-
#page_size ⇒ Object
Returns the value of attribute page_size.
-
#rows ⇒ Object
Returns the value of attribute rows.
-
#start_date ⇒ Object
Returns the value of attribute start_date.
-
#total_pages ⇒ Object
Returns the value of attribute total_pages.
-
#total_rows ⇒ Object
Returns the value of attribute total_rows.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetTikTokSmartPlusMaterialReport200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetTikTokSmartPlusMaterialReport200Response
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetTikTokSmartPlusMaterialReport200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetTikTokSmartPlusMaterialReport200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'level') self.level = attributes[:'level'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'end_date') self.end_date = attributes[:'end_date'] end if attributes.key?(:'page') self.page = attributes[:'page'] end if attributes.key?(:'page_size') self.page_size = attributes[:'page_size'] end if attributes.key?(:'total_rows') self.total_rows = attributes[:'total_rows'] end if attributes.key?(:'total_pages') self.total_pages = attributes[:'total_pages'] end if attributes.key?(:'rows') if (value = attributes[:'rows']).is_a?(Array) self.rows = value end end end |
Instance Attribute Details
#ad_account_id ⇒ Object
Returns the value of attribute ad_account_id.
18 19 20 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 18 def ad_account_id @ad_account_id end |
#end_date ⇒ Object
Returns the value of attribute end_date.
24 25 26 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 24 def end_date @end_date end |
#level ⇒ Object
Returns the value of attribute level.
20 21 22 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 20 def level @level end |
#page ⇒ Object
Returns the value of attribute page.
26 27 28 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 26 def page @page end |
#page_size ⇒ Object
Returns the value of attribute page_size.
28 29 30 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 28 def page_size @page_size end |
#rows ⇒ Object
Returns the value of attribute rows.
34 35 36 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 34 def rows @rows end |
#start_date ⇒ Object
Returns the value of attribute start_date.
22 23 24 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 22 def start_date @start_date end |
#total_pages ⇒ Object
Returns the value of attribute total_pages.
32 33 34 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 32 def total_pages @total_pages end |
#total_rows ⇒ Object
Returns the value of attribute total_rows.
30 31 32 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 30 def total_rows @total_rows end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 59 def self.attribute_map { :'ad_account_id' => :'adAccountId', :'level' => :'level', :'start_date' => :'startDate', :'end_date' => :'endDate', :'page' => :'page', :'page_size' => :'pageSize', :'total_rows' => :'totalRows', :'total_pages' => :'totalPages', :'rows' => :'rows' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 217 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 84 def self.openapi_types { :'ad_account_id' => :'String', :'level' => :'String', :'start_date' => :'String', :'end_date' => :'String', :'page' => :'Integer', :'page_size' => :'Integer', :'total_rows' => :'Integer', :'total_pages' => :'Integer', :'rows' => :'Array<GetTikTokSmartPlusMaterialReport200ResponseRowsInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 188 def ==(o) return true if self.equal?(o) self.class == o.class && ad_account_id == o.ad_account_id && level == o.level && start_date == o.start_date && end_date == o.end_date && page == o.page && page_size == o.page_size && total_rows == o.total_rows && total_pages == o.total_pages && rows == o.rows end |
#eql?(o) ⇒ Boolean
204 205 206 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 204 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 210 def hash [ad_account_id, level, start_date, end_date, page, page_size, total_rows, total_pages, rows].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 239 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 173 174 |
# File 'lib/zernio-sdk/models/get_tik_tok_smart_plus_material_report200_response.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' level_validator = EnumAttributeValidator.new('String', ["ad", "adGroup"]) return false unless level_validator.valid?(@level) true end |