Class: Zernio::GetWhatsAppCallingConfig200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::GetWhatsAppCallingConfig200Response
- Defined in:
- lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb
Instance Attribute Summary collapse
-
#call_deep_link ⇒ Object
Public calling deep link (https://wa.me/call/
). -
#call_icon_countries ⇒ Object
Returns the value of attribute call_icon_countries.
-
#calling_enabled ⇒ Object
Returns the value of attribute calling_enabled.
-
#forward_to ⇒ Object
tel:+E164 / sip:...
-
#phone_number ⇒ Object
Returns the value of attribute phone_number.
-
#phone_number_doc_id ⇒ Object
Phone number record ID (use on /v1/phone-numbers/id/whatsapp/calling).
-
#recording_enabled ⇒ Object
Returns the value of attribute recording_enabled.
-
#sip_auth_password_configured ⇒ Object
True when a SIP digest password is stored.
-
#sip_auth_username ⇒ Object
Returns the value of attribute sip_auth_username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetWhatsAppCallingConfig200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetWhatsAppCallingConfig200Response
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppCallingConfig200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppCallingConfig200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone_number_doc_id') self.phone_number_doc_id = attributes[:'phone_number_doc_id'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'calling_enabled') self.calling_enabled = attributes[:'calling_enabled'] end if attributes.key?(:'call_deep_link') self.call_deep_link = attributes[:'call_deep_link'] end if attributes.key?(:'forward_to') self.forward_to = attributes[:'forward_to'] end if attributes.key?(:'recording_enabled') self.recording_enabled = attributes[:'recording_enabled'] end if attributes.key?(:'sip_auth_username') self.sip_auth_username = attributes[:'sip_auth_username'] end if attributes.key?(:'sip_auth_password_configured') self.sip_auth_password_configured = attributes[:'sip_auth_password_configured'] end if attributes.key?(:'call_icon_countries') if (value = attributes[:'call_icon_countries']).is_a?(Array) self.call_icon_countries = value end end end |
Instance Attribute Details
#call_deep_link ⇒ Object
Public calling deep link (https://wa.me/call/
26 27 28 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 26 def call_deep_link @call_deep_link end |
#call_icon_countries ⇒ Object
Returns the value of attribute call_icon_countries.
38 39 40 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 38 def call_icon_countries @call_icon_countries end |
#calling_enabled ⇒ Object
Returns the value of attribute calling_enabled.
23 24 25 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 23 def calling_enabled @calling_enabled end |
#forward_to ⇒ Object
tel:+E164 / sip:... / wss://... destination
29 30 31 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 29 def forward_to @forward_to end |
#phone_number ⇒ Object
Returns the value of attribute phone_number.
21 22 23 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 21 def phone_number @phone_number end |
#phone_number_doc_id ⇒ Object
Phone number record ID (use on /v1/phone-numbers/id/whatsapp/calling)
19 20 21 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 19 def phone_number_doc_id @phone_number_doc_id end |
#recording_enabled ⇒ Object
Returns the value of attribute recording_enabled.
31 32 33 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 31 def recording_enabled @recording_enabled end |
#sip_auth_password_configured ⇒ Object
True when a SIP digest password is stored. The plaintext is never returned.
36 37 38 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 36 def sip_auth_password_configured @sip_auth_password_configured end |
#sip_auth_username ⇒ Object
Returns the value of attribute sip_auth_username.
33 34 35 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 33 def sip_auth_username @sip_auth_username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 41 def self.attribute_map { :'phone_number_doc_id' => :'phoneNumberDocId', :'phone_number' => :'phoneNumber', :'calling_enabled' => :'callingEnabled', :'call_deep_link' => :'callDeepLink', :'forward_to' => :'forwardTo', :'recording_enabled' => :'recordingEnabled', :'sip_auth_username' => :'sipAuthUsername', :'sip_auth_password_configured' => :'sipAuthPasswordConfigured', :'call_icon_countries' => :'callIconCountries' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 81 def self.openapi_nullable Set.new([ :'call_deep_link', :'forward_to', :'sip_auth_username', :'call_icon_countries' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 66 def self.openapi_types { :'phone_number_doc_id' => :'String', :'phone_number' => :'String', :'calling_enabled' => :'Boolean', :'call_deep_link' => :'String', :'forward_to' => :'String', :'recording_enabled' => :'Boolean', :'sip_auth_username' => :'String', :'sip_auth_password_configured' => :'Boolean', :'call_icon_countries' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && phone_number_doc_id == o.phone_number_doc_id && phone_number == o.phone_number && calling_enabled == o.calling_enabled && call_deep_link == o.call_deep_link && forward_to == o.forward_to && recording_enabled == o.recording_enabled && sip_auth_username == o.sip_auth_username && sip_auth_password_configured == o.sip_auth_password_configured && call_icon_countries == o.call_icon_countries end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 184 def hash [phone_number_doc_id, phone_number, calling_enabled, call_deep_link, forward_to, recording_enabled, sip_auth_username, sip_auth_password_configured, call_icon_countries].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 |
# File 'lib/zernio-sdk/models/get_whats_app_calling_config200_response.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |