Class: Zernio::GetWhatsAppTemplates200ResponseTemplatesInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetWhatsAppTemplates200ResponseTemplatesInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::GetWhatsAppTemplates200ResponseTemplatesInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::GetWhatsAppTemplates200ResponseTemplatesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'language')
    self.language = attributes[:'language']
  end

  if attributes.key?(:'components')
    if (value = attributes[:'components']).is_a?(Array)
      self.components = value
    end
  end
end

Instance Attribute Details

#categoryObject

Returns the value of attribute category.



25
26
27
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 25

def category
  @category
end

#componentsObject

Returns the value of attribute components.



29
30
31
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 29

def components
  @components
end

#idObject

WhatsApp template ID



19
20
21
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 19

def id
  @id
end

#languageObject

Returns the value of attribute language.



27
28
29
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 27

def language
  @language
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 21

def name
  @name
end

#statusObject

Returns the value of attribute status.



23
24
25
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 23

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 54

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'status' => :'status',
    :'category' => :'category',
    :'language' => :'language',
    :'components' => :'components'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 203

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 76

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'category' => :'String',
    :'language' => :'String',
    :'components' => :'Array<Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



177
178
179
180
181
182
183
184
185
186
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 177

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      status == o.status &&
      category == o.category &&
      language == o.language &&
      components == o.components
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


190
191
192
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 190

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



196
197
198
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 196

def hash
  [id, name, status, category, language, components].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



146
147
148
149
150
151
152
153
# File 'lib/zernio-sdk/models/get_whats_app_templates200_response_templates_inner.rb', line 146

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  status_validator = EnumAttributeValidator.new('String', ["APPROVED", "PENDING", "REJECTED"])
  return false unless status_validator.valid?(@status)
  category_validator = EnumAttributeValidator.new('String', ["AUTHENTICATION", "MARKETING", "UTILITY"])
  return false unless category_validator.valid?(@category)
  true
end