Class: Zernio::InlineObject4Details
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::InlineObject4Details
- Defined in:
- lib/zernio-sdk/models/inline_object4_details.rb
Overview
Structured context for SDK clients that want to render their own UX. Keys vary by reason.
Instance Attribute Summary collapse
-
#current_account_count ⇒ Object
How many accounts the team currently has connected.
-
#effective_account_limit ⇒ Object
The negotiated connected-account cap from the team's enterprise contract.
-
#free_tier_account_limit ⇒ Object
How many accounts the free tier allows.
-
#has_payment_method ⇒ Object
Whether the team currently has a card on file in Stripe.
-
#verification_amount_cents ⇒ Object
One-time card verification charge in USD cents, credited to usage.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InlineObject4Details
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InlineObject4Details
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::InlineObject4Details` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::InlineObject4Details`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'free_tier_account_limit') self.free_tier_account_limit = attributes[:'free_tier_account_limit'] end if attributes.key?(:'current_account_count') self.current_account_count = attributes[:'current_account_count'] end if attributes.key?(:'has_payment_method') self.has_payment_method = attributes[:'has_payment_method'] end if attributes.key?(:'verification_amount_cents') self.verification_amount_cents = attributes[:'verification_amount_cents'] end if attributes.key?(:'effective_account_limit') self.effective_account_limit = attributes[:'effective_account_limit'] end end |
Instance Attribute Details
#current_account_count ⇒ Object
How many accounts the team currently has connected. Set when reason=free_tier_exceeded or reason=enterprise_required.
23 24 25 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 23 def current_account_count @current_account_count end |
#effective_account_limit ⇒ Object
The negotiated connected-account cap from the team's enterprise contract. Self-service teams have no cap and never receive this reason. Only set when reason=enterprise_required.
32 33 34 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 32 def effective_account_limit @effective_account_limit end |
#free_tier_account_limit ⇒ Object
How many accounts the free tier allows. Only set when reason=free_tier_exceeded.
20 21 22 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 20 def free_tier_account_limit @free_tier_account_limit end |
#has_payment_method ⇒ Object
Whether the team currently has a card on file in Stripe. Set when reason=free_tier_exceeded or reason=twitter_passthrough.
26 27 28 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 26 def has_payment_method @has_payment_method end |
#verification_amount_cents ⇒ Object
One-time card verification charge in USD cents, credited to usage. Only set when reason=card_verification_required.
29 30 31 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 29 def verification_amount_cents @verification_amount_cents end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 35 def self.attribute_map { :'free_tier_account_limit' => :'free_tier_account_limit', :'current_account_count' => :'current_account_count', :'has_payment_method' => :'has_payment_method', :'verification_amount_cents' => :'verification_amount_cents', :'effective_account_limit' => :'effective_account_limit' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 56 def self.openapi_types { :'free_tier_account_limit' => :'Integer', :'current_account_count' => :'Integer', :'has_payment_method' => :'Boolean', :'verification_amount_cents' => :'Integer', :'effective_account_limit' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 126 def ==(o) return true if self.equal?(o) self.class == o.class && free_tier_account_limit == o.free_tier_account_limit && current_account_count == o.current_account_count && has_payment_method == o.has_payment_method && verification_amount_cents == o.verification_amount_cents && effective_account_limit == o.effective_account_limit end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 144 def hash [free_tier_account_limit, current_account_count, has_payment_method, verification_amount_cents, effective_account_limit].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
119 120 121 122 |
# File 'lib/zernio-sdk/models/inline_object4_details.rb', line 119 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |