Class: Zernio::LinkedInAdsPlatformDataConversation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::LinkedInAdsPlatformDataConversation
- Defined in:
- lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb
Overview
POST /v1/ads/create only. Conversation Ad: a choose-your-path message tree delivered to the member's LinkedIn inbox. Messages are flat nodes wired by local ids; each button either opens a url or leads to nextMessageId. Cycles, unknown ids and a missing firstMessageId return a 400. LinkedIn does not deliver message ads to EU members. Mutually exclusive with the other creative sources.
Instance Attribute Summary collapse
-
#body ⇒ Object
Optional intro body (HTML allowed).
-
#first_message_id ⇒ Object
Returns the value of attribute first_message_id.
-
#footer ⇒ Object
Terms shown at the bottom of the message.
-
#headline ⇒ Object
Conversation headline.
-
#messages ⇒ Object
Returns the value of attribute messages.
-
#sender ⇒ Object
Person or organization URN.
-
#subject ⇒ Object
InMail subject shown in the inbox.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LinkedInAdsPlatformDataConversation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LinkedInAdsPlatformDataConversation
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::LinkedInAdsPlatformDataConversation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::LinkedInAdsPlatformDataConversation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'subject') self.subject = attributes[:'subject'] else self.subject = nil end if attributes.key?(:'sender') self.sender = attributes[:'sender'] end if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'footer') self. = attributes[:'footer'] end if attributes.key?(:'headline') self.headline = attributes[:'headline'] end if attributes.key?(:'first_message_id') self. = attributes[:'first_message_id'] else self. = nil end if attributes.key?(:'messages') if (value = attributes[:'messages']).is_a?(Array) self. = value end else self. = nil end end |
Instance Attribute Details
#body ⇒ Object
Optional intro body (HTML allowed).
26 27 28 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 26 def body @body end |
#first_message_id ⇒ Object
Returns the value of attribute first_message_id.
34 35 36 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 34 def @first_message_id end |
#footer ⇒ Object
Terms shown at the bottom of the message.
29 30 31 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 29 def @footer end |
#headline ⇒ Object
Conversation headline. Defaults to the first message's first line.
32 33 34 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 32 def headline @headline end |
#messages ⇒ Object
Returns the value of attribute messages.
36 37 38 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 36 def @messages end |
#sender ⇒ Object
Person or organization URN. Defaults to the authoring Company Page. The sender must be approved for the ad account first (Campaign Manager > Manage message ad senders) or LinkedIn rejects the create with SINMAIL_SENDER_NOT_APPROVED.
23 24 25 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 23 def sender @sender end |
#subject ⇒ Object
InMail subject shown in the inbox.
20 21 22 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 20 def subject @subject end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 39 def self.attribute_map { :'subject' => :'subject', :'sender' => :'sender', :'body' => :'body', :'footer' => :'footer', :'headline' => :'headline', :'first_message_id' => :'firstMessageId', :'messages' => :'messages' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 240 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 62 def self.openapi_types { :'subject' => :'String', :'sender' => :'String', :'body' => :'String', :'footer' => :'String', :'headline' => :'String', :'first_message_id' => :'String', :'messages' => :'Array<LinkedInAdsPlatformDataConversationMessagesInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && subject == o.subject && sender == o.sender && body == o.body && == o. && headline == o.headline && == o. && == o. end |
#eql?(o) ⇒ Boolean
227 228 229 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 227 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
233 234 235 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 233 def hash [subject, sender, body, , headline, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @subject.nil? invalid_properties.push('invalid value for "subject", subject cannot be nil.') end if @first_message_id.nil? invalid_properties.push('invalid value for "first_message_id", first_message_id cannot be nil.') end if @messages.nil? invalid_properties.push('invalid value for "messages", messages cannot be nil.') end if @messages.length > 25 invalid_properties.push('invalid value for "messages", number of items must be less than or equal to 25.') end if @messages.length < 1 invalid_properties.push('invalid value for "messages", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 262 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 169 170 171 |
# File 'lib/zernio-sdk/models/linked_in_ads_platform_data_conversation.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @subject.nil? return false if @first_message_id.nil? return false if @messages.nil? return false if @messages.length > 25 return false if @messages.length < 1 true end |