Class: Zernio::LinkedInPlatformData
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::LinkedInPlatformData
- Defined in:
- lib/zernio-sdk/models/linked_in_platform_data.rb
Overview
Up to 20 images, no multi-video. Single PDF supported (max 100MB). Link previews auto-generated when no media attached. Use organizationUrn for multi-org posting. Geo-restriction only works for organization pages (not personal profiles) and requires the targeted audience to exceed 300 followers.
Instance Attribute Summary collapse
-
#disable_link_preview ⇒ Object
Set to true to disable automatic link previews for URLs in the post content (default is false).
-
#document_title ⇒ Object
Title displayed on LinkedIn document (PDF/carousel) posts.
-
#first_comment ⇒ Object
Optional first comment to add after the post is created.
-
#geo_restriction ⇒ Object
Returns the value of attribute geo_restriction.
-
#organization_urn ⇒ Object
Target LinkedIn Organization URN (e.g. "urn:li:organization:123456789").
-
#reshare_url ⇒ Object
LinkedIn post link to repost (use the post's "Copy link to post" action), or a urn:li:share / urn:li:ugcPost / urn:li:groupPost URN.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LinkedInPlatformData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LinkedInPlatformData
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::LinkedInPlatformData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::LinkedInPlatformData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'document_title') self.document_title = attributes[:'document_title'] end if attributes.key?(:'organization_urn') self.organization_urn = attributes[:'organization_urn'] end if attributes.key?(:'first_comment') self.first_comment = attributes[:'first_comment'] end if attributes.key?(:'disable_link_preview') self.disable_link_preview = attributes[:'disable_link_preview'] end if attributes.key?(:'reshare_url') self.reshare_url = attributes[:'reshare_url'] end if attributes.key?(:'geo_restriction') self.geo_restriction = attributes[:'geo_restriction'] end end |
Instance Attribute Details
#disable_link_preview ⇒ Object
Set to true to disable automatic link previews for URLs in the post content (default is false)
29 30 31 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 29 def disable_link_preview @disable_link_preview end |
#document_title ⇒ Object
Title displayed on LinkedIn document (PDF/carousel) posts. Required by LinkedIn for document posts. If omitted, falls back to the media item title, then the filename.
20 21 22 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 20 def document_title @document_title end |
#first_comment ⇒ Object
Optional first comment to add after the post is created
26 27 28 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 26 def first_comment @first_comment end |
#geo_restriction ⇒ Object
Returns the value of attribute geo_restriction.
34 35 36 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 34 def geo_restriction @geo_restriction end |
#organization_urn ⇒ Object
Target LinkedIn Organization URN (e.g. "urn:li:organization:123456789"). If omitted, uses the default org. Use GET /v1/accounts/id/linkedin-organizations to list orgs.
23 24 25 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 23 def organization_urn @organization_urn end |
#reshare_url ⇒ Object
LinkedIn post link to repost (use the post's "Copy link to post" action), or a urn:li:share / urn:li:ugcPost / urn:li:groupPost URN. The published post becomes a quote-reshare: your content is shown as the commentary and the original post is embedded underneath (LinkedIn's "repost with your thoughts"). Mutually exclusive with media. Works on personal profiles and organization pages.
32 33 34 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 32 def reshare_url @reshare_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 37 def self.attribute_map { :'document_title' => :'documentTitle', :'organization_urn' => :'organizationUrn', :'first_comment' => :'firstComment', :'disable_link_preview' => :'disableLinkPreview', :'reshare_url' => :'reshareUrl', :'geo_restriction' => :'geoRestriction' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 59 def self.openapi_types { :'document_title' => :'String', :'organization_urn' => :'String', :'first_comment' => :'String', :'disable_link_preview' => :'Boolean', :'reshare_url' => :'String', :'geo_restriction' => :'GeoRestriction' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && document_title == o.document_title && organization_urn == o.organization_urn && first_comment == o.first_comment && disable_link_preview == o.disable_link_preview && reshare_url == o.reshare_url && geo_restriction == o.geo_restriction end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 153 def hash [document_title, organization_urn, first_comment, disable_link_preview, reshare_url, geo_restriction].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 |
# File 'lib/zernio-sdk/models/linked_in_platform_data.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |