Class: Zernio::ListAdAudiences200ResponseAudiencesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListAdAudiences200ResponseAudiencesInner
- Defined in:
- lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Social account the audience was created against.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_audience_id ⇒ Object
Returns the value of attribute platform_audience_id.
-
#size ⇒ Object
Returns the value of attribute size.
-
#spec ⇒ Object
Returns the value of attribute spec.
-
#status ⇒ Object
Returns the value of attribute status.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListAdAudiences200ResponseAudiencesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListAdAudiences200ResponseAudiencesInner
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListAdAudiences200ResponseAudiencesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListAdAudiences200ResponseAudiencesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'platform_audience_id') self.platform_audience_id = attributes[:'platform_audience_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'spec') self.spec = attributes[:'spec'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'size') self.size = attributes[:'size'] end if attributes.key?(:'status') self.status = attributes[:'status'] end end |
Instance Attribute Details
#account_id ⇒ Object
Social account the audience was created against. Returned for saved_targeting items.
21 22 23 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 21 def account_id @account_id end |
#description ⇒ Object
Returns the value of attribute description.
27 28 29 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 27 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 18 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
25 26 27 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 25 def name @name end |
#platform ⇒ Object
Returns the value of attribute platform.
33 34 35 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 33 def platform @platform end |
#platform_audience_id ⇒ Object
Returns the value of attribute platform_audience_id.
23 24 25 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 23 def platform_audience_id @platform_audience_id end |
#size ⇒ Object
Returns the value of attribute size.
35 36 37 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 35 def size @size end |
#spec ⇒ Object
Returns the value of attribute spec.
31 32 33 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 31 def spec @spec end |
#status ⇒ Object
Returns the value of attribute status.
37 38 39 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 37 def status @status end |
#type ⇒ Object
Returns the value of attribute type.
29 30 31 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 29 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 62 def self.attribute_map { :'id' => :'id', :'account_id' => :'accountId', :'platform_audience_id' => :'platformAudienceId', :'name' => :'name', :'description' => :'description', :'type' => :'type', :'spec' => :'spec', :'platform' => :'platform', :'size' => :'size', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 227 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
104 105 106 107 108 109 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 104 def self.openapi_nullable Set.new([ :'id', :'spec', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 88 def self.openapi_types { :'id' => :'String', :'account_id' => :'String', :'platform_audience_id' => :'String', :'name' => :'String', :'description' => :'String', :'type' => :'String', :'spec' => :'TargetingSpec', :'platform' => :'String', :'size' => :'Integer', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && account_id == o.account_id && platform_audience_id == o.platform_audience_id && name == o.name && description == o.description && type == o.type && spec == o.spec && platform == o.platform && size == o.size && status == o.status end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 220 def hash [id, account_id, platform_audience_id, name, description, type, spec, platform, size, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 |
# File 'lib/zernio-sdk/models/list_ad_audiences200_response_audiences_inner.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' type_validator = EnumAttributeValidator.new('String', ["customer_list", "company_list", "engagement", "website", "website_retargeting", "lookalike", "saved_targeting"]) return false unless type_validator.valid?(@type) true end |