Class: Zernio::ListAdGroupAssets200Response

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/list_ad_group_assets200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListAdGroupAssets200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListAdGroupAssets200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListAdGroupAssets200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ad_group_id')
    self.ad_group_id = attributes[:'ad_group_id']
  end

  if attributes.key?(:'sitelinks')
    if (value = attributes[:'sitelinks']).is_a?(Array)
      self.sitelinks = value
    end
  end

  if attributes.key?(:'callouts')
    if (value = attributes[:'callouts']).is_a?(Array)
      self.callouts = value
    end
  end

  if attributes.key?(:'structured_snippets')
    if (value = attributes[:'structured_snippets']).is_a?(Array)
      self.structured_snippets = value
    end
  end

  if attributes.key?(:'cached_at')
    self.cached_at = attributes[:'cached_at']
  end

  if attributes.key?(:'stale')
    self.stale = attributes[:'stale']
  end
end

Instance Attribute Details

#ad_group_idObject

Returns the value of attribute ad_group_id.



18
19
20
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 18

def ad_group_id
  @ad_group_id
end

#cached_atObject

Time of the cached Google read. Null when no cache was used.



27
28
29
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 27

def cached_at
  @cached_at
end

#calloutsObject

Returns the value of attribute callouts.



22
23
24
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 22

def callouts
  @callouts
end

Returns the value of attribute sitelinks.



20
21
22
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 20

def sitelinks
  @sitelinks
end

#staleObject

True when exhausted quota required returning the last successful read.



30
31
32
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 30

def stale
  @stale
end

#structured_snippetsObject

Returns the value of attribute structured_snippets.



24
25
26
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 24

def structured_snippets
  @structured_snippets
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 33

def self.attribute_map
  {
    :'ad_group_id' => :'adGroupId',
    :'sitelinks' => :'sitelinks',
    :'callouts' => :'callouts',
    :'structured_snippets' => :'structuredSnippets',
    :'cached_at' => :'cachedAt',
    :'stale' => :'stale'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 163

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 67

def self.openapi_nullable
  Set.new([
    :'cached_at',
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 55

def self.openapi_types
  {
    :'ad_group_id' => :'String',
    :'sitelinks' => :'Array<ListAdGroupAssets200ResponseSitelinksInner>',
    :'callouts' => :'Array<ListAdGroupAssets200ResponseCalloutsInner>',
    :'structured_snippets' => :'Array<ListAdGroupAssets200ResponseStructuredSnippetsInner>',
    :'cached_at' => :'Time',
    :'stale' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
144
145
146
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ad_group_id == o.ad_group_id &&
      sitelinks == o.sitelinks &&
      callouts == o.callouts &&
      structured_snippets == o.structured_snippets &&
      cached_at == o.cached_at &&
      stale == o.stale
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


150
151
152
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 150

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



156
157
158
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 156

def hash
  [ad_group_id, sitelinks, callouts, structured_snippets, cached_at, stale].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
# File 'lib/zernio-sdk/models/list_ad_group_assets200_response.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end