Class: Zernio::ListAdSets200ResponseAdSetsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListAdSets200ResponseAdSetsInner
- Defined in:
- lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#ad_set_name ⇒ Object
Returns the value of attribute ad_set_name.
-
#budget ⇒ Object
Returns the value of attribute budget.
-
#currency ⇒ Object
Returns the value of attribute currency.
-
#is_external ⇒ Object
Returns the value of attribute is_external.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_ad_account_id ⇒ Object
Returns the value of attribute platform_ad_account_id.
-
#platform_ad_set_id ⇒ Object
Returns the value of attribute platform_ad_set_id.
-
#platform_ad_set_status ⇒ Object
Returns the value of attribute platform_ad_set_status.
-
#platform_campaign_id ⇒ Object
Returns the value of attribute platform_campaign_id.
-
#platform_created_at ⇒ Object
Returns the value of attribute platform_created_at.
-
#profile_id ⇒ Object
Returns the value of attribute profile_id.
-
#schedule ⇒ Object
Returns the value of attribute schedule.
-
#status ⇒ Object
Returns the value of attribute status.
-
#targeting ⇒ Object
Returns the value of attribute targeting.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListAdSets200ResponseAdSetsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListAdSets200ResponseAdSetsInner
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListAdSets200ResponseAdSetsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListAdSets200ResponseAdSetsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'platform_ad_set_id') self.platform_ad_set_id = attributes[:'platform_ad_set_id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'ad_set_name') self.ad_set_name = attributes[:'ad_set_name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'platform_ad_set_status') self.platform_ad_set_status = attributes[:'platform_ad_set_status'] end if attributes.key?(:'platform_campaign_id') self.platform_campaign_id = attributes[:'platform_campaign_id'] end if attributes.key?(:'platform_ad_account_id') self.platform_ad_account_id = attributes[:'platform_ad_account_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] end if attributes.key?(:'currency') self.currency = attributes[:'currency'] end if attributes.key?(:'budget') self.budget = attributes[:'budget'] end if attributes.key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.key?(:'targeting') self.targeting = attributes[:'targeting'] end if attributes.key?(:'is_external') self.is_external = attributes[:'is_external'] end if attributes.key?(:'platform_created_at') self.platform_created_at = attributes[:'platform_created_at'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
32 33 34 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 32 def account_id @account_id end |
#ad_set_name ⇒ Object
Returns the value of attribute ad_set_name.
22 23 24 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 22 def ad_set_name @ad_set_name end |
#budget ⇒ Object
Returns the value of attribute budget.
38 39 40 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 38 def budget @budget end |
#currency ⇒ Object
Returns the value of attribute currency.
36 37 38 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 36 def currency @currency end |
#is_external ⇒ Object
Returns the value of attribute is_external.
44 45 46 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 44 def is_external @is_external end |
#platform ⇒ Object
Returns the value of attribute platform.
20 21 22 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 20 def platform @platform end |
#platform_ad_account_id ⇒ Object
Returns the value of attribute platform_ad_account_id.
30 31 32 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 30 def platform_ad_account_id @platform_ad_account_id end |
#platform_ad_set_id ⇒ Object
Returns the value of attribute platform_ad_set_id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 18 def platform_ad_set_id @platform_ad_set_id end |
#platform_ad_set_status ⇒ Object
Returns the value of attribute platform_ad_set_status.
26 27 28 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 26 def platform_ad_set_status @platform_ad_set_status end |
#platform_campaign_id ⇒ Object
Returns the value of attribute platform_campaign_id.
28 29 30 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 28 def platform_campaign_id @platform_campaign_id end |
#platform_created_at ⇒ Object
Returns the value of attribute platform_created_at.
46 47 48 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 46 def platform_created_at @platform_created_at end |
#profile_id ⇒ Object
Returns the value of attribute profile_id.
34 35 36 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 34 def profile_id @profile_id end |
#schedule ⇒ Object
Returns the value of attribute schedule.
40 41 42 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 40 def schedule @schedule end |
#status ⇒ Object
Returns the value of attribute status.
24 25 26 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 24 def status @status end |
#targeting ⇒ Object
Returns the value of attribute targeting.
42 43 44 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 42 def targeting @targeting end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 49 def self.attribute_map { :'platform_ad_set_id' => :'platformAdSetId', :'platform' => :'platform', :'ad_set_name' => :'adSetName', :'status' => :'status', :'platform_ad_set_status' => :'platformAdSetStatus', :'platform_campaign_id' => :'platformCampaignId', :'platform_ad_account_id' => :'platformAdAccountId', :'account_id' => :'accountId', :'profile_id' => :'profileId', :'currency' => :'currency', :'budget' => :'budget', :'schedule' => :'schedule', :'targeting' => :'targeting', :'is_external' => :'isExternal', :'platform_created_at' => :'platformCreatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 243 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 101 def self.openapi_nullable Set.new([ :'ad_set_name', :'status', :'platform_ad_set_status', :'platform_campaign_id', :'account_id', :'currency', :'is_external', :'platform_created_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 80 def self.openapi_types { :'platform_ad_set_id' => :'String', :'platform' => :'String', :'ad_set_name' => :'String', :'status' => :'String', :'platform_ad_set_status' => :'String', :'platform_campaign_id' => :'String', :'platform_ad_account_id' => :'String', :'account_id' => :'String', :'profile_id' => :'String', :'currency' => :'String', :'budget' => :'ListAdSets200ResponseAdSetsInnerBudget', :'schedule' => :'ListAdSets200ResponseAdSetsInnerSchedule', :'targeting' => :'ListAdSets200ResponseAdSetsInnerTargeting', :'is_external' => :'Boolean', :'platform_created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 208 def ==(o) return true if self.equal?(o) self.class == o.class && platform_ad_set_id == o.platform_ad_set_id && platform == o.platform && ad_set_name == o.ad_set_name && status == o.status && platform_ad_set_status == o.platform_ad_set_status && platform_campaign_id == o.platform_campaign_id && platform_ad_account_id == o.platform_ad_account_id && account_id == o.account_id && profile_id == o.profile_id && currency == o.currency && budget == o.budget && schedule == o.schedule && targeting == o.targeting && is_external == o.is_external && platform_created_at == o.platform_created_at end |
#eql?(o) ⇒ Boolean
230 231 232 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 230 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 236 def hash [platform_ad_set_id, platform, ad_set_name, status, platform_ad_set_status, platform_campaign_id, platform_ad_account_id, account_id, profile_id, currency, budget, schedule, targeting, is_external, platform_created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 197 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 193 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
201 202 203 204 |
# File 'lib/zernio-sdk/models/list_ad_sets200_response_ad_sets_inner.rb', line 201 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |