Class: Zernio::ListInboxConversations200ResponseDataInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListInboxConversations200ResponseDataInner
- Defined in:
- lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#account_username ⇒ Object
Returns the value of attribute account_username.
-
#id ⇒ Object
Opaque conversation identifier.
-
#instagram_profile ⇒ Object
Returns the value of attribute instagram_profile.
-
#is_group ⇒ Object
iMessage only, true for a group thread.
-
#last_message ⇒ Object
Returns the value of attribute last_message.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#participant_id ⇒ Object
Returns the value of attribute participant_id.
-
#participant_name ⇒ Object
Returns the value of attribute participant_name.
-
#participant_picture ⇒ Object
Returns the value of attribute participant_picture.
-
#participant_verified_type ⇒ Object
X verified badge type.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#status ⇒ Object
Returns the value of attribute status.
-
#thread_control ⇒ Object
WhatsApp only, present once Meta Business Agent has touched the thread.
-
#unread_count ⇒ Object
Number of unread messages.
-
#updated_time ⇒ Object
Returns the value of attribute updated_time.
-
#url ⇒ Object
Direct link to open the conversation on the platform (if available).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListInboxConversations200ResponseDataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListInboxConversations200ResponseDataInner
Initializes the object
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 148 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListInboxConversations200ResponseDataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListInboxConversations200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'platform') self.platform = attributes[:'platform'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'account_username') self.account_username = attributes[:'account_username'] end if attributes.key?(:'participant_id') self.participant_id = attributes[:'participant_id'] end if attributes.key?(:'participant_name') self.participant_name = attributes[:'participant_name'] end if attributes.key?(:'participant_picture') self.participant_picture = attributes[:'participant_picture'] end if attributes.key?(:'participant_verified_type') self.participant_verified_type = attributes[:'participant_verified_type'] end if attributes.key?(:'last_message') self. = attributes[:'last_message'] end if attributes.key?(:'updated_time') self.updated_time = attributes[:'updated_time'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'unread_count') self.unread_count = attributes[:'unread_count'] end if attributes.key?(:'thread_control') self.thread_control = attributes[:'thread_control'] end if attributes.key?(:'is_group') self.is_group = attributes[:'is_group'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'instagram_profile') self.instagram_profile = attributes[:'instagram_profile'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
23 24 25 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 23 def account_id @account_id end |
#account_username ⇒ Object
Returns the value of attribute account_username.
25 26 27 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 25 def account_username @account_username end |
#id ⇒ Object
Opaque conversation identifier. Pass it back verbatim to any /v1/inbox/conversations/conversationId route; do not assume a fixed format.
19 20 21 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 19 def id @id end |
#instagram_profile ⇒ Object
Returns the value of attribute instagram_profile.
54 55 56 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 54 def instagram_profile @instagram_profile end |
#is_group ⇒ Object
iMessage only, true for a group thread. Manage it through the /v1/imessage/groups/conversationId endpoints.
49 50 51 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 49 def is_group @is_group end |
#last_message ⇒ Object
Returns the value of attribute last_message.
36 37 38 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 36 def @last_message end |
#metadata ⇒ Object
Returns the value of attribute metadata.
56 57 58 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 56 def @metadata end |
#participant_id ⇒ Object
Returns the value of attribute participant_id.
27 28 29 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 27 def participant_id @participant_id end |
#participant_name ⇒ Object
Returns the value of attribute participant_name.
29 30 31 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 29 def participant_name @participant_name end |
#participant_picture ⇒ Object
Returns the value of attribute participant_picture.
31 32 33 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 31 def participant_picture @participant_picture end |
#participant_verified_type ⇒ Object
X verified badge type. Only present for X conversations.
34 35 36 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 34 def participant_verified_type @participant_verified_type end |
#platform ⇒ Object
Returns the value of attribute platform.
21 22 23 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 21 def platform @platform end |
#status ⇒ Object
Returns the value of attribute status.
40 41 42 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 40 def status @status end |
#thread_control ⇒ Object
WhatsApp only, present once Meta Business Agent has touched the thread. ai_agent: the agent answers and new inbound arrive flagged metadata.standby; app: you hold control; other: another partner app does. Change it with POST /v1/inbox/conversations/conversationId/thread-control.
46 47 48 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 46 def thread_control @thread_control end |
#unread_count ⇒ Object
Number of unread messages
43 44 45 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 43 def unread_count @unread_count end |
#updated_time ⇒ Object
Returns the value of attribute updated_time.
38 39 40 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 38 def updated_time @updated_time end |
#url ⇒ Object
Direct link to open the conversation on the platform (if available)
52 53 54 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 52 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
104 105 106 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 104 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 109 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 81 def self.attribute_map { :'id' => :'id', :'platform' => :'platform', :'account_id' => :'accountId', :'account_username' => :'accountUsername', :'participant_id' => :'participantId', :'participant_name' => :'participantName', :'participant_picture' => :'participantPicture', :'participant_verified_type' => :'participantVerifiedType', :'last_message' => :'lastMessage', :'updated_time' => :'updatedTime', :'status' => :'status', :'unread_count' => :'unreadCount', :'thread_control' => :'threadControl', :'is_group' => :'isGroup', :'url' => :'url', :'instagram_profile' => :'instagramProfile', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 321 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
137 138 139 140 141 142 143 144 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 137 def self.openapi_nullable Set.new([ :'participant_picture', :'participant_verified_type', :'unread_count', :'url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 114 def self.openapi_types { :'id' => :'String', :'platform' => :'String', :'account_id' => :'String', :'account_username' => :'String', :'participant_id' => :'String', :'participant_name' => :'String', :'participant_picture' => :'String', :'participant_verified_type' => :'String', :'last_message' => :'String', :'updated_time' => :'Time', :'status' => :'String', :'unread_count' => :'Integer', :'thread_control' => :'String', :'is_group' => :'Boolean', :'url' => :'String', :'instagram_profile' => :'ListInboxConversations200ResponseDataInnerInstagramProfile', :'metadata' => :'ListInboxConversations200ResponseDataInnerMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 284 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && platform == o.platform && account_id == o.account_id && account_username == o.account_username && participant_id == o.participant_id && participant_name == o.participant_name && participant_picture == o.participant_picture && participant_verified_type == o.participant_verified_type && == o. && updated_time == o.updated_time && status == o.status && unread_count == o.unread_count && thread_control == o.thread_control && is_group == o.is_group && url == o.url && instagram_profile == o.instagram_profile && == o. end |
#eql?(o) ⇒ Boolean
308 309 310 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 308 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
314 315 316 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 314 def hash [id, platform, account_id, account_username, participant_id, participant_name, participant_picture, participant_verified_type, , updated_time, status, unread_count, thread_control, is_group, url, instagram_profile, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
233 234 235 236 237 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 233 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 343 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 245 246 247 248 249 250 |
# File 'lib/zernio-sdk/models/list_inbox_conversations200_response_data_inner.rb', line 241 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' participant_verified_type_validator = EnumAttributeValidator.new('String', ["blue", "government", "business", "none"]) return false unless participant_verified_type_validator.valid?(@participant_verified_type) status_validator = EnumAttributeValidator.new('String', ["active", "archived"]) return false unless status_validator.valid?(@status) thread_control_validator = EnumAttributeValidator.new('String', ["app", "ai_agent", "other"]) return false unless thread_control_validator.valid?(@thread_control) true end |