Class: Zernio::ListPhoneNumberCountries200ResponseCountriesInnerTypesInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListPhoneNumberCountries200ResponseCountriesInnerTypesInner
- Defined in:
- lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#calls_available ⇒ Object
Returns the value of attribute calls_available.
-
#in_stock ⇒ Object
Returns the value of attribute in_stock.
-
#monthly_cents ⇒ Object
Returns the value of attribute monthly_cents.
-
#needs_kyc ⇒ Object
Returns the value of attribute needs_kyc.
-
#number_type ⇒ Object
Returns the value of attribute number_type.
-
#sms_available ⇒ Object
Returns the value of attribute sms_available.
-
#tier ⇒ Object
Returns the value of attribute tier.
-
#whatsapp_available ⇒ Object
Always false for toll_free (WhatsApp does not reliably register toll-free numbers).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListPhoneNumberCountries200ResponseCountriesInnerTypesInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListPhoneNumberCountries200ResponseCountriesInnerTypesInner
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListPhoneNumberCountries200ResponseCountriesInnerTypesInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListPhoneNumberCountries200ResponseCountriesInnerTypesInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number_type') self.number_type = attributes[:'number_type'] end if attributes.key?(:'tier') self.tier = attributes[:'tier'] end if attributes.key?(:'needs_kyc') self.needs_kyc = attributes[:'needs_kyc'] end if attributes.key?(:'monthly_cents') self.monthly_cents = attributes[:'monthly_cents'] end if attributes.key?(:'whatsapp_available') self.whatsapp_available = attributes[:'whatsapp_available'] end if attributes.key?(:'sms_available') self.sms_available = attributes[:'sms_available'] end if attributes.key?(:'calls_available') self.calls_available = attributes[:'calls_available'] end if attributes.key?(:'in_stock') self.in_stock = attributes[:'in_stock'] end end |
Instance Attribute Details
#calls_available ⇒ Object
Returns the value of attribute calls_available.
31 32 33 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 31 def calls_available @calls_available end |
#in_stock ⇒ Object
Returns the value of attribute in_stock.
33 34 35 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 33 def in_stock @in_stock end |
#monthly_cents ⇒ Object
Returns the value of attribute monthly_cents.
24 25 26 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 24 def monthly_cents @monthly_cents end |
#needs_kyc ⇒ Object
Returns the value of attribute needs_kyc.
22 23 24 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 22 def needs_kyc @needs_kyc end |
#number_type ⇒ Object
Returns the value of attribute number_type.
18 19 20 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 18 def number_type @number_type end |
#sms_available ⇒ Object
Returns the value of attribute sms_available.
29 30 31 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 29 def sms_available @sms_available end |
#tier ⇒ Object
Returns the value of attribute tier.
20 21 22 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 20 def tier @tier end |
#whatsapp_available ⇒ Object
Always false for toll_free (WhatsApp does not reliably register toll-free numbers).
27 28 29 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 27 def whatsapp_available @whatsapp_available end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 58 def self.attribute_map { :'number_type' => :'numberType', :'tier' => :'tier', :'needs_kyc' => :'needsKyc', :'monthly_cents' => :'monthlyCents', :'whatsapp_available' => :'whatsappAvailable', :'sms_available' => :'smsAvailable', :'calls_available' => :'callsAvailable', :'in_stock' => :'inStock' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 219 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 96 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 82 def self.openapi_types { :'number_type' => :'String', :'tier' => :'Integer', :'needs_kyc' => :'Boolean', :'monthly_cents' => :'Integer', :'whatsapp_available' => :'Boolean', :'sms_available' => :'Boolean', :'calls_available' => :'Boolean', :'in_stock' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && number_type == o.number_type && tier == o.tier && needs_kyc == o.needs_kyc && monthly_cents == o.monthly_cents && whatsapp_available == o.whatsapp_available && sms_available == o.sms_available && calls_available == o.calls_available && in_stock == o.in_stock end |
#eql?(o) ⇒ Boolean
206 207 208 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 206 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 212 def hash [number_type, tier, needs_kyc, monthly_cents, whatsapp_available, sms_available, calls_available, in_stock].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 163 164 165 166 167 |
# File 'lib/zernio-sdk/models/list_phone_number_countries200_response_countries_inner_types_inner.rb', line 160 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' number_type_validator = EnumAttributeValidator.new('String', ["local", "mobile", "national", "toll_free"]) return false unless number_type_validator.valid?(@number_type) tier_validator = EnumAttributeValidator.new('Integer', [1, 2, 3, 4]) return false unless tier_validator.valid?(@tier) true end |