Class: Zernio::ListSmsRegistrations200ResponseRegistrationsInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::ListSmsRegistrations200ResponseRegistrationsInner
- Defined in:
- lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#admin_review_note ⇒ Object
The open change request as text (status changes_requested).
-
#awaiting_otp ⇒ Object
Sole-prop 10DLC only; the OTP step is still pending.
-
#brand_id ⇒ Object
TCR brand id, useful when referencing the brand in carrier support threads.
-
#brand_status ⇒ Object
Carrier-registry brand status (e.g. VERIFIED).
-
#campaign_id ⇒ Object
TCR campaign id.
-
#campaign_status ⇒ Object
Returns the value of attribute campaign_status.
-
#decline_reason ⇒ Object
Returns the value of attribute decline_reason.
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_rejected_at ⇒ Object
When the carriers last rejected it.
-
#last_response_at ⇒ Object
When you last answered a change request.
-
#otp_expired ⇒ Object
Sole proprietor only: the verification code was never entered within 30 days.
-
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
-
#previously_rejected ⇒ Object
Rejected by the carriers at least once.
-
#registration_type ⇒ Object
Returns the value of attribute registration_type.
-
#rejected_before_submission ⇒ Object
Rejected in our review before anything was filed with the carriers (not a carrier rejection; nothing to fix or appeal).
-
#review_request ⇒ Object
Returns the value of attribute review_request.
-
#status ⇒ Object
requested/changes_requested = pre-submission review states; customers see them as pending / needs changes.
-
#tf_action_required_at ⇒ Object
Toll-free only: when the carrier requested changes ("Waiting For Customer").
-
#throughput ⇒ Object
Returns the value of attribute throughput.
-
#trust_score ⇒ Object
Carrier-assigned brand trust score; drives throughput.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListSmsRegistrations200ResponseRegistrationsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListSmsRegistrations200ResponseRegistrationsInner
Initializes the object
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 177 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ListSmsRegistrations200ResponseRegistrationsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ListSmsRegistrations200ResponseRegistrationsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'registration_type') self.registration_type = attributes[:'registration_type'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'brand_status') self.brand_status = attributes[:'brand_status'] end if attributes.key?(:'campaign_status') self.campaign_status = attributes[:'campaign_status'] end if attributes.key?(:'brand_id') self.brand_id = attributes[:'brand_id'] end if attributes.key?(:'campaign_id') self.campaign_id = attributes[:'campaign_id'] end if attributes.key?(:'decline_reason') self.decline_reason = attributes[:'decline_reason'] end if attributes.key?(:'tf_action_required_at') self.tf_action_required_at = attributes[:'tf_action_required_at'] end if attributes.key?(:'phone_numbers') if (value = attributes[:'phone_numbers']).is_a?(Array) self.phone_numbers = value end end if attributes.key?(:'awaiting_otp') self.awaiting_otp = attributes[:'awaiting_otp'] end if attributes.key?(:'admin_review_note') self.admin_review_note = attributes[:'admin_review_note'] end if attributes.key?(:'last_response_at') self.last_response_at = attributes[:'last_response_at'] end if attributes.key?(:'previously_rejected') self.previously_rejected = attributes[:'previously_rejected'] end if attributes.key?(:'last_rejected_at') self.last_rejected_at = attributes[:'last_rejected_at'] end if attributes.key?(:'rejected_before_submission') self.rejected_before_submission = attributes[:'rejected_before_submission'] end if attributes.key?(:'otp_expired') self.otp_expired = attributes[:'otp_expired'] end if attributes.key?(:'review_request') self.review_request = attributes[:'review_request'] end if attributes.key?(:'trust_score') self.trust_score = attributes[:'trust_score'] end if attributes.key?(:'throughput') self.throughput = attributes[:'throughput'] end end |
Instance Attribute Details
#admin_review_note ⇒ Object
The open change request as text (status changes_requested).
49 50 51 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 49 def admin_review_note @admin_review_note end |
#awaiting_otp ⇒ Object
Sole-prop 10DLC only; the OTP step is still pending.
46 47 48 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 46 def awaiting_otp @awaiting_otp end |
#brand_id ⇒ Object
TCR brand id, useful when referencing the brand in carrier support threads.
33 34 35 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 33 def brand_id @brand_id end |
#brand_status ⇒ Object
Carrier-registry brand status (e.g. VERIFIED).
28 29 30 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 28 def brand_status @brand_status end |
#campaign_id ⇒ Object
TCR campaign id.
36 37 38 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 36 def campaign_id @campaign_id end |
#campaign_status ⇒ Object
Returns the value of attribute campaign_status.
30 31 32 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 30 def campaign_status @campaign_status end |
#decline_reason ⇒ Object
Returns the value of attribute decline_reason.
38 39 40 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 38 def decline_reason @decline_reason end |
#display_name ⇒ Object
Returns the value of attribute display_name.
22 23 24 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 22 def display_name @display_name end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 18 def id @id end |
#last_rejected_at ⇒ Object
When the carriers last rejected it.
58 59 60 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 58 def last_rejected_at @last_rejected_at end |
#last_response_at ⇒ Object
When you last answered a change request.
52 53 54 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 52 def last_response_at @last_response_at end |
#otp_expired ⇒ Object
Sole proprietor only: the verification code was never entered within 30 days. Start SMS setup again; it revives the same brand with no second brand fee.
64 65 66 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 64 def otp_expired @otp_expired end |
#phone_numbers ⇒ Object
Returns the value of attribute phone_numbers.
43 44 45 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 43 def phone_numbers @phone_numbers end |
#previously_rejected ⇒ Object
Rejected by the carriers at least once. A pending registration with this set is our fix, back with the carriers.
55 56 57 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 55 def previously_rejected @previously_rejected end |
#registration_type ⇒ Object
Returns the value of attribute registration_type.
20 21 22 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 20 def registration_type @registration_type end |
#rejected_before_submission ⇒ Object
Rejected in our review before anything was filed with the carriers (not a carrier rejection; nothing to fix or appeal).
61 62 63 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 61 def rejected_before_submission @rejected_before_submission end |
#review_request ⇒ Object
Returns the value of attribute review_request.
66 67 68 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 66 def review_request @review_request end |
#status ⇒ Object
requested/changes_requested = pre-submission review states; customers see them as pending / needs changes.
25 26 27 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 25 def status @status end |
#tf_action_required_at ⇒ Object
Toll-free only: when the carrier requested changes ("Waiting For Customer"). The request must be resubmitted within 7 days of this timestamp or it expires.
41 42 43 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 41 def tf_action_required_at @tf_action_required_at end |
#throughput ⇒ Object
Returns the value of attribute throughput.
71 72 73 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 71 def throughput @throughput end |
#trust_score ⇒ Object
Carrier-assigned brand trust score; drives throughput.
69 70 71 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 69 def trust_score @trust_score end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
123 124 125 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 123 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
128 129 130 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 128 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 96 def self.attribute_map { :'id' => :'id', :'registration_type' => :'registrationType', :'display_name' => :'displayName', :'status' => :'status', :'brand_status' => :'brandStatus', :'campaign_status' => :'campaignStatus', :'brand_id' => :'brandId', :'campaign_id' => :'campaignId', :'decline_reason' => :'declineReason', :'tf_action_required_at' => :'tfActionRequiredAt', :'phone_numbers' => :'phoneNumbers', :'awaiting_otp' => :'awaitingOtp', :'admin_review_note' => :'adminReviewNote', :'last_response_at' => :'lastResponseAt', :'previously_rejected' => :'previouslyRejected', :'last_rejected_at' => :'lastRejectedAt', :'rejected_before_submission' => :'rejectedBeforeSubmission', :'otp_expired' => :'otpExpired', :'review_request' => :'reviewRequest', :'trust_score' => :'trustScore', :'throughput' => :'throughput' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 360 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 160 def self.openapi_nullable Set.new([ :'display_name', :'brand_id', :'campaign_id', :'decline_reason', :'tf_action_required_at', :'admin_review_note', :'last_response_at', :'last_rejected_at', :'review_request', :'trust_score', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 133 def self.openapi_types { :'id' => :'String', :'registration_type' => :'String', :'display_name' => :'String', :'status' => :'String', :'brand_status' => :'String', :'campaign_status' => :'String', :'brand_id' => :'String', :'campaign_id' => :'String', :'decline_reason' => :'String', :'tf_action_required_at' => :'Time', :'phone_numbers' => :'Array<String>', :'awaiting_otp' => :'Boolean', :'admin_review_note' => :'String', :'last_response_at' => :'Time', :'previously_rejected' => :'Boolean', :'last_rejected_at' => :'Time', :'rejected_before_submission' => :'Boolean', :'otp_expired' => :'Boolean', :'review_request' => :'SmsRegistrationReviewRequest', :'trust_score' => :'Float', :'throughput' => :'ListSmsRegistrations200ResponseRegistrationsInnerThroughput' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 319 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && registration_type == o.registration_type && display_name == o.display_name && status == o.status && brand_status == o.brand_status && campaign_status == o.campaign_status && brand_id == o.brand_id && campaign_id == o.campaign_id && decline_reason == o.decline_reason && tf_action_required_at == o.tf_action_required_at && phone_numbers == o.phone_numbers && awaiting_otp == o.awaiting_otp && admin_review_note == o.admin_review_note && last_response_at == o.last_response_at && previously_rejected == o.previously_rejected && last_rejected_at == o.last_rejected_at && rejected_before_submission == o.rejected_before_submission && otp_expired == o.otp_expired && review_request == o.review_request && trust_score == o.trust_score && throughput == o.throughput end |
#eql?(o) ⇒ Boolean
347 348 349 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 347 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
353 354 355 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 353 def hash [id, registration_type, display_name, status, brand_status, campaign_status, brand_id, campaign_id, decline_reason, tf_action_required_at, phone_numbers, awaiting_otp, admin_review_note, last_response_at, previously_rejected, last_rejected_at, rejected_before_submission, otp_expired, review_request, trust_score, throughput].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
280 281 282 283 284 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 280 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 382 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
288 289 290 291 292 293 294 295 |
# File 'lib/zernio-sdk/models/list_sms_registrations200_response_registrations_inner.rb', line 288 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' registration_type_validator = EnumAttributeValidator.new('String', ["standard_10dlc", "sole_prop_10dlc", "toll_free"]) return false unless registration_type_validator.valid?(@registration_type) status_validator = EnumAttributeValidator.new('String', ["pending", "approved", "rejected", "requested", "changes_requested", "deactivated"]) return false unless status_validator.valid?(@status) true end |