Class: Zernio::MediaApi
- Inherits:
-
Object
- Object
- Zernio::MediaApi
- Defined in:
- lib/zernio-sdk/api/media_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_media_presigned_url(get_media_presigned_url_request, opts = {}) ⇒ GetMediaPresignedUrl200Response
Get upload URL Get a presigned URL to upload files directly to cloud storage (up to 5GB).
-
#get_media_presigned_url_with_http_info(get_media_presigned_url_request, opts = {}) ⇒ Array<(GetMediaPresignedUrl200Response, Integer, Hash)>
Get upload URL Get a presigned URL to upload files directly to cloud storage (up to 5GB).
-
#initialize(api_client = ApiClient.default) ⇒ MediaApi
constructor
A new instance of MediaApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/zernio-sdk/api/media_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_media_presigned_url(get_media_presigned_url_request, opts = {}) ⇒ GetMediaPresignedUrl200Response
Get upload URL Get a presigned URL to upload files directly to cloud storage (up to 5GB). Returns an uploadUrl and publicUrl. PUT your file to the uploadUrl, then use the publicUrl in your posts.
27 28 29 30 |
# File 'lib/zernio-sdk/api/media_api.rb', line 27 def get_media_presigned_url(get_media_presigned_url_request, opts = {}) data, _status_code, _headers = get_media_presigned_url_with_http_info(get_media_presigned_url_request, opts) data end |
#get_media_presigned_url_with_http_info(get_media_presigned_url_request, opts = {}) ⇒ Array<(GetMediaPresignedUrl200Response, Integer, Hash)>
Get upload URL Get a presigned URL to upload files directly to cloud storage (up to 5GB). Returns an uploadUrl and publicUrl. PUT your file to the uploadUrl, then use the publicUrl in your posts.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/zernio-sdk/api/media_api.rb', line 37 def get_media_presigned_url_with_http_info(get_media_presigned_url_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MediaApi.get_media_presigned_url ...' end # verify the required parameter 'get_media_presigned_url_request' is set if @api_client.config.client_side_validation && get_media_presigned_url_request.nil? fail ArgumentError, "Missing the required parameter 'get_media_presigned_url_request' when calling MediaApi.get_media_presigned_url" end # resource path local_var_path = '/v1/media/presign' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(get_media_presigned_url_request) # return_type return_type = opts[:debug_return_type] || 'GetMediaPresignedUrl200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"MediaApi.get_media_presigned_url", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MediaApi#get_media_presigned_url\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |