Class: Zernio::MetaLeadFormPlatformData

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/meta_lead_form_platform_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetaLeadFormPlatformData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::MetaLeadFormPlatformData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::MetaLeadFormPlatformData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'questions')
    if (value = attributes[:'questions']).is_a?(Array)
      self.questions = value
    end
  else
    self.questions = nil
  end

  if attributes.key?(:'privacy_policy_link_text')
    self.privacy_policy_link_text = attributes[:'privacy_policy_link_text']
  end

  if attributes.key?(:'follow_up_action_url')
    self.follow_up_action_url = attributes[:'follow_up_action_url']
  end

  if attributes.key?(:'locale')
    self.locale = attributes[:'locale']
  end

  if attributes.key?(:'thank_you_title')
    self.thank_you_title = attributes[:'thank_you_title']
  end

  if attributes.key?(:'thank_you_body')
    self.thank_you_body = attributes[:'thank_you_body']
  end

  if attributes.key?(:'thank_you_button_text')
    self.thank_you_button_text = attributes[:'thank_you_button_text']
  end

  if attributes.key?(:'thank_you_button_type')
    self.thank_you_button_type = attributes[:'thank_you_button_type']
  end

  if attributes.key?(:'thank_you_website_url')
    self.thank_you_website_url = attributes[:'thank_you_website_url']
  end

  if attributes.key?(:'is_optimized_for_quality')
    self.is_optimized_for_quality = attributes[:'is_optimized_for_quality']
  end

  if attributes.key?(:'form_type')
    self.form_type = attributes[:'form_type']
  end

  if attributes.key?(:'block_display_for_non_targeted_viewer')
    self.block_display_for_non_targeted_viewer = attributes[:'block_display_for_non_targeted_viewer']
  end

  if attributes.key?(:'allow_organic_lead_gen')
    self.allow_organic_lead_gen = attributes[:'allow_organic_lead_gen']
  end

  if attributes.key?(:'question_page_custom_headline')
    self.question_page_custom_headline = attributes[:'question_page_custom_headline']
  end

  if attributes.key?(:'context_card')
    self.context_card = attributes[:'context_card']
  end
end

Instance Attribute Details

#allow_organic_lead_genObject

Returns the value of attribute allow_organic_lead_gen.



42
43
44
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 42

def allow_organic_lead_gen
  @allow_organic_lead_gen
end

#block_display_for_non_targeted_viewerObject

Returns the value of attribute block_display_for_non_targeted_viewer.



40
41
42
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 40

def block_display_for_non_targeted_viewer
  @block_display_for_non_targeted_viewer
end

#context_cardObject

Returns the value of attribute context_card.



46
47
48
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 46

def context_card
  @context_card
end

#follow_up_action_urlObject

Returns the value of attribute follow_up_action_url.



22
23
24
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 22

def follow_up_action_url
  @follow_up_action_url
end

#form_typeObject

Returns the value of attribute form_type.



38
39
40
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 38

def form_type
  @form_type
end

#is_optimized_for_qualityObject

Returns the value of attribute is_optimized_for_quality.



36
37
38
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 36

def is_optimized_for_quality
  @is_optimized_for_quality
end

#localeObject

Returns the value of attribute locale.



24
25
26
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 24

def locale
  @locale
end

Returns the value of attribute privacy_policy_link_text.



20
21
22
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 20

def privacy_policy_link_text
  @privacy_policy_link_text
end

#question_page_custom_headlineObject

Returns the value of attribute question_page_custom_headline.



44
45
46
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 44

def question_page_custom_headline
  @question_page_custom_headline
end

#questionsObject

Returns the value of attribute questions.



18
19
20
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 18

def questions
  @questions
end

#thank_you_bodyObject

Returns the value of attribute thank_you_body.



28
29
30
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 28

def thank_you_body
  @thank_you_body
end

#thank_you_button_textObject

Returns the value of attribute thank_you_button_text.



30
31
32
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 30

def thank_you_button_text
  @thank_you_button_text
end

#thank_you_button_typeObject

Returns the value of attribute thank_you_button_type.



32
33
34
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 32

def thank_you_button_type
  @thank_you_button_type
end

#thank_you_titleObject

Returns the value of attribute thank_you_title.



26
27
28
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 26

def thank_you_title
  @thank_you_title
end

#thank_you_website_urlObject

Returns the value of attribute thank_you_website_url.



34
35
36
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 34

def thank_you_website_url
  @thank_you_website_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



92
93
94
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 92

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 97

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 71

def self.attribute_map
  {
    :'questions' => :'questions',
    :'privacy_policy_link_text' => :'privacyPolicyLinkText',
    :'follow_up_action_url' => :'followUpActionUrl',
    :'locale' => :'locale',
    :'thank_you_title' => :'thankYouTitle',
    :'thank_you_body' => :'thankYouBody',
    :'thank_you_button_text' => :'thankYouButtonText',
    :'thank_you_button_type' => :'thankYouButtonType',
    :'thank_you_website_url' => :'thankYouWebsiteUrl',
    :'is_optimized_for_quality' => :'isOptimizedForQuality',
    :'form_type' => :'formType',
    :'block_display_for_non_targeted_viewer' => :'blockDisplayForNonTargetedViewer',
    :'allow_organic_lead_gen' => :'allowOrganicLeadGen',
    :'question_page_custom_headline' => :'questionPageCustomHeadline',
    :'context_card' => :'contextCard'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 316

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 123

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 102

def self.openapi_types
  {
    :'questions' => :'Array<CreateLeadFormRequestQuestionsInner>',
    :'privacy_policy_link_text' => :'String',
    :'follow_up_action_url' => :'String',
    :'locale' => :'String',
    :'thank_you_title' => :'String',
    :'thank_you_body' => :'String',
    :'thank_you_button_text' => :'String',
    :'thank_you_button_type' => :'String',
    :'thank_you_website_url' => :'String',
    :'is_optimized_for_quality' => :'Boolean',
    :'form_type' => :'String',
    :'block_display_for_non_targeted_viewer' => :'Boolean',
    :'allow_organic_lead_gen' => :'Boolean',
    :'question_page_custom_headline' => :'String',
    :'context_card' => :'MetaLeadFormPlatformDataContextCard'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 281

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      questions == o.questions &&
      privacy_policy_link_text == o.privacy_policy_link_text &&
      follow_up_action_url == o.follow_up_action_url &&
      locale == o.locale &&
      thank_you_title == o.thank_you_title &&
      thank_you_body == o.thank_you_body &&
      thank_you_button_text == o.thank_you_button_text &&
      thank_you_button_type == o.thank_you_button_type &&
      thank_you_website_url == o.thank_you_website_url &&
      is_optimized_for_quality == o.is_optimized_for_quality &&
      form_type == o.form_type &&
      block_display_for_non_targeted_viewer == o.block_display_for_non_targeted_viewer &&
      allow_organic_lead_gen == o.allow_organic_lead_gen &&
      question_page_custom_headline == o.question_page_custom_headline &&
      context_card == o.context_card
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


303
304
305
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 303

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



309
310
311
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 309

def hash
  [questions, privacy_policy_link_text, follow_up_action_url, locale, thank_you_title, thank_you_body, thank_you_button_text, thank_you_button_type, thank_you_website_url, is_optimized_for_quality, form_type, block_display_for_non_targeted_viewer, allow_organic_lead_gen, question_page_custom_headline, context_card].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 211

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @questions.nil?
    invalid_properties.push('invalid value for "questions", questions cannot be nil.')
  end

  if @questions.length < 1
    invalid_properties.push('invalid value for "questions", number of items must be greater than or equal to 1.')
  end

  if !@privacy_policy_link_text.nil? && @privacy_policy_link_text.to_s.length > 70
    invalid_properties.push('invalid value for "privacy_policy_link_text", the character length must be smaller than or equal to 70.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 338

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



231
232
233
234
235
236
237
238
239
# File 'lib/zernio-sdk/models/meta_lead_form_platform_data.rb', line 231

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @questions.nil?
  return false if @questions.length < 1
  return false if !@privacy_policy_link_text.nil? && @privacy_policy_link_text.to_s.length > 70
  form_type_validator = EnumAttributeValidator.new('String', ["MORE_VOLUME", "HIGHER_INTENT", "RICH_CREATIVE"])
  return false unless form_type_validator.valid?(@form_type)
  true
end