Class: Zernio::PostAnalytics

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/post_analytics.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostAnalytics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/zernio-sdk/models/post_analytics.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::PostAnalytics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::PostAnalytics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'impressions')
    self.impressions = attributes[:'impressions']
  end

  if attributes.key?(:'reach')
    self.reach = attributes[:'reach']
  end

  if attributes.key?(:'likes')
    self.likes = attributes[:'likes']
  end

  if attributes.key?(:'comments')
    self.comments = attributes[:'comments']
  end

  if attributes.key?(:'shares')
    self.shares = attributes[:'shares']
  end

  if attributes.key?(:'saves')
    self.saves = attributes[:'saves']
  end

  if attributes.key?(:'clicks')
    self.clicks = attributes[:'clicks']
  end

  if attributes.key?(:'views')
    self.views = attributes[:'views']
  end

  if attributes.key?(:'follows')
    self.follows = attributes[:'follows']
  end

  if attributes.key?(:'ig_reels_avg_watch_time')
    self.ig_reels_avg_watch_time = attributes[:'ig_reels_avg_watch_time']
  end

  if attributes.key?(:'ig_reels_video_view_total_time')
    self.ig_reels_video_view_total_time = attributes[:'ig_reels_video_view_total_time']
  end

  if attributes.key?(:'engagement_rate')
    self.engagement_rate = attributes[:'engagement_rate']
  end

  if attributes.key?(:'last_updated')
    self.last_updated = attributes[:'last_updated']
  end
end

Instance Attribute Details

#clicksObject

Returns the value of attribute clicks.



31
32
33
# File 'lib/zernio-sdk/models/post_analytics.rb', line 31

def clicks
  @clicks
end

#commentsObject

Returns the value of attribute comments.



24
25
26
# File 'lib/zernio-sdk/models/post_analytics.rb', line 24

def comments
  @comments
end

#engagement_rateObject

Returns the value of attribute engagement_rate.



44
45
46
# File 'lib/zernio-sdk/models/post_analytics.rb', line 44

def engagement_rate
  @engagement_rate
end

#followsObject

Instagram feed posts and stories only: organic accounts that started following from this post. 0 for reels and other platforms.



36
37
38
# File 'lib/zernio-sdk/models/post_analytics.rb', line 36

def follows
  @follows
end

#ig_reels_avg_watch_timeObject

Instagram Reels only: average watch time per play, in milliseconds. 0 for non-Reels media and other platforms.



39
40
41
# File 'lib/zernio-sdk/models/post_analytics.rb', line 39

def ig_reels_avg_watch_time
  @ig_reels_avg_watch_time
end

#ig_reels_video_view_total_timeObject

Instagram Reels only: total watch time including replays, in milliseconds. 0 for non-Reels media and other platforms.



42
43
44
# File 'lib/zernio-sdk/models/post_analytics.rb', line 42

def ig_reels_video_view_total_time
  @ig_reels_video_view_total_time
end

#impressionsObject

Returns the value of attribute impressions.



18
19
20
# File 'lib/zernio-sdk/models/post_analytics.rb', line 18

def impressions
  @impressions
end

#last_updatedObject

Returns the value of attribute last_updated.



46
47
48
# File 'lib/zernio-sdk/models/post_analytics.rb', line 46

def last_updated
  @last_updated
end

#likesObject

Returns the value of attribute likes.



22
23
24
# File 'lib/zernio-sdk/models/post_analytics.rb', line 22

def likes
  @likes
end

#reachObject

Returns the value of attribute reach.



20
21
22
# File 'lib/zernio-sdk/models/post_analytics.rb', line 20

def reach
  @reach
end

#savesObject

Number of saves/bookmarks (Instagram, Pinterest)



29
30
31
# File 'lib/zernio-sdk/models/post_analytics.rb', line 29

def saves
  @saves
end

#sharesObject

Returns the value of attribute shares.



26
27
28
# File 'lib/zernio-sdk/models/post_analytics.rb', line 26

def shares
  @shares
end

#viewsObject

Returns the value of attribute views.



33
34
35
# File 'lib/zernio-sdk/models/post_analytics.rb', line 33

def views
  @views
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/zernio-sdk/models/post_analytics.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/zernio-sdk/models/post_analytics.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/zernio-sdk/models/post_analytics.rb', line 49

def self.attribute_map
  {
    :'impressions' => :'impressions',
    :'reach' => :'reach',
    :'likes' => :'likes',
    :'comments' => :'comments',
    :'shares' => :'shares',
    :'saves' => :'saves',
    :'clicks' => :'clicks',
    :'views' => :'views',
    :'follows' => :'follows',
    :'ig_reels_avg_watch_time' => :'igReelsAvgWatchTime',
    :'ig_reels_video_view_total_time' => :'igReelsVideoViewTotalTime',
    :'engagement_rate' => :'engagementRate',
    :'last_updated' => :'lastUpdated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/zernio-sdk/models/post_analytics.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/zernio-sdk/models/post_analytics.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/models/post_analytics.rb', line 78

def self.openapi_types
  {
    :'impressions' => :'Integer',
    :'reach' => :'Integer',
    :'likes' => :'Integer',
    :'comments' => :'Integer',
    :'shares' => :'Integer',
    :'saves' => :'Integer',
    :'clicks' => :'Integer',
    :'views' => :'Integer',
    :'follows' => :'Integer',
    :'ig_reels_avg_watch_time' => :'Integer',
    :'ig_reels_video_view_total_time' => :'Integer',
    :'engagement_rate' => :'Float',
    :'last_updated' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zernio-sdk/models/post_analytics.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      impressions == o.impressions &&
      reach == o.reach &&
      likes == o.likes &&
      comments == o.comments &&
      shares == o.shares &&
      saves == o.saves &&
      clicks == o.clicks &&
      views == o.views &&
      follows == o.follows &&
      ig_reels_avg_watch_time == o.ig_reels_avg_watch_time &&
      ig_reels_video_view_total_time == o.ig_reels_video_view_total_time &&
      engagement_rate == o.engagement_rate &&
      last_updated == o.last_updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/zernio-sdk/models/post_analytics.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/zernio-sdk/models/post_analytics.rb', line 214

def hash
  [impressions, reach, likes, comments, shares, saves, clicks, views, follows, ig_reels_avg_watch_time, ig_reels_video_view_total_time, engagement_rate, last_updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
# File 'lib/zernio-sdk/models/post_analytics.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/zernio-sdk/models/post_analytics.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
# File 'lib/zernio-sdk/models/post_analytics.rb', line 181

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end