Class: Zernio::ReplyToInboxPostRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/reply_to_inbox_post_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReplyToInboxPostRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::ReplyToInboxPostRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::ReplyToInboxPostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  else
    self. = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'comment_id')
    self.comment_id = attributes[:'comment_id']
  end

  if attributes.key?(:'parent_cid')
    self.parent_cid = attributes[:'parent_cid']
  end

  if attributes.key?(:'root_uri')
    self.root_uri = attributes[:'root_uri']
  end

  if attributes.key?(:'root_cid')
    self.root_cid = attributes[:'root_cid']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



18
19
20
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 18

def 
  @account_id
end

#comment_idObject

Reply to specific comment (optional)



23
24
25
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 23

def comment_id
  @comment_id
end

#messageObject

Returns the value of attribute message.



20
21
22
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 20

def message
  @message
end

#parent_cidObject

(Bluesky only) Parent content identifier



26
27
28
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 26

def parent_cid
  @parent_cid
end

#root_cidObject

(Bluesky only) Root post CID



32
33
34
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 32

def root_cid
  @root_cid
end

#root_uriObject

(Bluesky only) Root post URI



29
30
31
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 29

def root_uri
  @root_uri
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 35

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'message' => :'message',
    :'comment_id' => :'commentId',
    :'parent_cid' => :'parentCid',
    :'root_uri' => :'rootUri',
    :'root_cid' => :'rootCid'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 57

def self.openapi_types
  {
    :'account_id' => :'String',
    :'message' => :'String',
    :'comment_id' => :'String',
    :'parent_cid' => :'String',
    :'root_uri' => :'String',
    :'root_cid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
175
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      message == o.message &&
      comment_id == o.comment_id &&
      parent_cid == o.parent_cid &&
      root_uri == o.root_uri &&
      root_cid == o.root_cid
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 185

def hash
  [, message, comment_id, parent_cid, root_uri, root_cid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @account_id.nil?
    invalid_properties.push('invalid value for "account_id", account_id cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
142
# File 'lib/zernio-sdk/models/reply_to_inbox_post_request.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @account_id.nil?
  return false if @message.nil?
  true
end