Class: Zernio::SearchAvailablePhoneNumbers200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SearchAvailablePhoneNumbers200Response
- Defined in:
- lib/zernio-sdk/models/search_available_phone_numbers200_response.rb
Instance Attribute Summary collapse
-
#claim_id ⇒ Object
Keyless calls only: a claim for any number matching this search's country, type and area.
-
#claim_url ⇒ Object
Keyless calls only: signup link for any number matching this search.
-
#country ⇒ Object
Returns the value of attribute country.
-
#masked ⇒ Object
true on keyless calls.
-
#near ⇒ Object
With
country=auto: the caller's city the results were narrowed to, or null when there was no stock there. -
#number_type ⇒ Object
Returns the value of attribute number_type.
-
#numbers ⇒ Object
Returns the value of attribute numbers.
-
#require_sms ⇒ Object
Echo of the
smsfilter applied to this search.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SearchAvailablePhoneNumbers200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SearchAvailablePhoneNumbers200Response
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SearchAvailablePhoneNumbers200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SearchAvailablePhoneNumbers200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'number_type') self.number_type = attributes[:'number_type'] end if attributes.key?(:'require_sms') self.require_sms = attributes[:'require_sms'] end if attributes.key?(:'numbers') if (value = attributes[:'numbers']).is_a?(Array) self.numbers = value end end if attributes.key?(:'masked') self.masked = attributes[:'masked'] end if attributes.key?(:'near') self.near = attributes[:'near'] end if attributes.key?(:'claim_id') self.claim_id = attributes[:'claim_id'] end if attributes.key?(:'claim_url') self.claim_url = attributes[:'claim_url'] end end |
Instance Attribute Details
#claim_id ⇒ Object
Keyless calls only: a claim for any number matching this search's country, type and area.
34 35 36 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 34 def claim_id @claim_id end |
#claim_url ⇒ Object
Keyless calls only: signup link for any number matching this search.
37 38 39 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 37 def claim_url @claim_url end |
#country ⇒ Object
Returns the value of attribute country.
18 19 20 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 18 def country @country end |
#masked ⇒ Object
true on keyless calls.
28 29 30 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 28 def masked @masked end |
#near ⇒ Object
With country=auto: the caller's city the results were narrowed to, or null when there was no stock there.
31 32 33 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 31 def near @near end |
#number_type ⇒ Object
Returns the value of attribute number_type.
20 21 22 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 20 def number_type @number_type end |
#numbers ⇒ Object
Returns the value of attribute numbers.
25 26 27 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 25 def numbers @numbers end |
#require_sms ⇒ Object
Echo of the sms filter applied to this search.
23 24 25 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 23 def require_sms @require_sms end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 40 def self.attribute_map { :'country' => :'country', :'number_type' => :'numberType', :'require_sms' => :'requireSms', :'numbers' => :'numbers', :'masked' => :'masked', :'near' => :'near', :'claim_id' => :'claimId', :'claim_url' => :'claimUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 180 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 82 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 78 def self.openapi_nullable Set.new([ :'near', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 64 def self.openapi_types { :'country' => :'String', :'number_type' => :'String', :'require_sms' => :'Boolean', :'numbers' => :'Array<SearchAvailablePhoneNumbers200ResponseNumbersInner>', :'masked' => :'Boolean', :'near' => :'String', :'claim_id' => :'String', :'claim_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 152 def ==(o) return true if self.equal?(o) self.class == o.class && country == o.country && number_type == o.number_type && require_sms == o.require_sms && numbers == o.numbers && masked == o.masked && near == o.near && claim_id == o.claim_id && claim_url == o.claim_url end |
#eql?(o) ⇒ Boolean
167 168 169 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 167 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 173 def hash [country, number_type, require_sms, numbers, masked, near, claim_id, claim_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 |
# File 'lib/zernio-sdk/models/search_available_phone_numbers200_response.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |