Class: Zernio::StartSmsRegistrationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/start_sms_registration_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StartSmsRegistrationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::StartSmsRegistrationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::StartSmsRegistrationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'registration_type')
    self.registration_type = attributes[:'registration_type']
  else
    self.registration_type = nil
  end

  if attributes.key?(:'phone_numbers')
    if (value = attributes[:'phone_numbers']).is_a?(Array)
      self.phone_numbers = value
    end
  else
    self.phone_numbers = nil
  end

  if attributes.key?(:'brand')
    self.brand = attributes[:'brand']
  end

  if attributes.key?(:'campaign')
    self.campaign = attributes[:'campaign']
  end

  if attributes.key?(:'wizard_values')
    if (value = attributes[:'wizard_values']).is_a?(Hash)
      self.wizard_values = value
    end
  end

  if attributes.key?(:'resubmit_request_id')
    self.resubmit_request_id = attributes[:'resubmit_request_id']
  end

  if attributes.key?(:'toll_free')
    self.toll_free = attributes[:'toll_free']
  end
end

Instance Attribute Details

#brandObject

Returns the value of attribute brand.



23
24
25
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 23

def brand
  @brand
end

#campaignObject

Returns the value of attribute campaign.



25
26
27
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 25

def campaign
  @campaign
end

#phone_numbersObject

Your numbers this registration covers.



21
22
23
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 21

def phone_numbers
  @phone_numbers
end

#registration_typeObject

Returns the value of attribute registration_type.



18
19
20
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 18

def registration_type
  @registration_type
end

#resubmit_request_idObject

Resubmit a registration that was returned for changes — updates it in place instead of creating a new one.



31
32
33
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 31

def resubmit_request_id
  @resubmit_request_id
end

#toll_freeObject

Returns the value of attribute toll_free.



33
34
35
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 33

def toll_free
  @toll_free
end

#wizard_valuesObject

Raw dashboard-wizard answers, stored only to prefill edit-and-resubmit. API integrators can omit.



28
29
30
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 28

def wizard_values
  @wizard_values
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 58

def self.attribute_map
  {
    :'registration_type' => :'registrationType',
    :'phone_numbers' => :'phoneNumbers',
    :'brand' => :'brand',
    :'campaign' => :'campaign',
    :'wizard_values' => :'wizardValues',
    :'resubmit_request_id' => :'resubmitRequestId',
    :'toll_free' => :'tollFree'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 237

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 81

def self.openapi_types
  {
    :'registration_type' => :'String',
    :'phone_numbers' => :'Array<String>',
    :'brand' => :'StartSmsRegistrationRequestBrand',
    :'campaign' => :'StartSmsRegistrationRequestCampaign',
    :'wizard_values' => :'Hash<String, String>',
    :'resubmit_request_id' => :'String',
    :'toll_free' => :'StartSmsRegistrationRequestTollFree'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      registration_type == o.registration_type &&
      phone_numbers == o.phone_numbers &&
      brand == o.brand &&
      campaign == o.campaign &&
      wizard_values == o.wizard_values &&
      resubmit_request_id == o.resubmit_request_id &&
      toll_free == o.toll_free
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


224
225
226
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 224

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



230
231
232
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 230

def hash
  [registration_type, phone_numbers, brand, campaign, wizard_values, resubmit_request_id, toll_free].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @registration_type.nil?
    invalid_properties.push('invalid value for "registration_type", registration_type cannot be nil.')
  end

  if @phone_numbers.nil?
    invalid_properties.push('invalid value for "phone_numbers", phone_numbers cannot be nil.')
  end

  if @phone_numbers.length < 1
    invalid_properties.push('invalid value for "phone_numbers", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 259

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
# File 'lib/zernio-sdk/models/start_sms_registration_request.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @registration_type.nil?
  registration_type_validator = EnumAttributeValidator.new('String', ["standard_10dlc", "sole_prop_10dlc", "toll_free"])
  return false unless registration_type_validator.valid?(@registration_type)
  return false if @phone_numbers.nil?
  return false if @phone_numbers.length < 1
  true
end