Class: Zernio::SubmitPhoneNumberKycRequestAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::SubmitPhoneNumberKycRequestAddress
- Defined in:
- lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb
Instance Attribute Summary collapse
-
#administrative_area ⇒ Object
Returns the value of attribute administrative_area.
-
#business_name ⇒ Object
Returns the value of attribute business_name.
-
#country_code ⇒ Object
Returns the value of attribute country_code.
-
#extended_address ⇒ Object
Address complement: apartment, suite, unit, or the quadra/lote used in some countries.
-
#first_name ⇒ Object
Returns the value of attribute first_name.
-
#last_name ⇒ Object
Returns the value of attribute last_name.
-
#locality ⇒ Object
Returns the value of attribute locality.
-
#postal_code ⇒ Object
Returns the value of attribute postal_code.
-
#requirement_id ⇒ Object
Returns the value of attribute requirement_id.
-
#street_address ⇒ Object
Returns the value of attribute street_address.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubmitPhoneNumberKycRequestAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SubmitPhoneNumberKycRequestAddress
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::SubmitPhoneNumberKycRequestAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::SubmitPhoneNumberKycRequestAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'requirement_id') self.requirement_id = attributes[:'requirement_id'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] end if attributes.key?(:'business_name') self.business_name = attributes[:'business_name'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'street_address') self.street_address = attributes[:'street_address'] end if attributes.key?(:'extended_address') self.extended_address = attributes[:'extended_address'] end if attributes.key?(:'locality') self.locality = attributes[:'locality'] end if attributes.key?(:'administrative_area') self.administrative_area = attributes[:'administrative_area'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end end |
Instance Attribute Details
#administrative_area ⇒ Object
Returns the value of attribute administrative_area.
35 36 37 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 35 def administrative_area @administrative_area end |
#business_name ⇒ Object
Returns the value of attribute business_name.
22 23 24 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 22 def business_name @business_name end |
#country_code ⇒ Object
Returns the value of attribute country_code.
20 21 22 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 20 def country_code @country_code end |
#extended_address ⇒ Object
Address complement: apartment, suite, unit, or the quadra/lote used in some countries. Optional. Does not substitute for a building number on street_address.
31 32 33 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 31 def extended_address @extended_address end |
#first_name ⇒ Object
Returns the value of attribute first_name.
24 25 26 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 24 def first_name @first_name end |
#last_name ⇒ Object
Returns the value of attribute last_name.
26 27 28 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 26 def last_name @last_name end |
#locality ⇒ Object
Returns the value of attribute locality.
33 34 35 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 33 def locality @locality end |
#postal_code ⇒ Object
Returns the value of attribute postal_code.
37 38 39 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 37 def postal_code @postal_code end |
#requirement_id ⇒ Object
Returns the value of attribute requirement_id.
18 19 20 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 18 def requirement_id @requirement_id end |
#street_address ⇒ Object
Returns the value of attribute street_address.
28 29 30 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 28 def street_address @street_address end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 40 def self.attribute_map { :'requirement_id' => :'requirementId', :'country_code' => :'country_code', :'business_name' => :'business_name', :'first_name' => :'first_name', :'last_name' => :'last_name', :'street_address' => :'street_address', :'extended_address' => :'extended_address', :'locality' => :'locality', :'administrative_area' => :'administrative_area', :'postal_code' => :'postal_code' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 66 def self.openapi_types { :'requirement_id' => :'String', :'country_code' => :'String', :'business_name' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'street_address' => :'String', :'extended_address' => :'String', :'locality' => :'String', :'administrative_area' => :'String', :'postal_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && requirement_id == o.requirement_id && country_code == o.country_code && business_name == o.business_name && first_name == o.first_name && last_name == o.last_name && street_address == o.street_address && extended_address == o.extended_address && locality == o.locality && administrative_area == o.administrative_area && postal_code == o.postal_code end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 184 def hash [requirement_id, country_code, business_name, first_name, last_name, street_address, extended_address, locality, administrative_area, postal_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/zernio-sdk/models/submit_phone_number_kyc_request_address.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |