Class: Zernio::UpdateAccountSitelinksRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAccountSitelinksRequest
- Defined in:
- lib/zernio-sdk/models/update_account_sitelinks_request.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Zernio Google Ads connection id.
-
#ad_account_id ⇒ Object
Platform ad account ID (Google customer ID, digits only).
-
#customer_id ⇒ Object
Alias of adAccountId, kept for existing callers.
-
#updates ⇒ Object
Returns the value of attribute updates.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAccountSitelinksRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAccountSitelinksRequest
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAccountSitelinksRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAccountSitelinksRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'ad_account_id') self.ad_account_id = attributes[:'ad_account_id'] end if attributes.key?(:'customer_id') self.customer_id = attributes[:'customer_id'] end if attributes.key?(:'updates') if (value = attributes[:'updates']).is_a?(Array) self.updates = value end else self.updates = nil end end |
Instance Attribute Details
#account_id ⇒ Object
Zernio Google Ads connection id.
19 20 21 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 19 def account_id @account_id end |
#ad_account_id ⇒ Object
Platform ad account ID (Google customer ID, digits only). Required when the connection has multiple customers.
22 23 24 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 22 def ad_account_id @ad_account_id end |
#customer_id ⇒ Object
Alias of adAccountId, kept for existing callers
25 26 27 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 25 def customer_id @customer_id end |
#updates ⇒ Object
Returns the value of attribute updates.
27 28 29 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 27 def updates @updates end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 30 def self.attribute_map { :'account_id' => :'accountId', :'ad_account_id' => :'adAccountId', :'customer_id' => :'customerId', :'updates' => :'updates' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 50 def self.openapi_types { :'account_id' => :'String', :'ad_account_id' => :'String', :'customer_id' => :'String', :'updates' => :'Array<UpdateAccountSitelinksRequestUpdatesInner>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
222 223 224 225 226 227 228 229 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 222 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && ad_account_id == o.ad_account_id && customer_id == o.customer_id && updates == o.updates end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 239 def hash [account_id, ad_account_id, customer_id, updates].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end pattern = Regexp.new(/^[a-fA-F0-9]{24}$/) if @account_id !~ pattern invalid_properties.push("invalid value for \"account_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@ad_account_id.nil? && @ad_account_id !~ pattern invalid_properties.push("invalid value for \"ad_account_id\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^\d+$/) if !@customer_id.nil? && @customer_id !~ pattern invalid_properties.push("invalid value for \"customer_id\", must conform to the pattern #{pattern}.") end if @updates.nil? invalid_properties.push('invalid value for "updates", updates cannot be nil.') end if @updates.length > 20 invalid_properties.push('invalid value for "updates", number of items must be less than or equal to 20.') end if @updates.length < 1 invalid_properties.push('invalid value for "updates", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/zernio-sdk/models/update_account_sitelinks_request.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @account_id !~ Regexp.new(/^[a-fA-F0-9]{24}$/) return false if !@ad_account_id.nil? && @ad_account_id !~ Regexp.new(/^\d+$/) return false if !@customer_id.nil? && @customer_id !~ Regexp.new(/^\d+$/) return false if @updates.nil? return false if @updates.length > 20 return false if @updates.length < 1 true end |