Class: Zernio::UpdateAdSet200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAdSet200Response
- Defined in:
- lib/zernio-sdk/models/update_ad_set200_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bid_amount ⇒ Object
Returns the value of attribute bid_amount.
-
#bid_strategy ⇒ Object
Returns the value of attribute bid_strategy.
-
#budget ⇒ Object
Returns the value of attribute budget.
-
#budget_level ⇒ Object
Returns the value of attribute budget_level.
-
#platform_specific_data ⇒ Object
Returns the value of attribute platform_specific_data.
-
#roas_average_floor ⇒ Object
Returns the value of attribute roas_average_floor.
-
#status ⇒ Object
Returns the value of attribute status.
-
#status_skipped ⇒ Object
Returns the value of attribute status_skipped.
-
#status_updated ⇒ Object
Returns the value of attribute status_updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAdSet200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAdSet200Response
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdSet200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdSet200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'budget') self.budget = attributes[:'budget'] end if attributes.key?(:'budget_level') self.budget_level = attributes[:'budget_level'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'status_updated') self.status_updated = attributes[:'status_updated'] end if attributes.key?(:'status_skipped') self.status_skipped = attributes[:'status_skipped'] end if attributes.key?(:'bid_strategy') self.bid_strategy = attributes[:'bid_strategy'] end if attributes.key?(:'bid_amount') self.bid_amount = attributes[:'bid_amount'] end if attributes.key?(:'roas_average_floor') self.roas_average_floor = attributes[:'roas_average_floor'] end if attributes.key?(:'platform_specific_data') self.platform_specific_data = attributes[:'platform_specific_data'] end end |
Instance Attribute Details
#bid_amount ⇒ Object
Returns the value of attribute bid_amount.
30 31 32 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 30 def bid_amount @bid_amount end |
#bid_strategy ⇒ Object
Returns the value of attribute bid_strategy.
28 29 30 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 28 def bid_strategy @bid_strategy end |
#budget ⇒ Object
Returns the value of attribute budget.
18 19 20 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 18 def budget @budget end |
#budget_level ⇒ Object
Returns the value of attribute budget_level.
20 21 22 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 20 def budget_level @budget_level end |
#platform_specific_data ⇒ Object
Returns the value of attribute platform_specific_data.
34 35 36 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 34 def platform_specific_data @platform_specific_data end |
#roas_average_floor ⇒ Object
Returns the value of attribute roas_average_floor.
32 33 34 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 32 def roas_average_floor @roas_average_floor end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 22 def status @status end |
#status_skipped ⇒ Object
Returns the value of attribute status_skipped.
26 27 28 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 26 def status_skipped @status_skipped end |
#status_updated ⇒ Object
Returns the value of attribute status_updated.
24 25 26 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 24 def status_updated @status_updated end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 59 def self.attribute_map { :'budget' => :'budget', :'budget_level' => :'budgetLevel', :'status' => :'status', :'status_updated' => :'statusUpdated', :'status_skipped' => :'statusSkipped', :'bid_strategy' => :'bidStrategy', :'bid_amount' => :'bidAmount', :'roas_average_floor' => :'roasAverageFloor', :'platform_specific_data' => :'platformSpecificData' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 229 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 103 104 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 99 def self.openapi_nullable Set.new([ :'bid_amount', :'roas_average_floor', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 84 def self.openapi_types { :'budget' => :'AdBudget', :'budget_level' => :'String', :'status' => :'String', :'status_updated' => :'Integer', :'status_skipped' => :'Integer', :'bid_strategy' => :'BidStrategy', :'bid_amount' => :'Float', :'roas_average_floor' => :'Float', :'platform_specific_data' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 200 def ==(o) return true if self.equal?(o) self.class == o.class && budget == o.budget && budget_level == o.budget_level && status == o.status && status_updated == o.status_updated && status_skipped == o.status_skipped && bid_strategy == o.bid_strategy && bid_amount == o.bid_amount && roas_average_floor == o.roas_average_floor && platform_specific_data == o.platform_specific_data end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 222 def hash [budget, budget_level, status, status_updated, status_skipped, bid_strategy, bid_amount, roas_average_floor, platform_specific_data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
169 170 171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/update_ad_set200_response.rb', line 169 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' budget_level_validator = EnumAttributeValidator.new('String', ["adset"]) return false unless budget_level_validator.valid?(@budget_level) status_validator = EnumAttributeValidator.new('String', ["active", "paused"]) return false unless status_validator.valid?(@status) true end |