Class: Zernio::UpdateAdSetRequestPlatformSpecificDataPromotedObject
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateAdSetRequestPlatformSpecificDataPromotedObject
- Defined in:
- lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb
Overview
Meta ad-set promoted_object, forwarded verbatim (same shape as /v1/ads/create). Unknown keys are rejected with 400.
Instance Attribute Summary collapse
-
#application_id ⇒ Object
Returns the value of attribute application_id.
-
#custom_conversion_id ⇒ Object
Returns the value of attribute custom_conversion_id.
-
#custom_event_type ⇒ Object
Returns the value of attribute custom_event_type.
-
#object_store_url ⇒ Object
Returns the value of attribute object_store_url.
-
#offline_conversion_data_set_id ⇒ Object
Returns the value of attribute offline_conversion_data_set_id.
-
#page_id ⇒ Object
Returns the value of attribute page_id.
-
#pixel_id ⇒ Object
Returns the value of attribute pixel_id.
-
#product_catalog_id ⇒ Object
Returns the value of attribute product_catalog_id.
-
#product_set_id ⇒ Object
Returns the value of attribute product_set_id.
-
#whatsapp_phone_number ⇒ Object
Returns the value of attribute whatsapp_phone_number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAdSetRequestPlatformSpecificDataPromotedObject
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAdSetRequestPlatformSpecificDataPromotedObject
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateAdSetRequestPlatformSpecificDataPromotedObject` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateAdSetRequestPlatformSpecificDataPromotedObject`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'pixel_id') self.pixel_id = attributes[:'pixel_id'] end if attributes.key?(:'custom_event_type') self.custom_event_type = attributes[:'custom_event_type'] end if attributes.key?(:'page_id') self.page_id = attributes[:'page_id'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'object_store_url') self.object_store_url = attributes[:'object_store_url'] end if attributes.key?(:'custom_conversion_id') self.custom_conversion_id = attributes[:'custom_conversion_id'] end if attributes.key?(:'product_catalog_id') self.product_catalog_id = attributes[:'product_catalog_id'] end if attributes.key?(:'product_set_id') self.product_set_id = attributes[:'product_set_id'] end if attributes.key?(:'offline_conversion_data_set_id') self.offline_conversion_data_set_id = attributes[:'offline_conversion_data_set_id'] end if attributes.key?(:'whatsapp_phone_number') self.whatsapp_phone_number = attributes[:'whatsapp_phone_number'] end end |
Instance Attribute Details
#application_id ⇒ Object
Returns the value of attribute application_id.
25 26 27 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 25 def application_id @application_id end |
#custom_conversion_id ⇒ Object
Returns the value of attribute custom_conversion_id.
29 30 31 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 29 def custom_conversion_id @custom_conversion_id end |
#custom_event_type ⇒ Object
Returns the value of attribute custom_event_type.
21 22 23 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 21 def custom_event_type @custom_event_type end |
#object_store_url ⇒ Object
Returns the value of attribute object_store_url.
27 28 29 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 27 def object_store_url @object_store_url end |
#offline_conversion_data_set_id ⇒ Object
Returns the value of attribute offline_conversion_data_set_id.
35 36 37 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 35 def offline_conversion_data_set_id @offline_conversion_data_set_id end |
#page_id ⇒ Object
Returns the value of attribute page_id.
23 24 25 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 23 def page_id @page_id end |
#pixel_id ⇒ Object
Returns the value of attribute pixel_id.
19 20 21 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 19 def pixel_id @pixel_id end |
#product_catalog_id ⇒ Object
Returns the value of attribute product_catalog_id.
31 32 33 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 31 def product_catalog_id @product_catalog_id end |
#product_set_id ⇒ Object
Returns the value of attribute product_set_id.
33 34 35 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 33 def product_set_id @product_set_id end |
#whatsapp_phone_number ⇒ Object
Returns the value of attribute whatsapp_phone_number.
37 38 39 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 37 def whatsapp_phone_number @whatsapp_phone_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 40 def self.attribute_map { :'pixel_id' => :'pixelId', :'custom_event_type' => :'customEventType', :'page_id' => :'pageId', :'application_id' => :'applicationId', :'object_store_url' => :'objectStoreUrl', :'custom_conversion_id' => :'customConversionId', :'product_catalog_id' => :'productCatalogId', :'product_set_id' => :'productSetId', :'offline_conversion_data_set_id' => :'offlineConversionDataSetId', :'whatsapp_phone_number' => :'whatsappPhoneNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 191 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 66 def self.openapi_types { :'pixel_id' => :'String', :'custom_event_type' => :'String', :'page_id' => :'String', :'application_id' => :'String', :'object_store_url' => :'String', :'custom_conversion_id' => :'String', :'product_catalog_id' => :'String', :'product_set_id' => :'String', :'offline_conversion_data_set_id' => :'String', :'whatsapp_phone_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && pixel_id == o.pixel_id && custom_event_type == o.custom_event_type && page_id == o.page_id && application_id == o.application_id && object_store_url == o.object_store_url && custom_conversion_id == o.custom_conversion_id && product_catalog_id == o.product_catalog_id && product_set_id == o.product_set_id && offline_conversion_data_set_id == o.offline_conversion_data_set_id && whatsapp_phone_number == o.whatsapp_phone_number end |
#eql?(o) ⇒ Boolean
178 179 180 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 178 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
184 185 186 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 184 def hash [pixel_id, custom_event_type, page_id, application_id, object_store_url, custom_conversion_id, product_catalog_id, product_set_id, offline_conversion_data_set_id, whatsapp_phone_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 213 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/zernio-sdk/models/update_ad_set_request_platform_specific_data_promoted_object.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |