Class: Zernio::UpdateBlogArticleRequest

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/update_blog_article_request.rb

Overview

At least one field is required.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateBlogArticleRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateBlogArticleRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateBlogArticleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'body_html')
    self.body_html = attributes[:'body_html']
  end

  if attributes.key?(:'handle')
    self.handle = attributes[:'handle']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  end

  if attributes.key?(:'excerpt')
    self.excerpt = attributes[:'excerpt']
  end

  if attributes.key?(:'image')
    self.image = attributes[:'image']
  end

  if attributes.key?(:'seo')
    self.seo = attributes[:'seo']
  end

  if attributes.key?(:'is_published')
    self.is_published = attributes[:'is_published']
  end

  if attributes.key?(:'publish_date')
    self.publish_date = attributes[:'publish_date']
  end
end

Instance Attribute Details

#authorObject

Display name of the article author.



31
32
33
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 31

def author
  @author
end

#body_htmlObject

Article body as HTML.



22
23
24
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 22

def body_html
  @body_html
end

#excerptObject

Short summary shown in blog listings.



34
35
36
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 34

def excerpt
  @excerpt
end

#handleObject

URL slug of the article.



25
26
27
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 25

def handle
  @handle
end

#imageObject

Returns the value of attribute image.



36
37
38
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 36

def image
  @image
end

#is_publishedObject

Set false to unpublish the article back to a draft.



41
42
43
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 41

def is_published
  @is_published
end

#publish_dateObject

ISO 8601 datetime with offset (or Z). A future date schedules publication natively on the platform.



44
45
46
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 44

def publish_date
  @publish_date
end

#seoObject

Returns the value of attribute seo.



38
39
40
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 38

def seo
  @seo
end

#tagsObject

Replaces the full tag list.



28
29
30
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 28

def tags
  @tags
end

#titleObject

Returns the value of attribute title.



19
20
21
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 47

def self.attribute_map
  {
    :'title' => :'title',
    :'body_html' => :'bodyHtml',
    :'handle' => :'handle',
    :'tags' => :'tags',
    :'author' => :'author',
    :'excerpt' => :'excerpt',
    :'image' => :'image',
    :'seo' => :'seo',
    :'is_published' => :'isPublished',
    :'publish_date' => :'publishDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 73

def self.openapi_types
  {
    :'title' => :'String',
    :'body_html' => :'String',
    :'handle' => :'String',
    :'tags' => :'Array<String>',
    :'author' => :'String',
    :'excerpt' => :'String',
    :'image' => :'CreateBlogArticleRequestImage',
    :'seo' => :'CreateBlogArticleRequestSeo',
    :'is_published' => :'Boolean',
    :'publish_date' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      body_html == o.body_html &&
      handle == o.handle &&
      tags == o.tags &&
      author == o.author &&
      excerpt == o.excerpt &&
      image == o.image &&
      seo == o.seo &&
      is_published == o.is_published &&
      publish_date == o.publish_date
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 212

def hash
  [title, body_html, handle, tags, author, excerpt, image, seo, is_published, publish_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@title.nil? && @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
# File 'lib/zernio-sdk/models/update_blog_article_request.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@title.nil? && @title.to_s.length < 1
  true
end