Class: Zernio::UpdateCommentAutomation200ResponseAutomation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateCommentAutomation200ResponseAutomation
- Defined in:
- lib/zernio-sdk/models/update_comment_automation200_response_automation.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#audience ⇒ Object
Returns the value of attribute audience.
-
#buttons ⇒ Object
Inline DM buttons (up to 3).
-
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
-
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply.
-
#dm_message ⇒ Object
Returns the value of attribute dm_message.
-
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage.
-
#exclude_keywords ⇒ Object
Comments containing one of these never trigger the automation, even when a trigger keyword also matches.
-
#follow_gate ⇒ Object
Returns the value of attribute follow_gate.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#match_mode ⇒ Object
How a keyword is compared with the comment.
-
#name ⇒ Object
Returns the value of attribute name.
-
#template ⇒ Object
Returns the value of attribute template.
-
#typo_tolerance ⇒ Object
Only with matchMode=word: also fire on close misspellings of a keyword (one edit for 4-7 character keywords, two from 8 up).
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCommentAutomation200ResponseAutomation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCommentAutomation200ResponseAutomation
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateCommentAutomation200ResponseAutomation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateCommentAutomation200ResponseAutomation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'match_mode') self.match_mode = attributes[:'match_mode'] end if attributes.key?(:'exclude_keywords') if (value = attributes[:'exclude_keywords']).is_a?(Array) self.exclude_keywords = value end end if attributes.key?(:'typo_tolerance') self.typo_tolerance = attributes[:'typo_tolerance'] end if attributes.key?(:'dm_message') self. = attributes[:'dm_message'] end if attributes.key?(:'buttons') if (value = attributes[:'buttons']).is_a?(Array) self. = value end end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'comment_reply') self.comment_reply = attributes[:'comment_reply'] end if attributes.key?(:'dm_message_variations') if (value = attributes[:'dm_message_variations']).is_a?(Array) self. = value end end if attributes.key?(:'comment_reply_variations') if (value = attributes[:'comment_reply_variations']).is_a?(Array) self.comment_reply_variations = value end end if attributes.key?(:'audience') self.audience = attributes[:'audience'] end if attributes.key?(:'follow_gate') self.follow_gate = attributes[:'follow_gate'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#audience ⇒ Object
Returns the value of attribute audience.
48 49 50 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 48 def audience @audience end |
#buttons ⇒ Object
Inline DM buttons (up to 3). Omitted when none are set.
36 37 38 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 36 def @buttons end |
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
40 41 42 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 40 def comment_reply @comment_reply end |
#comment_reply_variations ⇒ Object
Alternate public replies rotated at random with commentReply. Omitted when none.
46 47 48 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 46 def comment_reply_variations @comment_reply_variations end |
#dm_message ⇒ Object
Returns the value of attribute dm_message.
33 34 35 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 33 def @dm_message end |
#dm_message_variations ⇒ Object
Alternate DM texts rotated at random with dmMessage. Omitted when none.
43 44 45 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 43 def @dm_message_variations end |
#exclude_keywords ⇒ Object
Comments containing one of these never trigger the automation, even when a trigger keyword also matches. Compared using the same matchMode.
28 29 30 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 28 def exclude_keywords @exclude_keywords end |
#follow_gate ⇒ Object
Returns the value of attribute follow_gate.
50 51 52 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 50 def follow_gate @follow_gate end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 18 def id @id end |
#is_active ⇒ Object
Returns the value of attribute is_active.
52 53 54 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 52 def is_active @is_active end |
#keywords ⇒ Object
Returns the value of attribute keywords.
22 23 24 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 22 def keywords @keywords end |
#match_mode ⇒ Object
How a keyword is compared with the comment. 'contains' (default) matches anywhere, even inside another word (keyword 'app' fires on 'happy'). 'word' matches the keyword only as a standalone word. 'exact' requires the whole comment to be exactly the keyword.
25 26 27 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 25 def match_mode @match_mode end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 20 def name @name end |
#template ⇒ Object
Returns the value of attribute template.
38 39 40 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 38 def template @template end |
#typo_tolerance ⇒ Object
Only with matchMode=word: also fire on close misspellings of a keyword (one edit for 4-7 character keywords, two from 8 up). Keywords shorter than 4 characters are never fuzzy-matched.
31 32 33 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 31 def typo_tolerance @typo_tolerance end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
54 55 56 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 54 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
101 102 103 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 101 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
106 107 108 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 106 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 79 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'keywords' => :'keywords', :'match_mode' => :'matchMode', :'exclude_keywords' => :'excludeKeywords', :'typo_tolerance' => :'typoTolerance', :'dm_message' => :'dmMessage', :'buttons' => :'buttons', :'template' => :'template', :'comment_reply' => :'commentReply', :'dm_message_variations' => :'dmMessageVariations', :'comment_reply_variations' => :'commentReplyVariations', :'audience' => :'audience', :'follow_gate' => :'followGate', :'is_active' => :'isActive', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 295 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
133 134 135 136 137 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 133 def self.openapi_nullable Set.new([ :'template', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 111 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'keywords' => :'Array<String>', :'match_mode' => :'String', :'exclude_keywords' => :'Array<String>', :'typo_tolerance' => :'Boolean', :'dm_message' => :'String', :'buttons' => :'Array<DmButton>', :'template' => :'CommentAutomationTemplate', :'comment_reply' => :'String', :'dm_message_variations' => :'Array<String>', :'comment_reply_variations' => :'Array<String>', :'audience' => :'CommentAutomationAudience', :'follow_gate' => :'CommentAutomationFollowGate', :'is_active' => :'Boolean', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && keywords == o.keywords && match_mode == o.match_mode && exclude_keywords == o.exclude_keywords && typo_tolerance == o.typo_tolerance && == o. && == o. && template == o.template && comment_reply == o.comment_reply && == o. && comment_reply_variations == o.comment_reply_variations && audience == o.audience && follow_gate == o.follow_gate && is_active == o.is_active && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
282 283 284 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 282 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
288 289 290 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 288 def hash [id, name, keywords, match_mode, exclude_keywords, typo_tolerance, , , template, comment_reply, , comment_reply_variations, audience, follow_gate, is_active, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
232 233 234 235 236 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 232 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 317 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
240 241 242 243 244 245 |
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 240 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains", "word"]) return false unless match_mode_validator.valid?(@match_mode) true end |