Class: Zernio::UpdateCommentAutomation200ResponseAutomation

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_comment_automation200_response_automation.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCommentAutomation200ResponseAutomation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateCommentAutomation200ResponseAutomation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateCommentAutomation200ResponseAutomation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Array)
      self.keywords = value
    end
  end

  if attributes.key?(:'match_mode')
    self.match_mode = attributes[:'match_mode']
  end

  if attributes.key?(:'dm_message')
    self.dm_message = attributes[:'dm_message']
  end

  if attributes.key?(:'buttons')
    if (value = attributes[:'buttons']).is_a?(Array)
      self.buttons = value
    end
  end

  if attributes.key?(:'comment_reply')
    self.comment_reply = attributes[:'comment_reply']
  end

  if attributes.key?(:'dm_message_variations')
    if (value = attributes[:'dm_message_variations']).is_a?(Array)
      self.dm_message_variations = value
    end
  end

  if attributes.key?(:'comment_reply_variations')
    if (value = attributes[:'comment_reply_variations']).is_a?(Array)
      self.comment_reply_variations = value
    end
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#buttonsObject

Inline DM buttons (up to 3). Omitted when none are set.



29
30
31
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 29

def buttons
  @buttons
end

#comment_replyObject

Returns the value of attribute comment_reply.



31
32
33
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 31

def comment_reply
  @comment_reply
end

#comment_reply_variationsObject

Alternate public replies rotated at random with commentReply. Omitted when none.



37
38
39
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 37

def comment_reply_variations
  @comment_reply_variations
end

#dm_messageObject

Returns the value of attribute dm_message.



26
27
28
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 26

def dm_message
  @dm_message
end

#dm_message_variationsObject

Alternate DM texts rotated at random with dmMessage. Omitted when none.



34
35
36
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 34

def dm_message_variations
  @dm_message_variations
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 18

def id
  @id
end

#is_activeObject

Returns the value of attribute is_active.



39
40
41
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 39

def is_active
  @is_active
end

#keywordsObject

Returns the value of attribute keywords.



22
23
24
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 22

def keywords
  @keywords
end

#match_modeObject

Returns the value of attribute match_mode.



24
25
26
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 24

def match_mode
  @match_mode
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 20

def name
  @name
end

#updated_atObject

Returns the value of attribute updated_at.



41
42
43
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 41

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 66

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'keywords' => :'keywords',
    :'match_mode' => :'matchMode',
    :'dm_message' => :'dmMessage',
    :'buttons' => :'buttons',
    :'comment_reply' => :'commentReply',
    :'dm_message_variations' => :'dmMessageVariations',
    :'comment_reply_variations' => :'commentReplyVariations',
    :'is_active' => :'isActive',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 110

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 93

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'keywords' => :'Array<String>',
    :'match_mode' => :'String',
    :'dm_message' => :'String',
    :'buttons' => :'Array<DmButton>',
    :'comment_reply' => :'String',
    :'dm_message_variations' => :'Array<String>',
    :'comment_reply_variations' => :'Array<String>',
    :'is_active' => :'Boolean',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      keywords == o.keywords &&
      match_mode == o.match_mode &&
      dm_message == o.dm_message &&
      buttons == o.buttons &&
      comment_reply == o.comment_reply &&
      dm_message_variations == o.dm_message_variations &&
      comment_reply_variations == o.comment_reply_variations &&
      is_active == o.is_active &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 237

def hash
  [id, name, keywords, match_mode, dm_message, buttons, comment_reply, dm_message_variations, comment_reply_variations, is_active, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
# File 'lib/zernio-sdk/models/update_comment_automation200_response_automation.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains"])
  return false unless match_mode_validator.valid?(@match_mode)
  true
end