Class: Zernio::UpdateCommentAutomationRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateCommentAutomationRequest
- Defined in:
- lib/zernio-sdk/models/update_comment_automation_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#also_match_in_dms ⇒ Object
Also fire these keywords on a plain inbound DM.
-
#audience ⇒ Object
Returns the value of attribute audience.
-
#buttons ⇒ Object
Inline DM buttons (1-3).
-
#click_tag ⇒ Object
Tag applied to a contact when they click a tracked link (requires linkTracking).
-
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
-
#comment_reply_delay_seconds ⇒ Object
Seconds to wait before posting the public comment reply.
-
#comment_reply_variations ⇒ Object
Alternate public replies for random rotation.
-
#dm_delay_seconds ⇒ Object
Seconds to wait after the trigger before sending the DM.
-
#dm_message ⇒ Object
Returns the value of attribute dm_message.
-
#dm_message_variations ⇒ Object
Alternate DM texts for random rotation (see create).
-
#exclude_keywords ⇒ Object
Comments containing one of these never trigger the automation, even when a trigger keyword also matches.
-
#follow_gate ⇒ Object
Returns the value of attribute follow_gate.
-
#is_active ⇒ Object
Returns the value of attribute is_active.
-
#keywords ⇒ Object
Returns the value of attribute keywords.
-
#link_tracking ⇒ Object
Wrap link buttons in a tracked redirect to count clicks.
-
#match_mode ⇒ Object
How a keyword is compared with the comment.
-
#name ⇒ Object
Returns the value of attribute name.
-
#template ⇒ Object
Returns the value of attribute template.
-
#trigger ⇒ Object
What fires the automation.
-
#typo_tolerance ⇒ Object
Only with matchMode=word: also fire on close misspellings of a keyword (one edit for 4-7 character keywords, two from 8 up).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateCommentAutomationRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateCommentAutomationRequest
Initializes the object
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 163 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateCommentAutomationRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateCommentAutomationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'trigger') self.trigger = attributes[:'trigger'] end if attributes.key?(:'keywords') if (value = attributes[:'keywords']).is_a?(Array) self.keywords = value end end if attributes.key?(:'match_mode') self.match_mode = attributes[:'match_mode'] end if attributes.key?(:'exclude_keywords') if (value = attributes[:'exclude_keywords']).is_a?(Array) self.exclude_keywords = value end end if attributes.key?(:'typo_tolerance') self.typo_tolerance = attributes[:'typo_tolerance'] end if attributes.key?(:'dm_message') self. = attributes[:'dm_message'] end if attributes.key?(:'buttons') if (value = attributes[:'buttons']).is_a?(Array) self. = value end end if attributes.key?(:'template') self.template = attributes[:'template'] end if attributes.key?(:'comment_reply') self.comment_reply = attributes[:'comment_reply'] end if attributes.key?(:'dm_message_variations') if (value = attributes[:'dm_message_variations']).is_a?(Array) self. = value end end if attributes.key?(:'comment_reply_variations') if (value = attributes[:'comment_reply_variations']).is_a?(Array) self.comment_reply_variations = value end end if attributes.key?(:'link_tracking') self.link_tracking = attributes[:'link_tracking'] end if attributes.key?(:'click_tag') self.click_tag = attributes[:'click_tag'] end if attributes.key?(:'also_match_in_dms') self.also_match_in_dms = attributes[:'also_match_in_dms'] end if attributes.key?(:'dm_delay_seconds') self.dm_delay_seconds = attributes[:'dm_delay_seconds'] end if attributes.key?(:'comment_reply_delay_seconds') self.comment_reply_delay_seconds = attributes[:'comment_reply_delay_seconds'] end if attributes.key?(:'audience') self.audience = attributes[:'audience'] end if attributes.key?(:'follow_gate') self.follow_gate = attributes[:'follow_gate'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end end |
Instance Attribute Details
#also_match_in_dms ⇒ Object
Also fire these keywords on a plain inbound DM. Enabling it requires the automation to end up with at least one keyword (this request's keywords if you send them, otherwise the stored ones) and is rejected on story_reply automations.
56 57 58 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 56 def also_match_in_dms @also_match_in_dms end |
#audience ⇒ Object
Returns the value of attribute audience.
64 65 66 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 64 def audience @audience end |
#buttons ⇒ Object
Inline DM buttons (1-3). Pass [] to clear all buttons.
37 38 39 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 37 def @buttons end |
#click_tag ⇒ Object
Tag applied to a contact when they click a tracked link (requires linkTracking). Empty string clears it.
53 54 55 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 53 def click_tag @click_tag end |
#comment_reply ⇒ Object
Returns the value of attribute comment_reply.
41 42 43 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 41 def comment_reply @comment_reply end |
#comment_reply_delay_seconds ⇒ Object
Seconds to wait before posting the public comment reply. Send 0 to clear it. The reply never goes out before the DM.
62 63 64 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 62 def comment_reply_delay_seconds @comment_reply_delay_seconds end |
#comment_reply_variations ⇒ Object
Alternate public replies for random rotation. Pass [] to clear.
47 48 49 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 47 def comment_reply_variations @comment_reply_variations end |
#dm_delay_seconds ⇒ Object
Seconds to wait after the trigger before sending the DM. Send 0 to clear the delay and reply immediately.
59 60 61 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 59 def dm_delay_seconds @dm_delay_seconds end |
#dm_message ⇒ Object
Returns the value of attribute dm_message.
34 35 36 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 34 def @dm_message end |
#dm_message_variations ⇒ Object
Alternate DM texts for random rotation (see create). Pass [] to clear.
44 45 46 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 44 def @dm_message_variations end |
#exclude_keywords ⇒ Object
Comments containing one of these never trigger the automation, even when a trigger keyword also matches. Compared using the same matchMode.
29 30 31 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 29 def exclude_keywords @exclude_keywords end |
#follow_gate ⇒ Object
Returns the value of attribute follow_gate.
66 67 68 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 66 def follow_gate @follow_gate end |
#is_active ⇒ Object
Returns the value of attribute is_active.
68 69 70 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 68 def is_active @is_active end |
#keywords ⇒ Object
Returns the value of attribute keywords.
23 24 25 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 23 def keywords @keywords end |
#link_tracking ⇒ Object
Wrap link buttons in a tracked redirect to count clicks. Pass false to send links untouched.
50 51 52 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 50 def link_tracking @link_tracking end |
#match_mode ⇒ Object
How a keyword is compared with the comment. 'contains' (default) matches anywhere, even inside another word (keyword 'app' fires on 'happy'). 'word' matches the keyword only as a standalone word. 'exact' requires the whole comment to be exactly the keyword.
26 27 28 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 26 def match_mode @match_mode end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 18 def name @name end |
#template ⇒ Object
Returns the value of attribute template.
39 40 41 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 39 def template @template end |
#trigger ⇒ Object
What fires the automation. Changing it detaches the automation from its bound post or story (a post id and a story id are different objects), unless this same request sets a new binding. 'story_reply' is Instagram only.
21 22 23 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 21 def trigger @trigger end |
#typo_tolerance ⇒ Object
Only with matchMode=word: also fire on close misspellings of a keyword (one edit for 4-7 character keywords, two from 8 up). Keywords shorter than 4 characters are never fuzzy-matched.
32 33 34 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 32 def typo_tolerance @typo_tolerance end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
119 120 121 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 119 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
124 125 126 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 124 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 93 def self.attribute_map { :'name' => :'name', :'trigger' => :'trigger', :'keywords' => :'keywords', :'match_mode' => :'matchMode', :'exclude_keywords' => :'excludeKeywords', :'typo_tolerance' => :'typoTolerance', :'dm_message' => :'dmMessage', :'buttons' => :'buttons', :'template' => :'template', :'comment_reply' => :'commentReply', :'dm_message_variations' => :'dmMessageVariations', :'comment_reply_variations' => :'commentReplyVariations', :'link_tracking' => :'linkTracking', :'click_tag' => :'clickTag', :'also_match_in_dms' => :'alsoMatchInDms', :'dm_delay_seconds' => :'dmDelaySeconds', :'comment_reply_delay_seconds' => :'commentReplyDelaySeconds', :'audience' => :'audience', :'follow_gate' => :'followGate', :'is_active' => :'isActive' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 462 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
155 156 157 158 159 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 155 def self.openapi_nullable Set.new([ :'template', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 129 def self.openapi_types { :'name' => :'String', :'trigger' => :'String', :'keywords' => :'Array<String>', :'match_mode' => :'String', :'exclude_keywords' => :'Array<String>', :'typo_tolerance' => :'Boolean', :'dm_message' => :'String', :'buttons' => :'Array<DmButton>', :'template' => :'CommentAutomationTemplate', :'comment_reply' => :'String', :'dm_message_variations' => :'Array<String>', :'comment_reply_variations' => :'Array<String>', :'link_tracking' => :'Boolean', :'click_tag' => :'String', :'also_match_in_dms' => :'Boolean', :'dm_delay_seconds' => :'Integer', :'comment_reply_delay_seconds' => :'Integer', :'audience' => :'CommentAutomationAudience', :'follow_gate' => :'CommentAutomationFollowGate', :'is_active' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 422 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && trigger == o.trigger && keywords == o.keywords && match_mode == o.match_mode && exclude_keywords == o.exclude_keywords && typo_tolerance == o.typo_tolerance && == o. && == o. && template == o.template && comment_reply == o.comment_reply && == o. && comment_reply_variations == o.comment_reply_variations && link_tracking == o.link_tracking && click_tag == o.click_tag && also_match_in_dms == o.also_match_in_dms && dm_delay_seconds == o.dm_delay_seconds && comment_reply_delay_seconds == o.comment_reply_delay_seconds && audience == o.audience && follow_gate == o.follow_gate && is_active == o.is_active end |
#eql?(o) ⇒ Boolean
449 450 451 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 449 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
455 456 457 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 455 def hash [name, trigger, keywords, match_mode, exclude_keywords, typo_tolerance, , , template, comment_reply, , comment_reply_variations, link_tracking, click_tag, also_match_in_dms, dm_delay_seconds, comment_reply_delay_seconds, audience, follow_gate, is_active].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 270 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@buttons.nil? && @buttons.length > 3 invalid_properties.push('invalid value for "buttons", number of items must be less than or equal to 3.') end if !@dm_message_variations.nil? && @dm_message_variations.length > 5 invalid_properties.push('invalid value for "dm_message_variations", number of items must be less than or equal to 5.') end if !@comment_reply_variations.nil? && @comment_reply_variations.length > 5 invalid_properties.push('invalid value for "comment_reply_variations", number of items must be less than or equal to 5.') end if !@dm_delay_seconds.nil? && @dm_delay_seconds > 86400 invalid_properties.push('invalid value for "dm_delay_seconds", must be smaller than or equal to 86400.') end if !@dm_delay_seconds.nil? && @dm_delay_seconds < 0 invalid_properties.push('invalid value for "dm_delay_seconds", must be greater than or equal to 0.') end if !@comment_reply_delay_seconds.nil? && @comment_reply_delay_seconds > 86400 invalid_properties.push('invalid value for "comment_reply_delay_seconds", must be smaller than or equal to 86400.') end if !@comment_reply_delay_seconds.nil? && @comment_reply_delay_seconds < 0 invalid_properties.push('invalid value for "comment_reply_delay_seconds", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 484 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 306 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' trigger_validator = EnumAttributeValidator.new('String', ["comment", "story_reply"]) return false unless trigger_validator.valid?(@trigger) match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains", "word"]) return false unless match_mode_validator.valid?(@match_mode) return false if !@buttons.nil? && @buttons.length > 3 return false if !@dm_message_variations.nil? && @dm_message_variations.length > 5 return false if !@comment_reply_variations.nil? && @comment_reply_variations.length > 5 return false if !@dm_delay_seconds.nil? && @dm_delay_seconds > 86400 return false if !@dm_delay_seconds.nil? && @dm_delay_seconds < 0 return false if !@comment_reply_delay_seconds.nil? && @comment_reply_delay_seconds > 86400 return false if !@comment_reply_delay_seconds.nil? && @comment_reply_delay_seconds < 0 true end |