Class: Zernio::UpdateCommentAutomationRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/update_comment_automation_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpdateCommentAutomationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateCommentAutomationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateCommentAutomationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'keywords')
    if (value = attributes[:'keywords']).is_a?(Array)
      self.keywords = value
    end
  end

  if attributes.key?(:'match_mode')
    self.match_mode = attributes[:'match_mode']
  end

  if attributes.key?(:'dm_message')
    self.dm_message = attributes[:'dm_message']
  end

  if attributes.key?(:'buttons')
    if (value = attributes[:'buttons']).is_a?(Array)
      self.buttons = value
    end
  end

  if attributes.key?(:'comment_reply')
    self.comment_reply = attributes[:'comment_reply']
  end

  if attributes.key?(:'dm_message_variations')
    if (value = attributes[:'dm_message_variations']).is_a?(Array)
      self.dm_message_variations = value
    end
  end

  if attributes.key?(:'comment_reply_variations')
    if (value = attributes[:'comment_reply_variations']).is_a?(Array)
      self.comment_reply_variations = value
    end
  end

  if attributes.key?(:'link_tracking')
    self.link_tracking = attributes[:'link_tracking']
  end

  if attributes.key?(:'click_tag')
    self.click_tag = attributes[:'click_tag']
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end
end

Instance Attribute Details

#buttonsObject

Inline DM buttons (1-3). Pass [] to clear all buttons.



27
28
29
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 27

def buttons
  @buttons
end

#click_tagObject

Tag applied to a contact when they click a tracked link (requires linkTracking). Empty string clears it.



41
42
43
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 41

def click_tag
  @click_tag
end

#comment_replyObject

Returns the value of attribute comment_reply.



29
30
31
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 29

def comment_reply
  @comment_reply
end

#comment_reply_variationsObject

Alternate public replies for random rotation. Pass [] to clear.



35
36
37
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 35

def comment_reply_variations
  @comment_reply_variations
end

#dm_messageObject

Returns the value of attribute dm_message.



24
25
26
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 24

def dm_message
  @dm_message
end

#dm_message_variationsObject

Alternate DM texts for random rotation (see create). Pass [] to clear.



32
33
34
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 32

def dm_message_variations
  @dm_message_variations
end

#is_activeObject

Returns the value of attribute is_active.



43
44
45
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 43

def is_active
  @is_active
end

#keywordsObject

Returns the value of attribute keywords.



20
21
22
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 20

def keywords
  @keywords
end

Wrap link buttons in a tracked redirect to count clicks. Pass false to send links untouched.



38
39
40
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 38

def link_tracking
  @link_tracking
end

#match_modeObject

Returns the value of attribute match_mode.



22
23
24
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 22

def match_mode
  @match_mode
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 18

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 68

def self.attribute_map
  {
    :'name' => :'name',
    :'keywords' => :'keywords',
    :'match_mode' => :'matchMode',
    :'dm_message' => :'dmMessage',
    :'buttons' => :'buttons',
    :'comment_reply' => :'commentReply',
    :'dm_message_variations' => :'dmMessageVariations',
    :'comment_reply_variations' => :'commentReplyVariations',
    :'link_tracking' => :'linkTracking',
    :'click_tag' => :'clickTag',
    :'is_active' => :'isActive'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 303

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 95

def self.openapi_types
  {
    :'name' => :'String',
    :'keywords' => :'Array<String>',
    :'match_mode' => :'String',
    :'dm_message' => :'String',
    :'buttons' => :'Array<DmButton>',
    :'comment_reply' => :'String',
    :'dm_message_variations' => :'Array<String>',
    :'comment_reply_variations' => :'Array<String>',
    :'link_tracking' => :'Boolean',
    :'click_tag' => :'String',
    :'is_active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 272

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      keywords == o.keywords &&
      match_mode == o.match_mode &&
      dm_message == o.dm_message &&
      buttons == o.buttons &&
      comment_reply == o.comment_reply &&
      dm_message_variations == o.dm_message_variations &&
      comment_reply_variations == o.comment_reply_variations &&
      link_tracking == o.link_tracking &&
      click_tag == o.click_tag &&
      is_active == o.is_active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


290
291
292
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 290

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



296
297
298
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 296

def hash
  [name, keywords, match_mode, dm_message, buttons, comment_reply, dm_message_variations, comment_reply_variations, link_tracking, click_tag, is_active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 188

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@buttons.nil? && @buttons.length > 3
    invalid_properties.push('invalid value for "buttons", number of items must be less than or equal to 3.')
  end

  if !@dm_message_variations.nil? && @dm_message_variations.length > 5
    invalid_properties.push('invalid value for "dm_message_variations", number of items must be less than or equal to 5.')
  end

  if !@comment_reply_variations.nil? && @comment_reply_variations.length > 5
    invalid_properties.push('invalid value for "comment_reply_variations", number of items must be less than or equal to 5.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



325
326
327
328
329
330
331
332
333
334
335
336
337
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 325

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
213
214
215
216
# File 'lib/zernio-sdk/models/update_comment_automation_request.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  match_mode_validator = EnumAttributeValidator.new('String', ["exact", "contains"])
  return false unless match_mode_validator.valid?(@match_mode)
  return false if !@buttons.nil? && @buttons.length > 3
  return false if !@dm_message_variations.nil? && @dm_message_variations.length > 5
  return false if !@comment_reply_variations.nil? && @comment_reply_variations.length > 5
  true
end