Class: Zernio::UpdateWebhookSettingsRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::UpdateWebhookSettingsRequest
- Defined in:
- lib/zernio-sdk/models/update_webhook_settings_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Webhook ID to update (required).
-
#custom_headers ⇒ Object
Custom headers to include in webhook requests.
-
#events ⇒ Object
Events to subscribe to.
-
#is_active ⇒ Object
Enable or disable webhook delivery.
-
#name ⇒ Object
Webhook name (1-50 characters).
-
#secret ⇒ Object
Secret key for HMAC-SHA256 signature verification.
-
#url ⇒ Object
Webhook endpoint URL (must be a valid URL, whitespace trimmed).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateWebhookSettingsRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateWebhookSettingsRequest
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::UpdateWebhookSettingsRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::UpdateWebhookSettingsRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'custom_headers') if (value = attributes[:'custom_headers']).is_a?(Hash) self.custom_headers = value end end end |
Instance Attribute Details
#_id ⇒ Object
Webhook ID to update (required)
19 20 21 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 19 def _id @_id end |
#custom_headers ⇒ Object
Custom headers to include in webhook requests
37 38 39 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 37 def custom_headers @custom_headers end |
#events ⇒ Object
Events to subscribe to. Must contain at least one event if provided.
31 32 33 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 31 def events @events end |
#is_active ⇒ Object
Enable or disable webhook delivery
34 35 36 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 34 def is_active @is_active end |
#name ⇒ Object
Webhook name (1-50 characters). Must be non-empty if provided.
22 23 24 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 22 def name @name end |
#secret ⇒ Object
Secret key for HMAC-SHA256 signature verification
28 29 30 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 28 def secret @secret end |
#url ⇒ Object
Webhook endpoint URL (must be a valid URL, whitespace trimmed). Must be a valid URL if provided.
25 26 27 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 25 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 62 def self.attribute_map { :'_id' => :'_id', :'name' => :'name', :'url' => :'url', :'secret' => :'secret', :'events' => :'events', :'is_active' => :'isActive', :'custom_headers' => :'customHeaders' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 85 def self.openapi_types { :'_id' => :'String', :'name' => :'String', :'url' => :'String', :'secret' => :'String', :'events' => :'Array<String>', :'is_active' => :'Boolean', :'custom_headers' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 219 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && name == o.name && url == o.url && secret == o.secret && events == o.events && is_active == o.is_active && custom_headers == o.custom_headers end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 239 def hash [_id, name, url, secret, events, is_active, custom_headers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if !@name.nil? && @name.to_s.length > 50 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@events.nil? && @events.length < 1 invalid_properties.push('invalid value for "events", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/update_webhook_settings_request.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if !@name.nil? && @name.to_s.length > 50 return false if !@name.nil? && @name.to_s.length < 1 return false if !@events.nil? && @events.length < 1 true end |