Class: Zernio::Webhook
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::Webhook
- Defined in:
- lib/zernio-sdk/models/webhook.rb
Overview
Individual webhook configuration for receiving real-time notifications
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_id ⇒ Object
Unique webhook identifier.
-
#custom_headers ⇒ Object
Custom headers included in webhook requests.
-
#events ⇒ Object
Events subscribed to.
-
#failure_count ⇒ Object
Consecutive delivery failures (resets on success, webhook disabled at 10).
-
#is_active ⇒ Object
Whether webhook delivery is enabled.
-
#last_fired_at ⇒ Object
Timestamp of last successful webhook delivery.
-
#name ⇒ Object
Webhook name (for identification).
-
#secret ⇒ Object
Secret key for HMAC-SHA256 signature verification.
-
#url ⇒ Object
Webhook endpoint URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Webhook
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Webhook
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/zernio-sdk/models/webhook.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::Webhook` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::Webhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'last_fired_at') self.last_fired_at = attributes[:'last_fired_at'] end if attributes.key?(:'failure_count') self.failure_count = attributes[:'failure_count'] end if attributes.key?(:'custom_headers') if (value = attributes[:'custom_headers']).is_a?(Hash) self.custom_headers = value end end end |
Instance Attribute Details
#_id ⇒ Object
Unique webhook identifier
20 21 22 |
# File 'lib/zernio-sdk/models/webhook.rb', line 20 def _id @_id end |
#custom_headers ⇒ Object
Custom headers included in webhook requests
44 45 46 |
# File 'lib/zernio-sdk/models/webhook.rb', line 44 def custom_headers @custom_headers end |
#events ⇒ Object
Events subscribed to
32 33 34 |
# File 'lib/zernio-sdk/models/webhook.rb', line 32 def events @events end |
#failure_count ⇒ Object
Consecutive delivery failures (resets on success, webhook disabled at 10)
41 42 43 |
# File 'lib/zernio-sdk/models/webhook.rb', line 41 def failure_count @failure_count end |
#is_active ⇒ Object
Whether webhook delivery is enabled
35 36 37 |
# File 'lib/zernio-sdk/models/webhook.rb', line 35 def is_active @is_active end |
#last_fired_at ⇒ Object
Timestamp of last successful webhook delivery
38 39 40 |
# File 'lib/zernio-sdk/models/webhook.rb', line 38 def last_fired_at @last_fired_at end |
#name ⇒ Object
Webhook name (for identification)
23 24 25 |
# File 'lib/zernio-sdk/models/webhook.rb', line 23 def name @name end |
#secret ⇒ Object
Secret key for HMAC-SHA256 signature verification.
29 30 31 |
# File 'lib/zernio-sdk/models/webhook.rb', line 29 def secret @secret end |
#url ⇒ Object
Webhook endpoint URL
26 27 28 |
# File 'lib/zernio-sdk/models/webhook.rb', line 26 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
84 85 86 |
# File 'lib/zernio-sdk/models/webhook.rb', line 84 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/zernio-sdk/models/webhook.rb', line 89 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/zernio-sdk/models/webhook.rb', line 69 def self.attribute_map { :'_id' => :'_id', :'name' => :'name', :'url' => :'url', :'secret' => :'secret', :'events' => :'events', :'is_active' => :'isActive', :'last_fired_at' => :'lastFiredAt', :'failure_count' => :'failureCount', :'custom_headers' => :'customHeaders' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/zernio-sdk/models/webhook.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/zernio-sdk/models/webhook.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/zernio-sdk/models/webhook.rb', line 94 def self.openapi_types { :'_id' => :'String', :'name' => :'String', :'url' => :'String', :'secret' => :'String', :'events' => :'Array<String>', :'is_active' => :'Boolean', :'last_fired_at' => :'Time', :'failure_count' => :'Integer', :'custom_headers' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/zernio-sdk/models/webhook.rb', line 207 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && name == o.name && url == o.url && secret == o.secret && events == o.events && is_active == o.is_active && last_fired_at == o.last_fired_at && failure_count == o.failure_count && custom_headers == o.custom_headers end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/zernio-sdk/models/webhook.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/zernio-sdk/models/webhook.rb', line 229 def hash [_id, name, url, secret, events, is_active, last_fired_at, failure_count, custom_headers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 |
# File 'lib/zernio-sdk/models/webhook.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 50 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 50.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/zernio-sdk/models/webhook.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 |
# File 'lib/zernio-sdk/models/webhook.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 50 true end |