Class: Zernio::WebhookPayloadAccountDisconnectedAccount
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadAccountDisconnectedAccount
- Defined in:
- lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
The account's unique identifier (same as used in /v1/accounts/accountId).
-
#disconnection_type ⇒ Object
Whether the disconnection was intentional (user action) or unintentional (token expired/revoked).
-
#display_name ⇒ Object
Returns the value of attribute display_name.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#profile_id ⇒ Object
The profile's unique identifier this account belongs to.
-
#reason ⇒ Object
Human-readable reason for the disconnection.
-
#username ⇒ Object
Returns the value of attribute username.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadAccountDisconnectedAccount
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadAccountDisconnectedAccount
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadAccountDisconnectedAccount` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadAccountDisconnectedAccount`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] else self.account_id = nil end if attributes.key?(:'profile_id') self.profile_id = attributes[:'profile_id'] else self.profile_id = nil end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'disconnection_type') self.disconnection_type = attributes[:'disconnection_type'] else self.disconnection_type = nil end if attributes.key?(:'reason') self.reason = attributes[:'reason'] else self.reason = nil end end |
Instance Attribute Details
#account_id ⇒ Object
The account's unique identifier (same as used in /v1/accounts/accountId)
19 20 21 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 19 def account_id @account_id end |
#disconnection_type ⇒ Object
Whether the disconnection was intentional (user action) or unintentional (token expired/revoked)
31 32 33 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 31 def disconnection_type @disconnection_type end |
#display_name ⇒ Object
Returns the value of attribute display_name.
28 29 30 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 28 def display_name @display_name end |
#platform ⇒ Object
Returns the value of attribute platform.
24 25 26 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 24 def platform @platform end |
#profile_id ⇒ Object
The profile's unique identifier this account belongs to
22 23 24 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 22 def profile_id @profile_id end |
#reason ⇒ Object
Human-readable reason for the disconnection
34 35 36 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 34 def reason @reason end |
#username ⇒ Object
Returns the value of attribute username.
26 27 28 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 26 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 59 def self.attribute_map { :'account_id' => :'accountId', :'profile_id' => :'profileId', :'platform' => :'platform', :'username' => :'username', :'display_name' => :'displayName', :'disconnection_type' => :'disconnectionType', :'reason' => :'reason' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 293 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 82 def self.openapi_types { :'account_id' => :'String', :'profile_id' => :'String', :'platform' => :'String', :'username' => :'String', :'display_name' => :'String', :'disconnection_type' => :'String', :'reason' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && profile_id == o.profile_id && platform == o.platform && username == o.username && display_name == o.display_name && disconnection_type == o.disconnection_type && reason == o.reason end |
#eql?(o) ⇒ Boolean
280 281 282 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 280 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
286 287 288 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 286 def hash [account_id, profile_id, platform, username, display_name, disconnection_type, reason].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @account_id.nil? invalid_properties.push('invalid value for "account_id", account_id cannot be nil.') end if @profile_id.nil? invalid_properties.push('invalid value for "profile_id", profile_id cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @disconnection_type.nil? invalid_properties.push('invalid value for "disconnection_type", disconnection_type cannot be nil.') end if @reason.nil? invalid_properties.push('invalid value for "reason", reason cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 315 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/zernio-sdk/models/webhook_payload_account_disconnected_account.rb', line 191 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @account_id.nil? return false if @profile_id.nil? return false if @platform.nil? return false if @username.nil? return false if @disconnection_type.nil? disconnection_type_validator = EnumAttributeValidator.new('String', ["intentional", "unintentional"]) return false unless disconnection_type_validator.valid?(@disconnection_type) return false if @reason.nil? true end |