Class: Zernio::WebhookPayloadCallEndedCall
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadCallEndedCall
- Defined in:
- lib/zernio-sdk/models/webhook_payload_call_ended_call.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#billing ⇒ Object
Returns the value of attribute billing.
-
#direction ⇒ Object
Returns the value of attribute direction.
-
#duration_seconds ⇒ Object
Returns the value of attribute duration_seconds.
-
#end_reason ⇒ Object
Returns the value of attribute end_reason.
-
#ended_at ⇒ Object
Returns the value of attribute ended_at.
-
#from ⇒ Object
Returns the value of attribute from.
-
#id ⇒ Object
Returns the value of attribute id.
-
#meta_call_id ⇒ Object
Returns the value of attribute meta_call_id.
-
#phone_number_id ⇒ Object
Returns the value of attribute phone_number_id.
-
#recording_expires_at ⇒ Object
Returns the value of attribute recording_expires_at.
-
#recording_url ⇒ Object
Returns the value of attribute recording_url.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#to ⇒ Object
Returns the value of attribute to.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadCallEndedCall
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadCallEndedCall
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadCallEndedCall` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadCallEndedCall`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'meta_call_id') self. = attributes[:'meta_call_id'] end if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'phone_number_id') self.phone_number_id = attributes[:'phone_number_id'] end if attributes.key?(:'direction') self.direction = attributes[:'direction'] end if attributes.key?(:'from') self.from = attributes[:'from'] end if attributes.key?(:'to') self.to = attributes[:'to'] end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'ended_at') self.ended_at = attributes[:'ended_at'] end if attributes.key?(:'duration_seconds') self.duration_seconds = attributes[:'duration_seconds'] end if attributes.key?(:'end_reason') self.end_reason = attributes[:'end_reason'] end if attributes.key?(:'recording_url') self.recording_url = attributes[:'recording_url'] end if attributes.key?(:'recording_expires_at') self.recording_expires_at = attributes[:'recording_expires_at'] end if attributes.key?(:'billing') self.billing = attributes[:'billing'] end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
22 23 24 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 22 def account_id @account_id end |
#billing ⇒ Object
Returns the value of attribute billing.
44 45 46 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 44 def billing @billing end |
#direction ⇒ Object
Returns the value of attribute direction.
26 27 28 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 26 def direction @direction end |
#duration_seconds ⇒ Object
Returns the value of attribute duration_seconds.
36 37 38 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 36 def duration_seconds @duration_seconds end |
#end_reason ⇒ Object
Returns the value of attribute end_reason.
38 39 40 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 38 def end_reason @end_reason end |
#ended_at ⇒ Object
Returns the value of attribute ended_at.
34 35 36 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 34 def ended_at @ended_at end |
#from ⇒ Object
Returns the value of attribute from.
28 29 30 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 28 def from @from end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 18 def id @id end |
#meta_call_id ⇒ Object
Returns the value of attribute meta_call_id.
20 21 22 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 20 def @meta_call_id end |
#phone_number_id ⇒ Object
Returns the value of attribute phone_number_id.
24 25 26 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 24 def phone_number_id @phone_number_id end |
#recording_expires_at ⇒ Object
Returns the value of attribute recording_expires_at.
42 43 44 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 42 def recording_expires_at @recording_expires_at end |
#recording_url ⇒ Object
Returns the value of attribute recording_url.
40 41 42 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 40 def recording_url @recording_url end |
#started_at ⇒ Object
Returns the value of attribute started_at.
32 33 34 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 32 def started_at @started_at end |
#to ⇒ Object
Returns the value of attribute to.
30 31 32 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 30 def to @to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 69 def self.attribute_map { :'id' => :'id', :'meta_call_id' => :'metaCallId', :'account_id' => :'accountId', :'phone_number_id' => :'phoneNumberId', :'direction' => :'direction', :'from' => :'from', :'to' => :'to', :'started_at' => :'startedAt', :'ended_at' => :'endedAt', :'duration_seconds' => :'durationSeconds', :'end_reason' => :'endReason', :'recording_url' => :'recordingUrl', :'recording_expires_at' => :'recordingExpiresAt', :'billing' => :'billing' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 273 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
119 120 121 122 123 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 119 def self.openapi_nullable Set.new([ :'meta_call_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 99 def self.openapi_types { :'id' => :'String', :'meta_call_id' => :'String', :'account_id' => :'String', :'phone_number_id' => :'String', :'direction' => :'String', :'from' => :'String', :'to' => :'String', :'started_at' => :'Time', :'ended_at' => :'Time', :'duration_seconds' => :'Integer', :'end_reason' => :'String', :'recording_url' => :'String', :'recording_expires_at' => :'Time', :'billing' => :'WebhookPayloadCallEndedCallBilling' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && == o. && account_id == o.account_id && phone_number_id == o.phone_number_id && direction == o.direction && from == o.from && to == o.to && started_at == o.started_at && ended_at == o.ended_at && duration_seconds == o.duration_seconds && end_reason == o.end_reason && recording_url == o.recording_url && recording_expires_at == o.recording_expires_at && billing == o.billing end |
#eql?(o) ⇒ Boolean
260 261 262 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 260 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
266 267 268 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 266 def hash [id, , account_id, phone_number_id, direction, from, to, started_at, ended_at, duration_seconds, end_reason, recording_url, recording_expires_at, billing].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
200 201 202 203 204 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 200 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 295 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 215 |
# File 'lib/zernio-sdk/models/webhook_payload_call_ended_call.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' direction_validator = EnumAttributeValidator.new('String', ["inbound", "outbound"]) return false unless direction_validator.valid?(@direction) end_reason_validator = EnumAttributeValidator.new('String', ["hangup", "no_answer", "rejected", "error"]) return false unless end_reason_validator.valid?(@end_reason) true end |