Class: Zernio::WebhookPayloadCommentComment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Zernio::WebhookPayloadCommentComment
- Defined in:
- lib/zernio-sdk/models/webhook_payload_comment_comment.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#ad ⇒ Object
Returns the value of attribute ad.
-
#attachment ⇒ Object
Returns the value of attribute attachment.
-
#author ⇒ Object
Returns the value of attribute author.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Platform comment ID.
-
#is_reply ⇒ Object
Whether this is a reply to another comment.
-
#parent_comment_id ⇒ Object
Parent comment ID if this is a reply.
-
#platform ⇒ Object
Returns the value of attribute platform.
-
#platform_post_id ⇒ Object
Platform's post ID.
-
#post_id ⇒ Object
Internal post ID (null for posts not published through Zernio).
-
#text ⇒ Object
Comment text content.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPayloadCommentComment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPayloadCommentComment
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadCommentComment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadCommentComment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'post_id') self.post_id = attributes[:'post_id'] else self.post_id = nil end if attributes.key?(:'platform_post_id') self.platform_post_id = attributes[:'platform_post_id'] else self.platform_post_id = nil end if attributes.key?(:'platform') self.platform = attributes[:'platform'] else self.platform = nil end if attributes.key?(:'text') self.text = attributes[:'text'] else self.text = nil end if attributes.key?(:'author') self. = attributes[:'author'] else self. = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'is_reply') self.is_reply = attributes[:'is_reply'] else self.is_reply = nil end if attributes.key?(:'parent_comment_id') self.parent_comment_id = attributes[:'parent_comment_id'] else self.parent_comment_id = nil end if attributes.key?(:'ad') self.ad = attributes[:'ad'] end if attributes.key?(:'attachment') self. = attributes[:'attachment'] end end |
Instance Attribute Details
#ad ⇒ Object
Returns the value of attribute ad.
42 43 44 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 42 def ad @ad end |
#attachment ⇒ Object
Returns the value of attribute attachment.
44 45 46 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 44 def @attachment end |
#author ⇒ Object
Returns the value of attribute author.
32 33 34 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 32 def @author end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 34 def created_at @created_at end |
#id ⇒ Object
Platform comment ID
19 20 21 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 19 def id @id end |
#is_reply ⇒ Object
Whether this is a reply to another comment
37 38 39 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 37 def is_reply @is_reply end |
#parent_comment_id ⇒ Object
Parent comment ID if this is a reply
40 41 42 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 40 def parent_comment_id @parent_comment_id end |
#platform ⇒ Object
Returns the value of attribute platform.
27 28 29 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 27 def platform @platform end |
#platform_post_id ⇒ Object
Platform's post ID
25 26 27 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 25 def platform_post_id @platform_post_id end |
#post_id ⇒ Object
Internal post ID (null for posts not published through Zernio)
22 23 24 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 22 def post_id @post_id end |
#text ⇒ Object
Comment text content
30 31 32 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 30 def text @text end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 69 def self.attribute_map { :'id' => :'id', :'post_id' => :'postId', :'platform_post_id' => :'platformPostId', :'platform' => :'platform', :'text' => :'text', :'author' => :'author', :'created_at' => :'createdAt', :'is_reply' => :'isReply', :'parent_comment_id' => :'parentCommentId', :'ad' => :'ad', :'attachment' => :'attachment' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 354 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 118 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 113 def self.openapi_nullable Set.new([ :'post_id', :'parent_comment_id', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 96 def self.openapi_types { :'id' => :'String', :'post_id' => :'String', :'platform_post_id' => :'String', :'platform' => :'String', :'text' => :'String', :'author' => :'WebhookPayloadCommentCommentAuthor', :'created_at' => :'Time', :'is_reply' => :'Boolean', :'parent_comment_id' => :'String', :'ad' => :'WebhookPayloadCommentCommentAd', :'attachment' => :'WebhookPayloadCommentCommentAttachment' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 323 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && post_id == o.post_id && platform_post_id == o.platform_post_id && platform == o.platform && text == o.text && == o. && created_at == o.created_at && is_reply == o.is_reply && parent_comment_id == o.parent_comment_id && ad == o.ad && == o. end |
#eql?(o) ⇒ Boolean
341 342 343 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 341 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
347 348 349 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 347 def hash [id, post_id, platform_post_id, platform, text, , created_at, is_reply, parent_comment_id, ad, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 201 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @platform_post_id.nil? invalid_properties.push('invalid value for "platform_post_id", platform_post_id cannot be nil.') end if @platform.nil? invalid_properties.push('invalid value for "platform", platform cannot be nil.') end if @text.nil? invalid_properties.push('invalid value for "text", text cannot be nil.') end if @author.nil? invalid_properties.push('invalid value for "author", author cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @is_reply.nil? invalid_properties.push('invalid value for "is_reply", is_reply cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
376 377 378 379 380 381 382 383 384 385 386 387 388 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 376 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/zernio-sdk/models/webhook_payload_comment_comment.rb', line 237 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @platform_post_id.nil? return false if @platform.nil? platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook", "twitter", "youtube", "linkedin", "bluesky", "reddit"]) return false unless platform_validator.valid?(@platform) return false if @text.nil? return false if @author.nil? return false if @created_at.nil? return false if @is_reply.nil? true end |