Class: Zernio::WebhookPayloadMessageDeliveryStatus

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb

Overview

Shared payload for message.delivered, message.read, and message.failed events. Fires when the platform reports a new delivery state for an outgoing message. Platform support: * message.delivered — WhatsApp, Facebook Messenger. * message.read — WhatsApp, Facebook Messenger, Instagram. * message.failed — WhatsApp only (other platforms don't expose per-message failure via webhook).

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadMessageDeliveryStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 104

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadMessageDeliveryStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadMessageDeliveryStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'status_at')
    self.status_at = attributes[:'status_at']
  else
    self.status_at = nil
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'conversation')
    self.conversation = attributes[:'conversation']
  else
    self.conversation = nil
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  else
    self. = nil
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



32
33
34
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 32

def 
  @account
end

#conversationObject

Returns the value of attribute conversation.



30
31
32
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 30

def conversation
  @conversation
end

#errorObject

Returns the value of attribute error.



28
29
30
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 28

def error
  @error
end

#eventObject

Returns the value of attribute event.



21
22
23
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 21

def event
  @event
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 19

def id
  @id
end

#messageObject

Returns the value of attribute message.



23
24
25
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 23

def message
  @message
end

#status_atObject

When the platform reported this status.



26
27
28
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 26

def status_at
  @status_at
end

#timestampObject

Returns the value of attribute timestamp.



34
35
36
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 34

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



73
74
75
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 73

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 78

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 59

def self.attribute_map
  {
    :'id' => :'id',
    :'event' => :'event',
    :'message' => :'message',
    :'status_at' => :'statusAt',
    :'error' => :'error',
    :'conversation' => :'conversation',
    :'account' => :'account',
    :'timestamp' => :'timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 317

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 97

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 83

def self.openapi_types
  {
    :'id' => :'String',
    :'event' => :'String',
    :'message' => :'InboxWebhookMessage',
    :'status_at' => :'Time',
    :'error' => :'WebhookPayloadMessageDeliveryStatusError',
    :'conversation' => :'InboxWebhookConversation',
    :'account' => :'InboxWebhookAccount',
    :'timestamp' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      event == o.event &&
      message == o.message &&
      status_at == o.status_at &&
      error == o.error &&
      conversation == o.conversation &&
       == o. &&
      timestamp == o.timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 304

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



310
311
312
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 310

def hash
  [id, event, message, status_at, error, conversation, , timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 167

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @status_at.nil?
    invalid_properties.push('invalid value for "status_at", status_at cannot be nil.')
  end

  if @conversation.nil?
    invalid_properties.push('invalid value for "conversation", conversation cannot be nil.')
  end

  if @account.nil?
    invalid_properties.push('invalid value for "account", account cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/zernio-sdk/models/webhook_payload_message_delivery_status.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @event.nil?
  event_validator = EnumAttributeValidator.new('String', ["message.delivered", "message.read", "message.failed"])
  return false unless event_validator.valid?(@event)
  return false if @message.nil?
  return false if @status_at.nil?
  return false if @conversation.nil?
  return false if @account.nil?
  return false if @timestamp.nil?
  true
end