Class: Zernio::WebhookPayloadMessageEdited

Inherits:
ApiModelBase show all
Defined in:
lib/zernio-sdk/models/webhook_payload_message_edited.rb

Overview

Webhook payload for message.edited events. Fires when the sender edits a previously-sent message. Supported platforms: Instagram, Facebook Messenger, Telegram. The message object reflects the LATEST state; editHistory contains every prior version in order (oldest first), so the last entry is the version immediately before the current content.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadMessageEdited

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadMessageEdited` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadMessageEdited`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  else
    self.event = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'edit_history')
    if (value = attributes[:'edit_history']).is_a?(Array)
      self.edit_history = value
    end
  else
    self.edit_history = nil
  end

  if attributes.key?(:'edit_count')
    self.edit_count = attributes[:'edit_count']
  else
    self.edit_count = nil
  end

  if attributes.key?(:'edited_at')
    self.edited_at = attributes[:'edited_at']
  else
    self.edited_at = nil
  end

  if attributes.key?(:'conversation')
    self.conversation = attributes[:'conversation']
  else
    self.conversation = nil
  end

  if attributes.key?(:'account')
    self. = attributes[:'account']
  else
    self. = nil
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  else
    self.timestamp = nil
  end
end

Instance Attribute Details

#accountObject

Returns the value of attribute account.



36
37
38
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 36

def 
  @account
end

#conversationObject

Returns the value of attribute conversation.



34
35
36
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 34

def conversation
  @conversation
end

#edit_countObject

Total number of edits applied to this message.



29
30
31
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 29

def edit_count
  @edit_count
end

#edit_historyObject

Prior versions of the message, oldest first.



26
27
28
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 26

def edit_history
  @edit_history
end

#edited_atObject

When the most recent edit happened.



32
33
34
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 32

def edited_at
  @edited_at
end

#eventObject

Returns the value of attribute event.



21
22
23
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 21

def event
  @event
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 19

def id
  @id
end

#messageObject

Returns the value of attribute message.



23
24
25
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 23

def message
  @message
end

#timestampObject

Returns the value of attribute timestamp.



38
39
40
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 38

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 63

def self.attribute_map
  {
    :'id' => :'id',
    :'event' => :'event',
    :'message' => :'message',
    :'edit_history' => :'editHistory',
    :'edit_count' => :'editCount',
    :'edited_at' => :'editedAt',
    :'conversation' => :'conversation',
    :'account' => :'account',
    :'timestamp' => :'timestamp'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 364

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 88

def self.openapi_types
  {
    :'id' => :'String',
    :'event' => :'String',
    :'message' => :'InboxWebhookMessage',
    :'edit_history' => :'Array<InboxMessageEditHistoryEntry>',
    :'edit_count' => :'Integer',
    :'edited_at' => :'Time',
    :'conversation' => :'InboxWebhookConversation',
    :'account' => :'InboxWebhookAccount',
    :'timestamp' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 335

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      event == o.event &&
      message == o.message &&
      edit_history == o.edit_history &&
      edit_count == o.edit_count &&
      edited_at == o.edited_at &&
      conversation == o.conversation &&
       == o. &&
      timestamp == o.timestamp
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


351
352
353
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 351

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



357
358
359
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 357

def hash
  [id, event, message, edit_history, edit_count, edited_at, conversation, , timestamp].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @event.nil?
    invalid_properties.push('invalid value for "event", event cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @edit_history.nil?
    invalid_properties.push('invalid value for "edit_history", edit_history cannot be nil.')
  end

  if @edit_count.nil?
    invalid_properties.push('invalid value for "edit_count", edit_count cannot be nil.')
  end

  if @edited_at.nil?
    invalid_properties.push('invalid value for "edited_at", edited_at cannot be nil.')
  end

  if @conversation.nil?
    invalid_properties.push('invalid value for "conversation", conversation cannot be nil.')
  end

  if @account.nil?
    invalid_properties.push('invalid value for "account", account cannot be nil.')
  end

  if @timestamp.nil?
    invalid_properties.push('invalid value for "timestamp", timestamp cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 386

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/zernio-sdk/models/webhook_payload_message_edited.rb', line 227

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @event.nil?
  event_validator = EnumAttributeValidator.new('String', ["message.edited"])
  return false unless event_validator.valid?(@event)
  return false if @message.nil?
  return false if @edit_history.nil?
  return false if @edit_count.nil?
  return false if @edited_at.nil?
  return false if @conversation.nil?
  return false if @account.nil?
  return false if @timestamp.nil?
  true
end