Class: Zernio::WebhookPayloadMessageSentMessage

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/zernio-sdk/models/webhook_payload_message_sent_message.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookPayloadMessageSentMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Zernio::WebhookPayloadMessageSentMessage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Zernio::WebhookPayloadMessageSentMessage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'conversation_id')
    self.conversation_id = attributes[:'conversation_id']
  else
    self.conversation_id = nil
  end

  if attributes.key?(:'platform')
    self.platform = attributes[:'platform']
  else
    self.platform = nil
  end

  if attributes.key?(:'platform_message_id')
    self.platform_message_id = attributes[:'platform_message_id']
  else
    self.platform_message_id = nil
  end

  if attributes.key?(:'direction')
    self.direction = attributes[:'direction']
  else
    self.direction = nil
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  else
    self.attachments = nil
  end

  if attributes.key?(:'sender')
    self.sender = attributes[:'sender']
  else
    self.sender = nil
  end

  if attributes.key?(:'sent_at')
    self.sent_at = attributes[:'sent_at']
  else
    self.sent_at = nil
  end

  if attributes.key?(:'is_read')
    self.is_read = attributes[:'is_read']
  else
    self.is_read = nil
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end
end

Instance Attribute Details

#attachmentsObject

Returns the value of attribute attachments.



34
35
36
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 34

def attachments
  @attachments
end

#conversation_idObject

Internal conversation ID



22
23
24
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 22

def conversation_id
  @conversation_id
end

#directionObject

Returns the value of attribute direction.



29
30
31
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 29

def direction
  @direction
end

#idObject

Internal message ID



19
20
21
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 19

def id
  @id
end

#is_readObject

Returns the value of attribute is_read.



40
41
42
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 40

def is_read
  @is_read
end

#platformObject

Returns the value of attribute platform.



24
25
26
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 24

def platform
  @platform
end

#platform_message_idObject

Platform's message ID



27
28
29
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 27

def platform_message_id
  @platform_message_id
end

#senderObject

Returns the value of attribute sender.



36
37
38
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 36

def sender
  @sender
end

#sent_atObject

Returns the value of attribute sent_at.



38
39
40
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 38

def sent_at
  @sent_at
end

#sourceObject

WhatsApp send origin. whatsapp_business_app when sent from the WhatsApp Business phone app on a Coexistence number; cloud_api when sent through Zernio (dashboard, API, or broadcasts). Absent on non-WhatsApp platforms. This is not the inbox metadata.source lineage field.



43
44
45
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 43

def source
  @source
end

#textObject

Message text content



32
33
34
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 32

def text
  @text
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



85
86
87
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 85

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



90
91
92
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 90

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 68

def self.attribute_map
  {
    :'id' => :'id',
    :'conversation_id' => :'conversationId',
    :'platform' => :'platform',
    :'platform_message_id' => :'platformMessageId',
    :'direction' => :'direction',
    :'text' => :'text',
    :'attachments' => :'attachments',
    :'sender' => :'sender',
    :'sent_at' => :'sentAt',
    :'is_read' => :'isRead',
    :'source' => :'source'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 400

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 112

def self.openapi_nullable
  Set.new([
    :'text',
  ])
end

.openapi_typesObject

Attribute type mapping.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 95

def self.openapi_types
  {
    :'id' => :'String',
    :'conversation_id' => :'String',
    :'platform' => :'String',
    :'platform_message_id' => :'String',
    :'direction' => :'String',
    :'text' => :'String',
    :'attachments' => :'Array<WebhookPayloadMessageSentMessageAttachmentsInner>',
    :'sender' => :'WebhookPayloadMessageSentMessageSender',
    :'sent_at' => :'Time',
    :'is_read' => :'Boolean',
    :'source' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 369

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      conversation_id == o.conversation_id &&
      platform == o.platform &&
      platform_message_id == o.platform_message_id &&
      direction == o.direction &&
      text == o.text &&
      attachments == o.attachments &&
      sender == o.sender &&
      sent_at == o.sent_at &&
      is_read == o.is_read &&
      source == o.source
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


387
388
389
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 387

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



393
394
395
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 393

def hash
  [id, conversation_id, platform, platform_message_id, direction, text, attachments, sender, sent_at, is_read, source].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 203

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @conversation_id.nil?
    invalid_properties.push('invalid value for "conversation_id", conversation_id cannot be nil.')
  end

  if @platform.nil?
    invalid_properties.push('invalid value for "platform", platform cannot be nil.')
  end

  if @platform_message_id.nil?
    invalid_properties.push('invalid value for "platform_message_id", platform_message_id cannot be nil.')
  end

  if @direction.nil?
    invalid_properties.push('invalid value for "direction", direction cannot be nil.')
  end

  if @attachments.nil?
    invalid_properties.push('invalid value for "attachments", attachments cannot be nil.')
  end

  if @sender.nil?
    invalid_properties.push('invalid value for "sender", sender cannot be nil.')
  end

  if @sent_at.nil?
    invalid_properties.push('invalid value for "sent_at", sent_at cannot be nil.')
  end

  if @is_read.nil?
    invalid_properties.push('invalid value for "is_read", is_read cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 422

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/zernio-sdk/models/webhook_payload_message_sent_message.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @conversation_id.nil?
  return false if @platform.nil?
  platform_validator = EnumAttributeValidator.new('String', ["instagram", "facebook", "telegram", "whatsapp"])
  return false unless platform_validator.valid?(@platform)
  return false if @platform_message_id.nil?
  return false if @direction.nil?
  direction_validator = EnumAttributeValidator.new('String', ["incoming", "outgoing"])
  return false unless direction_validator.valid?(@direction)
  return false if @attachments.nil?
  return false if @sender.nil?
  return false if @sent_at.nil?
  return false if @is_read.nil?
  source_validator = EnumAttributeValidator.new('String', ["whatsapp_business_app", "cloud_api"])
  return false unless source_validator.valid?(@source)
  true
end